package hanalife.a.cl.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.a.cl.service.ACLCLM05Service;
import hanalife.a.cl.vo.ACLCLM05DSSEARCH01VO;
import hanalife.a.cl.vo.ACLCLM05DSSEARCHVO;
import hanalife.a.cl.vo.ACLCLM05S01InVO;
import hanalife.a.cl.vo.ACLCLM05S01OutVO;
import hanalife.a.cl.vo.ACLCLM05S02InVO;
import hanalife.a.cl.vo.ACLCLM05S02OutVO;
import hanalife.a.cl.vo.ACLCLM05S03OutVo;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : ACLCLM05Controller.java Class
 * 클래스설명   : 자동전표현황조회 (ACLCLM05) Controller
 * 작성일자     : 2023. 05. 02.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@RequestMapping("/a/cl/cl")
@Controller
public class ACLCLM05Controller {
    private static final Logger LOGGER = LoggerFactory.getLogger(ACLCLM05Controller.class);

    @Autowired
    ACLCLM05Service ACLCLM05;

    /**
     * <pre>
     * 메소드명 : 자동전표내역조회 /ACLCLM05SO1.do
     * 작성일자 : 2023. 05. 03.
     * 작성자(author): 70366
     * 설명 : 자동전표내역조회 한다.
     * 예외처리 : Exception
     * </pre>
     */

    @RequestMapping("ACLCLM05SO1.do")
    public String ACLCLM05SO1 (HttpServletRequest request, HttpServletResponse response, ModelMap model) {

        LOGGER.info("##### ACLCLM05Controller ACLCLM05SO1.do START #####");
        try {
            /**XFrame5 UI에서 전달된 DataSet 정보를 Map 형태로 매핑*/
            Map<String,Object> requestMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

            ACLCLM05DSSEARCHVO dsSearchVo = new ACLCLM05DSSEARCHVO();

            dsSearchVo.setAcctDtFr((String)requestMap.get("acctDtFr"));                   /**회계_일자_시작일자*/
            dsSearchVo.setAcctDtTo((String)requestMap.get("acctDtTo"));              /**회계_일자_종료일자*/
            dsSearchVo.setOccrIamtFr((String)requestMap.get("occrIamtFr"));          /**발생_금액_시작*/
            dsSearchVo.setOccrIamtTo((String)requestMap.get("occrIamtTo"));          /**발생_금액_종료*/
            dsSearchVo.setLoanNo((String)requestMap.get("loanNo"));                   /**대출_번호 */
            dsSearchVo.setLoanSeq((String)requestMap.get("loanSeq"));                    /**대출_순서 */
            dsSearchVo.setFrstRegEmpNo((String)requestMap.get("frstRegEmpNo"));          /** 최초_등록_사원_번호*/
            dsSearchVo.setFrstRegEmpNm((String)requestMap.get("frstRegEmpNm"));          /** 최초_등록_사원_명*/
            dsSearchVo.setAcctDeptCd((String)requestMap.get("acctDeptCd"));          /**회계_부서_코드*/
            dsSearchVo.setAcctDeptNm((String)requestMap.get("acctDeptNm"));          /**회계_부서_명*/
            dsSearchVo.setTrTpCd((String)requestMap.get("trTpCd"));                      /** 이체_유형_코드*/
            dsSearchVo.setVochNo((String)requestMap.get("vochNo"));                   /** 전표_번호*/
            dsSearchVo.setAcctCd((String)requestMap.get("acctCd"));                  /** 계정_코드*/
            dsSearchVo.setAcctNm((String)requestMap.get("acctNm"));                   /** 계정_명*/
            dsSearchVo.setAcctUnitCd((String)requestMap.get("acctUnitCd"));          /**회계_단위_코드*/

            ACLCLM05S01InVO inVo = new ACLCLM05S01InVO();
            inVo.setaCLCLM05DSSEARCHVO(dsSearchVo);

            /**자동전표내역 조회 업무 서비스 호출 */
            ACLCLM05S01OutVO outVo =  ACLCLM05.getACLCLM05S01(inVo);

            /**자동전표내역 조회 DataSet 결과값 설정*/
            XFrame5Util.setOutputData("DS_SD_01", outVo.getListACLCLM05DSSD01VO(), model);

            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO1.do NORMAL END #####");
        }catch(Exception e) {
            LOGGER.info("#### Exception: "+ e.getMessage());

            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO1.do EXCEPTION END #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <pre>
     * 메소드명 : 자동전표내역조회된 아이템에 대하여 차번,대변 조회 /ACLCLM05SO2.do
     * 작성일자 : 2023. 05. 03.
     * 작성자(author): 70366
     * 설명 : 자동전표내역조회된 아이템에 대하여 차변, 대변을 조회 한다.
     * 예외처리 : Exception
     * </pre>
     */
    @RequestMapping("ACLCLM05SO2.do")
    public String ACLCLM05SO2(HttpServletRequest request ,HttpServletResponse response, ModelMap model) {
        LOGGER.info("##### ACLCLM05Controller ACLCLM05SO2.do START #####");


        try {
            /**XFrame5 UI에서 전달된 DataSet 정보를 Map 형태로 매핑*/
            Map<String, Object> requestMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH_01", request, response, model);

            ACLCLM05DSSEARCH01VO dsSearch01VO = new ACLCLM05DSSEARCH01VO();
            dsSearch01VO.setAcctDeptCd((String)requestMap.get("acctDeptCd"));
            dsSearch01VO.setAcctDt((String)requestMap.get("acctDt"));
            dsSearch01VO.setTrDescNo((String)requestMap.get("trDescNo"));
            dsSearch01VO.setTrSnum((String)requestMap.get("trSnum"));
            dsSearch01VO.setAcctUnitCd((String)requestMap.get("acctUnitCd"));

            ACLCLM05S02InVO inVo = new ACLCLM05S02InVO();
            inVo.setaCLCLM05DSSEARCH01VO(dsSearch01VO);

            ACLCLM05S02OutVO resultOutVo = ACLCLM05.getACLCLM05S02(inVo);

            XFrame5Util.setOutputData("DS_SD_DR", resultOutVo.getListACLCLM05DSSDDRVO(), model);
            XFrame5Util.setOutputData("DS_SD_CR", resultOutVo.getListACLCLM05DSSDCRVO(), model);

            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO2.do NORMAL END #####");
        }catch(Exception e) {
            LOGGER.info("#### Exception : "+e.getMessage());

            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL,e.getMessage());

            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO2.do EXCEPTION END #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <pre>
     * 메소드명 : 일반전표 내역 조회 /ACLCLM05SO3.do
     * 작성일자 : 2023. 05. 03.
     * 작성자(author): 70366
     * 설명 : Button_downloadList 한다.
     * 예외처리 : Exception
     * </pre>
     */
    @RequestMapping("ACLCLM05SO3.do")
    public String ACLCLM05SO3(HttpServletRequest request , HttpServletResponse response, ModelMap model) {
        LOGGER.info("##### ACLCLM05Controller ACLCLM05SO3.do START #####");

        try {
            /**XFrame5 UI에서 전달된 DataSet 정보를 Map 형태로 매핑*/
            Map<String, Object> requestMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model) ;

            ACLCLM05DSSEARCHVO dsSearchVo = new ACLCLM05DSSEARCHVO();

            dsSearchVo.setAcctDtFr((String)requestMap.get("acctDtFr"));
            dsSearchVo.setAcctDtTo((String)requestMap.get("acctDtTo"));
            dsSearchVo.setOccrIamtFr((String)requestMap.get("occrIamtFr"));
            dsSearchVo.setOccrIamtTo((String)requestMap.get("occrIamtTo"));
            dsSearchVo.setLoanNo((String)requestMap.get("loanNo"));
            dsSearchVo.setLoanSeq((String)requestMap.get("loanSeq"));
            dsSearchVo.setFrstRegEmpNo((String)requestMap.get("frstRegEmpNo"));
            dsSearchVo.setFrstRegEmpNm((String)requestMap.get("frstRegEmpNm"));
            dsSearchVo.setAcctDeptCd((String)requestMap.get("acctDeptCd"));
            dsSearchVo.setAcctDeptNm((String)requestMap.get("acctDeptNm"));
            dsSearchVo.setTrTpCd((String)requestMap.get("trTpCd"));
            dsSearchVo.setVochNo((String)requestMap.get("vochNo"));
            dsSearchVo.setAcctCd((String)requestMap.get("acctCd"));
            dsSearchVo.setAcctNm((String)requestMap.get("acctNm"));
            dsSearchVo.setAcctUnitCd((String)requestMap.get("acctUnitCd"));

            ACLCLM05S01InVO inVo = new ACLCLM05S01InVO();
            inVo.setaCLCLM05DSSEARCHVO(dsSearchVo);

            ACLCLM05S03OutVo resultOutVo = ACLCLM05.getACLCLM05S03(inVo);

            XFrame5Util.setOutputData("DS_SD_02", resultOutVo.getListACLCLM05DSSD02VO(), model);
            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO3.do NORMAL END #####");

        }catch(Exception e) {
            LOGGER.info("###  ERROR : "+e.getMessage());
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE,"-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL,e.getMessage());

            LOGGER.info("##### ACLCLM05Controller ACLCLM05SO3.do EXCEPTION END #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
