package hanalife.b.bm.gm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.bm.gm.mapper.BndByDivsManAsgnMngMapper;
import hanalife.b.bm.gm.mapper.dto.BndByDivsManAsgnMngDSSDDO01DTO;
import hanalife.b.bm.gm.mapper.dto.BndByDivsManAsgnMngDSSMDO01DTO;
import hanalife.b.bm.gm.service.BBMGMM01Service;
import hanalife.b.bm.gm.vo.BBMGMM01DSSDDO01VO;
import hanalife.b.bm.gm.vo.BBMGMM01S01InVO;
import hanalife.b.bm.gm.vo.BBMGMM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BBMGMM01ServiceImpl.java Class
 * 클래스설명   : BBMGMM01ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 20.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 20.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBBMGMM01S01 : 배정대상조회
 * </pre>
 */
@Service("BBMGMM01Service")
public class BBMGMM01ServiceImpl implements BBMGMM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BBMGMM01ServiceImpl.class);

    @Autowired
    private BndByDivsManAsgnMngMapper bndByDivsManAsgnMngMapper;

    /**
     *<pre>
     * 메소드명      : getBDLDLM03S01 : 배정대상 조회 ( 정상채권, 대손채권 )
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 배정대상을 조회 한다.
     * 메소드인수    : BBMGMM01S01InVO
     * 메소드리턴값  : BBMGMM01S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BBMGMM01S01OutVO getBBMGMM01S01(BBMGMM01S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceImpl} getBBMGMM01S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BBMGMM01S01OutVO                resultVo                        = new BBMGMM01S01OutVO();
        BndByDivsManAsgnMngDSSMDO01DTO  bndByDivsManAsgnMngDSSMDO01Dto  = new BndByDivsManAsgnMngDSSMDO01DTO();
        List<BBMGMM01DSSDDO01VO>        listVo                          = new ArrayList<BBMGMM01DSSDDO01VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        bndByDivsManAsgnMngDSSMDO01Dto.setDeptCd         (inVo.getBBMGMM01DSSMDO01VO().getDeptCd ()); // 부서_코드
        bndByDivsManAsgnMngDSSMDO01Dto.setProdLrgeClasCd (inVo.getBBMGMM01DSSMDO01VO().getProdLrgeClasCd ()); // 상품_대분류_코드
        bndByDivsManAsgnMngDSSMDO01Dto.setProdMidClasCd  (inVo.getBBMGMM01DSSMDO01VO().getProdMidClasCd  ()); // 상품_중분류_코드
        bndByDivsManAsgnMngDSSMDO01Dto.setBndDivsEmpNo   (inVo.getBBMGMM01DSSMDO01VO().getBndDivsEmpNo   ());
        bndByDivsManAsgnMngDSSMDO01Dto.setComgTimsSt     (inVo.getBBMGMM01DSSMDO01VO().getComgTimsSt     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setComgTimsEd     (inVo.getBBMGMM01DSSMDO01VO().getComgTimsEd     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setDlyTimsSt      (inVo.getBBMGMM01DSSMDO01VO().getDlyTimsSt      ());
        bndByDivsManAsgnMngDSSMDO01Dto.setDlyTimsEd      (inVo.getBBMGMM01DSSMDO01VO().getDlyTimsEd      ());
        bndByDivsManAsgnMngDSSMDO01Dto.setEprtDtSt       (inVo.getBBMGMM01DSSMDO01VO().getEprtDtSt       ());
        bndByDivsManAsgnMngDSSMDO01Dto.setEprtDtEd       (inVo.getBBMGMM01DSSMDO01VO().getEprtDtEd       ());
        bndByDivsManAsgnMngDSSMDO01Dto.setCrdtStatCd     (inVo.getBBMGMM01DSSMDO01VO().getCrdtStatCd     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLeglActnFg     (inVo.getBBMGMM01DSSMDO01VO().getLeglActnFg     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setAsgnStat       (inVo.getBBMGMM01DSSMDO01VO().getAsgnStat       ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLoanNo         (inVo.getBBMGMM01DSSMDO01VO().getLoanNo         ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLoanSeq        (inVo.getBBMGMM01DSSMDO01VO().getLoanSeq        ());
        bndByDivsManAsgnMngDSSMDO01Dto.setPreDlyTimsSt   (inVo.getBBMGMM01DSSMDO01VO().getPreDlyTimsSt   ());
        bndByDivsManAsgnMngDSSMDO01Dto.setPreDlyTimsEd   (inVo.getBBMGMM01DSSMDO01VO().getPreDlyTimsEd   ());
        bndByDivsManAsgnMngDSSMDO01Dto.setTranTimsSt     (inVo.getBBMGMM01DSSMDO01VO().getTranTimsSt     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setTranTimsEd     (inVo.getBBMGMM01DSSMDO01VO().getTranTimsEd     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setPrdtSmClasCd   (inVo.getBBMGMM01DSSMDO01VO().getPrdtSmClasCd   ()); // 상품_소분류_코드
        bndByDivsManAsgnMngDSSMDO01Dto.setLoanRegStat    (inVo.getBBMGMM01DSSMDO01VO().getLoanRegStat    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setBadDebtStat    (inVo.getBBMGMM01DSSMDO01VO().getBadDebtStat    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setBndMngPlcCd    (inVo.getBBMGMM01DSSMDO01VO().getBndMngPlcCd    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setSetlDtFr       (inVo.getBBMGMM01DSSMDO01VO().getSetlDtFr       ());
        bndByDivsManAsgnMngDSSMDO01Dto.setSetlDtTo       (inVo.getBBMGMM01DSSMDO01VO().getSetlDtTo       ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLnDivsEmpNo    (inVo.getBBMGMM01DSSMDO01VO().getLnDivsEmpNo    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setGodCd          (inVo.getBBMGMM01DSSMDO01VO().getGodCd          ());
        bndByDivsManAsgnMngDSSMDO01Dto.setBfmmMngPlcDivCd(inVo.getBBMGMM01DSSMDO01VO().getBfmmMngPlcDivCd());
        bndByDivsManAsgnMngDSSMDO01Dto.setDlyDdCntFr     (inVo.getBBMGMM01DSSMDO01VO().getDlyDdCntFr     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setDlyDdCntTo     (inVo.getBBMGMM01DSSMDO01VO().getDlyDdCntTo     ());
        bndByDivsManAsgnMngDSSMDO01Dto.setArea           (inVo.getBBMGMM01DSSMDO01VO().getArea           ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLoanPamtRamtFr (inVo.getBBMGMM01DSSMDO01VO().getLoanPamtRamtFr ());
        bndByDivsManAsgnMngDSSMDO01Dto.setLoanPamtRamtTo (inVo.getBBMGMM01DSSMDO01VO().getLoanPamtRamtTo ());
        bndByDivsManAsgnMngDSSMDO01Dto.setTotDlyAmtFr    (inVo.getBBMGMM01DSSMDO01VO().getTotDlyAmtFr    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setTotDlyAmtTo    (inVo.getBBMGMM01DSSMDO01VO().getTotDlyAmtTo    ());
        bndByDivsManAsgnMngDSSMDO01Dto.setBndStat        (inVo.getBBMGMM01DSSMDO01VO().getBndStat        ());
        bndByDivsManAsgnMngDSSMDO01Dto.setDebtAdju       (inVo.getBBMGMM01DSSMDO01VO().getDebtAdju       ());


        /**************************************************
         * ■ Call 배정대상 조회
         **************************************************/
        List<BndByDivsManAsgnMngDSSDDO01DTO> resultDto = this._search1(bndByDivsManAsgnMngDSSMDO01Dto);


        /**************************************************
         * □ 배정대상 리스트 LOOP처리
         **************************************************/
        for(BndByDivsManAsgnMngDSSDDO01DTO bndDivsIO : resultDto) {
            BBMGMM01DSSDDO01VO bbmgmM01DSSDDO01Vo = new BBMGMM01DSSDDO01VO();

            bbmgmM01DSSDDO01Vo.setChkFlg            (bndDivsIO.getChkFlg           () );  //
            bbmgmM01DSSDDO01Vo.setBndDivsEmpNm      (bndDivsIO.getBndDivsEmpNm     () );  //
            bbmgmM01DSSDDO01Vo.setBndDivsEmpNo      (bndDivsIO.getBndDivsEmpNo     () );  //
            bbmgmM01DSSDDO01Vo.setLoanNo            (bndDivsIO.getLoanNo           () );  // 대출_번호
            bbmgmM01DSSDDO01Vo.setLoanSeq           (bndDivsIO.getLoanSeq          () );  // 대출_순번
            bbmgmM01DSSDDO01Vo.setContManNm         (bndDivsIO.getContManNm        () );  //
            bbmgmM01DSSDDO01Vo.setPrdtNm            (bndDivsIO.getPrdtNm           () );  // 상품_명
            bbmgmM01DSSDDO01Vo.setPrdtSmClasNm      (bndDivsIO.getPrdtSmClasNm     () );  // 상품_소분류_명
            bbmgmM01DSSDDO01Vo.setBadSt             (bndDivsIO.getBadSt            () );  //
            bbmgmM01DSSDDO01Vo.setBadCnt            (bndDivsIO.getBadCnt           () );  //
            bbmgmM01DSSDDO01Vo.setBadAmt            (bndDivsIO.getBadAmt           () );  //
            bbmgmM01DSSDDO01Vo.setLeglActsDt        (bndDivsIO.getLeglActsDt       () );  //
            bbmgmM01DSSDDO01Vo.setLeglActsCnt       (bndDivsIO.getLeglActsCnt      () );  //
            bbmgmM01DSSDDO01Vo.setPmDlyTcnt         (bndDivsIO.getPmDlyTcnt        () );  //
            bbmgmM01DSSDDO01Vo.setDlyTcnt           (bndDivsIO.getDlyTcnt          () );  //
            bbmgmM01DSSDDO01Vo.setPmDlyAmt          (bndDivsIO.getPmDlyAmt         () );  //
            bbmgmM01DSSDDO01Vo.setDlyAmt            (bndDivsIO.getDlyAmt           () );  //
            bbmgmM01DSSDDO01Vo.setPmLoanAmt         (bndDivsIO.getPmLoanAmt        () );  //
            bbmgmM01DSSDDO01Vo.setLoanAmt           (bndDivsIO.getLoanAmt          () );  // 대출_금액
            bbmgmM01DSSDDO01Vo.setMngDeptNm         (bndDivsIO.getMngDeptNm        () );  //
            bbmgmM01DSSDDO01Vo.setLoanStatNm        (bndDivsIO.getLoanStatNm       () );  // 대출_상태_명
            bbmgmM01DSSDDO01Vo.setThmmComgTims      (bndDivsIO.getThmmComgTims     () );  //
            bbmgmM01DSSDDO01Vo.setBadDebtDeprDt     (bndDivsIO.getBadDebtDeprDt    () );  //
            bbmgmM01DSSDDO01Vo.setBadDebtRcptStatNm (bndDivsIO.getBadDebtRcptStatNm() );  //
            bbmgmM01DSSDDO01Vo.setSetlDt            (bndDivsIO.getSetlDt           () );  //
            bbmgmM01DSSDDO01Vo.setWdrwTpNm          (bndDivsIO.getWdrwTpNm         () );  //
            bbmgmM01DSSDDO01Vo.setCustAddr          (bndDivsIO.getCustAddr         () );  // 고객_주소
            bbmgmM01DSSDDO01Vo.setDocKeepPlcNo      (bndDivsIO.getDocKeepPlcNo     () );  //
            bbmgmM01DSSDDO01Vo.setCprtComNo         (bndDivsIO.getCprtComNo        () );  //
            bbmgmM01DSSDDO01Vo.setCprtBranCd        (bndDivsIO.getCprtBranCd       () );  //
            bbmgmM01DSSDDO01Vo.setLnDivsEmpNm       (bndDivsIO.getLnDivsEmpNm      () );  //
            bbmgmM01DSSDDO01Vo.setCprtEmpNm         (bndDivsIO.getCprtEmpNm        () );  //
            bbmgmM01DSSDDO01Vo.setSetlDd            (bndDivsIO.getSetlDd           () );  //
            bbmgmM01DSSDDO01Vo.setMngPlcDivNm       (bndDivsIO.getMngPlcDivNm      () );  //
            bbmgmM01DSSDDO01Vo.setReptCd            (bndDivsIO.getReptCd           () );  //
            bbmgmM01DSSDDO01Vo.setBfmmMngPlcDivNm   (bndDivsIO.getBfmmMngPlcDivNm  () );  //
            bbmgmM01DSSDDO01Vo.setLoanPamtRamt      (bndDivsIO.getLoanPamtRamt     () );  // 대출_원금_잔액
            bbmgmM01DSSDDO01Vo.setBndStatCd         (bndDivsIO.getBndStatCd        () );  // 채권_상태_코드
            bbmgmM01DSSDDO01Vo.setBndStatNm         (bndDivsIO.getBndStatNm        () );  // 채권_상태_명
            bbmgmM01DSSDDO01Vo.setTotDlyAmt         (bndDivsIO.getTotDlyAmt        () );  //
            bbmgmM01DSSDDO01Vo.setExecDt            (bndDivsIO.getExecDt           () );  // 실행_일자
            bbmgmM01DSSDDO01Vo.setDlyDdcnt          (bndDivsIO.getDlyDdcnt         () );  //
            bbmgmM01DSSDDO01Vo.setClasNm            (bndDivsIO.getClasNm           () );  //
            bbmgmM01DSSDDO01Vo.setBndRamt           (bndDivsIO.getBndRamt          () );  //
            bbmgmM01DSSDDO01Vo.setLoanTerm          (bndDivsIO.getLoanTerm         () );  // 대출_기간
            bbmgmM01DSSDDO01Vo.setLoanDt            (bndDivsIO.getLoanDt           () );  // 대출_일자
            bbmgmM01DSSDDO01Vo.setEprtDt            (bndDivsIO.getEprtDt           () );  // 만기_일자
            bbmgmM01DSSDDO01Vo.setCustNo            (bndDivsIO.getCustNo           () );  // 고객_번호
            bbmgmM01DSSDDO01Vo.setRcvrRvvlDivNm     (bndDivsIO.getRcvrRvvlDivNm    () );  //
            bbmgmM01DSSDDO01Vo.setLrgeClasNm        (bndDivsIO.getLrgeClasNm       () );  //
            bbmgmM01DSSDDO01Vo.setDlyPamt           (bndDivsIO.getDlyPamt          () );  // 연체_원금
            bbmgmM01DSSDDO01Vo.setDlyInt            (bndDivsIO.getDlyInt           () );  // 연체_이자
            bbmgmM01DSSDDO01Vo.setDfee              (bndDivsIO.getDfee             () );  // 연체_료
            bbmgmM01DSSDDO01Vo.setLeglActnCostRamt  (bndDivsIO.getLeglActnCostRamt () );  //
            bbmgmM01DSSDDO01Vo.setUnrcvRamt         (bndDivsIO.getUnrcvRamt        () );  //

            listVo.add(bbmgmM01DSSDDO01Vo);

        }

        resultVo.setBBMGMM01DSSDDO01VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : _searchPrdtList
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 상품별 목록을 조회 한다.
     * 메소드인수    : DlyTimsReptReadDSSMDODTO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    private List<BndByDivsManAsgnMngDSSDDO01DTO> _search1(BndByDivsManAsgnMngDSSMDO01DTO dto) throws Exception {

        /**************************************************
         * □ 초기선언
         **************************************************/
        List<BndByDivsManAsgnMngDSSDDO01DTO> resultDto  = new ArrayList<BndByDivsManAsgnMngDSSDDO01DTO>();


        /**************************************************
         * ■ Call 채권배정 조회
         **************************************************/
        if ("0".equals(dto.getBadDebtStat())) {
            // 정상채권
            resultDto = bndByDivsManAsgnMngMapper.btBndByDivsManAsgnMngSearch2(dto);
        } else {
            // 대손채권
            resultDto = bndByDivsManAsgnMngMapper.btBndByDivsManAsgnMngSearch4(dto);
        }

        return resultDto;

    }

}
