package hanalife.b.bm.gm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.bm.gm.service.BBMGMM01Service;
import hanalife.b.bm.gm.vo.BBMGMM01DSSMDO01VO;
import hanalife.b.bm.gm.vo.BBMGMM01S01InVO;
import hanalife.b.bm.gm.vo.BBMGMM01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BBMGMM01Controller.java Class
 * 클래스설명   : BBMGMM01Controller Controller
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/bm/gm")
@Controller
public class BBMGMM01Controller {

    @Resource(name="BBMGMM01Service")
    private BBMGMM01Service BBMGMM01Service;

    private static final Logger LOGGER = LoggerFactory.getLogger(BBMGMM01Controller.class);

    /**
     *<pre>
     * 메소드명      : 배정대상 조회 / BBMGMM01S01.do
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331
     * 설명          : 배정대상 목록을 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BBMGMM01S01.do")
    public String BBMGMM01S01(ModelMap model,HttpServletRequest request, HttpServletResponse response) {

        LOGGER.info("{PSY-controller} BBMGMM01S01 Start..");

        try {
            /**************************************************
             * □ 초기선언
             **************************************************/
            BBMGMM01DSSMDO01VO dsSMDOInVo       = new BBMGMM01DSSMDO01VO();
            BBMGMM01S01InVO    bbmgmM01S01InVo  = new BBMGMM01S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceDsSMDOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            dsSMDOInVo.setDeptCd         ((String)sourceDsSMDOMap.get("deptCd"          )); // 부서_코드
            dsSMDOInVo.setProdLrgeClasCd ((String)sourceDsSMDOMap.get("prodLrgeClasCd"  )); // 상품_대분류_코드
            dsSMDOInVo.setProdMidClasCd  ((String)sourceDsSMDOMap.get("prodMidClasCd"   )); // 상품_중분류_코드
            dsSMDOInVo.setBndDivsEmpNo   ((String)sourceDsSMDOMap.get("bndDivsEmpNo"    ));
            dsSMDOInVo.setComgTimsSt     ((String)sourceDsSMDOMap.get("comgTimsSt"      ));
            dsSMDOInVo.setComgTimsEd     ((String)sourceDsSMDOMap.get("comgTimsEd"      ));
            dsSMDOInVo.setDlyTimsSt      ((String)sourceDsSMDOMap.get("dlyTimsSt"       ));
            dsSMDOInVo.setDlyTimsEd      ((String)sourceDsSMDOMap.get("dlyTimsEd"       ));
            dsSMDOInVo.setEprtDtSt       ((String)sourceDsSMDOMap.get("eprtDtSt"        ));
            dsSMDOInVo.setEprtDtEd       ((String)sourceDsSMDOMap.get("eprtDtEd"        ));
            dsSMDOInVo.setCrdtStatCd     ((String)sourceDsSMDOMap.get("crdtStatCd"      ));
            dsSMDOInVo.setLeglActnFg     ((String)sourceDsSMDOMap.get("leglActnFg"      ));
            dsSMDOInVo.setAsgnStat       ((String)sourceDsSMDOMap.get("asgnStat"        ));
            dsSMDOInVo.setLoanNo         ((String)sourceDsSMDOMap.get("loanNo"          ));
            dsSMDOInVo.setLoanSeq        ((String)sourceDsSMDOMap.get("loanSeq"         ));
            dsSMDOInVo.setPreDlyTimsSt   ((String)sourceDsSMDOMap.get("preDlyTimsSt"    ));
            dsSMDOInVo.setPreDlyTimsEd   ((String)sourceDsSMDOMap.get("preDlyTimsEd"    ));
            dsSMDOInVo.setTranTimsSt     ((String)sourceDsSMDOMap.get("tranTimsSt"      ));
            dsSMDOInVo.setTranTimsEd     ((String)sourceDsSMDOMap.get("tranTimsEd"      ));
            dsSMDOInVo.setPrdtSmClasCd   ((String)sourceDsSMDOMap.get("prdtSmClasCd"    )); // 상품_소분류_코드
            dsSMDOInVo.setLoanRegStat    ((String)sourceDsSMDOMap.get("loanRegStat"     ));
            dsSMDOInVo.setBadDebtStat    ((String)sourceDsSMDOMap.get("badDebtStat"     ));
            dsSMDOInVo.setBndMngPlcCd    ((String)sourceDsSMDOMap.get("bndMngPlcCd"     ));
            dsSMDOInVo.setSetlDtFr       ((String)sourceDsSMDOMap.get("setlDtFr"        ));
            dsSMDOInVo.setSetlDtTo       ((String)sourceDsSMDOMap.get("setlDtTo"        ));
            dsSMDOInVo.setLnDivsEmpNo    ((String)sourceDsSMDOMap.get("lnDivsEmpNo"     ));
            dsSMDOInVo.setGodCd          ((String)sourceDsSMDOMap.get("godCd"           ));
            dsSMDOInVo.setBfmmMngPlcDivCd((String)sourceDsSMDOMap.get("bfmmMngPlcDivCd" ));
            dsSMDOInVo.setDlyDdCntFr     ((String)sourceDsSMDOMap.get("dlyDdCntFr"      ));
            dsSMDOInVo.setDlyDdCntTo     ((String)sourceDsSMDOMap.get("dlyDdCntTo"      ));
            dsSMDOInVo.setArea           ((String)sourceDsSMDOMap.get("area"            ));
            dsSMDOInVo.setLoanPamtRamtFr ((String)sourceDsSMDOMap.get("loanPamtRamtFr"  ));
            dsSMDOInVo.setLoanPamtRamtTo ((String)sourceDsSMDOMap.get("loanPamtRamtTo"  ));
            dsSMDOInVo.setTotDlyAmtFr    ((String)sourceDsSMDOMap.get("totDlyAmtFr"     ));
            dsSMDOInVo.setTotDlyAmtTo    ((String)sourceDsSMDOMap.get("totDlyAmtTo"     ));
            dsSMDOInVo.setBndStat        ((String)sourceDsSMDOMap.get("bndStat"         ));
            dsSMDOInVo.setDebtAdju       ((String)sourceDsSMDOMap.get("debtAdju"        ));


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bbmgmM01S01InVo.setBBMGMM01DSSMDO01VO(dsSMDOInVo);


            /**************************************************
             * ■ Call 배정대상 조회
             **************************************************/
            BBMGMM01S01OutVO resultListVo = BBMGMM01Service.getBBMGMM01S01(bbmgmM01S01InVo);


            /**************************************************
             * 결과값 화면으로 리턴처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO01", resultListVo.getBBMGMM01DSSDDO01VOList(), model);

        }
        catch (Exception e) {
            LOGGER.error("Error >>> "+e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
        }

        return XFrame5View.XFRAME5_VIEW;

    }

}
