package hanalife.b.cl.dl.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cl.dl.mapper.OnlnDlyReptMapper;
import hanalife.b.cl.dl.mapper.dto.OnlnDlyReptBndDTO;
import hanalife.b.cl.dl.mapper.dto.OnlnDlyReptComnDTO;
import hanalife.b.cl.dl.mapper.dto.OnlnDlyReptResultDTO;
import hanalife.b.cl.dl.service.OnlnDlyReptService;
import hanalife.b.cl.dl.vo.OnlnDlyReptInVO;
import hanalife.b.cl.dl.vo.OnlnDlyReptOutVO;
import hanalife.b.cl.dl.vo.tmp.AskUnrcvObjVO;
import hanalife.b.cl.dl.vo.tmp.AskUnrcvVO;
import hanalife.b.cl.dl.vo.tmp.BndVO;
import hanalife.c.co.iEnum.MsgEnum;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : OnlnDlyReptService.java Class
 * 클래스설명   : 실시간연체정보 생성 (OnlnDlyReptCC)  Service Implements
 * 작성일자     : 2023. 3. 14.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 14.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : ProcRealTmpDlyInfo 실시간연체정보 생성
 * </pre>
 */
@Service("OnlnDlyReptService")
public class OnlnDlyReptServiceImpl implements OnlnDlyReptService {

	private static final Logger LOGGER = LoggerFactory.getLogger(OnlnDlyReptServiceImpl.class);

	@Autowired
	private OnlnDlyReptMapper mapper;

	/**
	 * <p>메소드명      : ProcRealTmpDlyInfo : 연체정보 생성</p>
	 * <p>작성일자      : 2023. 3. 14.
	 * <p>작성자(author): 70320 / jaeho.jang
	 * <p>설명          : 실시간연체정보를 생성한다.</p>
	 * <p>메소드인수    : OnlnDlyReptInVO </p>
	 * <p>메소드리턴값  : OnlnDlyReptOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public OnlnDlyReptOutVO ProcRealTmpDlyInfo(OnlnDlyReptInVO inVo) throws Exception {
		OnlnDlyReptOutVO result = new OnlnDlyReptOutVO();
		result.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
		result.setRsltCntn(MsgEnum.SUCCESS.getDescription());

		String procUser = "Batch" ;
		String proc_id = "0" ;
		String LoanNo = inVo.getLoanNo();
		String LoanSeq = inVo.getLoanSeq();
		boolean isLog = inVo.getIsLog();
		OnlnDlyReptComnDTO comnDto = new OnlnDlyReptComnDTO();
		comnDto.setLoanNo(LoanNo);
		comnDto.setLoanSeq(LoanSeq);

		List<OnlnDlyReptResultDTO> rs = null;
		try {
			if((LoanNo != null && LoanNo.length() == 11) && (LoanSeq != null && LoanSeq.length() == 2)) {

				if(LoanNo.substring(0,8).equals("PARALLEL")) {
					procUser = "Batch_P" ;
					// proc_id = Integer.parseInt(LoanSeq) ;
					proc_id = String.valueOf(Integer.parseInt(LoanSeq)) ;
				} else {
					procUser = "OnLine" ;
				}

			}
		} catch (Exception e) {
			//result = false ;
			result.setRsltCd(MsgEnum.DLY_CREATE_ERROR.getErrorCd());
			result.setRsltCntn(MsgEnum.DLY_CREATE_ERROR.getDescription());
		}

		LOGGER.debug("Processing by : "+procUser+" : "+proc_id);

		try {

			// 현재일 이전 데이타 삭제
			mapper.sqlDelTmpOnlnDlyInfo(comnDto);

			if(procUser.equals("Batch")) { // Batch 로 실행시
				// 당일 신규건 Insert
				mapper.sqlInsTmpOnlnDlyInfo(comnDto);

				// 해지건 대상에서 제외
				mapper.sqlDelTmpOnlnDlyInfo2(comnDto);

				mapper.sqlDelTmpAfddDlyInfo2(comnDto);

				//채권마감기본 당일 - 해지건 반영
				mapper.sqlUpdBndClsBaseToday3(comnDto);

				// 당일 변경건 Update
				mapper.sqlUpTmpOnlnDlyInfo(comnDto);

				rs = mapper.sqlSelTmpOnlnDlyInfo(comnDto);

			} else if(procUser.equals("OnLine")) { // OnLine(대출건건) 실행시
				// 기존건 있으면 삭제
				mapper.sqlDelTmpOnlnDlyInfo1(comnDto);

				// Insert
				mapper.sqlInsTmpOnlnDlyInfo1(comnDto);

				rs = mapper.sqlSelTmpOnlnDlyInfo1(comnDto);
			} else if(procUser.equals("Batch_P")) { // Batch(Parallel) 로 실행시
				//String seq = "" ;
	            String loanNo_FR  = "" ;
	            String loanNo_TO  = "" ;
	            String str_Work_Loan_Info = "" ;

				// prodcess 별 처리 대상건 조회(FROM - TO)
	            //str_Work_Loan_Info = sql_Sel_Work_loan_info.replaceAll("<SEQ>", proc_id) ;
	            comnDto.setProcId(proc_id);
	            OnlnDlyReptResultDTO returnDto = mapper.sqlSelWorkLoanInfo(comnDto);
	            loanNo_FR = returnDto.getRlFr();
	            loanNo_TO = returnDto.getRlTo();

				// 당일 신규건 Insert
	            comnDto.setLoanFr(loanNo_FR);
	            comnDto.setLoanTo(loanNo_TO);
	            mapper.sqlInsTmpOnlnDlyInfoParal(comnDto);

				// 해지건 대상에서 제외
	            mapper.sqlDelTmpOnlnDlyInfo2Paral(comnDto);

	            mapper.sqlDelTmpAfddDlyInfo2Paral(comnDto);

				// 당일 변경건 Update
	            mapper.sqlUpTmpOnlnDlyInfoParal(comnDto);

	            rs = mapper.sqlSelTmpOnlnDlyInfoParal(comnDto);
			}

			//con.commit() ;

			//청구미수 로직을 멀티방식으로 처리하기 위해서 결과를 임시 ResultSet에 담아서 AskUnrcvVO 객체에 전체를 add 해둔다.
			int vo_cnt = 0 ;
			AskUnrcvVO vo = new AskUnrcvVO();

			for (int i = 0; i < rs.size(); i++) {
				if(vo_cnt < 100 ) {
					OnlnDlyReptResultDTO dto = rs.get(i);
					String sLoanNo = dto.getLoanNo();
					String sLoanSeq= dto.getLoanSeq();
					String sProcDt= dto.getProcDt();

					//입력 :대출_번호(LOAN_NO),대출_순번(LOAN_SEQ),상품_코드(PRDT_CD),결제_일자(SETL_DT),회계_일자(ACCT_DT)
					AskUnrcvObjVO objVO1 = new AskUnrcvObjVO();
					objVO1.setLoanNo(sLoanNo);
					objVO1.setLoanSeq(sLoanSeq);
					objVO1.setSetlDt(sProcDt);//sSetlDd;
					vo.addAskUnrcvObj(objVO1);
				}

				if((vo_cnt / 100 ) == 1) {
					procDlyInfo(vo, vo_cnt, procUser, isLog,result) ;
					vo_cnt = 0 ;
					//con.commit() ;
				} else {
					vo_cnt ++ ;
				}
			}

			procDlyInfo(vo, vo_cnt, procUser, isLog,result) ;
			//con.commit() ;
		} catch (Exception e) {
			//result = false ;
			result.setRsltCd(MsgEnum.DLY_CREATE_ERROR.getErrorCd());
			result.setRsltCntn(MsgEnum.DLY_CREATE_ERROR.getDescription());
        }

		return result;
	}

	private void procDlyInfo(AskUnrcvVO vo , int vo_cnt , String procUser, boolean isLog, OnlnDlyReptOutVO result) throws Exception {

		BndVO bndVO;

		try {
			if(vo_cnt > 0) {
				//TODO AskUnrcvProcCC 모듈 완성시 해당 모듈 호출 필요함
				//vo = AskUnrcvProcCC.calcAskUnrcv(vo, con);
			}
		}catch(Exception e){
			result.setRsltCd(MsgEnum.getEnum("D02").getErrorCd());
			result.setRsltCntn(MsgEnum.getEnum("D02").getDescription());
		}

		try {
			int bnd_cnt = vo.bndCnt ;
			OnlnDlyReptComnDTO comnDto;
			List<OnlnDlyReptResultDTO> rs;
			OnlnDlyReptBndDTO bndDto;
			if(bnd_cnt > 0) {
				for(int i = 0 ; i < bnd_cnt; i++) {
					bndDto = new OnlnDlyReptBndDTO();
					bndVO = vo.getBndVO(i) ;
					comnDto = new OnlnDlyReptComnDTO();
					comnDto.setLoanNo(bndVO.getLoanNo());
					comnDto.setLoanSeq(bndVO.getLoanSeq());

					/* 2018-08-01 (두비스) add start */
					/* 채권마감CC 에서 ....
					// * 연체_횟수, 연체_개월수 변경로직 추가 . 2018-08-01. 안흥조.
		            // EPRT_DT < 기준일 OR LOAN_STAT_CD == '29' 면  dlyMmCnt 값을 dlyTcnt 대신 사용함.
		            // 단, 둘 중에 큰값으로 할당한다.
		            if("29".equals(sLoanStatCd) || sEprtDt.compareTo(workDt) < 0 ) {
		            	if (bndVO.dlyTcnt < bndVO.dlyMmCnt) {
		            		bndVO.dlyTcnt = bndVO.dlyMmCnt;
		            	}
		            }
		            */

					rs = mapper.sqlSelTmpLoanInfo(comnDto);

					for (int j = 0; j < rs.size(); j++) {
						String chk_ind = rs.get(j).getChk();
						if("ETC".equals(chk_ind)) {
							if (bndVO.getDlyTcnt() < bndVO.getDlyMmCnt()) {
			            		bndVO.setDlyTcnt(bndVO.getDlyMmCnt());
			            	}
						}
					}
					bndDto.setDlyTcnt(bndVO.getDlyTcnt());
					bndDto.setDlyDdcnt(bndVO.getDlyDdcnt());
					bndDto.setDlyPamt(bndVO.getDlyPamt());
					bndDto.setDlyInt(bndVO.getDlyInt());
					bndDto.setDfee(bndVO.getDfee());
					bndDto.setDlyStrtTims(bndVO.getDlyStrtTims());
					bndDto.setPamtRamt(bndVO.getPamtRamt());
					bndDto.setIntRamt(bndVO.getIntRamt());
					bndDto.setOccrLeglActnCost(bndVO.getOccrLeglActnCost());
					bndDto.setAdjLeglActnCost(bndVO.getAdjLeglActnCost());
					bndDto.setLeglActnCostRamt(bndVO.getLeglActnCostRamt());
					bndDto.setTotTims(bndVO.getTotTims());
					bndDto.setRmbrFrmlCd(bndVO.getRmbrFrmlCd());
					bndDto.setLoanEprtDt(bndVO.getLoanEprtDt());
					bndDto.setLoanEprtTims(bndVO.getLoanEprtTims());
					bndDto.setLoanTotMmCnt(bndVO.getLoanTotMmCnt());
					bndDto.setSetlDt(bndVO.getSetlDt());
					bndDto.setThmmDueDt(bndVO.getThmmDueDt());
					bndDto.setThmmRlDueDt(bndVO.getThmmRlDueDt());
					bndDto.setThmmDueTims(bndVO.getThmmDueTims());
					bndDto.setNormPamt(bndVO.getNormPamt());
					bndDto.setNormInt(bndVO.getNormInt());
					bndDto.setNormPsgInt(bndVO.getNormPsgInt());
					bndDto.setLastSetlDt(bndVO.getLastSetlDt());
					bndDto.setLastSetlTims(bndVO.getLastSetlTims());
					bndDto.setProcUser(procUser);
					bndDto.setLoanNo(bndVO.getLoanNo());
					bndDto.setLoanSeq(bndVO.getLoanSeq());
					mapper.sqlLastUpTmpOnlnDlyInfo(bndDto);

					// 당월상환계획정보 생성 : 2018-08-01 (두비스) add
					// 채권마감 BCLBCD01CC.procIamtInfo4 와 동일한 처리 방식

					// 정상  : 당월_도래_일자, 당월_도래_회차, 당월_도래_원금, 당월_도래_이자 setting
					rs = mapper.sqlSelThmmRmbrInfo1(comnDto);
					for (int j = 0; j < rs.size(); j++) {
						long count1 = rs.get(j).getCount();
						if(count1 > 0) {
							mapper.sqlUpdThmmRmbrInfo1(comnDto);
						}
					}

					// 만기일 지난 것 : 지난 최종 회차를 당월 도래회차에 setting
					rs = mapper.sqlSelThmmRmbrInfo2(comnDto);
					for (int j = 0; j < rs.size(); j++) {
						long count1 = rs.get(j).getCount();
						if(count1 > 0) {
							mapper.sqlUpdThmmRmbrInfo2(comnDto);
						}
					}


					// 당일 해지 된것 처리
					rs = mapper.sqlSelThmmRmbrInfo3(comnDto);
					for (int j = 0; j < rs.size(); j++) {
						long count1 = rs.get(j).getCount();
						if(count1 > 0) {
							mapper.sqlUpdThmmRmbrInfo3(comnDto);
						}
					}

					//채권마감기본 당일
					mapper.sqlUpdBndClsBaseToday(comnDto);

					//채권마감기본 당일
					mapper.sqlUpdBndClsBaseNotoday(comnDto);

				}
			}
		} catch (Exception e) {
			result.setRsltCd(MsgEnum.getEnum("D01").getErrorCd());
			result.setRsltCntn(MsgEnum.getEnum("D01").getDescription());
		}
		finally {
			vo.init() ;
		}
	}
}
