package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.DlyListMngMapper;
import hanalife.b.cn.ui.mapper.dto.DlyListMngSDDODTO;
import hanalife.b.cn.ui.mapper.dto.DlyListMngSMDODTO;
import hanalife.b.cn.ui.service.BCNUIM01Service;
import hanalife.b.cn.ui.vo.BCNUIM01DSSDDOVO;
import hanalife.b.cn.ui.vo.BCNUIM01S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BLMLMM04ServiceImpl.java Class
 * 클래스설명   : todo1 (todo0) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70326 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIM01S01 : 연체리스트 목록조회
 * </pre>
 */
@Service("BCNUIM01Service")
public class BCNUIM01ServiceImpl implements BCNUIM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM01ServiceImpl.class);

	 @Autowired
	 private DlyListMngMapper dlyListMngMapper;

	/**
	 * <p>메소드명      : getBLMLM04S01 : 연체리스트 조회</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author):
	 * <p>설명          : 연체리스트  조회 한다.</p>
	 * <p>메소드인수    : BLMLMM04S01InVO </p>
	 * <p>메소드리턴값  : BLMLMM04S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BCNUIM01S01OutVO getBCNUIM01S01(BCNUIM01S01InVO inVo) throws Exception {

		/** 연체리스트 서비스 결과값 객체 생성 */
		BCNUIM01S01OutVO resultVo = new BCNUIM01S01OutVO();

		/** 연체리스트 조회 조건 입력값 객체 생성 및 대입 수행 */
		DlyListMngSMDODTO dly01Dto = new DlyListMngSMDODTO();
		;
		dly01Dto.setOrgCd(inVo.getBCNUIM01DSSMDOVO().getOrgCd());				/** 관리부서 */
		dly01Dto.setPrdtCd(inVo.getBCNUIM01DSSMDOVO().getPrdtCd());				/** 상품코드 */
		dly01Dto.setLoanStatCd(inVo.getBCNUIM01DSSMDOVO().getLoanStatCd());		/** 대출상태 */
		dly01Dto.setEprtDtSt(inVo.getBCNUIM01DSSMDOVO().getEprtDtSt());			/** 만기시작일자 */
		dly01Dto.setEprtDtEd(inVo.getBCNUIM01DSSMDOVO().getEprtDtEd());			/** 만기종료일자 */
		dly01Dto.setCrdtStatCd(inVo.getBCNUIM01DSSMDOVO().getCrdtStatCd());		/** 신용상태 */
		dly01Dto.setBndStatCd(inVo.getBCNUIM01DSSMDOVO().getBndStatCd());		/** 채권상태 */
		dly01Dto.setSecurityYn(inVo.getBCNUIM01DSSMDOVO().getSecurityYn());		/** 담보여부 */
		dly01Dto.setGoodCd(inVo.getBCNUIM01DSSMDOVO().getGoodCd());				/** 자산건전성 */
		dly01Dto.setLoanNo(inVo.getBCNUIM01DSSMDOVO().getLoanNo());				/** 대출번호 */
		dly01Dto.setLoanSeq(inVo.getBCNUIM01DSSMDOVO().getLoanSeq());	   		/** 대출순번 */
		dly01Dto.setThmmComgFrom(inVo.getBCNUIM01DSSMDOVO().getThmmComgFrom());	/** 도래회차시작 */
		dly01Dto.setThmmComgTo(inVo.getBCNUIM01DSSMDOVO().getThmmComgTo());		/** 도래회차종료 */
		dly01Dto.setCntSt(inVo.getBCNUIM01DSSMDOVO().getCntSt());				/** 연체회차시작 */
		dly01Dto.setCntEd(inVo.getBCNUIM01DSSMDOVO().getCntEd());				/** 연체회차종료 */
		dly01Dto.setDlyDdcntSt(inVo.getBCNUIM01DSSMDOVO().getDlyDdcntSt());		/** 연체일수시작 */
		dly01Dto.setDlyDdcntEd(inVo.getBCNUIM01DSSMDOVO().getDlyDdcntEd());		/** 연체일수종료 */
		dly01Dto.setKisanSt(inVo.getBCNUIM01DSSMDOVO().getKisanSt());			/** 결제일시작 */
		dly01Dto.setKisanEd(inVo.getBCNUIM01DSSMDOVO().getKisanEd());			/** 결제일종료 */
		dly01Dto.setContManNo(inVo.getBCNUIM01DSSMDOVO().getContManNo());		/** 고객번호 */
		dly01Dto.setThmmUnUrge(inVo.getBCNUIM01DSSMDOVO().getThmmUnUrge());		/** 당월미독촉 여부 */
		LOGGER.debug("dly01Dto : " + dly01Dto.getBndStatCd());
		LOGGER.debug("dly01Dto : " + dly01Dto.getLoanStatCd());
		LOGGER.debug("dly01Dto : " + dly01Dto.getThmmUnUrge());
		/** 연체리스트 조회 쿼리 Mapper 호출 수행 */
        List<DlyListMngSDDODTO> resultDTO = dlyListMngMapper.search(dly01Dto);
        LOGGER.debug("resultDTO : " + resultDTO);
        /** 연체리스트 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BCNUIM01DSSDDOVO> resultList = new ArrayList<BCNUIM01DSSDDOVO>();

        for (DlyListMngSDDODTO sourceIO : resultDTO) {

            /** 연체리스트 VO에 조회된 Mapper DTO 값을 대입 */
        	BCNUIM01DSSDDOVO targetIO = new BCNUIM01DSSDDOVO();

        	targetIO.setThmmUnUrge(sourceIO.getThmmUnUrge()); /* 합계구분(0:전체, 2:잔액) */
        	targetIO.setWlngPayStat(sourceIO.getWlngPayStat()); /* 합계구분(0:전체, 3:잔액) */
        	targetIO.setLoanNo(sourceIO.getLoanNo()); /* 합계구분(0:전체, 4:잔액) */
        	targetIO.setLoanSeq(sourceIO.getLoanSeq()); /* 합계구분(0:전체, 5:잔액) */
        	targetIO.setContManNo(sourceIO.getContManNo()); /* 합계구분(0:전체, 6:잔액) */
        	targetIO.setContManNm(sourceIO.getContManNm()); /* 합계구분(0:전체, 7:잔액) */
        	targetIO.setContManNoTran(sourceIO.getContManNoTran()); /* 합계구분(0:전체, 8:잔액) */
        	targetIO.setBndStatNm(sourceIO.getBndStatNm()); /* 합계구분(0:전체, 9:잔액) */
        	targetIO.setDlyDt(sourceIO.getDlyDt()); /* 합계구분(0:전체, 10:잔액) */
        	targetIO.setDlyTcnt(sourceIO.getDlyTcnt()); /* 합계구분(0:전체, 11:잔액) */
        	targetIO.setDlyDdcnt(sourceIO.getDlyDdcnt()); /* 합계구분(0:전체, 12:잔액) */
        	targetIO.setDlyAmt(sourceIO.getDlyAmt()); /* 합계구분(0:전체, 13:잔액) */
        	targetIO.setDfee(sourceIO.getDfee()); /* 합계구분(0:전체, 14:잔액) */
        	targetIO.setLoanPamt(sourceIO.getLoanPamt()); /* 합계구분(0:전체, 15:잔액) */
        	targetIO.setLoanAmt(sourceIO.getLoanAmt()); /* 합계구분(0:전체, 16:잔액) */
        	targetIO.setBndAmt(sourceIO.getBndAmt()); /* 합계구분(0:전체, 17:잔액) */
        	targetIO.setLoanDt(sourceIO.getLoanDt()); /* 합계구분(0:전체, 18:잔액) */
        	targetIO.setLoanTerm(sourceIO.getLoanTerm()); /* 합계구분(0:전체, 19:잔액) */
        	targetIO.setThmmComgDt(sourceIO.getThmmComgDt()); /* 합계구분(0:전체, 20:잔액) */
        	targetIO.setLastSetlTims(sourceIO.getLastSetlTims()); /* 합계구분(0:전체, 21:잔액) */
        	targetIO.setThmmAmt(sourceIO.getThmmAmt()); /* 합계구분(0:전체, 22:잔액) */
        	targetIO.setSetlDt(sourceIO.getSetlDt()); /* 합계구분(0:전체, 23:잔액) */
        	targetIO.setSetlAmt(sourceIO.getSetlAmt()); /* 합계구분(0:전체, 24:잔액) */
        	targetIO.setPrmsDt(sourceIO.getPrmsDt()); /* 합계구분(0:전체, 25:잔액) */
        	targetIO.setPrmsAmt(sourceIO.getPrmsAmt()); /* 합계구분(0:전체, 26:잔액) */
        	targetIO.setTelcDt(sourceIO.getTelcDt()); /* 합계구분(0:전체, 27:잔액) */
        	targetIO.setRlTelcMan(sourceIO.getRlTelcMan()); /* 합계구분(0:전체, 28:잔액) */
        	targetIO.setTelcCntn(sourceIO.getTelcCntn()); /* 합계구분(0:전체, 29:잔액) */
        	targetIO.setHometel(sourceIO.getHometel()); /* 합계구분(0:전체, 30:잔액) */
        	targetIO.setWorktel(sourceIO.getWorktel()); /* 합계구분(0:전체, 31:잔액) */
        	targetIO.setHandtel(sourceIO.getHandtel()); /* 합계구분(0:전체, 32:잔액) */
        	targetIO.setDlvrDt(sourceIO.getDlvrDt()); /* 합계구분(0:전체, 33:잔액) */
        	targetIO.setDlvrNm(sourceIO.getDlvrNm()); /* 합계구분(0:전체, 34:잔액) */
        	targetIO.setLoanStatNm(sourceIO.getLoanStatNm()); /* 합계구분(0:전체, 35:잔액) */
        	targetIO.setCrdtStatNm(sourceIO.getCrdtStatNm()); /* 합계구분(0:전체, 36:잔액) */
        	targetIO.setLeglActsStatNm(sourceIO.getLeglActsStatNm()); /* 합계구분(0:전체, 37:잔액) */
        	targetIO.setLeglActsObjDt(sourceIO.getLeglActsObjDt()); /* 합계구분(0:전체, 38:잔액) */
        	targetIO.setAsetSondTpClasNm(sourceIO.getAsetSondTpClasNm()); /* 합계구분(0:전체, 39:잔액) */
        	targetIO.setBadDebtApprAmt(sourceIO.getBadDebtApprAmt()); /* 합계구분(0:전체, 40:잔액) */
        	targetIO.setSetlDd(sourceIO.getSetlDd()); /* 합계구분(0:전체, 41:잔액) */
        	targetIO.setDueMeth(sourceIO.getDueMeth()); /* 합계구분(0:전체, 42:잔액) */
        	targetIO.setRmbrFrml(sourceIO.getRmbrFrml()); /* 합계구분(0:전체, 43:잔액) */
        	targetIO.setEprtDt(sourceIO.getEprtDt()); /* 합계구분(0:전체, 44:잔액) */
        	targetIO.setPrdtNm(sourceIO.getPrdtNm()); /* 합계구분(0:전체, 45:잔액) */
        	targetIO.setMrtgSmClasNm(sourceIO.getMrtgSmClasNm()); /* 합계구분(0:전체, 46:잔액) */
        	targetIO.setPrdtClasNm(sourceIO.getPrdtClasNm()); /* 합계구분(0:전체, 47:잔액) */
        	targetIO.setGodsNm(sourceIO.getGodsNm()); /* 합계구분(0:전체, 48:잔액) */
        	targetIO.setExamDgreNm(sourceIO.getExamDgreNm()); /* 합계구분(0:전체, 49:잔액) */
        	targetIO.setExamJudgNm(sourceIO.getExamJudgNm()); /* 합계구분(0:전체, 50:잔액) */
        	targetIO.setCprtComNm(sourceIO.getCprtComNm()); /* 합계구분(0:전체, 51:잔액) */
        	targetIO.setCprtBranNm(sourceIO.getCprtBranNm()); /* 합계구분(0:전체, 52:잔액) */
        	targetIO.setCprtEmpNm(sourceIO.getCprtEmpNm()); /* 합계구분(0:전체, 53:잔액) */
        	targetIO.setLnDivsEmpNm(sourceIO.getLnDivsEmpNm()); /* 합계구분(0:전체, 54:잔액) */
        	targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /* 합계구분(0:전체, 55:잔액) */
        	targetIO.setDocKeepNo(sourceIO.getDocKeepNo()); /* 합계구분(0:전체, 56:잔액) */
        	targetIO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm()); /* 합계구분(0:전체, 57:잔액) */
        	targetIO.setBndMngPlcNm(sourceIO.getBndMngPlcNm()); /* 합계구분(0:전체, 58:잔액) */
        	targetIO.setFrstDlyDt(sourceIO.getFrstDlyDt()); /* 합계구분(0:전체, 59:잔액) */
        	targetIO.setBadCn(sourceIO.getBadCn()); /* 합계구분(0:전체, 60:잔액) */
        	targetIO.setBadAmt(sourceIO.getBadAmt()); /* 합계구분(0:전체, 61:잔액) */
        	targetIO.setLeasStatNm(sourceIO.getLeasStatNm()); /* 합계구분(0:전체, 62:잔액) */
        	targetIO.setFlotIzeDivCd(sourceIO.getFlotIzeDivCd()); /* 합계구분(0:전체, 63:잔액) */
        	targetIO.setFlotIzeSeq(sourceIO.getFlotIzeSeq()); /* 합계구분(0:전체, 64:잔액) */
        	targetIO.setMrtgYn(sourceIO.getMrtgYn()); /* 합계구분(0:전체, 65:잔액) */
        	targetIO.setMrtgSmYn(sourceIO.getMrtgSmYn()); /* 합계구분(0:전체, 66:잔액) */
        	targetIO.setBndOldNewFg(sourceIO.getBndOldNewFg()); /* 합계구분(0:전체, 67:잔액) */
        	targetIO.setPrdtSmClasNm(sourceIO.getPrdtSmClasNm()); /* 합계구분(0:전체, 68:잔액) */
        	targetIO.setRelCnt(sourceIO.getRelCnt()); /* 합계구분(0:전체, 69:잔액) */
        	targetIO.setSplycomNm(sourceIO.getSplycomNm()); /* 합계구분(0:전체, 70:잔액) */
        	targetIO.setWdrwDivsMan(sourceIO.getWdrwDivsMan()); /* 합계구분(0:전체, 71:잔액) */
        	targetIO.setLeasGodsNm(sourceIO.getLeasGodsNm()); /* 합계구분(0:전체, 72:잔액) */
        	targetIO.setLeasGuarAmt(sourceIO.getLeasGuarAmt()); /* 합계구분(0:전체, 73:잔액) */
        	targetIO.setLeasRmnVal(sourceIO.getLeasRmnVal()); /* 합계구분(0:전체, 74:잔액) */
        	targetIO.setCntctDt(sourceIO.getCntctDt()); /* 합계구분(0:전체, 75:잔액) */
        	targetIO.setCntctCntn(sourceIO.getCntctCntn()); /* 합계구분(0:전체, 76:잔액) */
        	targetIO.setCntctDivsManNm(sourceIO.getCntctDivsManNm()); /* 합계구분(0:전체, 77:잔액) */
        	targetIO.setBssDgre(sourceIO.getBssDgre()); /* 합계구분(0:전체, 78:잔액) */
        	targetIO.setRssDgre(sourceIO.getRssDgre()); /* 합계구분(0:전체, 79:잔액) */
        	targetIO.setBsRsCombDgre(sourceIO.getBsRsCombDgre()); /* 합계구분(0:전체, 80:잔액) */
        	targetIO.setCustTpNm(sourceIO.getCustTpNm()); /* 합계구분(0:전체, 81:잔액) */
        	targetIO.setLeglCountRamt(sourceIO.getLeglCountRamt()); /* 합계구분(0:전체, 82:잔액) */
        	targetIO.setBadDebtRcptStatCd(sourceIO.getBadDebtRcptStatCd()); /* 합계구분(0:전체, 83:잔액) */
        	targetIO.setBadDebtRcptStatNm(sourceIO.getBadDebtRcptStatNm()); /* 합계구분(0:전체, 84:잔액) */
        	targetIO.setBadDebtAcctDt(sourceIO.getBadDebtAcctDt()); /* 합계구분(0:전체, 85:잔액) */
        	targetIO.setBadDebtSetlDt(sourceIO.getBadDebtSetlDt()); /* 합계구분(0:전체, 86:잔액) */
        	targetIO.setWdrwTpCd(sourceIO.getWdrwTpCd()); /* 합계구분(0:전체, 87:잔액) */
        	targetIO.setWdrwTpNm(sourceIO.getWdrwTpNm()); /* 합계구분(0:전체, 88:잔액) */
        	targetIO.setCustAddr(sourceIO.getCustAddr()); /* 합계구분(0:전체, 89:잔액) */
        	targetIO.setBadDebtDeprDt(sourceIO.getBadDebtDeprDt()); /* 합계구분(0:전체, 90:잔액) */
        	targetIO.setDlyPamt(sourceIO.getDlyPamt()); /* 합계구분(0:전체, 91:잔액) */
        	targetIO.setDlyInt(sourceIO.getDlyInt()); /* 합계구분(0:전체, 92:잔액) */
        	targetIO.setSumDlyAmt(sourceIO.getSumDlyAmt()); /* 합계구분(0:전체, 93:잔액) */
        	targetIO.setUnrcvRamt(sourceIO.getUnrcvRamt()); /* 합계구분(0:전체, 94:잔액) */

            /** 연체리스트 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }
        LOGGER.debug("resultList : " + resultList.get(0).getLoanNo());
        resultVo.setBCNUIM01DSSDDOVO(resultList);
        LOGGER.debug("resultVo : " + resultVo.getBCNUIM01DSSDDOVO().get(0).getLoanNo());

		return resultVo;
	}
}
