package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.SmsDlvrReadMapper;
import hanalife.b.cn.ui.mapper.dto.SmsDlvrReadSearch01DTO;
import hanalife.b.cn.ui.service.BCNUIM04Service;
import hanalife.b.cn.ui.vo.BCNUIM04DSSDDOVO;
import hanalife.b.cn.ui.vo.BCNUIM04DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIM04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM04ServiceImpl.java Class
 * 클래스설명   : SMS 발송내역 (BCNUIM04) Service Implements
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIM04S01 : SMS 발송내역목록조회
 *              registerBCNUIM04I01 : SMS 발송내역등록
 *              modifyBCNUIM04U01 : SMS 발송내역수정
 *              removeBCNUIM04U01 : SMS 발송내역삭제
 * </pre>
 */
@Service("BCNUIM04Service")
public class BCNUIM04ServiceImpl implements BCNUIM04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM04ServiceImpl.class);

	@Autowired
	private SmsDlvrReadMapper smsDlvrReadMapper;

	/**
	 * <p>메소드명      : getBCNUIM04S01 : SMS 발송내역목록조회</p>
	 * <p>작성일자      : 2023. 3. 6.
	 * <p>작성자(author): 70320 / jaeho.jang
	 * <p>설명          : SMS 발송내역목록을 조회 한다.</p>
	 * <p>메소드인수    : BCNUIM04S01InVo </p>
	 * <p>메소드리턴값  : BCNUIM04S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BCNUIM04S01OutVO getBCNUIM04S01(BCNUIM04DSSMDOVO inVo) throws Exception {

		BCNUIM04S01OutVO resultVo = new BCNUIM04S01OutVO();
		SmsDlvrReadSearch01DTO inDto = new SmsDlvrReadSearch01DTO();
		inDto.setDlvrFromDt(inVo.getDlvrFromDt()); /**  */
		inDto.setDlvrToDt(inVo.getDlvrToDt()); /**  */
		inDto.setDeptCd(inVo.getDeptCd()); /**  */
		inDto.setDlvrEmpNo(inVo.getDlvrEmpNo()); /**  */
		inDto.setLoanNo(inVo.getLoanNo()); /**  */
		inDto.setLoanSeq(inVo.getLoanSeq()); /**  */
		inDto.setCustNo(inVo.getCustNo()); /**  */
		inDto.setRecvTelNo(inVo.getRecvTelNo()); /**  */
		inDto.setSendStatDiv(inVo.getSendStatDiv()); /**  */
		inDto.setDlvrObjCd(inVo.getDlvrObjCd()); /**  */
		inDto.setDlvrDeptCd(inVo.getDlvrDeptCd()); /**  */

		//TODO - 임시 리스트
		List<SmsDlvrReadSearch01DTO> convertList = smsDlvrReadMapper.selectSmsDlvrRead(inDto);
		List<BCNUIM04DSSDDOVO> returnList = new ArrayList<BCNUIM04DSSDDOVO>();
		for(SmsDlvrReadSearch01DTO dto : convertList) {
			BCNUIM04DSSDDOVO vo = new BCNUIM04DSSDDOVO();
			vo.setConsDt(dto.getConsDt());
			vo.setCustNm(dto.getCustNm());
			vo.setCustNo(dto.getCustNo());
			vo.setDlvrDeptCd(dto.getDlvrDeptCd());
			vo.setDlvrDt(dto.getDlvrDt());
			vo.setDlvrEmpNm(dto.getDlvrEmpNm());
			vo.setDlvrEmpNo(dto.getDlvrEmpNo());
			vo.setDlvrObjCd(dto.getDlvrObjCd());
			vo.setLoanNo(dto.getLoanNo());
			vo.setLoanRelMan(dto.getLoanRelMan());
			vo.setLoanSeq(dto.getLoanSeq());
			vo.setMngDeptCd(dto.getMngDeptCd());
			vo.setMngDeptNm(dto.getMngDeptNm());
			vo.setMsgStatus(dto.getMsgStatus());
			vo.setMsgStatusNm(dto.getMsgStatusNm());
			vo.setMtPr(dto.getMtPr());
			vo.setRecvTelNo(dto.getRecvTelNo());
			vo.setSendDttm(dto.getSendDttm());
			vo.setSendId(dto.getSendId());
			vo.setSendRefKey(dto.getSendRefKey());
			vo.setSendTxt(dto.getSendTxt());
			vo.setSeq(dto.getSeq());
			returnList.add(vo);
		}

		resultVo.setListBCNUIM04S0101VO(returnList);

		return resultVo;

	}
}
