package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.LamtPrmsManSpecMapper;
import hanalife.b.cn.ui.mapper.dto.LamtPrmsManSpecDSDDODTO;
import hanalife.b.cn.ui.mapper.dto.LamtPrmsManSpecDSMDODTO;
import hanalife.b.cn.ui.service.BCNUIM05Service;
import hanalife.b.cn.ui.vo.BCNUIM05DSSDDOVO;
import hanalife.b.cn.ui.vo.BCNUIM05S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM05S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM05ServiceImpl.java Class
 * 클래스설명   : todo1 (todo0) Service Implements
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : gettodo0S01 : todo1목록조회
 * </pre>
 */
@Service("BCNUIM05Service")
public class BCNUIM05ServiceImpl implements BCNUIM05Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM05ServiceImpl.class);

    @Autowired
    private LamtPrmsManSpecMapper lamtPrmsManSpecMapper;

    /**
     *<pre>
     * 메소드명      : getBCNUIM05S01 : 입금약속자명세 조회
     * 작성일자      : 2023. 3. 17.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 입금약속자명세을 조회 한다.
     * 메소드인수    : BCNUIM05S01InVO
     * 메소드리턴값  : BCNUIM05S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BCNUIM05S01OutVO getBCNUIM05S01(BCNUIM05S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY getBCNUIM05S01 Start..}");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BCNUIM05S01OutVO        resultVo            = new BCNUIM05S01OutVO();
        LamtPrmsManSpecDSMDODTO lamtPrmsManSpecDto  = new LamtPrmsManSpecDSMDODTO();
        List<BCNUIM05DSSDDOVO>  resultList          = new ArrayList<BCNUIM05DSSDDOVO>();


        /**************************************************
         * □ 초기선언
         **************************************************/
        lamtPrmsManSpecDto.setMngDeptCd   (inVo.getBCNUIM05DSSMDOVO().getMngDeptCd()        ); // 관리_부서_코드
        lamtPrmsManSpecDto.setDivsManEmpNo(inVo.getBCNUIM05DSSMDOVO().getDivsManEmpNo()     ); // 담당자_ID
        lamtPrmsManSpecDto.setDivsManNm   (inVo.getBCNUIM05DSSMDOVO().getDivsManNm()        ); // 담당자_명
        lamtPrmsManSpecDto.setCnslObjManNm(inVo.getBCNUIM05DSSMDOVO().getCnslObjManNm()     );
        lamtPrmsManSpecDto.setPrmsFromDt  (inVo.getBCNUIM05DSSMDOVO().getPrmsFromDt()       );
        lamtPrmsManSpecDto.setPrmsToDt    (inVo.getBCNUIM05DSSMDOVO().getPrmsToDt()         );


        /**************************************************
         * ■ Call 입금약속자명세 조회
         **************************************************/
        List<LamtPrmsManSpecDSDDODTO> resultDTO = lamtPrmsManSpecMapper.search(lamtPrmsManSpecDto);


        /**************************************************
         * □ 입금약속자명세 LOOP처리
         **************************************************/
        for (LamtPrmsManSpecDSDDODTO sourceIO : resultDTO) {
            BCNUIM05DSSDDOVO bcnuiM05DSSDDOVo = new BCNUIM05DSSDDOVO();
            bcnuiM05DSSDDOVo.setNo          (sourceIO.getNo          ())     ;
            bcnuiM05DSSDDOVo.setLoanNo      (sourceIO.getLoanNo      ())     ;
            bcnuiM05DSSDDOVo.setCnslObjManNm(sourceIO.getCnslObjManNm())     ;
            bcnuiM05DSSDDOVo.setDivsManNm   (sourceIO.getDivsManNm   ())     ;
            bcnuiM05DSSDDOVo.setDivsManEmpNm(sourceIO.getDivsManEmpNm())     ;
            bcnuiM05DSSDDOVo.setPrmsDt      (sourceIO.getPrmsDt      ())     ;
            bcnuiM05DSSDDOVo.setPrmsAmt     (sourceIO.getPrmsAmt     ())     ;
            bcnuiM05DSSDDOVo.setDlyTcnt     (sourceIO.getDlyTcnt     ())     ;
            bcnuiM05DSSDDOVo.setLoan        (sourceIO.getLoan        ())     ;
            bcnuiM05DSSDDOVo.setRcptTpNm    (sourceIO.getRcptTpNm    ())     ;
            bcnuiM05DSSDDOVo.setBankNm      (sourceIO.getBankNm      ())     ;
            bcnuiM05DSSDDOVo.setEtc         (sourceIO.getEtc         ())     ;
            bcnuiM05DSSDDOVo.setHometel     (sourceIO.getHometel     ())     ;
            bcnuiM05DSSDDOVo.setWorktel     (sourceIO.getWorktel     ())     ;
            bcnuiM05DSSDDOVo.setHandtel     (sourceIO.getHandtel     ())     ;
            bcnuiM05DSSDDOVo.setLoanSeq     (sourceIO.getLoanSeq     ())     ;
            bcnuiM05DSSDDOVo.setCustNo      (sourceIO.getCustNo      ())     ;
            bcnuiM05DSSDDOVo.setDlyAmt      (sourceIO.getDlyAmt      ())     ;
            bcnuiM05DSSDDOVo.setRcntSetlDt  (sourceIO.getRcntSetlDt  ())     ;
            bcnuiM05DSSDDOVo.setRcntSetlAmt (sourceIO.getRcntSetlAmt ())     ;
            bcnuiM05DSSDDOVo.setMngDeptNm   (sourceIO.getMngDeptNm   ())     ;

            resultList.add(bcnuiM05DSSDDOVo);
        }

        /** 입금약속자명세 화면 출력 결과값 대입 */
        resultVo.setBCNUIM05DSSDDOVOList(resultList);

        return resultVo;
    }

}
