package hanalife.b.cn.ui.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIM03Service;
import hanalife.b.cn.ui.vo.BCNUIM03DSSDDO01VO;
import hanalife.b.cn.ui.vo.BCNUIM03DSSDDO03VO;
import hanalife.b.cn.ui.vo.BCNUIM03DSSMDO01VO;
import hanalife.b.cn.ui.vo.BCNUIM03DSSMDO02VO;
import hanalife.b.cn.ui.vo.BCNUIM03InVO;
import hanalife.b.cn.ui.vo.BCNUIM03OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM03Controller.java Class
 * 클래스설명   : 발송리스트 관리 Controller
 * 작성일자     : 2023. 4.21.
 * 작성자명     : 70320 / 70320 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4.21.][ 70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIM03Controller {

	@Resource(name = "BCNUIM03Service")
	private BCNUIM03Service BCNUIM03;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM03Controller.class);

	/**
	 * <p>메소드명      : BCNUIM03S01조회 / BCNUIM03S01.do </p>
	 * <p>작성일자      : 2023. 4. 26.
	 * <p>작성자(author): 70320
	 * <p>설명          : 발송리스트 조회해서 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM03S01.do")
	public String BCNUIM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM03Controller BCNUIM03S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);
			LOGGER.info("##### BCNUIM03Controller sourceMap #####" + sourceMap);
			/** 발송리스트 조회 서비스 호출 입력값 대입 */
			BCNUIM03DSSMDO01VO dsSMDOInVo = new BCNUIM03DSSMDO01VO();
			BeanUtil.mapToBean(sourceMap, dsSMDOInVo);

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BCNUIM03InVO inVO = new BCNUIM03InVO();
            inVO.setBCNUIM03DSSMDO01VO(dsSMDOInVo);

            LOGGER.info("##### BCNUIM03Controller InVO #####" + inVO.getBCNUIM03DSSMDO01VO());

            /** 발송리스트 업무 서비스 호출 수행 */
            BCNUIM03OutVO resultListVo = BCNUIM03.getBCNUIM03S01(inVO);

            /** 발송리스트 DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO01", resultListVo.getListBCNUIM03DSSDDO01(), model);

            LOGGER.info("##### BCNUIM03Controller BCNUIM03S01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIM03Controller Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : BCNUIM03S03조회 / BCNUIM03S03.do </p>
	 * <p>작성일자      : 2023. 4. 26.
	 * <p>작성자(author): 70320
	 * <p>설명          : 발송리스트 조회해서 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM03S03.do")
	public String BCNUIM03S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM03Controller BCNUIM03S03 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);
			LOGGER.info("##### BCNUIM03Controller sourceMap #####" + sourceMap);
			/** 발송리스트 조회 서비스 호출 입력값 대입 */
			BCNUIM03DSSMDO01VO dsSMDOInVo = new BCNUIM03DSSMDO01VO();

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BCNUIM03InVO inVO = new BCNUIM03InVO();
			inVO.setBCNUIM03DSSMDO01VO(dsSMDOInVo);

            LOGGER.info("##### BCNUIM03Controller InVO #####" + inVO.getBCNUIM03DSSMDO01VO());
			/** 발송리스트 업무 서비스 호출 수행 */
			BCNUIM03OutVO resultListVo = BCNUIM03.getBCNUIM03S03(inVO);

			/** 발송리스트 DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_SDDO02", resultListVo.getListBCNUIM03DSSDDO02(), model);

			/** 발송리스트 DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_SDDO03", resultListVo.getListBCNUIM03DSSDDO03(), model);

			LOGGER.info("##### BCNUIM03Controller BCNUIM03S03 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIM03Controller Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : BCNUIM03U01조회 / BCNUIM03U01.do </p>
	 * <p>작성일자      : 2023. 4. 26.
	 * <p>작성자(author): 70320
	 * <p>설명          : SMS 발송 Controller</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM03U01.do")
	public String BCNUIM03U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM03U01Controller BCNUIM03U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap1 = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO02", request, response, model);
			Map<String, Object> sourceMap2 = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO03", request, response, model);
			List<Map<String, Object>> sourceList = XFrame5DataSetUtil.getXFrameDataSetList("DS_SDDO01_SEND", request, response, model);

			/** SMS 전송 서비스 호출 입력값 대입 */
			BCNUIM03DSSMDO02VO BCNUIM03DSSMDO02VO = new BCNUIM03DSSMDO02VO();
			BeanUtil.mapToBean(sourceMap1, BCNUIM03DSSMDO02VO);

			BCNUIM03DSSDDO03VO BCNUIM03DSSDDO03VO = new BCNUIM03DSSDDO03VO();
			BeanUtil.mapToBean(sourceMap2, BCNUIM03DSSDDO03VO);

			List<BCNUIM03DSSDDO01VO> listBCNUIM03DSSDDO01VO = new ArrayList<BCNUIM03DSSDDO01VO>();
			for (Map<String, Object> sourceMap3 : sourceList) {
				BCNUIM03DSSDDO01VO vo = new BCNUIM03DSSDDO01VO();
				BeanUtil.mapToBean(sourceMap3, vo);
				listBCNUIM03DSSDDO01VO.add(vo);
			}

			LOGGER.info("##### BCNUIM03Controller sourceMap #####" + sourceMap1);
			LOGGER.info("##### BCNUIM03Controller sourceMap #####" + sourceMap2);
			LOGGER.info("##### BCNUIM03Controller sourceMap #####" + sourceList);

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BCNUIM03InVO inVO = new BCNUIM03InVO();
			inVO.setBCNUIM03DSSDDO03VO(BCNUIM03DSSDDO03VO);
			inVO.setBCNUIM03DSSMDO02VO(BCNUIM03DSSMDO02VO);
			inVO.setListBCNUIM03DSSDDO01VO(listBCNUIM03DSSDDO01VO);

			LOGGER.info("##### BCNUIM03Controller InVO #####" + inVO.getBCNUIM03DSSMDO01VO());
			/** 발송리스트 업무 서비스 호출 수행 */
			BCNUIM03OutVO resultVo = BCNUIM03.registerBCNUIM03I01(inVO);
			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, "1");
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultVo.getRsltCntn());

			LOGGER.info("##### BCNUIM03Controller BCNUIM03S03 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, "-1");
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, "SMS 전송중 오류가 발생했습니다.");

			LOGGER.info("##### BCNUIM03Controller Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}

}