package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIM06Service;
import hanalife.b.cn.ui.vo.BCNUIM06DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIM06S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM06S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM06Controller.java Class
 * 클래스설명   : todo1 (BCNUIM06) Controller
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIM06Controller {

	@Resource(name = "BCNUIM06Service")
	private BCNUIM06Service BCNUIM06;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM06Controller.class);

	/**
	 * <p>메소드명      : 연락불능자목록조회 /BCNUIM06S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 연락불능자목록조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM06S01.do")
	public String BCNUIM06S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM06Controller BCNUIM06S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);
			/** 연락불능자목록조회 DataSet 항목값 VO 객체 입력값 대입 */
			BCNUIM06DSSMDOVO dsSMDOInVo = new BCNUIM06DSSMDOVO();
			dsSMDOInVo.setMngDeptCd((String) sourceMap.get("mngDeptCd"));            // 관리부서코드
			dsSMDOInVo.setCntcStatCd((String) sourceMap.get("cntcStatCd"));          // 연락상태
			dsSMDOInVo.setProdLrgeClasCd((String) sourceMap.get("prodLrgeClasCd"));  // 상품대분류코드
			dsSMDOInVo.setProdMidClasCd((String) sourceMap.get("prodMidClasCd"));    // 상품중분류코드

			dsSMDOInVo.setCntSt((String) sourceMap.get("cntSt"));                      // 연체회차 시작
			dsSMDOInVo.setCntEd((String) sourceMap.get("cntEd"));                      // 연체회차 종료
			dsSMDOInVo.setEmpNo((String) sourceMap.get("empNo"));                      // 상담직원번호

			LOGGER.info("##### sourceMap.get(\"cntSt\") #####   :   " +  sourceMap.get("cntSt"));
			LOGGER.info("##### sourceMap.get(\"cntEd\") #####   :   " +  sourceMap.get("cntEd"));
			LOGGER.info("##### sourceMap.get(\"cmpNo\") #####   :   " +  sourceMap.get("empNo"));

            /** Service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BCNUIM06S01InVO InVO = new BCNUIM06S01InVO();
            InVO.setBCNUIM06DSSMDOVO(dsSMDOInVo); /** 연락불능자목록조회 DS_SMDO 입력값 VO 객체 대입 */
            /** 연락불능자목록조회 업무 서비스 호출 수행 */
            BCNUIM06S01OutVO resultListVo = BCNUIM06.getBCNUIM06S01(InVO);
            /** 연락불능자목록조회 DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_SDDO", resultListVo.getBCNUIM06DSSDDOVO(), model);

			LOGGER.info("##### BCNUIM06Controller BCNUIM06S01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIM06Controller BCNUIM06S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}


}
