package hanalife.b.dl.dl.service.impl;


import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.dl.dl.mapper.LoanTmbyWdrwRsltReptMapper;
import hanalife.b.dl.dl.mapper.dto.LoanTmbyWdrwRsltReptDSSDDO01DTO;
import hanalife.b.dl.dl.mapper.dto.LoanTmbyWdrwRsltReptDSSEARCHDTO;
import hanalife.b.dl.dl.mapper.dto.LoanTmbyWdrwRsltSpecDSSDDO02DTO;
import hanalife.b.dl.dl.service.BDLDLM02Service;
import hanalife.b.dl.dl.vo.BDLDLM02DSSDDO01VO;
import hanalife.b.dl.dl.vo.BDLDLM02DSSDDO02VO;
import hanalife.b.dl.dl.vo.BDLDLM02S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM02S01OutVO;
import hanalife.b.dl.dl.vo.BDLDLM02S02OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM02ServiceImpl.java Class
 * 클래스설명   : BDLDLM02ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBDLDLM02S01 : 결제일자별 회수실적현황조회
 *              getBDLDLM02S02 : 결제일자별 명세서      조회
 * </pre>
 */
@Service("BDLDLM02Service")
public class BDLDLM02ServiceImpl implements BDLDLM02Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM02ServiceImpl.class);

    /** 결제일자별 연체현황 Mapper */
    @Autowired
    private LoanTmbyWdrwRsltReptMapper loanTmbyWdrwRsltReptMapper;

    /**
     *<pre>
     * 메소드명      : getBDLDLM02S01 : 결제일자별 회수실적현황조회
     * 작성일자      : 2023. 3. 17.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 결제일자별 회수실적현황조회 한다.
     * 메소드인수    : BDLDLM02S01InVO
     * 메소드리턴값  : BDLDLM02S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BDLDLM02S01OutVO getBDLDLM02S01(BDLDLM02S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY getBDLDLM02S01 Start..}");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BDLDLM02S01OutVO                resultVo                            = new BDLDLM02S01OutVO();
        LoanTmbyWdrwRsltReptDSSEARCHDTO loanTmbyWdrwRsltReptDSSEARCHDto     = new LoanTmbyWdrwRsltReptDSSEARCHDTO();
        List<BDLDLM02DSSDDO01VO>        resultList                          = new ArrayList<BDLDLM02DSSDDO01VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkMngDeptCd     (inVo.getBDLDLM02DSSEARCHVO().getChkMngDeptCd()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkBndDivsEmpNo  (inVo.getBDLDLM02DSSEARCHVO().getChkBndDivsEmpNo()  );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkSetlDd        (inVo.getBDLDLM02DSSEARCHVO().getChkSetlDd()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkDlyTcnt       (inVo.getBDLDLM02DSSEARCHVO().getChkDlyTcnt()       );
        loanTmbyWdrwRsltReptDSSEARCHDto.setStndDt           (inVo.getBDLDLM02DSSEARCHVO().getStndDt()           );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanDtFr         (inVo.getBDLDLM02DSSEARCHVO().getLoanDtFr().substring(0, 6)         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanDtTo         (inVo.getBDLDLM02DSSEARCHVO().getLoanDtTo().substring(0, 6)         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setMngDeptCd        (inVo.getBDLDLM02DSSEARCHVO().getMngDeptCd()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setPrdtLrgeMidClasCd(inVo.getBDLDLM02DSSEARCHVO().getPrdtLrgeMidClasCd());
        loanTmbyWdrwRsltReptDSSEARCHDto.setThmmComgTimsFr   (inVo.getBDLDLM02DSSEARCHVO().getThmmComgTimsFr()   );
        loanTmbyWdrwRsltReptDSSEARCHDto.setThmmComgTimsTo   (inVo.getBDLDLM02DSSEARCHVO().getThmmComgTimsTo()   );
        loanTmbyWdrwRsltReptDSSEARCHDto.setBndDivsEmpNo     (inVo.getBDLDLM02DSSEARCHVO().getBndDivsEmpNo()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setMngPlcDivCd      (inVo.getBDLDLM02DSSEARCHVO().getMngPlcDivCd()      );
        loanTmbyWdrwRsltReptDSSEARCHDto.setPrdtSmClasCd     (inVo.getBDLDLM02DSSEARCHVO().getPrdtSmClasCd()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setDlyTcntFr        (inVo.getBDLDLM02DSSEARCHVO().getDlyTcntFr()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setDlyTcntTo        (inVo.getBDLDLM02DSSEARCHVO().getDlyTcntTo()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setSetlDdFr         (inVo.getBDLDLM02DSSEARCHVO().getSetlDdFr()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setSetlDdTo         (inVo.getBDLDLM02DSSEARCHVO().getSetlDdTo()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanNo           (inVo.getBDLDLM02DSSEARCHVO().getLoanNo()           ); // 대출_번호
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanSeq          (inVo.getBDLDLM02DSSEARCHVO().getLoanSeq()          ); // 대출_순번


        /**************************************************
         * ■ Call 회수실적현황 조회
         **************************************************/
        List<LoanTmbyWdrwRsltReptDSSDDO01DTO> resultDTO =
                    loanTmbyWdrwRsltReptMapper.loanTmbyWdrwRsltReptSearch(loanTmbyWdrwRsltReptDSSEARCHDto);


        /**************************************************
         * □ 회수실적현황 LOOP처리
         **************************************************/
        for (LoanTmbyWdrwRsltReptDSSDDO01DTO reptIO : resultDTO) {
            BDLDLM02DSSDDO01VO bdldlM02DSSDDO01Vo = new BDLDLM02DSSDDO01VO();

            bdldlM02DSSDDO01Vo.setMngDeptNm             (reptIO.getMngDeptNm()                ); // 관리_부서_명
            bdldlM02DSSDDO01Vo.setBndDivsEmpNm          (reptIO.getBndDivsEmpNm()             );
            bdldlM02DSSDDO01Vo.setBndDivsEmpNo          (reptIO.getBndDivsEmpNo()             );
            bdldlM02DSSDDO01Vo.setSetlDt                (reptIO.getSetlDt()                   ); // 결제_일자
            bdldlM02DSSDDO01Vo.setcDlyTcnt              (reptIO.getcDlyTcnt()                 ); //
            bdldlM02DSSDDO01Vo.setoObjCnt               (reptIO.getoObjCnt()                  ); //
            bdldlM02DSSDDO01Vo.setoDlyCnt               (reptIO.getoDlyCnt()                  ); //
            bdldlM02DSSDDO01Vo.setoDlyAmt               (reptIO.getoDlyAmt()                  ); //
            bdldlM02DSSDDO01Vo.setoWdrwObjAmt           (reptIO.getoWdrwObjAmt()              ); //
            bdldlM02DSSDDO01Vo.setoWdrwRsltAmt          (reptIO.getoWdrwRsltAmt()             ); //
            bdldlM02DSSDDO01Vo.setoWdrwRate             (reptIO.getoWdrwRate()                ); //
            bdldlM02DSSDDO01Vo.setoLoanPamtRamt         (reptIO.getoLoanPamtRamt()            ); //
            bdldlM02DSSDDO01Vo.setoLoanRamt             (reptIO.getoLoanRamt()                ); //
            bdldlM02DSSDDO01Vo.setoYojuBadDebtApprAmt   (reptIO.getoYojuBadDebtApprAmt()      ); //
            bdldlM02DSSDDO01Vo.settObjCnt               (reptIO.gettObjCnt()                  ); //
            bdldlM02DSSDDO01Vo.settDlyCnt               (reptIO.gettDlyCnt()                  ); //
            bdldlM02DSSDDO01Vo.settDlyAmt               (reptIO.gettDlyAmt()                  ); //
            bdldlM02DSSDDO01Vo.settWdrwObjAmt           (reptIO.gettWdrwObjAmt()              ); //
            bdldlM02DSSDDO01Vo.settWdrwRsltAmt          (reptIO.gettWdrwRsltAmt()             ); //
            bdldlM02DSSDDO01Vo.settWdrwRate             (reptIO.gettWdrwRate()                ); //
            bdldlM02DSSDDO01Vo.settLoanPamtRamt         (reptIO.gettLoanPamtRamt()            ); //
            bdldlM02DSSDDO01Vo.settLoanRamt             (reptIO.gettLoanRamt()                ); //
            bdldlM02DSSDDO01Vo.settYojuBadDebtApprAmt   (reptIO.gettYojuBadDebtApprAmt()      ); //
            bdldlM02DSSDDO01Vo.setObjCnt                (reptIO.getObjCnt()                   ); //
            bdldlM02DSSDDO01Vo.setDlyCnt                (reptIO.getDlyCnt()                   ); //
            bdldlM02DSSDDO01Vo.setDlyAmt                (reptIO.getDlyAmt()                   ); //
            bdldlM02DSSDDO01Vo.setWdrwObjAmt            (reptIO.getWdrwObjAmt()               ); //
            bdldlM02DSSDDO01Vo.setWdrwRsltAmt           (reptIO.getWdrwRsltAmt()              ); //
            bdldlM02DSSDDO01Vo.setWdrwRate              (reptIO.getWdrwRate()                 ); //
            bdldlM02DSSDDO01Vo.setLoanPamtRamt          (reptIO.getLoanPamtRamt()             ); // 대출_원금_잔액
            bdldlM02DSSDDO01Vo.setLoanRamt              (reptIO.getLoanRamt()                 ); // 대출_잔액
            bdldlM02DSSDDO01Vo.setYojuBadDebtApprAmt    (reptIO.getYojuBadDebtApprAmt()       );
            bdldlM02DSSDDO01Vo.setDeptChng              (reptIO.getDeptChng()                 ); // 부서체크를 위함

            resultList.add(bdldlM02DSSDDO01Vo);
        }

        /** 입금약속자명세 화면 출력 결과값 대입 */
        resultVo.setBDLDLM02DSSDDO01VOList(resultList);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBDLDLM02S01 : 결제일자별 명세서 조회
     * 작성일자      : 2023. 3. 23.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 결제일자별 명세서를 조회 한다.
     * 메소드인수    : BDLDLM02S01InVO
     * 메소드리턴값  : BDLDLM02S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BDLDLM02S02OutVO getBDLDLM02S02(BDLDLM02S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY getBDLDLM02S02 Start..}");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BDLDLM02S02OutVO                resultVo                            = new BDLDLM02S02OutVO();
        LoanTmbyWdrwRsltReptDSSEARCHDTO loanTmbyWdrwRsltReptDSSEARCHDto     = new LoanTmbyWdrwRsltReptDSSEARCHDTO();
        List<BDLDLM02DSSDDO02VO>        resultList                          = new ArrayList<BDLDLM02DSSDDO02VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkMngDeptCd     (inVo.getBDLDLM02DSSEARCHVO().getChkMngDeptCd()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkBndDivsEmpNo  (inVo.getBDLDLM02DSSEARCHVO().getChkBndDivsEmpNo()  );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkSetlDd        (inVo.getBDLDLM02DSSEARCHVO().getChkSetlDd()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setChkDlyTcnt       (inVo.getBDLDLM02DSSEARCHVO().getChkDlyTcnt()       );
        loanTmbyWdrwRsltReptDSSEARCHDto.setStndDt           (inVo.getBDLDLM02DSSEARCHVO().getStndDt()           );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanDtFr         (inVo.getBDLDLM02DSSEARCHVO().getLoanDtFr()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanDtTo         (inVo.getBDLDLM02DSSEARCHVO().getLoanDtTo()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setMngDeptCd        (inVo.getBDLDLM02DSSEARCHVO().getMngDeptCd()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setPrdtLrgeMidClasCd(inVo.getBDLDLM02DSSEARCHVO().getPrdtLrgeMidClasCd());
        loanTmbyWdrwRsltReptDSSEARCHDto.setThmmComgTimsFr   (inVo.getBDLDLM02DSSEARCHVO().getThmmComgTimsFr()   );
        loanTmbyWdrwRsltReptDSSEARCHDto.setThmmComgTimsTo   (inVo.getBDLDLM02DSSEARCHVO().getThmmComgTimsTo()   );
        loanTmbyWdrwRsltReptDSSEARCHDto.setBndDivsEmpNo     (inVo.getBDLDLM02DSSEARCHVO().getBndDivsEmpNo()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setMngPlcDivCd      (inVo.getBDLDLM02DSSEARCHVO().getMngPlcDivCd()      );
        loanTmbyWdrwRsltReptDSSEARCHDto.setPrdtSmClasCd     (inVo.getBDLDLM02DSSEARCHVO().getPrdtSmClasCd()     );
        loanTmbyWdrwRsltReptDSSEARCHDto.setDlyTcntFr        (inVo.getBDLDLM02DSSEARCHVO().getDlyTcntFr()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setDlyTcntTo        (inVo.getBDLDLM02DSSEARCHVO().getDlyTcntTo()        );
        loanTmbyWdrwRsltReptDSSEARCHDto.setSetlDdFr         (inVo.getBDLDLM02DSSEARCHVO().getSetlDdFr()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setSetlDdTo         (inVo.getBDLDLM02DSSEARCHVO().getSetlDdTo()         );
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanNo           (inVo.getBDLDLM02DSSEARCHVO().getLoanNo()           ); // 대출_번호
        loanTmbyWdrwRsltReptDSSEARCHDto.setLoanSeq          (inVo.getBDLDLM02DSSEARCHVO().getLoanSeq()          ); // 대출_순번


        /**************************************************
         * ■ Call 결제일자별 명세서 조회
         **************************************************/
        List<LoanTmbyWdrwRsltSpecDSSDDO02DTO> resultDTO =
                    loanTmbyWdrwRsltReptMapper.loanTmbyWdrwRsltSpecSearch(loanTmbyWdrwRsltReptDSSEARCHDto);


        /**************************************************
         * □ 명세서 LOOP처리
         **************************************************/
        for (LoanTmbyWdrwRsltSpecDSSDDO02DTO specIO : resultDTO) {
            BDLDLM02DSSDDO02VO bdldlM02DSSDDO02Vo = new BDLDLM02DSSDDO02VO();

            bdldlM02DSSDDO02Vo.setBndDivsEmpNm         (specIO.getBndDivsEmpNm      ())    ;
            bdldlM02DSSDDO02Vo.setLoanNo               (specIO.getLoanNo            ())    ; // 대출_번호
            bdldlM02DSSDDO02Vo.setCustNm               (specIO.getCustNm            ())    ; // 고객_명
            bdldlM02DSSDDO02Vo.setCustTpNm             (specIO.getCustTpNm          ())    ; // 고객_유형_명
            bdldlM02DSSDDO02Vo.setFrstDlyDt            (specIO.getFrstDlyDt         ())    ;
            bdldlM02DSSDDO02Vo.setDlyTcnt              (specIO.getDlyTcnt           ())    ;
            bdldlM02DSSDDO02Vo.setDlyAmt               (specIO.getDlyAmt            ())    ;
            bdldlM02DSSDDO02Vo.setLoanPamt             (specIO.getLoanPamt          ())    ; // 대출_원금
            bdldlM02DSSDDO02Vo.setLoanDt               (specIO.getLoanDt            ())    ; // 대출_일자
            bdldlM02DSSDDO02Vo.setLoanTerm             (specIO.getLoanTerm          ())    ; // 대출_기간
            bdldlM02DSSDDO02Vo.setThmmComgTims         (specIO.getThmmComgTims      ())    ;
            bdldlM02DSSDDO02Vo.setLoanPamtRamt         (specIO.getLoanPamtRamt      ())    ; // 대출_원금_잔액
            bdldlM02DSSDDO02Vo.setLoanRamt             (specIO.getLoanRamt          ())    ; // 대출_잔액
            bdldlM02DSSDDO02Vo.setSetlDd               (specIO.getSetlDd            ())    ; // 결제_일
            bdldlM02DSSDDO02Vo.setDueMethCd            (specIO.getDueMethCd         ())    ;
            bdldlM02DSSDDO02Vo.setWdrwObjAmt           (specIO.getWdrwObjAmt        ())    ;
            bdldlM02DSSDDO02Vo.setWdrwRsltAmt          (specIO.getWdrwRsltAmt       ())    ;
            bdldlM02DSSDDO02Vo.setUnrcvAmt             (specIO.getUnrcvAmt          ())    ;
            bdldlM02DSSDDO02Vo.setEprtDt               (specIO.getEprtDt            ())    ; // 만기_일자
            bdldlM02DSSDDO02Vo.setRcntSetlDt           (specIO.getRcntSetlDt        ())    ;
            bdldlM02DSSDDO02Vo.setRcntSetlAmt          (specIO.getRcntSetlAmt       ())    ;
            bdldlM02DSSDDO02Vo.setRegDt                (specIO.getRegDt             ())    ;
            bdldlM02DSSDDO02Vo.setDivsManEmpNm         (specIO.getDivsManEmpNm      ())    ;
            bdldlM02DSSDDO02Vo.setVsitDt               (specIO.getVsitDt            ())    ;
            bdldlM02DSSDDO02Vo.setInvtRsltCd           (specIO.getInvtRsltCd        ())    ;
            bdldlM02DSSDDO02Vo.setIntvManNm            (specIO.getIntvManNm         ())    ;
            bdldlM02DSSDDO02Vo.setMrtgSmYn             (specIO.getMrtgSmYn          ())    ;
            bdldlM02DSSDDO02Vo.setCrdtStatNm           (specIO.getCrdtStatNm        ())    ;
            bdldlM02DSSDDO02Vo.setNiceDlyCnt           (specIO.getNiceDlyCnt        ())    ;
            bdldlM02DSSDDO02Vo.setNiceDlyAmt           (specIO.getNiceDlyAmt        ())    ;
            bdldlM02DSSDDO02Vo.setAsetSondTpClasNm     (specIO.getAsetSondTpClasNm  ())    ;
            bdldlM02DSSDDO02Vo.setBadDebtApprAmt       (specIO.getBadDebtApprAmt    ())    ;
            bdldlM02DSSDDO02Vo.setPrdtLrgeMidClasNm    (specIO.getPrdtLrgeMidClasNm ())    ;
            bdldlM02DSSDDO02Vo.setPrdtSmClasNm         (specIO.getPrdtSmClasNm      ())    ;
            bdldlM02DSSDDO02Vo.setPrdtNm               (specIO.getPrdtNm            ())    ;
            bdldlM02DSSDDO02Vo.setMrtgSmClasNm         (specIO.getMrtgSmClasNm      ())    ;
            bdldlM02DSSDDO02Vo.setGodsNm               (specIO.getGodsNm            ())    ;
            bdldlM02DSSDDO02Vo.setLnDivsEmpNm          (specIO.getLnDivsEmpNm       ())    ;
            bdldlM02DSSDDO02Vo.setMngPlcBndDivsEmpNm   (specIO.getMngPlcBndDivsEmpNm())    ;
            bdldlM02DSSDDO02Vo.setMngDeptNm            (specIO.getMngDeptNm         ())    ;
            bdldlM02DSSDDO02Vo.setMngPlcDivCd          (specIO.getMngPlcDivCd       ())    ;

            resultList.add(bdldlM02DSSDDO02Vo);
        }

        resultVo.setBDLDLM02DSSDDO02VOList(resultList);

        return resultVo;
    }

}

