package hanalife.b.dl.dl.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.dl.dl.service.BDLDLM01Service;
import hanalife.b.dl.dl.vo.BDLDLM01DSSMDOVO;
import hanalife.b.dl.dl.vo.BDLDLM01S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM01Controller.java Class
 * 클래스설명   : 연체현황조회 (BDLDLM01) Controller
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/dl/dl")
@Controller
public class BDLDLM01Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM01Controller.class);

    @Autowired
    private BDLDLM01Service BDLDLM01Service;

    /**
     * <pre>
     * 메소드명        : 연체현황(부서별)조회 /BDLDLM01S01.do
     * 작성일자        : 2023. 2. 27.
     * 작성자(author)  : 70317
     * 설명            : 연체현황(부서별)조회 한다.
     * 예외처리        : Exception
     * </pre>
     */
    @RequestMapping("/BDLDLM01S01.do")
    public String BDLDLM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM01S01 Start..");

        try {
            /**************************************************
             * □ 초기선언
             **************************************************/
            BDLDLM01DSSMDOVO    dsSMDOInVo  = new BDLDLM01DSSMDOVO();
            BDLDLM01S01InVO     InVO        = new BDLDLM01S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceDsSMDOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);
            LOGGER.debug("{PSY} sourceDsSMDOMap : "+ sourceDsSMDOMap.toString());


            /**************************************************
             * □ Input Data Set
             **************************************************/
            BeanUtil.mapToBean(sourceDsSMDOMap, dsSMDOInVo);

            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            InVO.setBDLDLM01DSSMDOVO(dsSMDOInVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */


            /**************************************************
             * ■ Call 연체현황목록조회
             **************************************************/
            BDLDLM01S01OutVO resultListVo = BDLDLM01Service.getBDLDLM01S01(InVO);


            /**************************************************
             * □ 결과값 화면으로 Return
             **************************************************/
            // 연체현황목록조회(부서별) DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_SDDO01", resultListVo.getListBDLDLM01DSSDDO01VO(), model);

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <pre>
     * 메소드명        : 연체현황(상품별)목록조회 /BDLDLM01S02.do
     * 작성일자        : 2023. 2. 27.
     * 작성자(author)  : 70317
     * 설명            : 연체현황(상품별)목록조회 한다.
     * 예외처리        : Exception
     * </pre>
     */
    @RequestMapping("/BDLDLM01S02.do")
    public String BDLDLM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM01S02 Start..");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceDsSMDOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

            /** 연체현황목록조회 조회 DataSet 항목값 VO 객체 입력값 대입 */
            BDLDLM01DSSMDOVO dsSMDOInVo = new BDLDLM01DSSMDOVO();
            dsSMDOInVo.setSrchOpt((String) sourceDsSMDOMap.get("srchOpt")); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
            dsSMDOInVo.setStndDt((String) sourceDsSMDOMap.get("stndDt")); /** 기준일 */
            dsSMDOInVo.setMngDeptCd((String) sourceDsSMDOMap.get("mngDeptCd")); /** 관리부서 */
            dsSMDOInVo.setSetlDdFr((String) sourceDsSMDOMap.get("setlDdFr")); /** 결제일(시작) */
            dsSMDOInVo.setSetlDdTo((String) sourceDsSMDOMap.get("setlDdTo")); /** 결제일(종료) */
            dsSMDOInVo.setBndDivsEmpNoFg((String) sourceDsSMDOMap.get("bndDivsEmpNoFg")); /** 담당자구분 */
            dsSMDOInVo.setDivsEmpNo((String) sourceDsSMDOMap.get("divsEmpNo")); /** 담당자번호 */
            dsSMDOInVo.setDlyTcntFr((String) sourceDsSMDOMap.get("dlyTcntFr")); /** 연체회차(시작) */
            dsSMDOInVo.setDlyTcntTo((String) sourceDsSMDOMap.get("dlyTcntTo")); /** 연체회자(종료) */
            dsSMDOInVo.setPrdtLrgeClasCd((String) sourceDsSMDOMap.get("prdtLrgeClasCd")); /** 상품대분류 */
            dsSMDOInVo.setThmmComgTimsFr((String) sourceDsSMDOMap.get("thmmComgTimsFr")); /** 도래회차(시작) */
            dsSMDOInVo.setThmmComgTimsTo((String) sourceDsSMDOMap.get("thmmComgTimsTo")); /** 도래회차(종료) */
            dsSMDOInVo.setLoanNo((String) sourceDsSMDOMap.get("loanNo")); /** 대출번호 */
            dsSMDOInVo.setLoanSeq((String) sourceDsSMDOMap.get("loanSeq")); /** 대출순번 */
            dsSMDOInVo.setDlyDdCntFr((String) sourceDsSMDOMap.get("dlyDdCntFr")); /** 연체일수(시작) */
            dsSMDOInVo.setDlyDdCntTo((String) sourceDsSMDOMap.get("dlyDdCntTo")); /** 연체일수(종료) */
            dsSMDOInVo.setPrdtSmClasCd((String) sourceDsSMDOMap.get("prdtSmClasCd")); /** 상품소분류 */
            dsSMDOInVo.setPrdtCd((String) sourceDsSMDOMap.get("prdtCd")); /** 상품코드 */
            dsSMDOInVo.setChkMmstrBfmm((String) sourceDsSMDOMap.get("chkMmstrBfmm")); /** 월초(전월말)여부 */
            dsSMDOInVo.setNewReflFg((String) sourceDsSMDOMap.get("newReflFg")); /** 대출확정여부 */
            dsSMDOInVo.setLoanPamtRamtFr((String) sourceDsSMDOMap.get("loanPamtRamtFr")); /** 대출상환원금(시작) */
            dsSMDOInVo.setLoanPamtRamtTo((String) sourceDsSMDOMap.get("loanPamtRamtTo")); /** 대출상환원금(종료) */
            dsSMDOInVo.setIvltClosExpt((String) sourceDsSMDOMap.get("ivltClosExpt")); /** 강제해지여부 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BDLDLM01S01InVO InVO = new BDLDLM01S01InVO();
            InVO.setBDLDLM01DSSMDOVO(dsSMDOInVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

            /** 연체현황목록조회 업무 서비스 호출 수행 */
            BDLDLM01S01OutVO resultListVo = BDLDLM01Service.getBDLDLM01S02(InVO);

            /** 연체현황목록조회(상품별) DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO02", resultListVo.getListBDLDLM01DSSDDO02VO(), model);

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S02 Normal End #####");
        }
        catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S02 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <pre>
     * 메소드명         : 연체현황(담당자별)조회 /BDLDLM01S03.do
     * 작성일자         : 2023. 2. 27.
     * 작성자(author)   : 70317
     * 설명             : 연체현황(담당자별)조회 한다.
     * 예외처리         : Exception
     * </pre>
     */
    @RequestMapping("/BDLDLM01S03.do")
    public String BDLDLM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM01S03 Start..");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceDsSMDOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

            /** 연체현황목록조회 조회 DataSet 항목값 VO 객체 입력값 대입 */
            BDLDLM01DSSMDOVO dsSMDOInVo = new BDLDLM01DSSMDOVO();
            dsSMDOInVo.setSrchOpt((String) sourceDsSMDOMap.get("srchOpt")); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
            dsSMDOInVo.setStndDt((String) sourceDsSMDOMap.get("stndDt")); /** 기준일 */
            dsSMDOInVo.setMngDeptCd((String) sourceDsSMDOMap.get("mngDeptCd")); /** 관리부서 */
            dsSMDOInVo.setSetlDdFr((String) sourceDsSMDOMap.get("setlDdFr")); /** 결제일(시작) */
            dsSMDOInVo.setSetlDdTo((String) sourceDsSMDOMap.get("setlDdTo")); /** 결제일(종료) */
            dsSMDOInVo.setBndDivsEmpNoFg((String) sourceDsSMDOMap.get("bndDivsEmpNoFg")); /** 담당자구분 */
            dsSMDOInVo.setDivsEmpNo((String) sourceDsSMDOMap.get("divsEmpNo")); /** 담당자번호 */
            dsSMDOInVo.setDlyTcntFr((String) sourceDsSMDOMap.get("dlyTcntFr")); /** 연체회차(시작) */
            dsSMDOInVo.setDlyTcntTo((String) sourceDsSMDOMap.get("dlyTcntTo")); /** 연체회자(종료) */
            dsSMDOInVo.setPrdtLrgeClasCd((String) sourceDsSMDOMap.get("prdtLrgeClasCd")); /** 상품대분류 */
            dsSMDOInVo.setThmmComgTimsFr((String) sourceDsSMDOMap.get("thmmComgTimsFr")); /** 도래회차(시작) */
            dsSMDOInVo.setThmmComgTimsTo((String) sourceDsSMDOMap.get("thmmComgTimsTo")); /** 도래회차(종료) */
            dsSMDOInVo.setLoanNo((String) sourceDsSMDOMap.get("loanNo")); /** 대출번호 */
            dsSMDOInVo.setLoanSeq((String) sourceDsSMDOMap.get("loanSeq")); /** 대출순번 */
            dsSMDOInVo.setDlyDdCntFr((String) sourceDsSMDOMap.get("dlyDdCntFr")); /** 연체일수(시작) */
            dsSMDOInVo.setDlyDdCntTo((String) sourceDsSMDOMap.get("dlyDdCntTo")); /** 연체일수(종료) */
            dsSMDOInVo.setPrdtSmClasCd((String) sourceDsSMDOMap.get("prdtSmClasCd")); /** 상품소분류 */
            dsSMDOInVo.setPrdtCd((String) sourceDsSMDOMap.get("prdtCd")); /** 상품코드 */
            dsSMDOInVo.setChkMmstrBfmm((String) sourceDsSMDOMap.get("chkMmstrBfmm")); /** 월초(전월말)여부 */
            dsSMDOInVo.setNewReflFg((String) sourceDsSMDOMap.get("newReflFg")); /** 대출확정여부 */
            dsSMDOInVo.setLoanPamtRamtFr((String) sourceDsSMDOMap.get("loanPamtRamtFr")); /** 대출상환원금(시작) */
            dsSMDOInVo.setLoanPamtRamtTo((String) sourceDsSMDOMap.get("loanPamtRamtTo")); /** 대출상환원금(종료) */
            dsSMDOInVo.setIvltClosExpt((String) sourceDsSMDOMap.get("ivltClosExpt")); /** 강제해지여부 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BDLDLM01S01InVO InVO = new BDLDLM01S01InVO();
            InVO.setBDLDLM01DSSMDOVO(dsSMDOInVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

            /** 연체현황목록조회 업무 서비스 호출 수행 */
            BDLDLM01S01OutVO resultListVo = BDLDLM01Service.getBDLDLM01S03(InVO);

            /** 연체현황목록조회(담당자별) DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO03", resultListVo.getListBDLDLM01DSSDDO03VO(), model);

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S03 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S03 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <pre>
     * 메소드명         : 연체현황(명세)목록조회 /BDLDLM01S04.do
     * 작성일자         : 2023. 2. 27.
     * 작성자(author)   : 70317
     * 설명             : 연체현황(명세)목록조회 한다.
     * 예외처리         : Exception
     * </pre>
     */
    @RequestMapping("/BDLDLM01S04.do")
    public String BDLDLM01S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM01S04 Start..");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceDsSMDOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

            /** 연체현황목록조회 조회 DataSet 항목값 VO 객체 입력값 대입 */
            BDLDLM01DSSMDOVO dsSMDOInVo = new BDLDLM01DSSMDOVO();
            dsSMDOInVo.setSrchOpt((String) sourceDsSMDOMap.get("srchOpt")); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
            dsSMDOInVo.setStndDt((String) sourceDsSMDOMap.get("stndDt")); /** 기준일 */
            dsSMDOInVo.setMngDeptCd((String) sourceDsSMDOMap.get("mngDeptCd")); /** 관리부서 */
            dsSMDOInVo.setSetlDdFr((String) sourceDsSMDOMap.get("setlDdFr")); /** 결제일(시작) */
            dsSMDOInVo.setSetlDdTo((String) sourceDsSMDOMap.get("setlDdTo")); /** 결제일(종료) */
            dsSMDOInVo.setBndDivsEmpNoFg((String) sourceDsSMDOMap.get("bndDivsEmpNoFg")); /** 담당자구분 */
            dsSMDOInVo.setDivsEmpNo((String) sourceDsSMDOMap.get("divsEmpNo")); /** 담당자번호 */
            dsSMDOInVo.setDlyTcntFr((String) sourceDsSMDOMap.get("dlyTcntFr")); /** 연체회차(시작) */
            dsSMDOInVo.setDlyTcntTo((String) sourceDsSMDOMap.get("dlyTcntTo")); /** 연체회자(종료) */
            dsSMDOInVo.setPrdtLrgeClasCd((String) sourceDsSMDOMap.get("prdtLrgeClasCd")); /** 상품대분류 */
            dsSMDOInVo.setThmmComgTimsFr((String) sourceDsSMDOMap.get("thmmComgTimsFr")); /** 도래회차(시작) */
            dsSMDOInVo.setThmmComgTimsTo((String) sourceDsSMDOMap.get("thmmComgTimsTo")); /** 도래회차(종료) */
            dsSMDOInVo.setLoanNo((String) sourceDsSMDOMap.get("loanNo")); /** 대출번호 */
            dsSMDOInVo.setLoanSeq((String) sourceDsSMDOMap.get("loanSeq")); /** 대출순번 */
            dsSMDOInVo.setDlyDdCntFr((String) sourceDsSMDOMap.get("dlyDdCntFr")); /** 연체일수(시작) */
            dsSMDOInVo.setDlyDdCntTo((String) sourceDsSMDOMap.get("dlyDdCntTo")); /** 연체일수(종료) */
            dsSMDOInVo.setPrdtSmClasCd((String) sourceDsSMDOMap.get("prdtSmClasCd")); /** 상품소분류 */
            dsSMDOInVo.setPrdtCd((String) sourceDsSMDOMap.get("prdtCd")); /** 상품코드 */
            dsSMDOInVo.setChkMmstrBfmm((String) sourceDsSMDOMap.get("chkMmstrBfmm")); /** 월초(전월말)여부 */
            dsSMDOInVo.setNewReflFg((String) sourceDsSMDOMap.get("newReflFg")); /** 대출확정여부 */
            dsSMDOInVo.setLoanPamtRamtFr((String) sourceDsSMDOMap.get("loanPamtRamtFr")); /** 대출상환원금(시작) */
            dsSMDOInVo.setLoanPamtRamtTo((String) sourceDsSMDOMap.get("loanPamtRamtTo")); /** 대출상환원금(종료) */
            dsSMDOInVo.setIvltClosExpt((String) sourceDsSMDOMap.get("ivltClosExpt")); /** 강제해지여부 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BDLDLM01S01InVO InVO = new BDLDLM01S01InVO();
            InVO.setBDLDLM01DSSMDOVO(dsSMDOInVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

            /** 연체현황목록조회 업무 서비스 호출 수행 */
            BDLDLM01S01OutVO resultListVo = BDLDLM01Service.getBDLDLM01S04(InVO);

            /** 연체현황목록조회(명세) DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO04", resultListVo.getListBDLDLM01DSSDDO04VO(), model);

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S04 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### BDLDLM01Controller BDLDLM01S04 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}