package hanalife.b.dl.dl.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.dl.dl.service.BDLDLM02Service;
import hanalife.b.dl.dl.vo.BDLDLM02DSSEARCHVO;
import hanalife.b.dl.dl.vo.BDLDLM02S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM02S01OutVO;
import hanalife.b.dl.dl.vo.BDLDLM02S02OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM02Controller.java Class
 * 클래스설명   : BDLDLM02Controller Controller
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/dl/dl")
@Controller
public class BDLDLM02Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM02Controller.class);

    @Autowired
    private BDLDLM02Service bdldlM02Service;

    /**
     *<pre>
     * 메소드명      : 결제일자별 회수실적현황조회 /BDLDLM02S01.do
     * 작성일자      : 2023. 3. 17.
     * 작성자(author): 70331
     * 설명          : 결제일자별 회수실적현황조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BDLDLM02S01.do")
    public String BDLDLM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM02S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BDLDLM02DSSEARCHVO  inVo            = new BDLDLM02DSSEARCHVO();
            BDLDLM02S01InVO     bdldlM02S01InVO = new BDLDLM02S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setChkSetlDd        ((String) sourceMap.get("chkSetlDd"))          ;
            inVo.setChkMngDeptCd     ((String) sourceMap.get("chkMngDeptCd"));
            inVo.setChkBndDivsEmpNo  ((String) sourceMap.get("chkBndDivsEmpNo"))    ;
            inVo.setChkDlyTcnt       ((String) sourceMap.get("chkDlyTcnt"))         ;
            inVo.setStndDt           ((String) sourceMap.get("stndDt"))             ;
            inVo.setLoanDtFr         ((String) sourceMap.get("loanDtFr"))           ;
            inVo.setLoanDtTo         ((String) sourceMap.get("loanDtTo"))           ;
            inVo.setMngDeptCd        ((String) sourceMap.get("mngDeptCd"))          ;
            inVo.setPrdtLrgeMidClasCd((String) sourceMap.get("prdtLrgeMidClasCd"))  ;
            inVo.setThmmComgTimsFr   ((String) sourceMap.get("thmmComgTimsFr"))     ;
            inVo.setThmmComgTimsTo   ((String) sourceMap.get("thmmComgTimsTo"))     ;
            inVo.setBndDivsEmpNo     ((String) sourceMap.get("bndDivsEmpNo"))       ;
            inVo.setMngPlcDivCd      ((String) sourceMap.get("mngPlcDivCd"))        ;
            inVo.setPrdtSmClasCd     ((String) sourceMap.get("prdtSmClasCd"))       ;
            inVo.setDlyTcntFr        ((String) sourceMap.get("dlyTcntFr"))          ;
            inVo.setDlyTcntTo        ((String) sourceMap.get("dlyTcntTo"))          ;
            inVo.setSetlDdFr         ((String) sourceMap.get("setlDdFr"))           ; // 결제_일
            inVo.setSetlDdTo         ((String) sourceMap.get("setlDdTo"))           ; // 결제_일
            inVo.setLoanNo           ((String) sourceMap.get("loanNo"))             ; // 대출_번호
            inVo.setLoanSeq          ((String) sourceMap.get("loanSeq"))            ; // 대출_순번


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bdldlM02S01InVO.setBDLDLM02DSSEARCHVO(inVo);


            /**************************************************
             * ■ Call 결제일자별 회수실적현황 조회
             **************************************************/
            BDLDLM02S01OutVO resultListVo = bdldlM02Service.getBDLDLM02S01(bdldlM02S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_REPT", resultListVo.getBDLDLM02DSSDDO01VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 결제일자별 명세서 조회 /BDLDLM02S02.do
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70317
     * 설명          : 결제일자별 명세서를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BDLDLM02S02.do")
    public String BDLDLM02S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM02S02 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BDLDLM02DSSEARCHVO  inVo            = new BDLDLM02DSSEARCHVO();
            BDLDLM02S01InVO     bdldlM02S01InVO = new BDLDLM02S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setChkSetlDd        ((String) sourceMap.get("chkSetlDd"))          ;
            inVo.setChkMngDeptCd     ((String) sourceMap.get("chkMngDeptCd"))       ;
            inVo.setChkBndDivsEmpNo  ((String) sourceMap.get("chkBndDivsEmpNo"))    ;
            inVo.setChkDlyTcnt       ((String) sourceMap.get("chkDlyTcnt"))         ;
            inVo.setStndDt           ((String) sourceMap.get("stndDt"))             ;
            inVo.setLoanDtFr         ((String) sourceMap.get("loanDtFr"))           ;
            inVo.setLoanDtTo         ((String) sourceMap.get("loanDtTo"))           ;
            inVo.setMngDeptCd        ((String) sourceMap.get("mngDeptCd"))          ;
            inVo.setPrdtLrgeMidClasCd((String) sourceMap.get("prdtLrgeMidClasCd"))  ;
            inVo.setThmmComgTimsFr   ((String) sourceMap.get("thmmComgTimsFr"))     ;
            inVo.setThmmComgTimsTo   ((String) sourceMap.get("thmmComgTimsTo"))     ;
            inVo.setBndDivsEmpNo     ((String) sourceMap.get("bndDivsEmpNo"))       ;
            inVo.setMngPlcDivCd      ((String) sourceMap.get("mngPlcDivCd"))        ;
            inVo.setPrdtSmClasCd     ((String) sourceMap.get("prdtSmClasCd"))       ;
            inVo.setDlyTcntFr        ((String) sourceMap.get("dlyTcntFr"))          ;
            inVo.setDlyTcntTo        ((String) sourceMap.get("dlyTcntTo"))          ;
            inVo.setSetlDdFr         ((String) sourceMap.get("setlDdFr"))           ; // 결제_일
            inVo.setSetlDdTo         ((String) sourceMap.get("setlDdTo"))           ; // 결제_일
            inVo.setLoanNo           ((String) sourceMap.get("loanNo"))             ; // 대출_번호
            inVo.setLoanSeq          ((String) sourceMap.get("loanSeq"))            ; // 대출_순번


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bdldlM02S01InVO.setBDLDLM02DSSEARCHVO(inVo);


            /**************************************************
             * ■ Call 결제일자별 명세서 조회
             **************************************************/
            BDLDLM02S02OutVO resultListVo = bdldlM02Service.getBDLDLM02S02(bdldlM02S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SPEC", resultListVo.getBDLDLM02DSSDDO02VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
