package hanalife.b.dl.dl.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.dl.dl.service.BDLDLM03Service;
import hanalife.b.dl.dl.vo.BDLDLM03DSSMDOVO;
import hanalife.b.dl.dl.vo.BDLDLM03S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM03S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM03Controller.java Class
 * 클래스설명   : BDLDLM03Controller Controller
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/dl/dl")
@Controller
public class BDLDLM03Controller {

    @Autowired
    private BDLDLM03Service bdldlM03Service;

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM03Controller.class);

    /** ASIS와 동일하게 조회구분 상수값 정의 */
    private static final int FIND_DEPT = 0;  // 부서별 검색
    private static final int FIND_PRDT = 1;  // 상품별 검색
    private static final int FIND_EMP  = 2;  // 담당자별 검색
    private static final int FIND_SPEC = 3;  // 명세 검색

    /**
     *<pre>
     * 메소드명      : 연체회차별현황 목록 조회 / BDLDLM03S01.do
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70317
     * 설명          : 연체회차별현황 목록을 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BDLDLM03S01.do")
    public String BDLDLM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BDLDLM03S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BDLDLM03DSSMDOVO  inVo            = new BDLDLM03DSSMDOVO();
            BDLDLM03S01InVO   bdldlM03S01InVo = new BDLDLM03S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setSrchOpt       ((String) sourceMap.get("srchOpt"         ));
            inVo.setStndDt        ((String) sourceMap.get("stndDt"          )); // 기준일
            inVo.setMngDeptCd     ((String) sourceMap.get("mngDeptCd"       )); // 관리부서
            inVo.setAsetSondTp    ((String) sourceMap.get("asetSondTp"      )); // 자산건전성
            inVo.setBndDivsEmpNoFg((String) sourceMap.get("bndDivsEmpNoFg"  )); // 담당자구분(채권/여신)
            inVo.setDivsEmpNo     ((String) sourceMap.get("divsEmpNo"       )); // 담당자
            inVo.setPrdtLrgeClasCd((String) sourceMap.get("prdtLrgeClasCd"  )); // 상품대분류
            inVo.setSetlDdFr      ((String) sourceMap.get("setlDdFr"        )); // 결제일
            inVo.setSetlDdTo      ((String) sourceMap.get("setlDdTo"        ));
            inVo.setDlyTcntFr     ((String) sourceMap.get("dlyTcntFr"       )); // 연체회차
            inVo.setDlyTcntTo     ((String) sourceMap.get("dlyTcntTo"       ));
            inVo.setLoanNo        ((String) sourceMap.get("loanNo"          )); // 대출번호
            inVo.setLoanSeq       ((String) sourceMap.get("loanSeq"         )); // 대출순번
            inVo.setPrdtSmClasCd  ((String) sourceMap.get("prdtSmClasCd"    )); // 상품소분류
            inVo.setReptCd        ((String) sourceMap.get("reptCd"          )); // 물품구분
            inVo.setThmmComgTimsFr((String) sourceMap.get("thmmComgTimsFr"  )); // 도래회차
            inVo.setThmmComgTimsTo((String) sourceMap.get("thmmComgTimsTo"  ));


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bdldlM03S01InVo.setBDLDLM03DSSMDOVO(inVo);


            /**************************************************
             * ■ Call 연체회차별현황 목록 조회
             **************************************************/
            BDLDLM03S01OutVO resultVo = bdldlM03Service.getBDLDLM03S01(bdldlM03S01InVo);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            // 화면에서 넘어온 조회구분값으로 분기처리
            int srchOpt = Integer.parseInt(inVo.getSrchOpt());
            switch(srchOpt) {
                case FIND_DEPT : // 부서별 목록 조회
                    XFrame5Util.setOutputData("DS_SDDO01", resultVo.getBDLDLM03DSSDDO01VOList(), model);
                    break;

                case FIND_PRDT : // 상품별 목록 조회
                    XFrame5Util.setOutputData("DS_SDDO02", resultVo.getBDLDLM03DSSDDO02VOList(), model);
                    break;

                case FIND_EMP :  // 담당자별 목록 조회
                    XFrame5Util.setOutputData("DS_SDDO03", resultVo.getBDLDLM03DSSDDO03VOList(), model);
                    break;

                case FIND_SPEC : // 명세 목록 조회
                    XFrame5Util.setOutputData("DS_SDDO04", resultVo.getBDLDLM03DSSDDO04VOList(), model);
                    break;

                default :
                    throw new IllegalStateException("검색옵션이 유효하지 않습니다. : [" + srchOpt + "]");
            }

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}