package hanalife.b.lm.lm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.lm.lm.mapper.LoanByActnDescMngMapper;
import hanalife.b.lm.lm.mapper.dto.LoanByActnDescMngDSBTLEGLACTNCOSTSDDODTO;
import hanalife.b.lm.lm.mapper.dto.LoanByActnDescMngSDDO01DTO;
import hanalife.b.lm.lm.mapper.dto.LoanByActnDescMngSDDO02DTO;
import hanalife.b.lm.lm.mapper.dto.LoanByActnDescMngSDDO03DTO;
import hanalife.b.lm.lm.mapper.dto.LoanByActnDescMngSMDO01DTO;
import hanalife.b.lm.lm.service.BLMLMM04Service;
import hanalife.b.lm.lm.vo.BLMLMM04DSBTLEGLACTNCOSTSDDOVO;
import hanalife.b.lm.lm.vo.BLMLMM04DSSDDO01VO;
import hanalife.b.lm.lm.vo.BLMLMM04DSSDDO02VO;
import hanalife.b.lm.lm.vo.BLMLMM04DSSDDO03VO;
import hanalife.b.lm.lm.vo.BLMLMM04S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BLMLMM04ServiceImpl.java Class
 * 클래스설명   : todo1 (todo0) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70326 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : gettodo0S01 : todo1목록조회
 *              registertodo0I01 : todo1등록
 *              modifytodo0U01 : todo1수정
 *              removetodo0U01 : todo1삭제
 * </pre>
 */
@Service("BLMLMM04Service")
public class BLMLMM04ServiceImpl implements BLMLMM04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM04ServiceImpl.class);

	 @Autowired
	 private LoanByActnDescMngMapper loanByActnDescMngMapper;

	/**
	 * <p>메소드명      : getBLMLM04S01 : 상단의 대출내역 원금/대출기간/사건번호 목록조회</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author):
	 * <p>설명          : 상단의 대출내역 원금/대출기간/사건번호 목록을 조회 한다.</p>
	 * <p>메소드인수    : BLMLMM04S01InVO </p>
	 * <p>메소드리턴값  : BLMLMM04S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BLMLMM04S01OutVO getBLMLM04S01(BLMLMM04S01InVO inVo) throws Exception {

		/** 법조치 상단의 대출내역 원금/대출기간/사건번호 서비스 결과값 객체 생성 */
		BLMLMM04S01OutVO resultVo = new BLMLMM04S01OutVO();

		/** 법조치 상단의 대출내역 원금/대출기간/사건번호 조회 조건 입력값 객체 생성 및 대입 수행 */
		LoanByActnDescMngSMDO01DTO i01Dto = new LoanByActnDescMngSMDO01DTO();

		i01Dto.setLoanNo(inVo.getBLMLMM04DSSMDO01VO().getLoanNo());		/** 대출번호 */
		i01Dto.setLoanSeq(inVo.getBLMLMM04DSSMDO01VO().getLoanSeq());	/** 대출순번 */
		i01Dto.setCustNo(inVo.getBLMLMM04DSSMDO01VO().getCustNo());		/** 고객번호 */
		LOGGER.debug("고객번호 : " + i01Dto.getCustNo());

		/** 상단의 대출내역 원금/대출기간/사건번호 조회 쿼리 Mapper 호출 수행 */
        List<LoanByActnDescMngSDDO01DTO> resultDTO = loanByActnDescMngMapper.search(i01Dto);

        /** 상단의 대출내역 원금/대출기간/사건번호 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BLMLMM04DSSDDO01VO> resultList = new ArrayList<BLMLMM04DSSDDO01VO>();

        for (LoanByActnDescMngSDDO01DTO sourceIO : resultDTO) {
            /** 상단의 대출내역 원금/대출기간/사건번호 VO에 조회된 Mapper DTO 값을 대입 */
        	BLMLMM04DSSDDO01VO targetIO = new BLMLMM04DSSDDO01VO();

            targetIO.setLoanNo(sourceIO.getLoanNo()); 				/** 대출번호 */
            targetIO.setLoanSeq(sourceIO.getLoanSeq()); 			/** 대출순번 */
            targetIO.setCustNm(sourceIO.getCustNm()); 				/** 고객명 */
            targetIO.setActnTpCd(sourceIO.getActnTpCd()); 			/** 조치유형코드 */
            targetIO.setActnTpNm(sourceIO.getActnTpNm()); 			/** 조치유형명 */
            targetIO.setCaseNo(sourceIO.getCaseNo()); 				/** 사건번호 */
            targetIO.setThmmComgTims(sourceIO.getThmmComgTims()); 	/** 도래회차 */
            targetIO.setLoanPamt(sourceIO.getLoanPamt()); 			/** 대출원금 */
            targetIO.setLoanTerm(sourceIO.getLoanTerm()); 			/** 대출기간 */
            targetIO.setDlyTcnt(sourceIO.getDlyTcnt()); 			/** 연체회차 */
            targetIO.setPrdtNm(sourceIO.getPrdtNm()); 				/** 상품명 */
            targetIO.setDlyAmt(sourceIO.getDlyAmt()); 				/** 연체금액 */
            targetIO.setRmbrFrmlNm(sourceIO.getRmbrFrmlNm()); 		/** 최초연체일 */
            targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); 		/** 관리부서 */
            targetIO.setLoanAmtRamt(sourceIO.getLoanAmtRamt()); 	/** 채권잔액 */
            targetIO.setBndStatNm(sourceIO.getBndStatNm()); 		/** 채권상태명 */
            targetIO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm());	/** 채권담당자명 */
            targetIO.setRelCaseNo(sourceIO.getRelCaseNo()); 		/** 관련사건번호 */
            targetIO.setConsShNo(sourceIO.getConsShNo()); 			/** 품의번호 */
            targetIO.setSpayAmt(sourceIO.getSpayAmt()); 			/**  */
            targetIO.setLoanPamtRamt(sourceIO.getLoanPamtRamt()); 	/** 대출원금잔액 */
            targetIO.setCustNo(sourceIO.getCustNo()); 				/** 고객번호 */
            targetIO.setLoanStatNm(sourceIO.getLoanStatNm()); 		/** 대출상태명 */
            targetIO.setBndMngPlcCd(sourceIO.getBndMngPlcCd()); 	/** 관리부처 */
            targetIO.setLnDivsEmpNo(sourceIO.getLnDivsEmpNo()); 	/** 여신담당자 */

            /** 상단의 대출내역 원금/대출기간/사건번호 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
            LOGGER.debug("impl 대출원금" + resultList.get(0).getLoanPamt());
        }

        resultVo.setBLMLMM04DSSDDO01VO(resultList);

		return resultVo;
	}

	/**
	 * <p>메소드명      : getBLMLM04S02 : 법적조치 그리드 목록조회</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author):
	 * <p>설명          : 법적조치 그리드 목록을 조회 한다.</p>
	 * <p>메소드인수    : BLMLMM04S01InVO </p>
	 * <p>메소드리턴값  : BLMLMM04S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BLMLMM04S01OutVO getBLMLM04S02(BLMLMM04S01InVO inVo) throws Exception {

		/** 법적조치 그리드 서비스 결과값 객체 생성 */
		BLMLMM04S01OutVO resultVo = new BLMLMM04S01OutVO();

		/** 법적조치 그리드 조회 조건 입력값 객체 생성 및 대입 수행 */
		LoanByActnDescMngSMDO01DTO i02Dto = new LoanByActnDescMngSMDO01DTO();

		i02Dto.setLoanNo(inVo.getBLMLMM04DSSMDO01VO().getLoanNo());		/** 대출번호 */
		i02Dto.setLoanSeq(inVo.getBLMLMM04DSSMDO01VO().getLoanSeq());	/** 대출순번 */
		i02Dto.setCustNo(inVo.getBLMLMM04DSSMDO01VO().getCustNo());		/** 고객번호 */

		/** 법적조치 그리드 조회 쿼리 Mapper 호출 수행 */
        List<LoanByActnDescMngSDDO02DTO> resultDTO = loanByActnDescMngMapper.searchQuarantors(i02Dto);

        /** 법적조치 그리드 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BLMLMM04DSSDDO02VO> resultList = new ArrayList<BLMLMM04DSSDDO02VO>();

        for (LoanByActnDescMngSDDO02DTO sourceIO : resultDTO) {
            /** 법적조치 그리드 VO에 조회된 Mapper DTO 값을 대입 */
        	BLMLMM04DSSDDO02VO targetIO = new BLMLMM04DSSDDO02VO();

            targetIO.setCustNm(sourceIO.getCustNm()); 			/** 고객명 */
            targetIO.setCustNo(sourceIO.getCustNo()); 			/** 고객번호 */
            targetIO.setLoanRelNm(sourceIO.getLoanRelNm()); 	/** 관계 */
            targetIO.setOffcNm(sourceIO.getOffcNm()); 			/** 직장명 */
            targetIO.setLoanCnt(sourceIO.getLoanCnt()); 		/** 대출건수 */
            targetIO.setBadCnt(sourceIO.getBadCnt()); 			/** 불량건수 */
            targetIO.setBadAmt(sourceIO.getBadAmt()); 			/** 불량금액 */

            /** 법적조치 그리드 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        resultVo.setBLMLMM04DSSDDO02VO(resultList);

		return resultVo;
	}

	/**
	 * <p>메소드명      : getBLMLM04S03 : 법적조치 그리드 목록조회</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author):
	 * <p>설명          : 법적조치 그리드 목록을 조회 한다.</p>
	 * <p>메소드인수    : BLMLMM04S01InVO </p>
	 * <p>메소드리턴값  : BLMLMM04S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BLMLMM04S01OutVO getBLMLM04S03(BLMLMM04S01InVO inVo) throws Exception {

		/** 법적조치 그리드 서비스 결과값 객체 생성 */
		BLMLMM04S01OutVO resultVo = new BLMLMM04S01OutVO();

		/** 법적조치 그리드 조회 조건 입력값 객체 생성 및 대입 수행 */
		LoanByActnDescMngSMDO01DTO i03Dto = new LoanByActnDescMngSMDO01DTO();

		i03Dto.setLoanNo(inVo.getBLMLMM04DSSMDO01VO().getLoanNo());		/** 대출번호 */
		i03Dto.setLoanSeq(inVo.getBLMLMM04DSSMDO01VO().getLoanSeq());	/** 대출순번 */
		i03Dto.setCustNo(inVo.getBLMLMM04DSSMDO01VO().getCustNo());		/** 고객번호 */

		/** 법적조치 그리드 조회 쿼리 Mapper 호출 수행 */
        List<LoanByActnDescMngSDDO03DTO> resultDTO = loanByActnDescMngMapper.searchLoanActns(i03Dto);

        /** 법적조치 그리드 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BLMLMM04DSSDDO03VO> resultList = new ArrayList<BLMLMM04DSSDDO03VO>();

        for (LoanByActnDescMngSDDO03DTO sourceIO : resultDTO) {
            /** 법적조치 그리드 VO에 조회된 Mapper DTO 값을 대입 */
        	BLMLMM04DSSDDO03VO targetIO = new BLMLMM04DSSDDO03VO();

        	targetIO.setConsDt(sourceIO.getConsDt()); 					/** 품의일자 */
            targetIO.setCustNm(sourceIO.getCustNm()); 					/** 고객명 */
            targetIO.setActnTpNm(sourceIO.getActnTpNm()); 				/** 조치유형명 */
            targetIO.setPrptKindNm(sourceIO.getPrptKindNm()); 			/** 물건종류명 */
            targetIO.setCaseNo(sourceIO.getCaseNo()); 					/** 사건번호 */
            targetIO.setActnStatNm(sourceIO.getActnStatNm()); 			/** 조치상태명 */
            targetIO.setActnStatOccrDt(sourceIO.getActnStatOccrDt()); 	/** 조치상태일 */
            targetIO.setDistCortCd(sourceIO.getDistCortCd()); 			/** 법원명 */
            targetIO.setGodsInfo(sourceIO.getGodsInfo()); 				/** 물건정보 */

            /** 법적조치 그리드 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        resultVo.setBLMLMM04DSSDDO03VO(resultList);

		return resultVo;
	}

	/**
	 * <p>메소드명      : getBLMLM04S04 : 법적조치 비용 그리드 목록조회</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author):
	 * <p>설명          : 법적조치비용 그리드 목록을 조회 한다.</p>
	 * <p>메소드인수    : BLMLMM04S01InVO </p>
	 * <p>메소드리턴값  : BLMLMM04S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BLMLMM04S01OutVO getBLMLM04S04(BLMLMM04S01InVO inVo) throws Exception {

		/** 법적조치비용 그리드 서비스 결과값 객체 생성 */
		BLMLMM04S01OutVO resultVo = new BLMLMM04S01OutVO();

		/** 법적조치비용 그리드 조회 조건 입력값 객체 생성 및 대입 수행 */
		LoanByActnDescMngSMDO01DTO i04Dto = new LoanByActnDescMngSMDO01DTO();

		i04Dto.setLoanNo(inVo.getBLMLMM04DSSMDO01VO().getLoanNo());		/** 대출번호 */
		i04Dto.setLoanSeq(inVo.getBLMLMM04DSSMDO01VO().getLoanSeq());	/** 대출순번 */
		i04Dto.setCustNo(inVo.getBLMLMM04DSSMDO01VO().getCustNo());		/** 고객번호 */

		/** 법적조치비용 그리드 조회 쿼리 Mapper 호출 수행 */
        List<LoanByActnDescMngDSBTLEGLACTNCOSTSDDODTO> resultDTO = loanByActnDescMngMapper.searchLeglActnCost(i04Dto);

        /** 법적조치비용 그리드 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BLMLMM04DSBTLEGLACTNCOSTSDDOVO> resultList = new ArrayList<BLMLMM04DSBTLEGLACTNCOSTSDDOVO>();

        for (LoanByActnDescMngDSBTLEGLACTNCOSTSDDODTO sourceIO : resultDTO) {
            /** 법적조치비용 그리드 VO에 조회된 Mapper DTO 값을 대입 */
        	BLMLMM04DSBTLEGLACTNCOSTSDDOVO targetIO = new BLMLMM04DSBTLEGLACTNCOSTSDDOVO();

        	targetIO.setLoanNo(sourceIO.getLoanNo()); 			/**  */
            targetIO.setLoanSeq(sourceIO.getLoanSeq()); 		/**  */
            targetIO.setCustNo(sourceIO.getCustNo()); 			/**  */
            targetIO.setCustNm(sourceIO.getCustNm()); 			/**  */
            targetIO.setConsDt(sourceIO.getConsDt()); 			/**  */
            targetIO.setConsShNo(sourceIO.getConsShNo()); 		/**  */
            targetIO.setActnTpNm(sourceIO.getActnTpNm()); 		/**  */
            targetIO.setAskAmt(sourceIO.getAskAmt()); 			/**  */
            targetIO.setVochNo(sourceIO.getVochNo()); 			/**  */
            targetIO.setAskDt(sourceIO.getAskDt()); 			/**  */
            targetIO.setDepsAmt(sourceIO.getDepsAmt()); 		/**  */
            targetIO.setEtcCost(sourceIO.getEtcCost()); 		/**  */
            targetIO.setSetlDt(sourceIO.getSetlDt()); 			/**  */
            targetIO.setRcptAmt(sourceIO.getRcptAmt()); 		/**  */
            targetIO.setAmt(sourceIO.getAmt()); 				/**  */
            targetIO.setLoanRelNm(sourceIO.getLoanRelNm()); 	/**  */

            /** 법적조치비용 그리드 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }
        resultVo.setBLMLMM04DSBTLEGLACTNCOSTSDDOVO(resultList);

		return resultVo;
	}
}
