package hanalife.b.lm.lm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.lm.lm.mapper.LeglActsFnshSpecMapper;
import hanalife.b.lm.lm.mapper.dto.LeglActsFnshSpecDSSDDO01DTO;
import hanalife.b.lm.lm.mapper.dto.LeglActsFnshSpecDSSMDODTO;
import hanalife.b.lm.lm.service.BLMLMM05Service;
import hanalife.b.lm.lm.vo.BLMLMM05DSSDDO01VO;
import hanalife.b.lm.lm.vo.BLMLMM05S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM05S01OutVO;

/**
 * <pre>
 * 클래스명    : BLMLMM05ServiceImpl.java Class
 * 클래스설명  : 법조치진행현황조회 (BLMLMM05) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 09
 * 작성자명    : 70281 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 09.][70281 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("BLMLMM05Service")
public class BLMLMM05ServiceImpl implements BLMLMM05Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM05ServiceImpl.class);

	@Autowired
	private LeglActsFnshSpecMapper leglActsFnshSpecMapper;

	/**
	 * <p>메소드명      : BLMLMM05S01 : 법조치진행현황내역조회</p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317 / younghwe.kim
	 * <p>설명          : 법조치진행현황내역을 조회 한다.</p>
	 * <p>메소드인수    : BLMLMM05S01InVo </p>
	 * <p>메소드리턴값  : BLMLMM05S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@SuppressWarnings("unchecked")
	@Override
	public BLMLMM05S01OutVO getBLMLMM05S01(BLMLMM05S01InVO inVo) throws Exception {

		BLMLMM05S01OutVO resultVo = new BLMLMM05S01OutVO();

		// 법조치진행현황내역 조회
		LeglActsFnshSpecDSSMDODTO inDto = new LeglActsFnshSpecDSSMDODTO();
		inDto.setDeptCd(			inVo.getBLMLMM05DSSMDOVO().getDeptCd());			/* 관리부서코드 */
		inDto.setActnTpCd(			inVo.getBLMLMM05DSSMDOVO().getActnTpCd());			/* 조치유형코드 */
		inDto.setEmpNo(				inVo.getBLMLMM05DSSMDOVO().getEmpNo());				/* 채권담당자번호 */
		inDto.setCaseNoUnRegFg(		inVo.getBLMLMM05DSSMDOVO().getCaseNoUnRegFg());		/* 사건번호미등록건유무 */
		inDto.setTpCd(				inVo.getBLMLMM05DSSMDOVO().getTpCd());				/* 날짜유형코드 */
		inDto.setFromDt(			inVo.getBLMLMM05DSSMDOVO().getFromDt());			/* 시작일자 */
		inDto.setToDt(				inVo.getBLMLMM05DSSMDOVO().getToDt());				/* 종료일자 */
		inDto.setLoanNo(			inVo.getBLMLMM05DSSMDOVO().getLoanNo());			/* 대출번호 */
		inDto.setLoanSeq(			inVo.getBLMLMM05DSSMDOVO().getLoanSeq());			/* 대출번호순번 */
		inDto.setRsltDlyTimsStrt(	inVo.getBLMLMM05DSSMDOVO().getRsltDlyTimsStrt());	/* 시작연체회차 */
		inDto.setRsltDlyTimsEnd(	inVo.getBLMLMM05DSSMDOVO().getRsltDlyTimsEnd());	/* 종료연체회차 */
		inDto.setLoanStatCdFg(		inVo.getBLMLMM05DSSMDOVO().getLoanStatCdFg());		/* 대출진행여부 */
		inDto.setActnStatCd(		inVo.getBLMLMM05DSSMDOVO().getActnStatCd());		/* 조치상태코드 */
		inDto.setRelCaseNo(			inVo.getBLMLMM05DSSMDOVO().getRelCaseNo());			/* 사건번호 */
		inDto.setCustNo(			inVo.getBLMLMM05DSSMDOVO().getCustNo());			/* 고객번호 */

		List<LeglActsFnshSpecDSSDDO01DTO> leglActsFnshSpecDTO = leglActsFnshSpecMapper.searchLeglActsFnshSpecList(inDto);

		List<BLMLMM05DSSDDO01VO> resultList = new ArrayList<BLMLMM05DSSDDO01VO>();

		if(leglActsFnshSpecDTO != null) {
			for( LeglActsFnshSpecDSSDDO01DTO outDTO :  leglActsFnshSpecDTO ) {
				BLMLMM05DSSDDO01VO sddoVo = new BLMLMM05DSSDDO01VO();

				sddoVo.setLoanNo(outDTO.getLoanNo());
				sddoVo.setLoanSeq(outDTO.getLoanSeq());
				sddoVo.setContManNm(outDTO.getContManNm());
				sddoVo.setCustNm(outDTO.getCustNm());
				sddoVo.setLoanRelNm(outDTO.getLoanRelNm());
				sddoVo.setActnTpNm(outDTO.getActnTpNm());
				sddoVo.setActnStatNm(outDTO.getActnStatNm());
				sddoVo.setActnStatOccrDt(outDTO.getActnStatOccrDt());
				sddoVo.setCaseNo(outDTO.getCaseNo());
				sddoVo.setDistCortNm(outDTO.getDistCortNm());
				sddoVo.setCaseDivsDept(outDTO.getCaseDivsDept());
				sddoVo.setRelCaseNo(outDTO.getRelCaseNo());
				sddoVo.setLwstKindNm(outDTO.getLwstKindNm());
				sddoVo.setPledSeq(outDTO.getPledSeq());
				sddoVo.setTndrDd(outDTO.getTndrDd());
				sddoVo.setAlotDd(outDTO.getAlotDd());
				sddoVo.setPledDt(outDTO.getPledDt());
				sddoVo.setCaseEndDt(outDTO.getCaseEndDt());
				sddoVo.setEndTpNm(outDTO.getEndTpNm());
				sddoVo.setConsDt(outDTO.getConsDt());
				sddoVo.setMngDeptNm(outDTO.getMngDeptNm());
				sddoVo.setLnDivsEmpNm(outDTO.getLnDivsEmpNm());
				sddoVo.setConsShNo(outDTO.getConsShNo());
				sddoVo.setCustNo(outDTO.getCustNo());
				sddoVo.setLawCostAskAmt(outDTO.getLawCostAskAmt());
				sddoVo.setLawCostAdjAmt(outDTO.getLawCostAdjAmt());
				sddoVo.setLawCostRamt(outDTO.getLawCostRamt());
				sddoVo.setBndOldNewFg(outDTO.getBndOldNewFg());
				sddoVo.setBndDivsEmpNo(outDTO.getBndDivsEmpNo());
				sddoVo.setBndDivsManEmpNo(outDTO.getBndDivsManEmpNo());
				sddoVo.setLoanStatCd(outDTO.getLoanStatCd());
				sddoVo.setDlyTcnt(outDTO.getDlyTcnt());
				sddoVo.setDlyAmt(outDTO.getDlyAmt());
				sddoVo.setLoanRamt(outDTO.getLoanRamt());
				sddoVo.setPrptKindNm(outDTO.getPrptKindNm());
				sddoVo.setPrdtNm(outDTO.getPrdtNm());
				sddoVo.setCaseKindNm(outDTO.getCaseKindNm());
				sddoVo.setCrimTpLrgeClasNm(outDTO.getCrimTpLrgeClasNm());
				sddoVo.setCrimTpClasCd(outDTO.getCrimTpClasCd());
				sddoVo.setLoanStatNm(outDTO.getLoanStatNm());

				/** 법조치진행현황내역 List 객체에 추가하도록 수행 */
				resultList.add(sddoVo);
			}
		}

		resultVo.setBLMLMM05DSSDDO01VO(resultList);

		return resultVo;
	}

}
