package hanalife.b.lm.lm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.lm.lm.service.BLMLMM01Service;
import hanalife.b.lm.lm.vo.BLMLMM01DSSMDOVO;
import hanalife.b.lm.lm.vo.BLMLMM01S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: BLMLMM01Controller.java Class
 * 클래스설명	: 법조치품의승인목록조회 (BLMLMM01) Controller
 * 작성일자	: 2023. 3. 6.
 * 작성자명	: 70305 / bhansuk.ko / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/lm/lm")
@Controller
public class BLMLMM01Controller {

	@Resource(name = "BLMLMM01Service")
	private BLMLMM01Service BLMLMM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM01Controller.class);

	/**
	 * <p>메소드명			: 법조치품의승인내역조회 /BLMLMM01S01.do </p>
	 * <p>작성일자			: 2023. 2. 27.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: 법조치품의승인내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
	@RequestMapping("/BLMLMM01S01.do")
	public String BLMLMM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM01Controller BLMLMM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			LOGGER.info("##### BLMLMM01Controller BLMLMM01S01 추출 #####");
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			/** 법조치품의승인내역 조회 업무 서비스 호출 입력값 대입 */
			BLMLMM01DSSMDOVO dsSMDOInVo = new BLMLMM01DSSMDOVO();
			dsSMDOInVo.setConsFromDt((String) sourceMap.get("consFromDt"));     /* 품의시작일자 */
			dsSMDOInVo.setConsToDt((String)   sourceMap.get("consToDt"));       /* 품의종료일자 */
			dsSMDOInVo.setDeptCd((String)     sourceMap.get("deptCd"));         /* 관리부서코드 */
			dsSMDOInVo.setTpCd((String)       sourceMap.get("tpCd"));           /* 조회구분코드 */
			dsSMDOInVo.setReadCntn((String)   sourceMap.get("readCntn"));       /* 조회구분내용 */

			LOGGER.info("##### inVO = " + dsSMDOInVo.getTpCd() );

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BLMLMM01S01InVO InVO = new BLMLMM01S01InVO();
			/** 법조치품의승인내역조회 DS_SMDO 입력값 VO 객체 대입 */
			InVO.setBLMLMM01DSSMDOVO(dsSMDOInVo);

			/** 법조치품의승인내역 조회 업무 서비스 호출 수행 */
			BLMLMM01S01OutVO resultListVo = BLMLMM01.getBLMLMM01S01(InVO);

			/** 법조치품의승인내역 조회 DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_SDDO", resultListVo.getListBLMLMM01DSSDDO01VO(), model); // 법조치품의승인내역조회

			LOGGER.info("##### BLMLMM01Controller BLMLMM01S01 Normal End #####");

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BLMLMM01Controller BLMLMM01S01 Exception End #####");

		}

		LOGGER.info("##### BLMLMM01Controller BLMLMM01S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

}
