package hanalife.b.lm.lm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.lm.lm.service.BLMLMM04Service;
import hanalife.b.lm.lm.vo.BLMLMM04DSSMDO01VO;
import hanalife.b.lm.lm.vo.BLMLMM04S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM04S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BLMLMM04Controller.java Class
 * 클래스설명   : 법조치 상태/비용조회 Controller
 * 작성일자     : 2023. 3. 9.
 * 작성자명     :  / YouHyunSik / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][ ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/lm/lm")
@Controller
public class BLMLMM04Controller {

	@Resource(name = "BLMLMM04Service")
	private BLMLMM04Service BLMLMM04;

	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM04Controller.class);

	/**
	 * <p>메소드명      : BLMLMM04S01조회 / BLMLMM04S01.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): YouHyunSik
	 * <p>설명          : 상단의 대출내역 원금/대출기간/사건번호등을 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BLMLMM04S01.do")
	public String BLMLMM04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM04Controller BLMLMM04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);

			/** 상단 대출내역 원금/대출기간/사건번호 등 조회 서비스 호출 입력값 대입 */
			BLMLMM04DSSMDO01VO dsSMDOInVo = new BLMLMM04DSSMDO01VO();
			dsSMDOInVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
			dsSMDOInVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
			dsSMDOInVo.setCustNo((String) sourceMap.get("custNo"));      /** 고객번호 */
			LOGGER.debug(" 고객번호 : " + dsSMDOInVo.getCustNo());

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BLMLMM04S01InVO InVO = new BLMLMM04S01InVO();
            InVO.setBLMLMM04DSSMDO01VO(dsSMDOInVo);	/** 상단의 대출내역 원금/대출기간/사건번호 등 DS_SMDO 입력값 VO 객체 대입 */

            /** 상단의 대출내역 원금/대출기간/사건번호 등 업무 서비스 호출 수행 */
            BLMLMM04S01OutVO resultListVo = BLMLMM04.getBLMLM04S01(InVO);
            if(resultListVo.getBLMLMM04DSSDDO01VO().size() > 0) {
            	LOGGER.debug(" 대출원금 : " + resultListVo.getBLMLMM04DSSDDO01VO().get(0).getLoanPamt());
            	XFrame5Util.setOutputData("DS_SDDO01", resultListVo.getBLMLMM04DSSDDO01VO(), model);
            }
            /** 상단의 대출내역 원금/대출기간/사건번호 등 DataSet 결과값 설정 */

            LOGGER.info("##### BLMLMM04Controller BDLDLM01S01 Normal End #####");

		} catch (Exception e) {

			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BLMLMM04Controller Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : BLMLMM04S02조회 / BLMLMM04S02.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): YouHyunSik
	 * <p>설명          : 상단 오른쪽의 관계/고객명/고객번호등을 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BLMLMM04S02.do")
	public String BLMLMM04S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM04Controller BLMLMM04S02 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);

			/** 상단 오른쪽의 관계/고객명/고객번호 등 조회 서비스 호출 입력값 대입 */
			BLMLMM04DSSMDO01VO dsSMDOInVo = new BLMLMM04DSSMDO01VO();
			dsSMDOInVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
			dsSMDOInVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
			dsSMDOInVo.setCustNo((String) sourceMap.get("custNo"));      /** 고객번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BLMLMM04S01InVO InVO = new BLMLMM04S01InVO();
            InVO.setBLMLMM04DSSMDO01VO(dsSMDOInVo);	/** 상단 오른쪽의 관계/고객명/고객번호 등 DS_SMDO 입력값 VO 객체 대입 */

            /** 상단 오른쪽의 관계/고객명/고객번호 등 업무 서비스 호출 수행 */
            BLMLMM04S01OutVO resultListVo = BLMLMM04.getBLMLM04S02(InVO);

            /** 상단 오른쪽의 관계/고객명/고객번호 등 DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO02", resultListVo.getBLMLMM04DSSDDO02VO(), model);

            LOGGER.info("##### BLMLMM04Controller BLMLMM01S02 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BLMLMM04Controller Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : BLMLMM04S03조회 / BLMLMM04S03.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): YouHyunSik
	 * <p>설명          : 법적조치 그리드 조회내용을 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BLMLMM04S03.do")
	public String BLMLMM04S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM04Controller BLMLMM04S03 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);

			/** 법적조치 그리드 조회 서비스 호출 입력값 대입 */
			BLMLMM04DSSMDO01VO dsSMDOInVo = new BLMLMM04DSSMDO01VO();
			dsSMDOInVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
			dsSMDOInVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
			dsSMDOInVo.setCustNo((String) sourceMap.get("custNo"));      /** 고객번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BLMLMM04S01InVO InVO = new BLMLMM04S01InVO();
            InVO.setBLMLMM04DSSMDO01VO(dsSMDOInVo);	/** 법적조치 그리드 등 DS_SMDO 입력값 VO 객체 대입 */

            /** 법적조치 그리드 업무 서비스 호출 수행 */
            BLMLMM04S01OutVO resultListVo = BLMLMM04.getBLMLM04S03(InVO);

            /** 법적조치 그리드 등 DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO03", resultListVo.getBLMLMM04DSSDDO03VO(), model);

            LOGGER.info("##### BLMLMM04Controller BLMLMM01S03 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BLMLMM04Controller Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : BLMLMM04S04조회 / BLMLMM04S04.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): YouHyunSik
	 * <p>설명          : 법적조치비용 그리드 조회내용을 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BLMLMM04S04.do")
	public String BLMLMM04S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM04Controller BLMLMM04S04 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);

			/** 법적조치비용 그리드 조회 서비스 호출 입력값 대입 */
			BLMLMM04DSSMDO01VO dsSMDOInVo = new BLMLMM04DSSMDO01VO();
			dsSMDOInVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
			dsSMDOInVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
			dsSMDOInVo.setCustNo((String) sourceMap.get("custNo"));      /** 고객번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BLMLMM04S01InVO InVO = new BLMLMM04S01InVO();
            InVO.setBLMLMM04DSSMDO01VO(dsSMDOInVo);	/** 법적조치비용 그리드 DS_SMDO 입력값 VO 객체 대입 */

            /** 법적조치비용 그리드 등 업무 서비스 호출 수행 */
            BLMLMM04S01OutVO resultListVo = BLMLMM04.getBLMLM04S04(InVO);

            /** 법적조치비용 그리드 등 DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_BTLEGLACTNCOST_SDDO", resultListVo.getBLMLMM04DSBTLEGLACTNCOSTSDDOVO(), model);

            LOGGER.info("##### BLMLMM04Controller BLMLMM01S04 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BLMLMM04Controller Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}
