package hanalife.b.vi.wd.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.vi.wd.service.BVIWDM01Service;
import hanalife.b.vi.wd.vo.BVIWDM01DSSDDO03VO;
import hanalife.b.vi.wd.vo.BVIWDM01DSSMDO01VO;
import hanalife.b.vi.wd.vo.BVIWDM01DSSMDO02VO;
import hanalife.b.vi.wd.vo.BVIWDM01DSSMDO03VO;
import hanalife.b.vi.wd.vo.BVIWDM01S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S01OutVO;
import hanalife.b.vi.wd.vo.BVIWDM01S02InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S02OutVO;
import hanalife.b.vi.wd.vo.BVIWDM01S03InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S03OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM01Controller.java Class
 * 클래스설명   : BVIWDM01Controller Controller
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/vi/wd")
@Controller
public class BVIWDM01Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM01Controller.class);

    @Autowired
    private BVIWDM01Service bviwd01Service;

    /**
     *<pre>
     * 메소드명      : 면담대상자리스트조회 / BVIWDM01S01.do
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70317
     * 설명          : 면담대상자리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM01S01.do")
    public String BVIWDM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM01S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM01DSSMDO01VO  inVo             = new BVIWDM01DSSMDO01VO();
            BVIWDM01S01InVO     bviwdM01S01InVo  = new BVIWDM01S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo          ((String) sourceMap.get("loanNo"            )); // 대출_번호
            inVo.setLoanSeq         ((String) sourceMap.get("loanSeq"           )); // 대출_순번
            inVo.setIntvObjManResiNo((String) sourceMap.get("intvObjManResiNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwdM01S01InVo.setBVIWDM01DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 면담대상자리스트조회
             **************************************************/
            BVIWDM01S01OutVO resultVo = bviwd01Service.getBVIWDM01S01(bviwdM01S01InVo);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO01", resultVo.getBVIWDM01DSSDDO01VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 면담내용리스트조회 / BVIWDM01S02.do
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331
     * 설명          : 면담내용리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM01S02.do")
    public String BVIWDM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM01S02 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM01DSSMDO02VO  inVo             = new BVIWDM01DSSMDO02VO();
            BVIWDM01S02InVO     bviwdM01S02InVo  = new BVIWDM01S02InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO02", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo          ((String) sourceMap.get("loanNo"            )); // 대출_번호
            inVo.setLoanSeq         ((String) sourceMap.get("loanSeq"           )); // 대출_순번
            inVo.setIntvObjManResiNo((String) sourceMap.get("intvObjManResiNo"  ));


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwdM01S02InVo.setBVIWDM01DSSMDO02VO(inVo);


            /**************************************************
             * ■ Call 면담내용자리스트조회
             **************************************************/
            BVIWDM01S02OutVO resultVo = bviwd01Service.getBVIWDM01S02(bviwdM01S02InVo);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO02", resultVo.getBVIWDM01DSSDDO02VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 면담조회 / BVIWDM01S03.do
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331
     * 설명          : 면담을 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM01S03.do")
    public String BVIWDM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM01S03 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM01DSSMDO03VO  inVo             = new BVIWDM01DSSMDO03VO();
            BVIWDM01S03InVO     bviwdM01S03InVo  = new BVIWDM01S03InVO   ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO03", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo            ((String) sourceMap.get("loanNo"              )); // 대출_번호
            inVo.setLoanSeq           ((String) sourceMap.get("loanSeq"             )); // 대출_순번
            inVo.setIntvObjManResiNo  ((String) sourceMap.get("intvObjManResiNo"    ));
            inVo.setVsitDt            ((String) sourceMap.get("vsitDt"              )); // 방문_일자
            inVo.setSnum              ((String) sourceMap.get("snum"                )); // 일련_번호
            inVo.setPlanSnum          ((String) sourceMap.get("planSnum"            ));


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwdM01S03InVo.setBVIWDM01DSSMDO03VO(inVo);


            /**************************************************
             * ■ Call 면담조회
             **************************************************/
            BVIWDM01S03OutVO resultVo = bviwd01Service.getBVIWDM01S03(bviwdM01S03InVo);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO03", resultVo.getBVIWDM01DSSDDO03VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 방문내용결과등록 /BVIWDM01I01.do
     * 작성일자      : 2023. 3. 29.
     * 작성자(author): 70331
     * 설명          : 방문내용결과등록 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM01I01.do")
    public String BVIWDM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("{PSY} BVIWDM01I01 Start..");

        try {
            /**************************************************
             * □ 적재할 항목 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO03", request, response, model);


            /**************************************************
             * □ 적재할 항목 Set
             **************************************************/
            BVIWDM01DSSDDO03VO targetVo = new BVIWDM01DSSDDO03VO();

            targetVo.setLoanNo          ((String) sourceMap.get("loanNo")); // 대출_번호
            targetVo.setLoanSeq         ((String) sourceMap.get("loanSeq")); // 대출_순번
            targetVo.setIntvManResiNo   ((String) sourceMap.get("intvManResiNo")); // 면담자_주민등록번호
            targetVo.setVsitDt          ((String) sourceMap.get("vistDt")); // 방문_일자
            // 일련번호 채번로직 필요
            //targetVo.setSnum            ((String) sourceMap.get("snum")); // 일련번호
            targetVo.setIntvEmpNo       ((String) sourceMap.get("intvEmpNo")); // 방문_사원_번호
            targetVo.setIntvManNm       ((String) sourceMap.get("intvManNm")); // 면담자_명
            targetVo.setRelCd           ((String) sourceMap.get("relCd")); // 관계_코드
            targetVo.setReroomFg        ((String) sourceMap.get("reroomFg")); // 면담_여부
            targetVo.setRsltSetlCd      ((String) sourceMap.get("rsltSetlCd")); // 결과_결제_코드
            targetVo.setIntvObjManResiNo((String) sourceMap.get("intvObjManResiNo")); // 면담_대상자_주민등록번호
            targetVo.setIntvPlanDt      ((String) sourceMap.get("intvPlanDt")); // 면담_계획_일자
            targetVo.setPlanSnum        ((String) sourceMap.get("planSnum")); // 계획_일련번호
            targetVo.setIntvObjCd       ((String) sourceMap.get("intvObjCd")); // 면담_목적_코드
            targetVo.setIntvRsltCd      ((String) sourceMap.get("intvRsltCd")); // 면담_결과_코드
            targetVo.setIntvPlcCd       ((String) sourceMap.get("intvPlcCd")); // 면담_장소_코드
            targetVo.setVsitAprvFg      ((String) sourceMap.get("vsitAprvFg")); // 방문_승인_여부
            targetVo.setIntvCntn        ((String) sourceMap.get("intvCntn")); // 면담_내용
            targetVo.setHafPlan         ((String) sourceMap.get("hafPlan")); // 향후_계획
            targetVo.setResiFg          ((String) sourceMap.get("resiFg")); // 거주_여부
            targetVo.setWhrbAmbgTpCd    ((String) sourceMap.get("whrbAmbgTpCd")); // 행불_유형_코드
            targetVo.setBsnIndcCntn     ((String) sourceMap.get("bsnIndcCntn")); // 업무_지시_내용
            targetVo.setPropExecPossFg  ((String) sourceMap.get("propExecPossFg")); // 동산_집행_가능_여부
            targetVo.setWdrwPossDoCd    ((String) sourceMap.get("wdrwPossDoCd")); // 회수_가능_도_코드
            targetVo.setZipCd           ((String) sourceMap.get("zipCd")); // 우편번호
            targetVo.setAddrCi          ((String) sourceMap.get("addrCi")); // 주소_시
            targetVo.setAddrGu          ((String) sourceMap.get("addrGu")); // 주소_구
            targetVo.setAddrDong        ((String) sourceMap.get("addrDong")); // 주소_동
            targetVo.setAddrSpec        ((String) sourceMap.get("addrSpec")); // 주소_상세
            targetVo.setMakeMan         ((String) sourceMap.get("makeMan")); // 작성자
            targetVo.setJstMan          ((String) sourceMap.get("jstMan")); // 결재자
            targetVo.setIntvObjManNm    ((String) sourceMap.get("intvObjManNm")); // 결재자
            targetVo.setLoanRelNm       ((String) sourceMap.get("loanRelNm")); // 결재자


            /**************************************************
             * ■ Call 방문내용결과 등록
             **************************************************/
            //int count = bviwd01Service.registerBVIWDM01I01(targetVo);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.debug("##### todo0Controller todo0I01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
