package hanalife.b.vi.wd.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.vi.wd.service.BVIWDM02Service;
import hanalife.b.vi.wd.vo.BVIWDM02DSSMDOVO;
import hanalife.b.vi.wd.vo.BVIWDM02S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM02S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM02Controller.java Class
 * 클래스설명   : BVIWDM02Controller Controller
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/vi/wd")
@Controller
public class BVIWDM02Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM02Controller.class);

    @Resource(name = "BVIWDM02Service")
    private BVIWDM02Service bviwd02Service;

    /**
     *<pre>
     * 메소드명      : 면담관리대장 리스트 조회 / BVIWDM02S01.do
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70317
     * 설명          : 면담관리대장 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM02S01.do")
    public String BVIWDM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM02S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM02DSSMDOVO    inVo             = new BVIWDM02DSSMDOVO();
            BVIWDM02S01InVO     bviwdM02S01InVo  = new BVIWDM02S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setMngDeptCd   ((String) sourceMap.get("mngDeptCd"      ));
            inVo.setBndDivsEmpNo((String) sourceMap.get("bndDivsEmpNo"   ));
            inVo.setIntvPlanSt  ((String) sourceMap.get("intvPlanSt"     ));
            inVo.setIntvPlanEd  ((String) sourceMap.get("intvPlanEd"     ));
            inVo.setIntvObjCd   ((String) sourceMap.get("intvObjCd"      ));


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwdM02S01InVo.setBVIWDM02DSSMDOVO(inVo);


            /**************************************************
             * ■ Call 대출내역정보 리스트 조회
             **************************************************/
            BVIWDM02S01OutVO resultVo = bviwd02Service.getBVIWDM02S01(bviwdM02S01InVo);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO", resultVo.getBVIWDM02DSSDDOVOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
