package hanalife.batch;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import hanalife.util.BizException;

/**
 * <pre>
 * 클래스명    : ProcSysDAOImpl
 * 클래스설명 : ProcSysDAOImpl
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class ProcSysDAOImpl {

	private ProcSysDAOImpl() {
	}

	public static ProcObj getBatchProcInfo(Connection con) throws Exception {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		try {
			String sql =
				"SELECT                                                            \n" +
				"    TO_CHAR(CURRENT_DATE ,'YYYYMMDD')                    PROC_DT,             \n" +
				"     TO_CHAR(CURRENT_DATE ,'HH24MISS')  PROC_TM,             \n" +
				//"    REPLACE(VARCHAR(CURRENT TIME - 5 minute), '.', '')  JOB_TM,  \n" + //2018-08-01 수정(분단위계산은 안함) 두비스
				 "     TO_CHAR(CURRENT_DATE ,'HH24MISS')  JOB_TM,             \n" +		 //2018-08-01 수정(분단위계산은 안함) 두비스
				"    CLAS1                                    ISRT_DEPT_CD,        \n" +
				"    CLAS2                                    ISRT_EMP_NO,         \n" +
				"    MARK_ODR                                 FETCH_CNT            \n" +
				"FROM DBSCOMM.CT_COMM_CD_DESC                                      \n" +
				"WHERE CD_KIND_NO = ?   /*R00038*/                                 \n" +
				"  AND CD_DESC_NO = ?   /*'1'      */                              \n" +
				"                                                           \n";
			//pstmt = new LoggableStatement(con, sql );
			pstmt = con.prepareStatement(sql);
				pstmt.setString(1, "R00038"); //공통코드 종류번호
				pstmt.setString(2, "1");
			rs = pstmt.executeQuery();

			if (rs.next()) {
				ProcObj procObj = new ProcObj();
					procObj.setProcDt(rs.getString("PROC_DT")); //시스템반영일자
					procObj.setProcTm(rs.getString("PROC_TM")); //시스템반영시간
					procObj.setJobDt(rs.getString("PROC_DT")); //작업_일자
					procObj.setJobTm(rs.getString("JOB_TM")); //작업_시각
					procObj.setIsrtDeptCd(rs.getString("ISRT_DEPT_CD"));
					procObj.setIsrtEmpNo(rs.getString("ISRT_EMP_NO"));
					procObj.setFetchCnt(rs.getInt("FETCH_CNT"));
				return procObj;
			}
			throw new BatchException("청구입금 배치담당 사원,부서정보를 찾을수 없습니다. 공통코드종류번호(R00038) 확인");
		} finally {
			ConnMng.closeResultSet(rs);
			ConnMng.closeStatement(pstmt);
		}
	}

	/**
	 * <p>메소드명 : searchReprAddr </p>
	 * <p>설명 :대표_주소_조회 </p>
	 * <p>메소드인수1 : con Connection - commit, rollback은 호출한 매소드에서 처리</p>
	 * <p>메소드리턴값 : ReprAddrObj - 조회된 대표발신자정보가 셋팅된다.</p>
	 */
	public static ReprAddrObj searchReprAddr(Connection con) {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		try {
			String sql =
				"SELECT                                                                                            \n"+
				"      B.REPR                                                                                     \n"+
				"     , A.ZIP_CD        AS REPR_ZIP_CD                                                            \n"+
				"     , A.ADDR_CI || ' ' || A.ADDR_GU || ' ' || A.ADDR_DONG AS REPR_ADDR1                         \n"+
				"     , A.ADDR_SPEC    AS REPR_ADDR2                                                              \n"+
				"     , A.OFFC_TEL_NO1  AS REPR_TEL1                                                              \n"+
				"     , A.OFFC_TEL_NO2  AS REPR_TEL2                                                              \n"+
				"     , A.OFFC_TEL_NO3  AS REPR_TEL3                                                              \n"+
				"     , B.REPR_URL                                                                                \n"+
				"     , B.REPR_EMAIL                                                                              \n"+
				"     , A.FAX_NO1 AS REPR_FAX_NO1                                                                 \n"+
				"     , A.FAX_NO2 AS REPR_FAX_NO2                                                                 \n"+
				"     , A.FAX_NO3 AS REPR_FAX_NO3                                                                 \n"+
				"     ,(SELECT KOR_NAME                                                                           \n"+
				"         FROM DBSCOMM.HT_EMP_BASE                                                                \n"+
				"        WHERE A.DEPT_MGR_EMP_NO = EMP_NO) as REPR_NM                                             \n"+
				"     , B.REPR_RETURN_EMAIL                                                                       \n"+
				"     , A.BIZ_NO                                                                                  \n"+
				"FROM   DBSCOMM.HT_ORG A,                                                                         \n"+
				"     (                                                                                           \n"+
				"     SELECT                                                                                      \n"+
				"     	  MAX(CASE WHEN CD_DESC_NO = '01' THEN CD_DESC_KOR_NM ELSE '' END) AS REPR                \n"+
				"     	, MAX(CASE WHEN CD_DESC_NO = '10' THEN CD_DESC_KOR_NM ELSE '' END) AS REPR_URL            \n"+
				"     	, MAX(CASE WHEN CD_DESC_NO = '11' THEN CD_DESC_KOR_NM ELSE '' END) AS REPR_EMAIL          \n"+
				"     	, MAX(CASE WHEN CD_DESC_NO = '12' THEN CD_DESC_KOR_NM ELSE '' END) AS REPR_RETURN_EMAIL   \n"+
				"     FROM DBSCOMM.CT_COMM_CD_DESC Z                                                              \n"+
				"    WHERE CD_KIND_NO = ?                                                                         \n"+
				"     ) B                                                                                         \n"+
				"WHERE  A.DEPT_CD = ?                                                                             \n";

//			String sql =
//				"SELECT                                                                            \n"+
//				"    MAX(CASE                                                                      \n"+
//				"        WHEN CD_DESC_NO = '01' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR             \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '02' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_ZIP_CD      \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '03' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                                          \n"+
//				"    ||' '|| MAX(CASE                                                              \n"+
//				"              WHEN CD_DESC_NO = '04' THEN CD_DESC_KOR_NM                          \n"+
//				"              ELSE ''                                                             \n"+
//				"            END)                                                                  \n"+
//				"    ||' '|| MAX(CASE                                                              \n"+
//				"              WHEN CD_DESC_NO = '05' THEN CD_DESC_KOR_NM                          \n"+
//				"              ELSE ''                                                             \n"+
//				"            END)                                              AS REPR_ADDR1       \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '06' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_ADDR2       \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '07' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_TEL1        \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '08' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_TEL2        \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '09' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_TEL3        \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '10' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_URL         \n"+
//				"    ,MAX(CASE                                                                     \n"+
//				"        WHEN CD_DESC_NO = '11' THEN CD_DESC_KOR_NM                                \n"+
//				"        ELSE ''                                                                   \n"+
//				"    END)                                                      AS REPR_EMAIL       \n"+
//				"FROM DBSCOMM.CT_COMM_CD_DESC                                                      \n"+
//				"WHERE CD_KIND_NO = ?   /* 대표_발신자(R00034) */                                  \n"+
//				"                                                                           \n";

			//IN : 코드종류번호 ( 대표 발신자 )
			//pstmt = new LoggableStatement(con, sql );
			pstmt = con.prepareStatement(sql);
				pstmt.setString(1, "R00034");
				pstmt.setString(2, "00000000");
			rs = pstmt.executeQuery();

			if (rs.next()) {
				ReprAddrObj reprAddrObj = new ReprAddrObj();
					reprAddrObj.setRepr(rs.getString("REPR"));
					reprAddrObj.setReprZipCd(rs.getString("REPR_ZIP_CD"));
					reprAddrObj.setReprAddr1(rs.getString("REPR_ADDR1"));
					reprAddrObj.setReprAddr2(rs.getString("REPR_ADDR2"));
					reprAddrObj.setReprTel1(rs.getString("REPR_TEL1"));
					reprAddrObj.setReprTel2(rs.getString("REPR_TEL2"));
					reprAddrObj.setReprTel3(rs.getString("REPR_TEL3"));
					reprAddrObj.setReprUrl(rs.getString("REPR_URL"));
					reprAddrObj.setReprEmail(rs.getString("REPR_EMAIL"));
					reprAddrObj.setReprNm(rs.getString("REPR_NM"));
					reprAddrObj.setReprFaxNo1(rs.getString("REPR_FAX_NO1"));
					reprAddrObj.setReprFaxNo2(rs.getString("REPR_FAX_NO2"));
					reprAddrObj.setReprFaxNo3(rs.getString("REPR_FAX_NO3"));
					reprAddrObj.setReprReturnEmail(rs.getString("REPR_RETURN_EMAIL"));
					reprAddrObj.setReprBizNo(rs.getString("BIZ_NO"));
				return reprAddrObj;
			} else {
				throw new BizException("발송 대표정보가 존재하지 않습니다.");
			}
		} catch (SQLException e) {
			throw new BizException("발송 대표정보 조회실패(" + e.getMessage() +")", e);
		} finally {
			ConnMng.closeResultSet(rs);
			ConnMng.closeStatement(pstmt);
		}
	}

	/**
	 * <p>메소드명 : 마감일련번호 채번</p>
	 * <p>설명 : </p>
	 * <p>메소드인수1 : </p>
	 * <p>메소드리턴값 : </p>
	 */
	public static double getClsSnum(Connection con) throws SQLException {
		Statement stmt = null;
		ResultSet rs = null;
		try {
			stmt = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE,ResultSet.CONCUR_READ_ONLY);
			//rs = stmt.executeQuery("VALUES ((NEXTVAL FOR DBSRQST.RS_DLVR_CLS_SNUM))");
			rs = stmt.executeQuery("SELECT DBSRQST.RS_DLVR_CLS_SNUM.NEXTVAL FROM DUAL");
			if (rs.next()) {
				return rs.getDouble(1);
			} else {
				throw new RuntimeException("마감순번 채번 실패");
			}
		} finally {
			ConnMng.closeResultSet(rs);
			ConnMng.closeStatement(stmt);
		}
	}

	/**
	 * @deprecated 사용하지 않음.
	 * <p>처리장애 SMS 전송
	 * <p>TPDP 전화번호를 properties로 관리하도록 추후수정.
	 * @param title 내용의 제목. ex) [RATDL04]입금에러
	 * @param exception Exception 내용을 메세지에 출력하기위함.
	 */
	@Deprecated
	public static void sendSmsErr(String title, Throwable exception){
		return;
//		try{
//			SimpleSmsCC smsCC = new SimpleSmsCC();
//			String msg = title + "("+ (exception==null?"":exception.getMessage())+")";
//			smsCC.addMsg("XXXX-XXXX", "010-9999-9999",msg);
//			smsCC.sendMsg();
//		}catch(Throwable tr){
//			tr.printStackTrace();
//			//전송에러는 아무처리하지 않음.
//		}
	}

	/**
     * <p>계획을 등록한다.
     * @return
     */
    public static String setBatchProcInfo() {
        StringBuffer sql = new StringBuffer(1024);
		sql.append("\n   MERGE INTO DBSRQST.RT_JOB_PLAN_BASE A            ");
		sql.append("\n   USING(SELECT JOB_DT                              ");
		sql.append("\n              , ? AS JOB_ID                         ");
		sql.append("\n              , SNUM                                ");
		sql.append("\n              , JOB_STAT_CD                         ");
		sql.append("\n              , STRT_LOAN_NO                        ");
		sql.append("\n              , END_LOAN_NO                         ");
		sql.append("\n              , JOB_LOAN_NO                         ");
		sql.append("\n              , FRST_REG_DT                         ");
		sql.append("\n              , FRST_REG_TM                         ");
		sql.append("\n              , FRST_REG_EMP_NO                     ");
		sql.append("\n              , LAST_PROC_DT                        ");
		sql.append("\n              , LAST_PROC_TM                        ");
		sql.append("\n              , LAST_PROC_EMP_NO                    ");
		sql.append("\n          FROM DBSRQST.RT_JOB_PLAN_BASE             ");
		sql.append("\n         WHERE JOB_DT = ?                           ");
		sql.append("\n           AND JOB_ID = 'BCLBC1107'                 ");
		sql.append("\n           AND SNUM   = ? ) B                       ");
		sql.append("\n   ON (A.JOB_DT = B.JOB_DT                          ");
		sql.append("\n   AND A.JOB_ID = B.JOB_ID                          ");
		sql.append("\n   AND A.SNUM   = B.SNUM)                           ");
		sql.append("\n   WHEN MATCHED                                     ");
		sql.append("\n   THEN UPDATE SET A.JOB_STAT_CD  = B.JOB_STAT_CD   ");
		sql.append("\n                 , A.STRT_LOAN_NO = B.STRT_LOAN_NO  ");
		sql.append("\n                 , A.END_LOAN_NO  = B.END_LOAN_NO   ");
		sql.append("\n                 , A.JOB_LOAN_NO  = B.JOB_LOAN_NO   ");
		sql.append("\n   WHEN NOT MATCHED                                 ");
		sql.append("\n   THEN INSERT (                                    ");
		sql.append("\n                JOB_DT                              ");
		sql.append("\n              , JOB_ID                              ");
		sql.append("\n              , SNUM                                ");
		sql.append("\n              , JOB_STAT_CD                         ");
		sql.append("\n              , STRT_LOAN_NO                        ");
		sql.append("\n              , END_LOAN_NO                         ");
		sql.append("\n              , JOB_LOAN_NO                         ");
		sql.append("\n              , FRST_REG_DT                         ");
		sql.append("\n              , FRST_REG_TM                         ");
		sql.append("\n              , FRST_REG_EMP_NO                     ");
		sql.append("\n              , LAST_PROC_DT                        ");
		sql.append("\n              , LAST_PROC_TM                        ");
		sql.append("\n              , LAST_PROC_EMP_NO)                   ");
		sql.append("\n   VALUES (     B.JOB_DT                            ");
		sql.append("\n              , B.JOB_ID                            ");
		sql.append("\n              , B.SNUM                              ");
		sql.append("\n              , B.JOB_STAT_CD                       ");
		sql.append("\n              , B.STRT_LOAN_NO                      ");
		sql.append("\n              , B.END_LOAN_NO                       ");
		sql.append("\n              , B.JOB_LOAN_NO                       ");
		sql.append("\n              , B.FRST_REG_DT                       ");
		sql.append("\n              , B.FRST_REG_TM                       ");
		sql.append("\n              , B.FRST_REG_EMP_NO                   ");
		sql.append("\n              , B.LAST_PROC_DT                      ");
		sql.append("\n              , B.LAST_PROC_TM                      ");
		sql.append("\n              , B.LAST_PROC_EMP_NO)                 ");
		return sql.toString();
    }
}
