package hanalife.batch.util;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.apache.log4j.Logger;

import hanalife.batch.ConnMng;
import hanalife.batch.DbsBatchException;
import hanalife.c.co.util.StringUtil;

/**
 * <pre>
 * 클래스명    : BatchJobUtil
 * 클래스설명 : BatchJobUtil의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class BatchJobUtil {
    public final static String YYYY_MM_DD = "yyyy-MM-dd";
    public final static String YYYYMMDD = "yyyyMMdd";
    public final static String MMDD = "MMdd";
    private final static String BR = "\n";
    static final String SEP = System.getProperty("file.separator"); //window : "\", unix : "/"

    static Logger log;

    static {

        log = Logger.getLogger(BatchJobUtil.class.getName());
    }

    /**
     * 주어진 날짜 달의 마지막 일자  Check
     *
     * @return 정상 영업일 유무
     * @throws SQLException
     * @param1 String inJobDt :실행일
     */
    public static boolean chklastDayOfMonth(String inJobDt, Connection con) throws Exception {
        boolean fg_LastDay = false;

        ResultSet rs_chkLastDay = null;
        PreparedStatement stmt_chkLastDay = null;
        String sql_chkLastDay = ""
                + " select case when to_CHAR(to_DATE('<WORK_DT>'+1),'yyyy-mm-dd') = SUBSTR(to_char(ADD_MONTHS('<WORK_DT>',1),'yyyy-mm-dd'),1,8) || '01' " + BR
                + "             then 1                                                                                       " + BR
                + "             else 0                                                                                       " + BR
                + "             end as chkLastDay                                                                            " + BR
                + "   from DUAL                                                                                  " + BR
                + "                                                                                                    ";
        sql_chkLastDay = sql_chkLastDay.replaceAll("<WORK_DT>", inJobDt);

        try {
            stmt_chkLastDay = con.prepareStatement(sql_chkLastDay);
            rs_chkLastDay = stmt_chkLastDay.executeQuery();
            if (rs_chkLastDay.next()) {
                if (rs_chkLastDay.getInt(1) > 0) {
                    fg_LastDay = true;
                }
            }

            if (fg_LastDay) {
                log.info("기준일[" + inJobDt + "] 은 말일 입니다.");
            }

            rs_chkLastDay.close();
            stmt_chkLastDay.close();
        } catch (Exception e) {
            throw new Exception("작업일(매월말일) Check 중 시스템 에러발생 : " + e.getMessage());
        } finally {
            ConnMng.closeResultSet(rs_chkLastDay);
            ConnMng.closeStatement(stmt_chkLastDay);
        }
        return fg_LastDay;
    }

    /**
     * 주어진 날짜 달의 마지막 영업일자  Check
     *
     * @return 정상 영업일 유무
     * @throws SQLException
     * @param1 String inJobDt :실행일
     */
    public static boolean chkLastBizDay(String inJobDt, Connection con) throws Exception {
        boolean fg_LastDay = false;

        ResultSet rs_chkLastDay = null;
        PreparedStatement stmt_chkLastDay = null;
        String sql_chkLastDay = ""
                + " select case when '<WORK_DT>' = (SELECT * FROM (SELECT ATTD_DT  								" + BR
                + "         FROM DBSCOMM.HT_WORK_CHAR_DD 														" + BR
                + "		            WHERE ATTD_DT >= '<WORK_DT>' AND ATTD_DT <= SUBSTR('<WORK_DT>',1,8) || '31' " + BR
                + "		             AND OCPT_CD = 'B'           												" + BR
                + "		             AND CHAR_DIV_CD = 'AA0'     												" + BR
                + "		           ORDER BY ATTD_DT DESC             											" + BR
                + "		           ) WHERE ROWNUM = 1)															" + BR
                + "					then 1                                                                      " + BR
                + "				     else 0                                                                     " + BR
                + "		    	   end as chkLastDay                                                            " + BR
                + "				from DUAL                                        			                   	" + BR
                + "				                                                            	              	";
        sql_chkLastDay = sql_chkLastDay.replaceAll("<WORK_DT>", inJobDt);

        try {
            stmt_chkLastDay = con.prepareStatement(sql_chkLastDay);
            rs_chkLastDay = stmt_chkLastDay.executeQuery();
            if (rs_chkLastDay.next()) {
                if (rs_chkLastDay.getInt(1) > 0) {
                    fg_LastDay = true;
                }
            }

            if (fg_LastDay) {
                log.info("기준일[" + inJobDt + "] 은 말일(영업일) 입니다.");
            }

            rs_chkLastDay.close();
            stmt_chkLastDay.close();
        } catch (Exception e) {
            throw new Exception("작업일(매월말일) Check 중 시스템 에러발생 : " + e.getMessage());
        } finally {
            ConnMng.closeResultSet(rs_chkLastDay);
            ConnMng.closeStatement(stmt_chkLastDay);
        }
        return fg_LastDay;
    }

    public static boolean chkFirstBizDay(String inJobDt, Connection con) throws Exception {
        boolean fg_LastDay = false;

        ResultSet rs_chkLastDay = null;
        PreparedStatement stmt_chkLastDay = null;
        String sql_chkLastDay = ""
                + "select case when '<WORK_DT>' = (SELECT ATTD_DT               									" + BR
                + "         FROM DBSCOMM.HT_WORK_CHAR_DD 															" + BR
                + "		            WHERE  ATTD_DT >= SUBSTR('<WORK_DT>',1,8) || '01' AND ATTD_DT <= '<WORK_DT>'  	" + BR
                + "		             AND OCPT_CD = 'B'           													" + BR
                + "		             AND CHAR_DIV_CD = 'AA0'     													" + BR
                + "		           ORDER BY ATTD_DT ASC             												" + BR
                + "		           FETCH FIRST 1 ROWS ONLY) 														" + BR
                + "					then 1                                                                          " + BR
                + "				     else 0                                                                         " + BR
                + "		    	   end as chkLastDay                                                                " + BR
                + "				from DUAL                                                             	" + BR
                + "				   																			";
        sql_chkLastDay = sql_chkLastDay.replaceAll("<WORK_DT>", inJobDt);

        try {
            stmt_chkLastDay = con.prepareStatement(sql_chkLastDay);
            rs_chkLastDay = stmt_chkLastDay.executeQuery();
            if (rs_chkLastDay.next()) {
                if (rs_chkLastDay.getInt(1) > 0) {
                    fg_LastDay = true;
                }
            }

            if (fg_LastDay) {
                log.info("기준일[" + inJobDt + "] 은 말일(영업일) 입니다.");
            }

            rs_chkLastDay.close();
            stmt_chkLastDay.close();
        } catch (Exception e) {
            throw new Exception("작업일(매월말일) Check 중 시스템 에러발생 : " + e.getMessage());
        } finally {
            ConnMng.closeResultSet(rs_chkLastDay);
            ConnMng.closeStatement(stmt_chkLastDay);
        }
        return fg_LastDay;
    }


    /**
     * 주어진 JOB의 선행 JOB 실행결과 Check
     *
     * @return 선행 JOB 정상실행 여부
     * @throws SQLException
     * @param1 String inJobId :실행 JOB ID
     */
    public static boolean chkPreProcess(String inBatchId, Connection con) {
        boolean fg_preProcess = false;

        ResultSet rs_chkPreProcess = null;
        PreparedStatement stmt_chkPreProcess = null;
        String sql_chkPreProcess = ""
                + "	SELECT PRE_BATCH_ID " + BR
                + "	FROM DBSCOMM.CT_BATCH_SCH A " + BR
                + "	WHERE A.BATCH_ID =? " + BR
                + "	            			  ";

        String pre_batchId = "";
        try {
            stmt_chkPreProcess = con.prepareStatement(sql_chkPreProcess);
            stmt_chkPreProcess.setString(1, inBatchId);
            rs_chkPreProcess = stmt_chkPreProcess.executeQuery();
            while (rs_chkPreProcess.next()) {
                pre_batchId = rs_chkPreProcess.getString(1);
                log.info("선행배치[" + pre_batchId + "]");
            }
//			//Pre JOB 결과가 성공이면 Pre Batch 결과 확인
            fg_preProcess = chkPreBatch(pre_batchId, inBatchId, con);
            if (fg_preProcess) {
                updateBatchFlag(inBatchId, "S", "1", con);
            }

        } catch (Exception e) {
            throw new DbsBatchException("선행 JOB 실행여부 Check 중 시스템 에러발생 : " + e.getMessage(), e);
        } finally {
            ConnMng.closeResultSet(rs_chkPreProcess);
            ConnMng.closeStatement(stmt_chkPreProcess);

            log.info("선행 BATCH 실행결과[" + fg_preProcess + "]");
        }
        return fg_preProcess;
    }


    /**
     * 주어진 JOB의 선행 JOB 실행결과 Check
     *
     * @return 선행 JOB 정상실행 여부
     * @throws SQLException
     * @param1 String inJobId :실행 JOB ID
     */
    public static boolean chkPreJob(String inJobId, Connection con) throws Exception {
        boolean fg_preJob = false;
        boolean fg_preProcess = false;

        ResultSet rs_chkprejob = null;
        PreparedStatement stmt_chkprejob = null;
        String sql_chkprejob = ""
                + " SELECT CASE JOB_RST_CD WHEN '0' THEN 0  							" + BR
                + "   WHEN '1' THEN 0													" + BR
                + "WHEN '2' THEN 1 END	 												" + BR
                + "FROM DBSCOMM.CT_JOB_SCH												" + BR
                + "WHERE JOB_ID = '<JOB_ID>' 											" + BR
                + "                 											    ";

        sql_chkprejob = sql_chkprejob.replaceAll("<JOB_ID>", inJobId);

        try {
            stmt_chkprejob = con.prepareStatement(sql_chkprejob);
            rs_chkprejob = stmt_chkprejob.executeQuery();
            if (rs_chkprejob.next()) {
                if (rs_chkprejob.getInt(1) > 0) {
                    fg_preJob = true;
                }
            }

            if (fg_preJob) {
                log.info("선행 Batch 결과 검사 ");
                fg_preProcess = chkPreBatch(inJobId, inJobId, con);
            }

        } catch (Exception e) {
            throw new Exception("선행 JOB 실행여부 Check 중 시스템 에러발생 : " + e.getMessage());
        } finally {
            ConnMng.closeResultSet(rs_chkprejob);
            ConnMng.closeStatement(stmt_chkprejob);
            log.info("선행 JOB   실행결과[" + fg_preJob + "]");
            log.info("선행 BATCH 실행결과[" + fg_preProcess + "]");
        }
        return fg_preProcess;
    }

    /**
     * 주어진 JOB의 선행 JOB 실행결과 Check
     *
     * @return 선행 JOB 정상실행 여부
     * @throws SQLException
     * @param1 String inJobId :실행 JOB ID
     */
    public static boolean chkPreBatch(String preBatchId, String inBatchId, Connection con) throws Exception {
        boolean fg_preBatch = false;

        ResultSet rs_chkPreBatch = null;
        PreparedStatement stmt_chkPreBatch = null;
        String sql_chkPreBatch = ""
                + " SELECT CASE BATCH_RST_CD WHEN '0' THEN 0  							" + BR
                + "    WHEN '1' THEN 0						 							" + BR
                + " WHEN '2' THEN 1 END	  												" + BR
                + " FROM DBSCOMM.CT_BATCH_SCH 											" + BR
                + " WHERE BATCH_ID = ?	 									" + BR
                + "                    											";

        try {
            stmt_chkPreBatch = con.prepareStatement(sql_chkPreBatch);
            stmt_chkPreBatch.setString(1, preBatchId);
            rs_chkPreBatch = stmt_chkPreBatch.executeQuery();
            if (rs_chkPreBatch.next()) {
                if (rs_chkPreBatch.getInt(1) > 0) {
                    fg_preBatch = true;
                }
            }

            if (fg_preBatch) {
                log.info("배치ID[" + inBatchId + "]은 선행 BATCH[" + preBatchId + "]가 정상적으로 수행되었습니다.");
            }
        } catch (Exception e) {
            throw new Exception("선행BATCH 정상종료 Check 중 시스템 에러발생 : " + e.getMessage());
        } finally {
            ConnMng.closeResultSet(rs_chkPreBatch);
            ConnMng.closeStatement(stmt_chkPreBatch);
        }
        return fg_preBatch;
    }

    /**
     * 배치 실행 성공, 실패 기록
     * @param inBatchId
     * @param work_fg
     * @param flag
     * @param con
     * @throws Exception
     */
    public static void updateBatchFlag(String inBatchId, String work_fg, String flag, Connection con) throws Exception {
        PreparedStatement pstmt = null;
        try {
            String sql_result = ""
                    + " 	UPDATE  DBSCOMM.CT_BATCH_SCH  " + BR
                    + " 	SET	  BATCH_RST_CD = ? " + BR
                    + "  WHERE BATCH_ID =?";

            pstmt = new LoggableStatement(con, sql_result);
            pstmt.setString(1, flag);
            pstmt.setString(2, inBatchId);
            log.info(((LoggableStatement) pstmt).getQueryString());

            int rs_result = pstmt.executeUpdate();

            if (rs_result > 0) {
                insertBatchHistory(inBatchId, con, work_fg, flag);
            }
        } catch (Exception e) {
//            ConnMng.rollback(con);
            con.rollback();
            throw new DbsBatchException("BATCH 실행 History 기록 중 시스템 에러발생 : " + e.getMessage(), e);
        } finally {
            ConnMng.closeStatement(pstmt);
        }
    }

    /**
     * 주어진 JOB의 선행 JOB 실행결과 Check
     *
     * @return 선행 JOB 정상실행 여부
     * @throws SQLException
     * @param1 String inJobId :실행 JOB ID
     */
    public static void updateBatchFlag(String inBatchId, String work_fg, String flag) throws Exception {

        String batchHm = StringUtil.trimString(System.getProperty("batch.home"));
        if (batchHm == null || "".equals(batchHm)) {
            log.info("배치 홈디렉토리가 입력되지 않았습니다.");
        }      //
        String config = batchHm + SEP + "config" + SEP + "batch.config";

        // connection manager 설정
        ConnMng conMng = new ConnMng(config);

//        PropertyManager pm = PropertyManager.getInstance();
//        String tranSvr = pm.getStr("SMS_SERVER");
//
//        //개발서버
//        if ("T".equals(tranSvr)) {
//            conMng.init("DOBSCAPDHT", "jcbsc", "jcbsc");
//        }
//        //운영서버
//        else {
//            conMng.init("DWCDB", "jcbsc", "jcbsc");
//        }

        Connection con = null;
        try{
            // con = conMng.getConnection();
            con = conMng.getConnectionAutoCommit();
            updateBatchFlag(inBatchId, work_fg, flag, con);

            con.commit();

        }catch(Exception e){
//            ConnMng.rollback(con);
        	con.rollback();
            throw new DbsBatchException("BATCH 실행 History 기록 중 시스템 에러발생 : " + e.getMessage(), e);
        } finally {
            ConnMng.closeConnection(con);
        }
    }

    public static int insertBatchHistory(String inBatchId, Connection con, String work_fg, String flag) throws Exception {

        Integer rs_result = null;
        PreparedStatement pstmt = null;

        String sql = ""

                + " INSERT INTO DBSCOMM.CT_BATCH_JOB_HIS"
                + " SELECT B.JOB_EXEC_DATE, JOB_ID, BATCH_ID, '<WORK_FG>', '<FLAG>' AS BATCH_RST_CD, ' ' AS BATCH_ERROR, B.JOB_REG_DATE AS FRST_REG_DT, ' ' AS FRST_REG_EMP_NO, ' ' AS PARAMETER, 0 AS SEQ" + BR
                + " FROM DBSCOMM.CT_BATCH_SCH A,  " + BR
                // [DOBSCAP] 2018-08-01
                // 두비스
                // 서버에서 sysdate를 정상적으로 가져오지 못하여 오류가 발생하여 DB날짜를 바로 세팅하도록 수정함.
                + "(SELECT TO_CHAR(CURRENT_DATE,'YYYY-MM-DD')||TO_CHAR(CURRENT_DATE, 'HH24MISS') AS JOB_REG_DATE, TO_CHAR(CURRENT_DATE,'YYYY-MM-DD') AS JOB_EXEC_DATE " + BR
                //+		"(SELECT '"+ServerSysDate.getServerDate(ServerSysDate.YYYYMMDDHHMMSS)+"' AS JOB_REG_DATE,  '" +ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD_WITH_DELIMETER)+"' AS JOB_EXEC_DATE "+ BR
                + "FROM DUAL) B" + BR
                + " WHERE A.BATCH_ID ='<BATCH_ID>' " + BR
                + "   ";

        sql = sql.replaceAll("<BATCH_ID>", inBatchId);
        sql = sql.replaceAll("<WORK_FG>", work_fg);
        sql = sql.replaceAll("<FLAG>", flag);

        log.info(sql);

        try {
            pstmt = con.prepareStatement(sql);
            rs_result = pstmt.executeUpdate();
        } catch (Exception e) {
//            ConnMng.rollback(con);
            con.rollback();
            //throw new Exception("BATCH 실행 History 기록 중 시스템 에러발생1 : " + e.getMessage());
        } finally {
            ConnMng.closeStatement(pstmt);
        }

        return rs_result;
    }
}
