package hanalife.batch.util.dtf;

import java.io.FileOutputStream;
import java.util.Map;

import org.apache.log4j.Logger;

/**
 * <pre>
 * 클래스명    : DTFGenerator
 * 클래스설명 : DTFGenerator의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class DTFGenerator
	implements IDTFGenerator {
	private static Logger log = Logger.getLogger(DTFGenerator.class.getName());
	DTFParser parser;
	Map msgMap;
	String fileDesc;

	int writeCnt = 0; //파일에 기록된 건수

	public DTFGenerator() {
		this.parser = new DTFParser();
	}

	@Override
	public int getWriteCount() {
		return this.writeCnt;
	}

	/* (non-Javadoc)
	 * @see com.dobscap.dtf.bat.IDTFGenerator#setDTFList(com.dobscap.dtf.bat.DTFMsgVOList, java.lang.String, java.lang.String, boolean)
	 */
	@Override
	public DTFMsgVOList setDTFList(DTFMsgVOList dtfl, String xmlFileUrl,
								   String outFileUrl, boolean b) throws
		DTFException {
		//xml을 파싱하여 메타정보를 저장한다.
		setXmlLayout(parser, xmlFileUrl);

		FileOutputStream fos = null;
		DTFMsgVO dtfo = null;
		DTFMsgLayout msgLayout = null;
		String recTypeCd = "";

		try {
			if (b == true) {
                //기존파일에 append
				fos = new FileOutputStream(outFileUrl, true);
			}
			else {
                //기존파일의 내용을 지우고 새로 write
				fos = new FileOutputStream(outFileUrl);
			}

			//전문을 레코드 한줄씩 생성한다.
			for (int j = 0; j < dtfl.size(); j++) {
				//입력된 전문 VO
				dtfo = (DTFMsgVO) dtfl.get(j);

				//레코드의 타입 : ex) H : header, B : body, F : footer
				recTypeCd = dtfo.getRecDiv();

				//xml(msg) layout
				msgLayout = getMsgLayout(recTypeCd);

				dtfo.setRecord( msgLayout.getParamList(), fos);
				writeEnter(fos);
			}

			log.debug("총 레코드 건수 : " + dtfl.size());
		}
		catch (Exception e) {
			e.printStackTrace();
			throw new DTFException(e.getMessage());
		}finally{
            try{
                if(fos != null){
					fos.close();
				}
            }catch(Exception e){
                e.printStackTrace();
            }
        }

		return dtfl;
	}

	/**
	 * <p> </p>
	 * @param parser
	 * @param xmlFileUrl
	 * @throws DTFException
	 */
	private void setXmlLayout(DTFParser parser, String xmlFileUrl) throws
		DTFException {
		try {
			parser.setLayoutXml(xmlFileUrl);
			parser.parse();

			this.fileDesc = parser.getMsgDesc();
			this.msgMap = parser.getMsgMap();

		}
		catch (Exception e) {
			throw new DTFException(e.getMessage());
		}
	}

	/**
	 * <p>라인뒤에 엔터를 넣는다.</p>
	 * @param fos
	 * @throws DTFException
	 */
	private void writeEnter(FileOutputStream fos) throws DTFException {
		try {
			byte[] b = "\n".getBytes();
			fos.write(b);
			writeCnt++;
		}
		catch (Exception e) {
			e.printStackTrace();
			throw new DTFException(e.getMessage());
		}
	}

	/**
	 * <p>전문 layout을 정의한 Obj를 리턴한다.</p>
	 * @param recTypeCd
	 * @return
	 */
	private DTFMsgLayout getMsgLayout(String recTypeCd) {
		try {
			return (DTFMsgLayout)this.msgMap.get(recTypeCd);
		}
		catch (Exception e) {
			return null;
		}
	}
}
