package hanalife.batch.util.ftd;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

/**
 * <pre>
 * 클래스명    : FTDParser
 * 클래스설명 : xml을 파싱하여 정보를 담고있는 Parser
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class FTDParser
{
	public FTDParser() {}

	private String xmlFileNm;
	private String deftClassNm;       //파일 아이디 : 생성될 클래스명이 된다.
	private String msgDesc;			//파일 설명

	private Map msgMap;
	Logger log = Logger.getLogger(this.getClass().getName());

	public void setLayoutXml( String fileName )
	{
		this.xmlFileNm = fileName;
	}

	/**
	 * xml을 파싱하여 전문의 layout을 저장하는 메서드
	 */
	public void parse() throws FTDException
	{
		try
		{
			msgMap = new HashMap();

			Document document = getDocument( this.xmlFileNm );
			Element root  = document.getRootElement();
			Iterator i = null;
			for ( i = root.elementIterator(); i.hasNext(); ) {
	            startXMLParsing((Element) i.next());
	        }

		} catch ( Exception e ) {
			e.printStackTrace();
			throw new FTDException( e.getMessage() );
		}
	}

	/**
	 * @param url : xml파일 full path + file name
	 * @return 전문(xml) Document
	 * @throws SAXException
	 * @throws DocumentException
	 */
	private Document getDocument( String url ) throws SAXException, DocumentException {

		XMLReader xmlreader = XMLReaderFactory.createXMLReader("org.apache.xerces.parsers.SAXParser");
		SAXReader reader = new SAXReader(xmlreader);

		return reader.read( url );
	}

	private void startXMLParsing(Element element ) throws FTDException{
		if( element == null ) {
			throw new FTDException("전문포맷 파싱오류 : 파싱할 데이터가 없습니다.");
		}

		String elName = element.getName();
		String classNm = "";
		if( "deftClassNm".equals(elName )) {
			deftClassNm   = element.getText();
		}else if( "msgDesc".equals(elName )) {
			msgDesc = element.getText();
		}else if( "record".equals(elName)){
			FTDMsgLayout layout = new FTDMsgLayout();
			classNm = element.valueOf("@classname");
/**
 * <pre>
 * 클래스명    : FTDParser
 * 클래스설명 : FTDParser의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
			if( "".equals(classNm)){
				classNm = deftClassNm;
			}
			layout.setClassNm( classNm );
			layout.setName( element.valueOf("@name") );
			layout.setRecDiv(element.valueOf("@recDiv"));

			List list = element.elements();
			if(list == null || list.size()<1) {
				throw new FTDException("전문포맷 파싱오류 : 파싱할 데이터가 없습니다.");
			}

			List paramList = new ArrayList();
			parseList(list, paramList);
			layout.setParamList(paramList);
            System.out.println("layout.getRecDiv() : " + layout.getRecDiv() );
			msgMap.put( layout.getRecDiv(), layout );
		}
	}

	/**
	 * header, body, footer의 attribute를 파싱하여 정보를 배열에 저장한다.
	 * @param list
	 * @param paramList
	 */
	private void parseList( List list, List paramList )
	{

		Element attribute = null;
		for( int i=0; i< list.size(); i++) {
			attribute =(Element)list.get(i);
			String[] param = {
				attribute.attributeValue("label"),
				attribute.attributeValue("startPos"),
				attribute.attributeValue("byte"),
				attribute.attributeValue("align"),
				attribute.attributeValue("blank")};
			paramList.add( param );
		}
	}

	/**
	 * @return Returns the data.
	 */
	public Map getMsgMap() {
		return msgMap;
	}

	/**
	 * @return Returns the msgDesc.
	 */
	public String getMsgDesc() {
		return msgDesc;
	}
	/**
	 * @return Returns the deftClassNm.
	 */
	public String getDeftClassNm() {
		return deftClassNm;
	}
}
