package hanalife.c.bc.cc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.bc.cc.mapper.CBCCCM01Mapper;
import hanalife.c.bc.cc.mapper.dto.CBCCCM01DSSEARCHDTO;
import hanalife.c.bc.cc.service.CBCCCM01Service;
import hanalife.c.bc.cc.vo.CBCCCM01DSCTCOMMCDDESCVO;
import hanalife.c.bc.cc.vo.CBCCCM01DSCTCOMMCDKINDVO;
import hanalife.c.bc.cc.vo.CBCCCM01InVO;
import hanalife.c.bc.cc.vo.CBCCCM01OutVO;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.dto.CtCommCdDescDTO;
import hanalife.c.co.mapper.dto.CtCommCdKindDTO;
import hanalife.c.co.util.StringUtil;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CBCCCM01ServiceImpl.java Class
 * 클래스설명	: 공통코드관리 (CBCCCM01) Service Implements
 * 작성일자	: 2023.03.28.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023.03.27.][702809][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCBCCCM01S01 : 공통코드관리내역_조회
 * </pre>
 */

@Service("CBCCCM01Service")
public class CBCCCM01ServiceImpl implements CBCCCM01Service
{
    private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCM01ServiceImpl.class);


    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;


	@Autowired
	private CBCCCM01Mapper cBCCCM01Mapper;


    /**
     * <p>메소드명			: getCBCCCM01S01 : 공통코드(CT_COMM_CD_KIND) 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 공통코드(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: CBCCCM01S01InVO </p>
     * <p>메소드리턴값		: CBCCCM01S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public CBCCCM01OutVO getCBCCCM01S01(CBCCCM01InVO inVo) throws Exception
    {
        LOGGER.debug("CBCCCM01ServiceImpl getCBCCCM01S01 Start");

        // 공통코드관리 내역 서비스 결과값 객체 생성
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();

        // 공통코드관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        CBCCCM01DSSEARCHDTO oSearchDto = new CBCCCM01DSSEARCHDTO();

        oSearchDto.setCdKindNo      (inVo.getCBCCCM01DSSEARCHVO().getCdKindNo()     );  /* 코드_종류_번호 */
        oSearchDto.setCdKindNm      (inVo.getCBCCCM01DSSEARCHVO().getCdKindNm()     );  /* 코드_종류_명 */
        oSearchDto.setCdDescShrtNm  (inVo.getCBCCCM01DSSEARCHVO().getCdDescShrtNm());;  /* 코드_종류_단축_명 */

        LOGGER.info("" + "oSearchDto.getCdKindNo()     : " + oSearchDto.getCdKindNo());
        LOGGER.info("" + "oSearchDto.getCdKindNm()     : " + oSearchDto.getCdKindNm());
        LOGGER.info("" + "oSearchDto.getCdDescShrtNm() : " + oSearchDto.getCdDescShrtNm());

        // 공통코드 내역 조회 쿼리 Mapper 호출 수행
        List<CtCommCdKindDTO> resultDTO = cBCCCM01Mapper.searchCommCdList(oSearchDto);

        // 공통코드 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCCCM01DSCTCOMMCDKINDVO> resultList = new ArrayList<CBCCCM01DSCTCOMMCDKINDVO>();
        for (CtCommCdKindDTO sourceIO : resultDTO)
        {

            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            CBCCCM01DSCTCOMMCDKINDVO targetIO = new CBCCCM01DSCTCOMMCDKINDVO();

            targetIO.setCdKindNo                (sourceIO.getCdKindNo()        );   /* */
            targetIO.setCdKindNm                (sourceIO.getCdKindNm()        );   /* */
            targetIO.setCdKindShrtNm            (sourceIO.getCdKindShrtNm()    );   /* */
            targetIO.setBsnZoneCd               (sourceIO.getBsnZoneCd()       );   /* */
            targetIO.setMngDeptCd               (sourceIO.getMngDeptCd()       );   /* */
            targetIO.setRqstDeptCd              (sourceIO.getRqstDeptCd()      );   /* */
            targetIO.setFrstRegDt               (sourceIO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (sourceIO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (sourceIO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (sourceIO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (sourceIO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (sourceIO.getLastProcEmpNo()   );   /* */

            // 공통코드 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 공통코드내역조회 화면 출력 결과값 대입
        resultVo.setListCBCCCM01DSCTCOMMCDKINDVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명			: getCBCCCM01S02 : 공통코드(CT_COMM_CD_DESC) 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 공통코드(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: CBCCCM01S01InVO </p>
     * <p>메소드리턴값		: CBCCCM01S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public CBCCCM01OutVO getCBCCCM01S02(CBCCCM01InVO inVo) throws Exception
    {
        LOGGER.debug("CBCCCM01ServiceImpl getCBCCCM01S02 Start");

        // 공통코드관리 내역 서비스 결과값 객체 생성
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();

        // 공통코드관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        CBCCCM01DSSEARCHDTO oSearchDto = new CBCCCM01DSSEARCHDTO();

        oSearchDto.setCdKindNo      (inVo.getCBCCCM01DSSEARCHVO().getCdKindNo());           /* 코드_종류_번호 */

        LOGGER.info("" + "oSearchDto.getCdKindNo()     : " + oSearchDto.getCdKindNo());

        // 공통코드 내역 조회 쿼리 Mapper 호출 수행
        List<CtCommCdDescDTO> resultDTO = cBCCCM01Mapper.searchCommCdDescList(oSearchDto);

        // 공통코드 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCCCM01DSCTCOMMCDDESCVO> resultList = new ArrayList<CBCCCM01DSCTCOMMCDDESCVO>();
        for (CtCommCdDescDTO sourceIO : resultDTO)
        {

            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            CBCCCM01DSCTCOMMCDDESCVO targetIO = new CBCCCM01DSCTCOMMCDDESCVO();

            targetIO.setCdKindNo         (sourceIO.getCdKindNo()                   );  /* */
            targetIO.setCdDescNo         (sourceIO.getCdDescNo()                   );  /* */
            targetIO.setCdDescKorNm      (sourceIO.getCdDescKorNm()                );  /* */
            targetIO.setCdDescEngNm      (sourceIO.getCdDescEngNm()                );  /* */
            targetIO.setCdDescShrtNm     (sourceIO.getCdDescShrtNm()               );  /* */
            targetIO.setCdDescEtcNm      (sourceIO.getCdDescEtcNm()                );  /* */
            targetIO.setClas1            (sourceIO.getClas1()                      );  /* */
            targetIO.setClas2            (sourceIO.getClas2()                      );  /* */
            targetIO.setMarkOdr          (Long.toString(sourceIO.getMarkOdr())     );  /* */
            targetIO.setUseYn            (sourceIO.getUseYn()                      );  /* */
            targetIO.setFrstRegDt        (sourceIO.getFrstRegDt()                  );  /* */
            targetIO.setFrstRegTm        (sourceIO.getFrstRegTm()                  );  /* */
            targetIO.setFrstRegEmpNo     (sourceIO.getFrstRegEmpNo()               );  /* */
            targetIO.setLastProcDt       (sourceIO.getLastProcDt()                 );  /* */
            targetIO.setLastProcTm       (sourceIO.getLastProcTm()                 );  /* */
            targetIO.setLastProcEmpNo    (sourceIO.getLastProcEmpNo()              );  /* */

            targetIO.setpKeyCdKindNo     (sourceIO.getCdKindNo()                   );  /* */
            targetIO.setpKeyCdDescNo     (sourceIO.getCdDescNo()                   );  /* */

            // 공통코드 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 공통코드내역조회 화면 출력 결과값 대입
        resultVo.setListCBCCCM01DSCTCOMMCDDESCVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명			: getCBCCCM01S03 : 공통코드(CT_COMM_CD_KIND) 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 공통코드(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: CBCCCM01S01InVO </p>
     * <p>메소드리턴값		: CBCCCM01S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public CBCCCM01OutVO getCBCCCM01S03(CBCCCM01InVO inVo) throws Exception
    {
        LOGGER.debug("CBCCCM01ServiceImpl getCBCCCM01S03 Start");

        // 공통코드관리 내역 서비스 결과값 객체 생성
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();

        // 공통코드관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        CtCommCdKindDTO oSearchDto = new CtCommCdKindDTO();

        oSearchDto.setCdKindNo      (inVo.getCBCCCM01DSSEARCHVO().getCdKindNo()     );  /* 코드_종류_번호 */

        LOGGER.info("" + "oSearchDto.getCdKindNo()     : " + oSearchDto.getCdKindNo());

        // 공통코드 내역 조회 쿼리 Mapper 호출 수행
        CtCommCdKindDTO resultDTO = cBCCCM01Mapper.selectCtCommCdKind(oSearchDto);

        // 공통코드 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCCCM01DSCTCOMMCDKINDVO> resultList = new ArrayList<CBCCCM01DSCTCOMMCDKINDVO>();
        if (resultDTO != null)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            CBCCCM01DSCTCOMMCDKINDVO targetIO = new CBCCCM01DSCTCOMMCDKINDVO();

            targetIO.setCdKindNo                (resultDTO.getCdKindNo()        );   /* */
            targetIO.setCdKindNm                (resultDTO.getCdKindNm()        );   /* */
            targetIO.setCdKindShrtNm            (resultDTO.getCdKindShrtNm()    );   /* */
            targetIO.setBsnZoneCd               (resultDTO.getBsnZoneCd()       );   /* */
            targetIO.setMngDeptCd               (resultDTO.getMngDeptCd()       );   /* */
            targetIO.setRqstDeptCd              (resultDTO.getRqstDeptCd()      );   /* */
            targetIO.setFrstRegDt               (resultDTO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (resultDTO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (resultDTO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (resultDTO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (resultDTO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (resultDTO.getLastProcEmpNo()   );   /* */

            // 공통코드 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 공통코드내역조회 화면 출력 결과값 대입
        resultVo.setListCBCCCM01DSCTCOMMCDKINDVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명			: getCBCCCM01I01 : 공통코드(CT_COMM_CD_DESC) 내역_저장</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 공통코드(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: CBCCCM01I01InVO </p>
     * <p>메소드리턴값		: CBCCCM01I01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public CBCCCM01OutVO insertCtCommCdKind(CBCCCM01InVO inVo) throws Exception
    {

        LOGGER.debug("CBCCCM01ServiceImpl insertCtCommCdKind Start");

        // 결과값 출력 객체 VO 선언 및 정상 초기값 설정
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 유효성 체크
        String sCdKindNo        = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getCdKindNo().toString();
        String sCdKindNm        = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getCdKindNm().toString();
        String sBsnZoneCd       = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getBsnZoneCd().toString();
        String sCdKindShrtNm    = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getCdKindShrtNm().toString();
        String sFrstRegEmpNo    = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getFrstRegEmpNo().toString();
        String sLastProcEmpNo   = inVo.getCBCCCM01DSCTCOMMCDKINDVO().getLastProcEmpNo().toString();

        if (StringUtils.isEmpty(sCdKindNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sCdKindNm))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sBsnZoneCd))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sFrstRegEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sLastProcEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        // 공통코드 (CT_COMM_CD_KIND) 저장
        try
        {
            CtCommCdKindDTO inDto = new CtCommCdKindDTO();
            inDto.setCdKindNo      (sCdKindNo);
            inDto.setCdKindNm      (sCdKindNm);
            inDto.setBsnZoneCd     (sBsnZoneCd);
            inDto.setCdKindShrtNm  (sCdKindShrtNm);
            inDto.setFrstRegEmpNo  (sFrstRegEmpNo);
            inDto.setLastProcEmpNo (sLastProcEmpNo);

            CtCommCdKindDTO outDto = cBCCCM01Mapper.selectCtCommCdKind(inDto);

            if (outDto == null)
            {
                cBCCCM01Mapper.insertCtCommCdKind(inDto);
            }
            else
            {
                // TODO. 에러처리
            }
        }
        catch (Exception e)
        {
            LOGGER.error("[공통코드(CT_COMM_CD_KIND)] : 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }


    /**
     * <p>메소드명        : getCBCCCM01S02 : 공통코드(CT_COMM_CD_DESC) 내역 삭제</p>
     * <p>작성일자        : 2023. 3. 28.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : 공통코드 내역을 조회한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public CBCCCM01OutVO deleteCtCommCdDesc(CBCCCM01InVO inVo) throws Exception
    {

        LOGGER.debug("CBCCCM01ServiceImpl deleteCtCommCdDesc Start");

        // 결과값 출력 객체 VO 선언 및 정상 초기값 설정
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 유효성 체크
        String sCdKindNo        = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdKindNo().toString();
        String sCdDescNo        = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescNo().toString();

        if (StringUtils.isEmpty(sCdKindNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sCdDescNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        // 공통코드 (CT_COMM_CD_KIND) 저장
        try
        {
            CtCommCdDescDTO inDto = new CtCommCdDescDTO();
            inDto.setCdKindNo      (sCdKindNo);
            inDto.setCdDescNo      (sCdDescNo);

            cBCCCM01Mapper.deleteCtCommCdDesc(inDto);
        }
        catch (Exception e)
        {
            LOGGER.error("[공통코드(CT_COMM_CD_DESC)] : 삭제 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }


        return resultVo;
    }


    /**
     * <p>메소드명        : getCBCCCM01S02 : 공통코드(CT_COMM_CD_DESC) 내역 수정</p>
     * <p>작성일자        : 2023. 3. 28.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : 공통코드 내역을 조회한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public CBCCCM01OutVO updateCtCommCdDesc(CBCCCM01InVO inVo) throws Exception
    {

        LOGGER.info("CBCCCM01ServiceImpl updateCtCommCdDesc Start");

        // 공통코드관리 내역 서비스 결과값 객체 생성
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 유효성 체크
        String sCdKindNo         = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdKindNo().toString();        /*                   */
        String sCdDescNo         = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescNo().toString();        /*                   */
        String sCdDescKorNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescKorNm().toString();     /*                   */
        String sCdDescEngNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescEngNm().toString();     /*                   */
        String sCdDescShrtNm     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescShrtNm().toString();    /*                   */
        String sCdDescEtcNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescEtcNm().toString();     /*                   */
        String sClas1            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getClas1().toString();           /*                   */
        String sClas2            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getClas2().toString();           /*                   */
        long   nMarkOdr          = StringUtil.parseLong(inVo.getCBCCCM01DSCTCOMMCDDESCVO().getMarkOdr());   /*                   */
        String sUseYn            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getUseYn().toString();           /*                   */
        String sFrstRegEmpNo     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getFrstRegEmpNo().toString();    /*                   */
        String sLastProcEmpNo    = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getLastProcEmpNo().toString();   /*                   */

        String spKeyCdKindNo     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getpKeyCdKindNo().toString();    /*                   */
        String spKeyCdDescNo     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getpKeyCdDescNo().toString();    /*                   */

        if (StringUtils.isEmpty(spKeyCdKindNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(spKeyCdDescNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sCdKindNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sCdDescNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        /*
        if (StringUtils.isEmpty(sFrstRegEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }
        */

        if (StringUtils.isEmpty(sLastProcEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        // 공통코드 (CT_COMM_CD_KIND) 저장
        try
        {
            CtCommCdDescDTO inDto = new CtCommCdDescDTO();
            inDto.setCdKindNo      (sCdKindNo          );
            inDto.setCdDescNo      (sCdDescNo          );
            inDto.setCdDescKorNm   (sCdDescKorNm       );
            inDto.setCdDescEngNm   (sCdDescEngNm       );
            inDto.setCdDescShrtNm  (sCdDescShrtNm      );
            inDto.setCdDescEtcNm   (sCdDescEtcNm       );
            inDto.setClas1         (sClas1             );
            inDto.setClas2         (sClas2             );
            inDto.setMarkOdr       (nMarkOdr           );
            inDto.setUseYn         (sUseYn             );
            inDto.setFrstRegEmpNo  (sFrstRegEmpNo      );
            inDto.setLastProcEmpNo (sLastProcEmpNo     );
            inDto.setpKeyCdKindNo  (spKeyCdKindNo      );
            inDto.setpKeyCdDescNo  (spKeyCdDescNo      );

            cBCCCM01Mapper.updateCtCommCdDesc(inDto);
        }
        catch (Exception e)
        {
            LOGGER.error("[공통코드(CT_COMM_CD_DESC)] : 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }


    /**
     * <p>메소드명        : getCBCCCM01S02 : 공통코드(CT_COMM_CD_DESC) 내역 저장</p>
     * <p>작성일자        : 2023. 3. 28.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : 공통코드 내역을 조회한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public CBCCCM01OutVO insertCtCommCdDesc(CBCCCM01InVO inVo) throws Exception
    {
        LOGGER.debug("CBCCCM01ServiceImpl insertCtCommCdDesc Start");

        // 공통코드관리 내역 서비스 결과값 객체 생성
        CBCCCM01OutVO resultVo = new CBCCCM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 유효성 체크
        String sCdKindNo         = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdKindNo().toString();        /*                   */
        String sCdDescNo         = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescNo().toString();        /*                   */
        String sCdDescKorNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescKorNm().toString();     /*                   */
        String sCdDescEngNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescEngNm().toString();     /*                   */
        String sCdDescShrtNm     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescShrtNm().toString();    /*                   */
        String sCdDescEtcNm      = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getCdDescEtcNm().toString();     /*                   */
        String sClas1            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getClas1().toString();           /*                   */
        String sClas2            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getClas2().toString();           /*                   */
        long   nMarkOdr          = 0;
        String sUseYn            = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getUseYn().toString();           /*                   */
        String sFrstRegEmpNo     = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getFrstRegEmpNo().toString();    /*                   */
        String sLastProcEmpNo    = inVo.getCBCCCM01DSCTCOMMCDDESCVO().getLastProcEmpNo().toString();   /*                   */

        if (!StringUtils.isEmpty(inVo.getCBCCCM01DSCTCOMMCDDESCVO().getMarkOdr()))
        {
            nMarkOdr             = Long.parseLong(inVo.getCBCCCM01DSCTCOMMCDDESCVO().getMarkOdr());    /*                   */
        }

        if (StringUtils.isEmpty(sCdKindNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sCdDescNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sFrstRegEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        if (StringUtils.isEmpty(sLastProcEmpNo))
        {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        // 공통코드 (CT_COMM_CD_KIND) 저장
        try
        {
            CtCommCdDescDTO inDto = new CtCommCdDescDTO();
            inDto.setCdKindNo      (sCdKindNo          );
            inDto.setCdDescNo      (sCdDescNo          );
            inDto.setCdDescKorNm   (sCdDescKorNm       );
            inDto.setCdDescEngNm   (sCdDescEngNm       );
            inDto.setCdDescShrtNm  (sCdDescShrtNm      );
            inDto.setCdDescEtcNm   (sCdDescEtcNm       );
            inDto.setClas1         (sClas1             );
            inDto.setClas2         (sClas2             );
            inDto.setMarkOdr       (nMarkOdr           );
            inDto.setUseYn         (sUseYn             );
            inDto.setFrstRegEmpNo  (sFrstRegEmpNo      );
            inDto.setLastProcEmpNo (sLastProcEmpNo     );

            cBCCCM01Mapper.insertCtCommCdDesc(inDto);
        }
        catch (Exception e)
        {
            LOGGER.error("[공통코드(CT_COMM_CD_DESC)] : 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }
}