package hanalife.c.bc.cc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.bc.cc.mapper.ZipCdMapper;
import hanalife.c.bc.cc.mapper.dto.ZipCdDSZIPCDSDDTO;
import hanalife.c.bc.cc.mapper.dto.ZipCdDSZIPCDSMDTO;
import hanalife.c.bc.cc.service.CBCCCP03Service;
import hanalife.c.bc.cc.vo.CBCCCP03DSZIPCDSDVO;
import hanalife.c.bc.cc.vo.CBCCCP03S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP03S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP03ServiceImpl.java Class
 * 클래스설명   : 우편번호검색 (CBCCCP03) Service Implements
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCBCCCP03S01 : 우편번호검색목록조회
 * </pre>
 */
@Service("CBCCCP03Service")
public class CBCCCP03ServiceImpl implements CBCCCP03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP03ServiceImpl.class);

	@Autowired
	private ZipCdMapper zipCdMapper;

	/**
	 * <p>메소드명      : getCBCCCP03S01 : 우편번호검색목록조회</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70322 / sungjin.park
	 * <p>설명          : 우편번호검색목록을 조회 한다.</p>
	 * <p>메소드인수    : CBCCCP03S01InVo </p>
	 * <p>메소드리턴값  : CBCCCP03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCP03S01OutVO getCBCCCP03S01(CBCCCP03S01InVO inVo) throws Exception {

		/** 수납내역상세조회 서비스 결과값 객체 생성 */
		CBCCCP03S01OutVO resultVo = new CBCCCP03S01OutVO();

		/** 수납내역상세조회 조회 조건 입력값 객체 생성 및 대입 수행 */
		ZipCdDSZIPCDSMDTO i01Dto = new ZipCdDSZIPCDSMDTO();

		i01Dto.setAddrTpCd(inVo.getCBCCCP03DSZIPCDSMVO().getAddrTpCd());			/** 검색구분(지번,도로명) */
		i01Dto.setCiDoNm(inVo.getCBCCCP03DSZIPCDSMVO().getCiDoNm());				/** 시도명 */
		i01Dto.setCiGunGuNm(inVo.getCBCCCP03DSZIPCDSMVO().getCiGunGuNm());			/** 시군구명 */
		i01Dto.setEubMyunDongNm(inVo.getCBCCCP03DSZIPCDSMVO().getEubMyunDongNm());	/** 읍면동명 */
		i01Dto.setRoadNm(inVo.getCBCCCP03DSZIPCDSMVO().getRoadNm());				/** 도로명 */
		i01Dto.setBldNm(inVo.getCBCCCP03DSZIPCDSMVO().getBldNm());					/** 건물명 */
		i01Dto.setStnoNm(inVo.getCBCCCP03DSZIPCDSMVO().getStnoNm());				/** 지번 */
		i01Dto.setFrstRegEmpNo(inVo.getCBCCCP03DSZIPCDSMVO().getFrstRegEmpNo());	/** 최초등록사번 */
		i01Dto.setLastDealEmpNo(inVo.getCBCCCP03DSZIPCDSMVO().getLastDealEmpNo());	/** 최종처리사번 */
		i01Dto.setRowStstus(inVo.getCBCCCP03DSZIPCDSMVO().getRowStstus());			/** 최종처리사번 */

		// DSZIPCDSD
		/** 연체현황목록조회(부서별) 조회 쿼리 Mapper 호출 수행 */
        List<ZipCdDSZIPCDSDDTO> resultZipCdSdDTO = zipCdMapper.search(i01Dto);

        /** 연체현황목록조회(부서별) 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<CBCCCP03DSZIPCDSDVO> resultZipCdSdList = new ArrayList<CBCCCP03DSZIPCDSDVO>();

        for(ZipCdDSZIPCDSDDTO sourceIO : resultZipCdSdDTO) {
        	/** 연체현황목록조회(부서별) VO에 조회된 Mapper DTO 값을 대입 */
        	CBCCCP03DSZIPCDSDVO targetIO = new CBCCCP03DSZIPCDSDVO();
        	targetIO.setSeq(sourceIO.getSeq()); /** 일련번호 */
        	targetIO.setZipCd(sourceIO.getZipCd()); /** 우편번호 */
        	targetIO.setCiDoNm(sourceIO.getCiDoNm()); /** 시도명 */
        	targetIO.setCiGunGuNm(sourceIO.getCiGunGuNm()); /** 시군구명 */
        	targetIO.setEubMyunDongNm(sourceIO.getEubMyunDongNm()); /** 읍면동명 */
        	targetIO.setRoadNm(sourceIO.getRoadNm()); /** 도로명 */
        	targetIO.setBldNm(sourceIO.getBldNm()); /** 건물명 */
        	targetIO.setRiBldNm(sourceIO.getRiBldNm()); /** 법정리명 */
        	targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); /** 최초등록사번 */
        	targetIO.setLastDealEmpNo(sourceIO.getLastDealEmpNo()); /** 최종처리사번 */
        	targetIO.setSpecRoadNm(sourceIO.getSpecRoadNm()); /** 상세_도로_명 */
        	targetIO.setRefrItem(sourceIO.getRefrItem()); /** 참고_항목 */
        	targetIO.setStnoNm(sourceIO.getStnoNm()); /** 번지 */
        	targetIO.setSpecAddr(sourceIO.getSpecAddr()); /** 상세_주소 */
        	targetIO.setRoadNmNo(sourceIO.getRoadNmNo()); /** 도로명_번호 */

			/** 연체현황목록조회(부서별) List 객체에 추가하도록 수행 */
        	resultZipCdSdList.add(targetIO);
        }

        /** 연체현황목록조회(부서별) 화면 출력 결과값 대입 */
        resultVo.setListCBCCCP03DSZIPCDSDVO(resultZipCdSdList);

		return resultVo;

	}

}
