package hanalife.c.bc.cc.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.nprotect.pluginfree.util.StringUtil;

import hanalife.c.bc.cc.mapper.ChngPswdFrameMapper;
import hanalife.c.bc.cc.service.CBCCCP06Service;
import hanalife.c.bc.cc.vo.CBCCCP06U01InVO;
import hanalife.c.bc.cc.vo.CBCCCP06U01OutVO;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.CtUserMapper;
import hanalife.c.co.mapper.dto.CtUserDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP06ServiceImpl.java Class
 * 클래스설명   : 비밀번호 변경 (CBCCCP06) Service Implements
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : updatePswd     : 비밀번호 변경
 *           updateInitPswd : 비밀번호 초기화
 * </pre>
 */
@Service("CBCCCP06Service")
public class CBCCCP06ServiceImpl implements CBCCCP06Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP06ServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 **/
    private MsgEnum msgEnum;

	@Autowired
	private CtUserMapper ctUserMapper;

	@Autowired
	private ChngPswdFrameMapper ChngPswdFrameMapper;

	/**
	 * <p>메소드명      : updatePswd : 비밀번호 변경</p>
	 * <p>작성일자      : 2023. 3. 27.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 비밀번호를 변경한다.</p>
	 * <p>메소드인수    : CBCCCP06U01InVO </p>
	 * <p>메소드리턴값  : CBCCCP06U01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCP06U01OutVO updatePswd(CBCCCP06U01InVO inVo) throws Exception {

		// 비밀번호값 복호화 불가 -> 신규 비밀번호로 변경 시 암호화 후 이전 비밀번호와 동일 여부 체크

		/*************************************************
		 * ■ 비밀번호 변경 서비스 결과값 객체생성
		 *************************************************/
		CBCCCP06U01OutVO resultVo = new CBCCCP06U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());


		/*************************************************
		 * ■ 비밀번호 변경 조건입력값 객체생성 및 대입수행
		 *************************************************/
		try {

			/**********************************
			 * □ CT-사용자(CT_USER) 조회
			 **********************************/
			CtUserDTO ctUserDTO = new CtUserDTO();
			ctUserDTO.setUserNo(inVo.getCBCCCP06DSPSWDVO().getUserNo());        // 사용자명
			ctUserDTO.setNewPswd(inVo.getCBCCCP06DSPSWDVO().getNewPswd());      // 새로운 비밀번호

			ctUserDTO = ctUserMapper.select(ctUserDTO);

			/**********************************
			 * □ Validation Check
			 **********************************/
			String tmp      = null;
			String pswd    = ctUserDTO.getPswd();       // 기존_비밀번호
			String reqNewPswd = ctUserDTO.getReqNewPswd(); // 신규_비밀번호

			if( ctUserDTO == null ){
			    throw new Exception("등록된 사용자가 아닙니다.");
			}

			// □ 전_비밀번호
			tmp = StringUtil.trim( ctUserDTO.getBfPswd() );
			if( tmp.equals( reqNewPswd ) ){
				//throw new Exception("이전 비밀번호와 같은 비밀번호가 사용 되었습니다.");
				throw new Exception("BFPSWD");
			}

			// □ 전전_비밀번호
			tmp = StringUtil.trim( ctUserDTO.getBf2Pswd() );
			if( tmp.equals( reqNewPswd ) ){
				//throw new Exception("전전 비밀번호와 같은 비밀번호가 사용 되었습니다.");
				throw new Exception("BFPSWD");
			}

			System.out.println("################### ctUserDTO : " + ctUserDTO.getBfPswd());
			
			
			
			/**********************************
			 * □ CT-사용자(CT_USER) 비밀번호 변경
			 **********************************/
			CtUserDTO param = new CtUserDTO();
			param.setPswd(inVo.getCBCCCP06DSPSWDVO().getNewPswd());                    // 변경비밀번호Set
			param.setPswdErrCnt(0);                                                    // 패스워드오류건수
			param.setBfPswd(inVo.getCBCCCP06DSPSWDVO().getPswd());                     // 전패스워드
			param.setBf2Pswd(ctUserDTO.getBfPswd());                                   // 전전패스워드
			param.setLastProcEmpNo(inVo.getCBCCCP06DSPSWDVO().getUserNo());            // 최종처리사원번호
			param.setUserNo(inVo.getCBCCCP06DSPSWDVO().getUserNo());                   // 사용자번호

			System.out.println("################### getBf2Pswd : " + param.getBf2Pswd());
			
			ctUserMapper.pwUpdate(param);

		} catch( Exception e ) {
            throw new Exception(e.getMessage());
		}

		return resultVo;

	}


	/**
	 * <p>메소드명      : updateInitPswd : 비밀번호 초기화</p>
	 * <p>작성일자      : 2023. 3. 27.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 비밀번호를 초기화한다.</p>
	 * <p>메소드인수    : CBCCCP06U01InVO </p>
	 * <p>메소드리턴값  : CBCCCP06U01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCP06U01OutVO updateInitPswd(CBCCCP06U01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 비밀번호 초기화 서비스 결과값 객체생성
		 *************************************************/
		CBCCCP06U01OutVO resultVo = new CBCCCP06U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());


		/*************************************************
		 * ■ 비밀번호 초기화 조건입력값 객체생성 및 대입수행
		 *************************************************/
		try {

			/**********************************
			 * □ CT-사용자(CT_USER) 조회
			 **********************************/
			CtUserDTO ctUserDTO = new CtUserDTO();
			ctUserDTO.setUserNo(inVo.getCBCCCP06DSPSWDVO().getUserNo());      // 사용자명

			ctUserDTO = ctUserMapper.select(ctUserDTO);


			/**********************************
			 * □ Validation Check
			 **********************************/
			if( ctUserDTO == null ){
			    resultVo.setRsltCd(msgEnum.NOT_FOUND.getErrorCd());
                resultVo.setRsltCntn("등록된 사용자가 아닙니다.");
                return resultVo;
			}


			/**********************************
			 * □ CT-사용자(CT_USER) 비밀번호 초기화
			 **********************************/
			ctUserDTO.setPswd(Constants.PSWD);                                               // 신규_비밀번호 셋팅(수정대상)
			ctUserDTO.setPswdErrCnt(0);                                                    // 패스워드오류건수
			ctUserDTO.setBfPswd(ctUserDTO.getPswd());                                      // 전패스워드
			ctUserDTO.setBf2Pswd(ctUserDTO.getBfPswd());                                   // 전전패스워드
			ctUserDTO.setLastProcEmpNo(inVo.getCBCCCP06DSPSWDVO().getLogInEmpNo());        // 최종처리사원번호

			ctUserMapper.pwUpdate(ctUserDTO);

		} catch( Exception e ) {
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
		}

		return resultVo;

	}

}
