package hanalife.c.bc.cc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCP03Service;
import hanalife.c.bc.cc.vo.CBCCCP03DSZIPCDSMVO;
import hanalife.c.bc.cc.vo.CBCCCP03S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP03S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP03Controller.java Class
 * 클래스설명   : 우편번호검색팝업 (CBCCCP03) Controller
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCP03Controller {

	@Resource(name = "CBCCCP03Service")
	private CBCCCP03Service CBCCCP03;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP03Controller.class);

	/**
	 * <p>메소드명      : 우편번호검색팝업조회 /CBCCCP03S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 우편번호검색팝업조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCP03S01.do")
	public String CBCCCP03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCP03Controller CBCCCP03S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ZIP_CD_SM", request, response, model);

			/** 우편번호검색팝업내역조회 업무 서비스 호출 입력값 대입 */
			CBCCCP03DSZIPCDSMVO targetVo = new CBCCCP03DSZIPCDSMVO();

			targetVo.setAddrTpCd((String)sourceMap.get("addrTpCd"));			/*검색구분(지번,도로명)*/
			targetVo.setCiDoNm((String)sourceMap.get("ciDoNm"));				/*시도명*/
			targetVo.setCiGunGuNm((String)sourceMap.get("ciGunGuNm"));			/*시군구명*/
			targetVo.setEubMyunDongNm((String)sourceMap.get("eubMyunDongNm"));	/*읍면동명*/
			targetVo.setRoadNm((String)sourceMap.get("roadNm"));				/*도로명*/
			targetVo.setBldNm((String)sourceMap.get("bldNm"));					/*건물명*/
			targetVo.setStnoNm((String)sourceMap.get("stnoNm"));				/*지번*/
			targetVo.setFrstRegEmpNo((String)sourceMap.get("frstRegEmpNo"));	/*최초등록사번*/
			targetVo.setLastDealEmpNo((String)sourceMap.get("lastDealEmpNo"));	/*최종처리사번*/
			targetVo.setRowStstus((String)sourceMap.get("rowStstus"));			/*최종처리사번*/

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			CBCCCP03S01InVO InVO = new CBCCCP03S01InVO();
            InVO.setCBCCCP03DSZIPCDSMVO(targetVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

			/** 우편번호검색팝업내역조회 업무 서비스 호출 수행 */
			CBCCCP03S01OutVO resultCBCCCP03S01 = CBCCCP03.getCBCCCP03S01(InVO);

			XFrame5Util.setOutputData("DS_ZIP_CD_SD", resultCBCCCP03S01.getListCBCCCP03DSZIPCDSDVO(), model); /** 대출정보조회 */

			LOGGER.info("##### CBCCCP03Controller CBCCCP03S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCP03Controller CBCCCP03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
