package hanalife.c.bc.ci.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import hanalife.c.bc.ci.service.CBCCIM02Service;
import hanalife.c.bc.ci.vo.CBCCIM02DSSMDOVO;
import hanalife.c.bc.ci.vo.CBCCIM02InVO;
import hanalife.c.bc.ci.vo.CBCCIM02OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

@RestController
@RequestMapping("/c/bc/ci")
public class CBCCIM02Controller {
	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCIM02Controller.class);

	@Resource(name = "CBCCIM02Service")
	private CBCCIM02Service CBCCIM02Service;

	@RequestMapping("/CBCCIM02S01.do")
	public String CBCCIM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model)throws Exception{
		/**
		 * <p>메소드명      : 신용정보목록 조회 /CBCCIM02S01.do </p>
		 * <p>작성일자      : 2023. 3. 27.
		 * <p>작성자(author): 70325 / Jaeheon Kim
		 * <p>설명          :신용정보목록 조회한다.</p>
		 * <p>예외처리      : Exception</p>
		 */
		LOGGER.info("##### CBCCIM02Controller CBCCIM02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			/** 화면의 입력값을 VO에 대입 */
			CBCCIM02DSSMDOVO targetVo= new CBCCIM02DSSMDOVO();
			CBCCIM02InVO targetIO= new CBCCIM02InVO();
			targetVo.setResiNo((String)sourceMap.get("resiNo")); /** 주민등록번호 */
			targetVo.setInqDtFr((String)sourceMap.get("inqDtFr")); /** 조회일자 시작 */
			targetVo.setInqDtTo((String)sourceMap.get("inqDtTo")); /** 조회일자 끝 */
			targetVo.setInqInfo((String)sourceMap.get("inqInfo")); /** 조회 정보 */

			/**InVO에 입력값 대입*/

			targetIO.setCBCCIM02DSSMDOVO(targetVo);

			/** 서비스 호출*/
			CBCCIM02OutVO resultVO=CBCCIM02Service.getCBCCIM02S01(targetIO);

			/**결과값 설정*/
			XFrame5Util.setOutputData("DS_SDDO",resultVO.getListCBCCIM02DSSDDOVO(),model);

			LOGGER.info("##### CBCCIM02Controller CBCCIM02S01 Normal End #####");

		}catch(Exception e){
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCIM02Controller CBCCIM02S01 Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;

	}
}
