package hanalife.c.bc.kb.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.bc.kb.mapper.CBCKBM01Mapper;
import hanalife.c.bc.kb.mapper.dto.CBCKBM01DSSRCHSDDTO;
import hanalife.c.bc.kb.mapper.dto.CBCKBM01DSSRCHSMDTO;
import hanalife.c.bc.kb.service.CBCKBM01Service;
import hanalife.c.bc.kb.vo.CBCKBM01DSKBAPTINFOSDVO;
import hanalife.c.bc.kb.vo.CBCKBM01DSKBLDONGCDSDVO;
import hanalife.c.bc.kb.vo.CBCKBM01DSKBMKPRINFOSDVO;
import hanalife.c.bc.kb.vo.CBCKBM01DSKBPNTPINFOSDVO;
import hanalife.c.bc.kb.vo.CBCKBM01InVO;
import hanalife.c.bc.kb.vo.CBCKBM01OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CBCKBM01ServiceImpl.java Class
 * 클래스설명	: KB아파트시세등록 (CBCKBM01) Service Implements
 * 작성일자	: 2023.03.20.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 20.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getCBCKBM01S01	: KB법정동_시도 조회
 * 			getCBCKBM01S02	: KB법정동_시군구 조회
 * 			getCBCKBM01S03	: KB법정동_읍면동 조회
 * 			getCBCKBM01S04	: KB아파트정보 조회
 * 			getCBCKBM01S05	: KB평형정보 조회
 * 			getCBCKBM01S06	: KB아파트시세 조회
 * </pre>
 */
@Service("CBCKBM01Service")
public class CBCKBM01ServiceImpl implements CBCKBM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCKBM01ServiceImpl.class);

	@Autowired
	private CBCKBM01Mapper cBCKBM01Mapper;

	/**
	 * <p>메소드명			: getCBCKBM01S01 : KB법정동_시도 조회</p>
	 * <p>작성일자			: 2023. 3. 20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KB법정동_시도내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S01(CBCKBM01InVO inVo) throws Exception {
		LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S01 Start #####");

	    // KB법정동_시도 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB법정동_시도 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();

	    // 조건값 없음

        // KB법정동_시도 조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchLDongCd01();

        // KB법정동_시도 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBLDONGCDSDVO> resultList = new ArrayList<CBCKBM01DSKBLDONGCDSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

       		// KB법정동_시도 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBLDONGCDSDVO targetIO = new CBCKBM01DSKBLDONGCDSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());	/** 시도명 */

            // KB법정동_시도 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S01 End #####");
        // KB법정동_시도 조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBLDONGCDSDVO(resultList);


        return resultVo;
	}

	/**
	 * <p>메소드명			: getCBCKBM01S01 : KB법정동_시군구 조회</p>
	 * <p>작성일자			: 2023. 3. 20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KKB법정동_시군구 내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S02(CBCKBM01InVO inVo) throws Exception {
		LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S02 Start #####");

	    // KB법정동_시군구 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB법정동_시군구 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();

        i01Dto.setProvNm(inVo.getCBCKBM01DSSRCHSMVO().getProvNm());	/** 시도명 */
   		LOGGER.info("" + "i01Dto.getProvNm()		: " + i01Dto.getProvNm());

        // KB법정동_시군구 조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchLDongCd02(i01Dto);

        // KB법정동_시군구 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBLDONGCDSDVO> resultList = new ArrayList<CBCKBM01DSKBLDONGCDSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

        	// KB법정동_시군구 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBLDONGCDSDVO targetIO = new CBCKBM01DSKBLDONGCDSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());			/* 시도명 */
       		targetIO.setCigunguNm(sourceIO.getCigunguNm());		/* 시군구명 */

            // KB법정동_시군구 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S02 End #####");

        // KB법정동_시군구 조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBLDONGCDSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명			: getCBCKBM01S03 : KB법정동_읍면동 조회</p>
	 * <p>작성일자			: 2023. 3. 20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KB법정동_읍면동 내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S03(CBCKBM01InVO inVo) throws Exception {
		LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S03 Start #####");

	    // KB법정동_읍면동 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB법정동_읍면동 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();

        i01Dto.setProvNm(inVo.getCBCKBM01DSSRCHSMVO().getProvNm());			/** 시도명 */
        i01Dto.setCigunguNm(inVo.getCBCKBM01DSSRCHSMVO().getCigunguNm());	/** 시군구명 */
   		LOGGER.info("" + "i01Dto.getProvNm()		: " + i01Dto.getProvNm());
   		LOGGER.info("" + "i01Dto.getCigunguNm()		: " + i01Dto.getCigunguNm());

        // KB법정동_읍면동 조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchLDongCd03(i01Dto);

        // KB법정동_읍면동 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBLDONGCDSDVO> resultList = new ArrayList<CBCKBM01DSKBLDONGCDSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

        	// KB법정동_읍면동 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBLDONGCDSDVO targetIO = new CBCKBM01DSKBLDONGCDSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());					/* 시도명 */
       		targetIO.setCigunguNm(sourceIO.getCigunguNm()); 			/* 시군구명 */
       		targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm()); 	/* 읍면동명 */

            // KB법정동_읍면동 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S03 End #####");

        // KB법정동_읍면동 조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBLDONGCDSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명			: getCBCKBM01S04 : KB아파트정보 조회</p>
	 * <p>작성일자			: 2023. 3. 20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KB아파트정보 내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S04(CBCKBM01InVO inVo) throws Exception {
		LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S04 Start #####");

	    // KB평형정보 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB평형정보 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();

        i01Dto.setProvNm(inVo.getCBCKBM01DSSRCHSMVO().getProvNm());					/** 시도명 */
        i01Dto.setCigunguNm(inVo.getCBCKBM01DSSRCHSMVO().getCigunguNm());			/** 시군구명 */
        i01Dto.setEubmyundongNm(inVo.getCBCKBM01DSSRCHSMVO().getEubmyundongNm());	/** 읍면동명 */
   		LOGGER.info("" + "i01Dto.getProvNm()		: " + i01Dto.getProvNm());
   		LOGGER.info("" + "i01Dto.getCigunguNm()		: " + i01Dto.getCigunguNm());
   		LOGGER.info("" + "i01Dto.getEubmyundongNm()	: " + i01Dto.getEubmyundongNm());

        // KB아파트정보조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchAptInfo(i01Dto);

        // KB아파트정보조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBAPTINFOSDVO> resultList = new ArrayList<CBCKBM01DSKBAPTINFOSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

        	// KB평형정보 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBAPTINFOSDVO targetIO = new CBCKBM01DSKBAPTINFOSDVO();

       		targetIO.setEsttGodsCd(sourceIO.getEsttGodsCd());				/* 부동산물건코드 */
            targetIO.setProvNm(sourceIO.getProvNm());						/* 시도명 */
            targetIO.setCigunguNm(sourceIO.getCigunguNm());					/* 시군구명 */
            targetIO.setGuNm(sourceIO.getGuNm());							/* 구명 */
            targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());			/* 읍면동명 */
            targetIO.setRiNm(sourceIO.getRiNm());							/* 리명 */
            targetIO.setStno(sourceIO.getStno());							/* 번지 */
            targetIO.setEtcStno(sourceIO.getEtcStno());						/* 기타번지 */
            targetIO.setAptNm(sourceIO.getAptNm());							/* 아파트명 */
            targetIO.setTotDongcnt(sourceIO.getTotDongcnt());				/* 총동수 */
            targetIO.setGrpMaxflor(sourceIO.getGrpMaxflor());				/* 단지최고층 */
            targetIO.setGrpMinflor(sourceIO.getGrpMinflor());				/* 단지최저층 */
            targetIO.setCmplYymm(sourceIO.getCmplYymm());					/* 준공년월 */
            targetIO.setConsVndrNm(sourceIO.getConsVndrNm());				/* 건설업체명 */
            targetIO.setHeatFrml(sourceIO.getHeatFrml());					/* 난방방식 */
            targetIO.setHeatFuel(sourceIO.getHeatFuel());					/* 난방연료 */
            targetIO.setParkQty(sourceIO.getParkQty());						/* 주차대수 */
            targetIO.setMngOffcTelNo(sourceIO.getMngOffcTelNo());			/* 관리사무소전화번호 */
            targetIO.setBunygRigtFg(sourceIO.getBunygRigtFg());				/* 분양권여부 */
            targetIO.setInHousYymm(sourceIO.getInHousYymm());				/* 입주년월 */
            targetIO.setGrpFeat(sourceIO.getGrpFeat());						/* 단지특징 */
            targetIO.setZipCd(sourceIO.getZipCd());							/* 우편번호 */
            targetIO.setHousShopMixFg(sourceIO.getHousShopMixFg());			/* 주상복합여부 */
            targetIO.setVillaRowHousFg(sourceIO.getVillaRowHousFg());		/* 빌라연립여부 */
            targetIO.setLdongCd(sourceIO.getLdongCd());						/* 법정동코드 */
            targetIO.setRimdlFg(sourceIO.getRimdlFg());						/* 리모델여부 */
            targetIO.setRoadNmZipCd(sourceIO.getRoadNmZipCd());				/* 도로명우편번호 */
            targetIO.setRoadNmEubmyunNo(sourceIO.getRoadNmEubmyunNo());		/* 도로명읍면번호 */
            targetIO.setRoadNmSubNo(sourceIO.getRoadNmSubNo());				/* 도로명보조번호 */
            targetIO.setRoadNmZoneNo(sourceIO.getRoadNmZoneNo());			/* 도로명구역번호 */
            targetIO.setUdgdDiv(sourceIO.getUdgdDiv());						/* 지하구분 */
            targetIO.setRoadNmBldgMainNo(sourceIO.getRoadNmBldgMainNo());   /* 도로명건물메인번호 */
            targetIO.setRoadNmBldgSubNo(sourceIO.getRoadNmBldgSubNo());		/* 도로명건물보조번호 */
            targetIO.setRoadNmBldgMngNo(sourceIO.getRoadNmBldgMngNo());		/* 도로명건물관리번호 */
            targetIO.setRoadBaseAddr(sourceIO.getRoadBaseAddr());			/* 도로기본주소 */
            targetIO.setRoadSpecAddr(sourceIO.getRoadSpecAddr());			/* 도로상세주소 */
            targetIO.setxPos(sourceIO.getxPos());							/* X좌표값 */
            targetIO.setyPos(sourceIO.getyPos());							/* Y좌표값 */
            targetIO.setMkprExpstYn(sourceIO.getMkprExpstYn());				/* 시세노출여부 */
            targetIO.setPntpKind(sourceIO.getPntpKind());					/* 평형종류 */
            targetIO.setWficeNm(sourceIO.getWficeNm());						/* 구청명 */
            targetIO.setDongOffcNm(sourceIO.getDongOffcNm());				/* 동사무소명 */
            targetIO.setPoliBoxNm(sourceIO.getPoliBoxNm());					/* 파출소명 */
            targetIO.setOffcroomdocNm(sourceIO.getOffcroomdocNm());			/* 소방서명 */
            targetIO.setBankNm(sourceIO.getBankNm());						/* 은행명 */
            targetIO.setHospNm(sourceIO.getHospNm());						/* 병원명 */
            targetIO.setSportCntrNm(sourceIO.getSportCntrNm());				/* 스포츠센터명 */
            targetIO.setShopCntrNm(sourceIO.getShopCntrNm());				/* 쇼핑센터명 */
            targetIO.setSchlNm(sourceIO.getSchlNm());						/* 학교명 */
            targetIO.setParkNm(sourceIO.getParkNm());						/* 공원명 */
            targetIO.setGenbusNo(sourceIO.getGenbusNo());					/* 일반버스번호 */
            targetIO.setSeatbusNo(sourceIO.getSeatbusNo());					/* 좌석버스번호 */
            targetIO.setSubwLineNm(sourceIO.getSubwLineNm());				/* 지하철노선명 */
            targetIO.setSubwStanNm(sourceIO.getSubwStanNm());				/* 지하철역명 */
            targetIO.setNeedTm(sourceIO.getNeedTm());						/* 소요시간 */

            // KB아파트정보조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S04 End #####");

        // KB아파트정보조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBAPTINFOSDVO(resultList);

        return resultVo;
	}


	/**
	 * <p>메소드명			: getCBCKBM01S05 : KB평형정보 조회</p>
	 * <p>작성일자			: 2023.03.20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KB평형정보 내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S05(CBCKBM01InVO inVo) throws Exception {
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S05 Start #####");

	    // KB평형정보 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB평형정보 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();
        i01Dto.setEsttGodsCd(inVo.getCBCKBM01DSSRCHSMVO().getEsttGodsCd());		/** 부동산물건코드 */

        // KB평형정보 조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchPntpInfo(i01Dto);

        // KB평형정보 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBPNTPINFOSDVO> resultList = new ArrayList<CBCKBM01DSKBPNTPINFOSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

        	// KB평형정보 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBPNTPINFOSDVO targetIO = new CBCKBM01DSKBPNTPINFOSDVO();

			targetIO.setEsttGodsCd(sourceIO.getEsttGodsCd());	/* 부동산물건코드 */
		    targetIO.setPntpSeq(sourceIO.getPntpSeq());			/* 평형순번 */
		    targetIO.setSplyArea(sourceIO.getSplyArea());		/* 공급면적 */
		    targetIO.setPntpDiv(sourceIO.getPntpDiv());			/* 평형구분 */
		    targetIO.setEuseArea(sourceIO.getEuseArea());		/* 전용면적 */
		    targetIO.setHshdCnt(sourceIO.getHshdCnt());			/* 세대수 */
		    targetIO.setRoomCnt(sourceIO.getRoomCnt());			/* 방수 */
		    targetIO.setBathCnt(sourceIO.getBathCnt());			/* 욕실수 */
		    targetIO.setBunygAmt(sourceIO.getBunygAmt());		/* 분양가 */
		    targetIO.setDrct(sourceIO.getDrct());				/* 방향 */
		    targetIO.setNowclasCons(sourceIO.getNowclasCons());	/* 현관구조 */
		    targetIO.setEtcEuseArea(sourceIO.getEtcEuseArea());	/* 기타전용면적 */
		    targetIO.setHoustpArea(sourceIO.getHoustpArea());	/* 주택형면적 */

            // KB평형정보 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S05 End #####");

        // KB평형정보 조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBPNTPINFOSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명			: getCBCKBM01S06 : KB아파트시세 조회</p>
	 * <p>작성일자			: 2023. 3. 20.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: KB평형정보 내역을 조회한다.</p>
	 * <p>메소드인수		: CBCKBM01InVO </p>
	 * <p>메소드리턴값		: CBCKBM01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CBCKBM01OutVO getCBCKBM01S06(CBCKBM01InVO inVo) throws Exception {
		LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S06 Start #####");

	    // KB아파트시세정보 조회 서비스 결과값 객체 생성
		CBCKBM01OutVO resultVo = new CBCKBM01OutVO();

	    // KB아파트시세정보 조회 조건 입력값 객체 생성 및 대입 수행
	    CBCKBM01DSSRCHSMDTO i01Dto = new CBCKBM01DSSRCHSMDTO();
        i01Dto.setEsttGodsCd(inVo.getCBCKBM01DSSRCHSMVO().getEsttGodsCd());		/** 부동산물건코드 */
        i01Dto.setPntpSeq(inVo.getCBCKBM01DSSRCHSMVO().getPntpSeq());			/** 평형seq */

        // KB아파트시세정보 조회 쿼리 Mapper 호출 수행
        List<CBCKBM01DSSRCHSDDTO> resultDTO = cBCKBM01Mapper.searchMkprInfo(i01Dto);

        // KB아파트시세정보 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CBCKBM01DSKBMKPRINFOSDVO> resultList = new ArrayList<CBCKBM01DSKBMKPRINFOSDVO>();
       	for (CBCKBM01DSSRCHSDDTO sourceIO : resultDTO) {

        	// KB아파트시세정보 조회 VO에 조회된 Mapper DTO 값을 대입
       		CBCKBM01DSKBMKPRINFOSDVO targetIO = new CBCKBM01DSKBMKPRINFOSDVO();

			targetIO.setRschStndDt(sourceIO.getRschStndDt());			/* 조사기준일 */
			targetIO.setEsttGodsCd(sourceIO.getEsttGodsCd());			/* 부동산물건코드 */
			targetIO.setPntpSeq(sourceIO.getPntpSeq());					/* 평형순번 */
			targetIO.setProvNm(sourceIO.getProvNm());					/* 시도명 */
			targetIO.setCigunguNm(sourceIO.getCigunguNm());				/* 시군구명 */
			targetIO.setGuNm(sourceIO.getGuNm());						/* 구명 */
			targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());		/* 읍면동명 */
			targetIO.setRiNm(sourceIO.getRiNm());						/* 리명 */
			targetIO.setStno(sourceIO.getStno());						/* 번지 */
			targetIO.setEtcAddr(sourceIO.getEtcAddr());					/* 기타주소 */
			targetIO.setAptNm(sourceIO.getAptNm());						/* 아파트명 */
			targetIO.setSaleBtmlAmt(sourceIO.getSaleBtmlAmt());			/* 매매하한가 */
			targetIO.setSaleGenTrAmt(sourceIO.getSaleGenTrAmt());		/* 매매일반거래가 */
			targetIO.setSaleUplmitAmt(sourceIO.getSaleUplmitAmt());		/* 매매상한가 */
			targetIO.setDpstBtmlAmt(sourceIO.getDpstBtmlAmt());			/* 전세하한가 */
			targetIO.setDpstGenTrAmt(sourceIO.getDpstGenTrAmt());		/* 전세일반거래가 */
			targetIO.setDpstUplmitAmt(sourceIO.getDpstUplmitAmt());		/* 전세상한가 */
			targetIO.setMmTaxGuarAmt(sourceIO.getMmTaxGuarAmt());		/* 월세보증금 */
			targetIO.setMmRentMinAmt(sourceIO.getMmRentMinAmt());		/* 월임대최저금액 */
			targetIO.setMmRentMaxAmt(sourceIO.getMmRentMaxAmt());		/* 월임대최고금액 */
			targetIO.setLdongCd(sourceIO.getLdongCd());					/* 법정동코드 */
			targetIO.setInShopVndrNm(sourceIO.getInShopVndrNm());		/* 입점업체명 */
			targetIO.setOffcTelNo(sourceIO.getOffcTelNo());				/* 사무실전화번호 */
			targetIO.setInShopVndrNm2(sourceIO.getInShopVndrNm2());		/* 입점업체명2 */
			targetIO.setOffcTelNo2(sourceIO.getOffcTelNo2());			/* 사무실전화번호2 */
			targetIO.setMkprClsTm(sourceIO.getMkprClsTm());				/* 시세마감년월일 */
			targetIO.setMkprExpstYn(sourceIO.getMkprExpstYn());			/* 시세노출여부 */

            // KB아파트시세정보 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### CBCBM01 ServiceImpl getCBCKBM01S06 End #####");

        // KB아파트시세정보 조회 화면 출력 결과값 대입
        resultVo.setListCBCKBM01DSKBMKPRINFOSDVO(resultList);

        return resultVo;
	}

}
