package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.BtCustRefInfoDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BtCustRefInfoMapper.java Class
 * 클래스설명   : BT_고객_참조_정보(BT_CUST_REF_INFO) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("BtCustRefInfoMapper")
public interface BtCustRefInfoMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 조회
     * 메소드인수1   : {BtCustRefInfoDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {BtCustRefInfoDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public BtCustRefInfoDTO select(BtCustRefInfoDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 목록조회
     * 메소드인수1   : {BtCustRefInfoDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<BtCustRefInfoDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<BtCustRefInfoDTO> selectList(BtCustRefInfoDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 등록(신규)
     * 메소드인수1   : {BtCustRefInfoDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(BtCustRefInfoDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 변경(수정)
     * 메소드인수1   : {BtCustRefInfoDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(BtCustRefInfoDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {BtCustRefInfoDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(BtCustRefInfoDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : BT_고객_참조_정보(BT_CUST_REF_INFO) 제거(테이블에서 삭제)
     * 메소드인수1   : {BtCustRefInfoDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(BtCustRefInfoDTO inDto) throws Exception;

}
