package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.CommBizINDTO;
import hanalife.c.co.mapper.dto.GetHpNoByLoanNoDTO;
import hanalife.c.co.mapper.dto.HtWorkCharDdDTO;
import hanalife.c.co.mapper.dto.ProcGetNextNumberDTO;
import hanalife.c.co.vo.CommCdVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CommBizMapper.java Class
 * 클래스설명   : 업무별 공통 유틸리티 Interface Mapper
 * 작성일자     : 2023. 3. 14.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 14.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>CommBizMapper
 */
@Mapper("CommBizMapper")
public interface CommBizMapper {

    /**
     * <pre>
     * 메소드명      : selectWorkDt
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70317 / younghwe.kim / 가계대출 시스템 구축
     * 설명          : 영업일여부 조회
     * 메소드인수1   : {HtWorkCharDdDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {HtWorkCharDdDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public HtWorkCharDdDTO selectWorkDt(HtWorkCharDdDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectLastWkdt
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70317 / younghwe.kim / 가계대출 시스템 구축
     * 설명          : 최근영업일 - 입력된 날짜보다 작은 가장 최근 과거영업일
     * 메소드인수1   : {HtWorkCharDdDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {HtWorkCharDdDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public HtWorkCharDdDTO selectLastWkdt(HtWorkCharDdDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectArrvWkdt
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70317 / younghwe.kim / 가계대출 시스템 구축
     * 설명          : 미래영업일 - 입력된 날짜보다 작은 큰 최근 도래영업일
     * 메소드인수1   : {HtWorkCharDdDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {HtWorkCharDdDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public HtWorkCharDdDTO selectArrvWkdt(HtWorkCharDdDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectArrvWkdt
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70279 / 가계대출 시스템 구축
     * 설명          : 날짜계산(영업일, input이 휴일일경우 당일포함)
     * 메소드인수1   : CommBizINDTO
     * 메소드리턴값  : String
     * 예외처리      : Exception
     * </pre>
     */
    public String selectAddWkdt(CommBizINDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : procGetNextNumber
     * 작성일자      : 2023. 4. 19.
     * 작성자(author): 70279 / 가계대출 시스템 구축
     * 설명          : 분류종류번호와 분류번호 1~6을 넣고 채번된 값을 반환한다.
     * 메소드인수1   : ProcGetNextNumberDTO
     * 메소드리턴값  : ProcGetNextNumberDTO
     * 예외처리      : Exception
     * </pre>
     */
    public ProcGetNextNumberDTO procGetNextNumber(ProcGetNextNumberDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchCommCdList
     * 작성일자      : 2023. 4. 19.
     * 작성자(author): 70279 / 가계대출 시스템 구축
     * 설명          : 공통코드 조회
     * 메소드인수1   : SearchCommCdListINDTO
     * 메소드리턴값  : SearchCommCdListOUTDTO
     * 예외처리      : Exception
     * </pre>
     */
    public List<CommCdVO> searchCommCdList(CommCdVO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : getHpNo
     * 작성일자      : 2023. 4. 19.
     * 작성자(author): 70279 / 가계대출 시스템 구축
     * 설명          : 휴대폰번호 조회
     * 메소드인수1   : GetHpNoByLoanNoDTO
     * 메소드리턴값  : GetHpNoByLoanNoDTO
     * 예외처리      : Exception
     * </pre>
     */
    public GetHpNoByLoanNoDTO getHpNo(GetHpNoByLoanNoDTO inVO) throws Exception;

}
