package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.CtUserDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CtUserMapper.java Class
 * 클래스설명   : CT-사용자(CT_USER) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("CtUserMapper")
public interface CtUserMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : CT-사용자(CT_USER) 조회
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {CtUserDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public CtUserDTO select(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : CT-사용자(CT_USER) 목록조회
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<CtUserDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<CtUserDTO> selectList(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : CT-사용자(CT_USER) 등록(신규)
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : CT-사용자(CT_USER) 변경(수정)
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : CT-사용자(CT_USER) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : CT-사용자(CT_USER) 제거(테이블에서 삭제)
     * 메소드인수1   : {CtUserDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(CtUserDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : pwUpdate
     * 설명          : 패스워드 변경(수정) 및 초기화
     * 메소드인수1   : {CtUserDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int pwUpdate(CtUserDTO inDto) throws Exception;

}
