package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.HtOrgDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : HtOrgMapper.java Class
 * 클래스설명   : HT-기관코드(HT_ORG) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("HtOrgMapper")
public interface HtOrgMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : HT-기관코드(HT_ORG) 조회
     * 메소드인수1   : {HtOrgDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {HtOrgDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public HtOrgDTO select(HtOrgDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : HT-기관코드(HT_ORG) 목록조회
     * 메소드인수1   : {HtOrgDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<HtOrgDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<HtOrgDTO> selectList(HtOrgDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : HT-기관코드(HT_ORG) 등록(신규)
     * 메소드인수1   : {HtOrgDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(HtOrgDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : HT-기관코드(HT_ORG) 변경(수정)
     * 메소드인수1   : {HtOrgDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(HtOrgDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : HT-기관코드(HT_ORG) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {HtOrgDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(HtOrgDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : HT-기관코드(HT_ORG) 제거(테이블에서 삭제)
     * 메소드인수1   : {HtOrgDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(HtOrgDTO inDto) throws Exception;

}
