package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StElecRegDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StElecRegMapper.java Class
 * 클래스설명   : 전자등기원장(ST_ELEC_REG) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 5.10.
 * 작성자명     : 70319 / jeongseon.shin / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5.10.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StElecRegMapper")
public interface StElecRegMapper {

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : 전자등기원장(ST_ELEC_REG) 조회
     * 메소드인수1   : {StElecRegDTO} inDto(대출신청번호:loanApplNo)
     * 메소드리턴값  : {StElecRegDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StElecRegDTO> selectList(StElecRegDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : 전자등기원장(ST_ELEC_REG) 등록(신규)
     * 메소드인수1   : {StElecRegDTO} inDto
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StElecRegDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : 전자등기원장(ST_ELEC_REG) 변경(수정)
     * 메소드인수1   : {StElecRegDTO} inDto(대출신청번호:loanApplNo)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StElecRegDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : 전자등기원장(ST_ELEC_REG) 제거(테이블에서 삭제)
     * 메소드인수1   : {StElecRegDTO}(대출신청번호:loanApplNo)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StElecRegDTO inDto) throws Exception;

}
