package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StLoanChngConsStagDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StLoanChngConsStagMapper.java Class
 * 클래스설명   : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StLoanChngConsStagMapper")
public interface StLoanChngConsStagMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 조회
     * 메소드인수1   : {StLoanChngConsStagDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StLoanChngConsStagDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StLoanChngConsStagDTO select(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 목록조회
     * 메소드인수1   : {StLoanChngConsStagDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StLoanChngConsStagDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StLoanChngConsStagDTO> selectList(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 등록(신규)
     * 메소드인수1   : {StLoanChngConsStagDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 변경(수정)
     * 메소드인수1   : {StLoanChngConsStagDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StLoanChngConsStagDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-대출변경품의단계(ST_LOAN_CHNG_CONS_STAG) 제거(테이블에서 삭제)
     * 메소드인수1   : {StLoanChngConsStagDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insertStLoanChngConsStag
     * 작성일자      : 2023. 3. 16.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : [대출 변경 품의] 생성 한다.
     * 메소드인수1   : StLoanChngConsStagDTO 입력
     * 메소드리턴값  : StLoanChngConsStagDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public void insertStLoanChngConsStag(StLoanChngConsStagDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : updateStLoanChngConsStag
     * 작성일자      : 2023. 3. 16.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : [대출 변경 품의] 수정 한다.
     * 메소드인수1   : StLoanChngConsStagDTO 입력
     * 메소드리턴값  : StLoanChngConsStagDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public void updateStLoanChngConsStag(StLoanChngConsStagDTO inDto) throws Exception;

}
