package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StLoanGodsDescDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StLoanGodsDescMapper.java Class
 * 클래스설명   : ST-대출물품내역(ST_LOAN_GODS_DESC) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StLoanGodsDescMapper")
public interface StLoanGodsDescMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 조회
     * 메소드인수1   : {StLoanGodsDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StLoanGodsDescDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StLoanGodsDescDTO select(StLoanGodsDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 목록조회
     * 메소드인수1   : {StLoanGodsDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StLoanGodsDescDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StLoanGodsDescDTO> selectList(StLoanGodsDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 등록(신규)
     * 메소드인수1   : {StLoanGodsDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StLoanGodsDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 변경(수정)
     * 메소드인수1   : {StLoanGodsDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StLoanGodsDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StLoanGodsDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StLoanGodsDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-대출물품내역(ST_LOAN_GODS_DESC) 제거(테이블에서 삭제)
     * 메소드인수1   : {StLoanGodsDescDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StLoanGodsDescDTO inDto) throws Exception;

}
