package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StLoanPiamtDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StLoanPiamtMapper.java Class
 * 클래스설명   : 대출원리금(ST_LOAN_PIAMT) 테이블 Interface Mapper
 * 작성일자     : 2023. 3. 16.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 14.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("stLoanPiamtMapper")
public interface StLoanPiamtMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 조회
     * 메소드인수1   : {StLoanPiamtDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StLoanPiamtDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StLoanPiamtDTO select(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 목록조회
     * 메소드인수1   : {StLoanPiamtDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StLoanPiamtDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StLoanPiamtDTO> selectList(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 등록(신규)
     * 메소드인수1   : {StLoanPiamtDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 변경(수정)
     * 메소드인수1   : {StLoanPiamtDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StLoanPiamtDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-대출원리금(ST-LOAN_PIAMT) 제거(테이블에서 삭제)
     * 메소드인수1   : {StLoanPiamtDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StLoanPiamtDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchMaxTrSnum
     * 작성일자      : 2023. 3. 16.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 대출원리금(ST_LOAN_PIAMT) 등록
     * 메소드인수1   : StLoanPiamtDTO 입력
     * 메소드리턴값  : StLoanPiamtDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public StLoanPiamtDTO searchMaxTrSnum(StLoanPiamtDTO inDto) throws Exception;

}
