package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StReprDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StReprMapper.java Class
 * 클래스설명   : ST-대표자(ST_REPR) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 24.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 24.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StReprMapper")
public interface StReprMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-대표자(ST_REPR) 조회
     * 메소드인수1   : {StReprDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StReprDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StReprDTO select(StReprDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-대표자(ST_REPR) 목록조회
     * 메소드인수1   : {StReprDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StReprDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StReprDTO> selectList(StReprDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-대표자(ST_REPR) 등록(신규)
     * 메소드인수1   : {StReprDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StReprDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-대표자(ST_REPR) 변경(수정)
     * 메소드인수1   : {StReprDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StReprDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-대표자(ST_REPR) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StReprDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StReprDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-대표자(ST_REPR) 제거(테이블에서 삭제)
     * 메소드인수1   : {StReprDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StReprDTO inDto) throws Exception;

}
