package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StSetlDdChngHistDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StSetlDdChngHistMapper.java Class
 * 클래스설명   : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StSetlDdChngHistMapper")
public interface StSetlDdChngHistMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 조회
     * 메소드인수1   : {StSetlDdChngHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StSetlDdChngHistDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StSetlDdChngHistDTO select(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 목록조회
     * 메소드인수1   : {StSetlDdChngHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StSetlDdChngHistDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StSetlDdChngHistDTO> selectList(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 등록(신규)
     * 메소드인수1   : {StSetlDdChngHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 변경(수정)
     * 메소드인수1   : {StSetlDdChngHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StSetlDdChngHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-결제일변경이력(ST_SETL_DD_CHNG_HIST) 제거(테이블에서 삭제)
     * 메소드인수1   : {StSetlDdChngHistDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchSetlDdChng
     * 작성일자      : 2023. 3. 13.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 결제일변경 히스토리를 조회 한다.
     * 메소드인수1   : StSetlDdChngHistDTO 입력
     * 메소드리턴값  : StSetlDdChngHistDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public List<StSetlDdChngHistDTO> searchSetlDdChngList(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchSetlDdChngHist2
     * 작성일자      : 2023. 3. 13.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 가장 최근 결제일 변경 이력 조회 한다.
     * 메소드인수1   : StSetlDdChngHistDTO 입력
     * 메소드리턴값  : StSetlDdChngHistDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public List<StSetlDdChngHistDTO> searchSetlDdChngHist2(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insertStSetlDdChngHist
     * 작성일자      : 2023. 3. 13.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 결제일변경 이력 등록 한다.
     * 메소드인수1   : StSetlDdChngHistDTO 입력
     * 메소드리턴값  : StSetlDdChngHistDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public void insertStSetlDdChngHist(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insertStSetlDdChngHist
     * 작성일자      : 2023. 3. 13.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 결제일변경내역 테이블에서 max snum을 조회 한다.
     * 메소드인수1   : StSetlDdChngHistDTO 입력
     * 메소드리턴값  : String 출력
     * 예외처리      : Exception
     * </pre>
     */
    public String searchMaxSnum(StSetlDdChngHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : updateStSetlDdChngHist
     * 작성일자      : 2023. 3. 13.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 결제일변경 이력 수정 한다.
     * 메소드인수1   : StSetlDdChngHistDTO 입력
     * 메소드리턴값  : StSetlDdChngHistDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public void updateStSetlDdChngHist(StSetlDdChngHistDTO inDto) throws Exception;

}
