package hanalife.c.co.mapper.dto;

import java.math.BigDecimal;

import hanalife.c.co.vo.AbstractVO;
import lombok.ToString;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StSgiDalyAdjInfoDTO.java Class
 * 클래스설명    : ST_SGI_일일정산정보(ST_SGI_DALY_ADJ_INFO)를(을) 위한 테이블 DTO(VO)
 * 작성일자     : 2023. 4. 17.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 17.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@ToString
public class StSgiDalyAdjInfoDTO extends AbstractVO {

    private static final long serialVersionUID = 1L;

    private String adjDt = "";                                      /* 정산_일자 */
    private String adjObjDt = "";                                   /* 정산_대상_영업일자 */
    private String rsltCd = "";                                     /* 결과코드 */
    private int newCnt = 0;                                         /* 신규건수 */
    private int sgiNewCnt = 0;                                      /* SGI신규건수 */
    private BigDecimal newFee = BigDecimal.ZERO;                    /* 신규보험료 */
    private BigDecimal sgiNewFee = BigDecimal.ZERO;                 /* SGI신규보험료 */
    private int closCnt = 0;                                        /* 해지건수 */
    private int sgiClosCnt = 0;                                     /* SGI해지건수 */
    private BigDecimal closFee = BigDecimal.ZERO;                   /* 해지보험료 */
    private BigDecimal sgiClosFee = BigDecimal.ZERO;                /* SGI해지보험료 */
    private int scrtIssuClosCnt = 0;                                /* 증권발급해지건수 */
    private int sgiScrtIssuClosCnt = 0;                             /* SGI증권발급해지건수 */
    private BigDecimal scrtIssuClosFee = BigDecimal.ZERO;           /* 증권발급해지보험료 */
    private BigDecimal sgiScrtIssuClosFee = BigDecimal.ZERO;        /* SGI증권발급해지보험료 */
    private int guarExtnCnt = 0;                                    /* 보증연장건수 */
    private int sgiGuarExtnCnt = 0;                                 /* SGI보증연장건수 */
    private BigDecimal guarExtnFee = BigDecimal.ZERO;               /* 보증연장보험료 */
    private BigDecimal sgiGuarExtnFee = BigDecimal.ZERO;            /* SGI보증연장보험료 */
    private int insdMidContChngCnt = 0;                             /* 피보험자중도계약변경건수 */
    private int sgiMidContChngCnt = 0;                              /* SGI중도계약변경건수 */
    private BigDecimal insdMidContChngFee = BigDecimal.ZERO;        /* 피보험자중도계약변경보험료 */
    private BigDecimal sgiMidContChngFee = BigDecimal.ZERO;         /* SGI중도계약변경보험료 */
    private int rdctCnt = 0;                                        /* 감액건수 */
    private int sgiRdctCnt = 0;                                     /* SGI감액건수 */
    private BigDecimal rdctFee = BigDecimal.ZERO;                   /* 감액보험료 */
    private BigDecimal sgiRdctFee = BigDecimal.ZERO;                /* SGI감액보험료 */
    private BigDecimal adjAmt = BigDecimal.ZERO;                    /* 정산금액 */
    private BigDecimal sgiAdjAmt = BigDecimal.ZERO;                 /* SGI정산금액 */
    private int endrCrctToutCnt = 0;                                /* 정정배서 환급건수(은행) */
    private int sgiEndrCrctToutCnt = 0;                             /* 정정배서 환급건수(SGI) */
    private BigDecimal endrCrctToutFee = BigDecimal.ZERO;           /* 정정배서 환급보험료(은행) */
    private BigDecimal sgiEndrCrctToutFee = BigDecimal.ZERO;        /* 정정배서 환급보험료(SGI) */
    private int endrCrctAddCnt = 0;                                 /* 정정배서 추가건수(은행) */
    private int sgiEndrCrctAddCnt = 0;                              /* 정정배서 추가건수(SGI) */
    private BigDecimal endrCrctAddFee = BigDecimal.ZERO;            /* 정정배서 추가보험료(은행) */
    private BigDecimal sgiEndrCrctAddFee = BigDecimal.ZERO;         /* 정정배서 추가보험료(SGI) */
    private int sgiAdjAfCnclCnt = 0;                                /* SGI정산후취소 건수 */
    private BigDecimal sgiAdjAfCnclFee = BigDecimal.ZERO;           /* SGI정산후취소 보험료 */
    private BigDecimal lastAdjAmt = BigDecimal.ZERO;                /* 최종정산금액 */
    private String adjYn = "";                                      /* 정산여부 */
    private String sendDt = "";                                     /* 전송일자 */
    private String sendTm = "";                                     /* 전송시각 */
    private String adjEmpNo = "";                                   /* 정산_사원번호 */
    private String procEmpNo = "";                                  /* 처리_사원번호 */

    public String getAdjDt() {
        return adjDt;
    }
    public void setAdjDt(String adjDt) {
        this.adjDt = adjDt;
    }
    public String getAdjObjDt() {
        return adjObjDt;
    }
    public void setAdjObjDt(String adjObjDt) {
        this.adjObjDt = adjObjDt;
    }
    public String getRsltCd() {
        return rsltCd;
    }
    public void setRsltCd(String rsltCd) {
        this.rsltCd = rsltCd;
    }
    public int getNewCnt() {
        return newCnt;
    }
    public void setNewCnt(int newCnt) {
        this.newCnt = newCnt;
    }
    public int getSgiNewCnt() {
        return sgiNewCnt;
    }
    public void setSgiNewCnt(int sgiNewCnt) {
        this.sgiNewCnt = sgiNewCnt;
    }
    public BigDecimal getNewFee() {
        return newFee;
    }
    public void setNewFee(BigDecimal newFee) {
        this.newFee = newFee;
    }
    public BigDecimal getSgiNewFee() {
        return sgiNewFee;
    }
    public void setSgiNewFee(BigDecimal sgiNewFee) {
        this.sgiNewFee = sgiNewFee;
    }
    public int getClosCnt() {
        return closCnt;
    }
    public void setClosCnt(int closCnt) {
        this.closCnt = closCnt;
    }
    public int getSgiClosCnt() {
        return sgiClosCnt;
    }
    public void setSgiClosCnt(int sgiClosCnt) {
        this.sgiClosCnt = sgiClosCnt;
    }
    public BigDecimal getClosFee() {
        return closFee;
    }
    public void setClosFee(BigDecimal closFee) {
        this.closFee = closFee;
    }
    public BigDecimal getSgiClosFee() {
        return sgiClosFee;
    }
    public void setSgiClosFee(BigDecimal sgiClosFee) {
        this.sgiClosFee = sgiClosFee;
    }
    public int getScrtIssuClosCnt() {
        return scrtIssuClosCnt;
    }
    public void setScrtIssuClosCnt(int scrtIssuClosCnt) {
        this.scrtIssuClosCnt = scrtIssuClosCnt;
    }
    public int getSgiScrtIssuClosCnt() {
        return sgiScrtIssuClosCnt;
    }
    public void setSgiScrtIssuClosCnt(int sgiScrtIssuClosCnt) {
        this.sgiScrtIssuClosCnt = sgiScrtIssuClosCnt;
    }
    public BigDecimal getScrtIssuClosFee() {
        return scrtIssuClosFee;
    }
    public void setScrtIssuClosFee(BigDecimal scrtIssuClosFee) {
        this.scrtIssuClosFee = scrtIssuClosFee;
    }
    public BigDecimal getSgiScrtIssuClosFee() {
        return sgiScrtIssuClosFee;
    }
    public void setSgiScrtIssuClosFee(BigDecimal sgiScrtIssuClosFee) {
        this.sgiScrtIssuClosFee = sgiScrtIssuClosFee;
    }
    public int getGuarExtnCnt() {
        return guarExtnCnt;
    }
    public void setGuarExtnCnt(int guarExtnCnt) {
        this.guarExtnCnt = guarExtnCnt;
    }
    public int getSgiGuarExtnCnt() {
        return sgiGuarExtnCnt;
    }
    public void setSgiGuarExtnCnt(int sgiGuarExtnCnt) {
        this.sgiGuarExtnCnt = sgiGuarExtnCnt;
    }
    public BigDecimal getGuarExtnFee() {
        return guarExtnFee;
    }
    public void setGuarExtnFee(BigDecimal guarExtnFee) {
        this.guarExtnFee = guarExtnFee;
    }
    public BigDecimal getSgiGuarExtnFee() {
        return sgiGuarExtnFee;
    }
    public void setSgiGuarExtnFee(BigDecimal sgiGuarExtnFee) {
        this.sgiGuarExtnFee = sgiGuarExtnFee;
    }
    public int getInsdMidContChngCnt() {
        return insdMidContChngCnt;
    }
    public void setInsdMidContChngCnt(int insdMidContChngCnt) {
        this.insdMidContChngCnt = insdMidContChngCnt;
    }
    public int getSgiMidContChngCnt() {
        return sgiMidContChngCnt;
    }
    public void setSgiMidContChngCnt(int sgiMidContChngCnt) {
        this.sgiMidContChngCnt = sgiMidContChngCnt;
    }
    public BigDecimal getInsdMidContChngFee() {
        return insdMidContChngFee;
    }
    public void setInsdMidContChngFee(BigDecimal insdMidContChngFee) {
        this.insdMidContChngFee = insdMidContChngFee;
    }
    public BigDecimal getSgiMidContChngFee() {
        return sgiMidContChngFee;
    }
    public void setSgiMidContChngFee(BigDecimal sgiMidContChngFee) {
        this.sgiMidContChngFee = sgiMidContChngFee;
    }
    public int getRdctCnt() {
        return rdctCnt;
    }
    public void setRdctCnt(int rdctCnt) {
        this.rdctCnt = rdctCnt;
    }
    public int getSgiRdctCnt() {
        return sgiRdctCnt;
    }
    public void setSgiRdctCnt(int sgiRdctCnt) {
        this.sgiRdctCnt = sgiRdctCnt;
    }
    public BigDecimal getRdctFee() {
        return rdctFee;
    }
    public void setRdctFee(BigDecimal rdctFee) {
        this.rdctFee = rdctFee;
    }
    public BigDecimal getSgiRdctFee() {
        return sgiRdctFee;
    }
    public void setSgiRdctFee(BigDecimal sgiRdctFee) {
        this.sgiRdctFee = sgiRdctFee;
    }
    public BigDecimal getAdjAmt() {
        return adjAmt;
    }
    public void setAdjAmt(BigDecimal adjAmt) {
        this.adjAmt = adjAmt;
    }
    public BigDecimal getSgiAdjAmt() {
        return sgiAdjAmt;
    }
    public void setSgiAdjAmt(BigDecimal sgiAdjAmt) {
        this.sgiAdjAmt = sgiAdjAmt;
    }
    public int getEndrCrctToutCnt() {
        return endrCrctToutCnt;
    }
    public void setEndrCrctToutCnt(int endrCrctToutCnt) {
        this.endrCrctToutCnt = endrCrctToutCnt;
    }
    public int getSgiEndrCrctToutCnt() {
        return sgiEndrCrctToutCnt;
    }
    public void setSgiEndrCrctToutCnt(int sgiEndrCrctToutCnt) {
        this.sgiEndrCrctToutCnt = sgiEndrCrctToutCnt;
    }
    public BigDecimal getEndrCrctToutFee() {
        return endrCrctToutFee;
    }
    public void setEndrCrctToutFee(BigDecimal endrCrctToutFee) {
        this.endrCrctToutFee = endrCrctToutFee;
    }
    public BigDecimal getSgiEndrCrctToutFee() {
        return sgiEndrCrctToutFee;
    }
    public void setSgiEndrCrctToutFee(BigDecimal sgiEndrCrctToutFee) {
        this.sgiEndrCrctToutFee = sgiEndrCrctToutFee;
    }
    public int getEndrCrctAddCnt() {
        return endrCrctAddCnt;
    }
    public void setEndrCrctAddCnt(int endrCrctAddCnt) {
        this.endrCrctAddCnt = endrCrctAddCnt;
    }
    public int getSgiEndrCrctAddCnt() {
        return sgiEndrCrctAddCnt;
    }
    public void setSgiEndrCrctAddCnt(int sgiEndrCrctAddCnt) {
        this.sgiEndrCrctAddCnt = sgiEndrCrctAddCnt;
    }
    public BigDecimal getEndrCrctAddFee() {
        return endrCrctAddFee;
    }
    public void setEndrCrctAddFee(BigDecimal endrCrctAddFee) {
        this.endrCrctAddFee = endrCrctAddFee;
    }
    public BigDecimal getSgiEndrCrctAddFee() {
        return sgiEndrCrctAddFee;
    }
    public void setSgiEndrCrctAddFee(BigDecimal sgiEndrCrctAddFee) {
        this.sgiEndrCrctAddFee = sgiEndrCrctAddFee;
    }
    public int getSgiAdjAfCnclCnt() {
        return sgiAdjAfCnclCnt;
    }
    public void setSgiAdjAfCnclCnt(int sgiAdjAfCnclCnt) {
        this.sgiAdjAfCnclCnt = sgiAdjAfCnclCnt;
    }
    public BigDecimal getSgiAdjAfCnclFee() {
        return sgiAdjAfCnclFee;
    }
    public void setSgiAdjAfCnclFee(BigDecimal sgiAdjAfCnclFee) {
        this.sgiAdjAfCnclFee = sgiAdjAfCnclFee;
    }
    public BigDecimal getLastAdjAmt() {
        return lastAdjAmt;
    }
    public void setLastAdjAmt(BigDecimal lastAdjAmt) {
        this.lastAdjAmt = lastAdjAmt;
    }
    public String getAdjYn() {
        return adjYn;
    }
    public void setAdjYn(String adjYn) {
        this.adjYn = adjYn;
    }
    public String getSendDt() {
        return sendDt;
    }
    public void setSendDt(String sendDt) {
        this.sendDt = sendDt;
    }
    public String getSendTm() {
        return sendTm;
    }
    public void setSendTm(String sendTm) {
        this.sendTm = sendTm;
    }
    public String getAdjEmpNo() {
        return adjEmpNo;
    }
    public void setAdjEmpNo(String adjEmpNo) {
        this.adjEmpNo = adjEmpNo;
    }
    public String getProcEmpNo() {
        return procEmpNo;
    }
    public void setProcEmpNo(String procEmpNo) {
        this.procEmpNo = procEmpNo;
    }
}
