package hanalife.c.co.service;

import java.util.List;

import hanalife.batch.ProcObj;
import hanalife.c.co.vo.CommCdVO;
import hanalife.c.co.vo.SearchCommCdOutVO;
import hanalife.c.co.vo.SearchCommCdVO;
import hanalife.c.co.vo.SearchLoanSeqVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CommBizUtil.java Class
 * 클래스설명   : 업무별 공통 Util Service
 * 작성일자     : 2023. 4. 5.
 * 작성자명     : 70279 / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 5.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * Method Information
 * -----------------------------------------------------------------------------
 * 1. SearchLoanSeq     : 대출번호/순번 존재여부 조회
 * 2. isWorkDt          : 영업일 여부 조회
 * 3. gvnoDsrcNo        : 예/가수번호 채번
 * 4. gvnoLoanNo        : 대출번호 채번
 * 5. addWkdt           : 영업일 날짜계산 (영업일, input이 휴일일경우 당일포함)
 * 6. isChk             : 체크값 조회
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface CommBizService {

    /**
     * <pre>
     * 메소드명 : SearchLoanSeq
     * 설명 : 대출번호/순번 존재여부 조회
     * 메소드인수1: 대출번호, 대출순번, 관리번호
     * 사용예) CommBizUtil.SearchLoanSeq(대출번호, 대출순번, 관리번호)
     * 메소드리턴값: SearchLoanSeqVO(대출번호, 대출순번, 관리번호, 최종여부)
     * </pre>
     */
    public SearchLoanSeqVO SearchLoanSeq(String pstrLoanNo, String pstrLoanSeq, String pstrMngNo) throws Exception;

    /** 공통 영업일자 Util ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■ */
    /**
     * <pre>
     * 메소드명 : isWorkDt
     * 설 명 : 영업일 여부
     * 메소드인수 : {String} pstWorkDt 일자(yyyyMMdd)
     * 리 턴 값 : boolean
     * </pre>
     */
    public boolean isWorkDt(String pstWorkDt) throws Exception;

    /**
     * <pre>
     * 메소드명 : isOprTime
     * 설 명 : 운영시간 여부
     * 메소드인수 : {String} pstWorkDt 일자(HHmm)
     * 리 턴 값 : boolean
     * </pre>
     */
    public boolean isOprTime(String dttm) throws Exception;

    /**
     * <pre>
     * 메소드명     : isLastWkdt
     * 설 명        : 최근영업일 - 입력된 날짜보다 작은 가장 최근 과거영업일
     * 메소드인수   : {String} pstWorkDt : 일자(yyyyMMdd)
     *                {String} pstrIncludeFlag : 1(Y)=당일포함, 0(N)=당일제외
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    public String isLastWkdt(String pstWorkDt, String pstrIncludeFlag) throws Exception;

    /**
     * <pre>
     * 메소드명     : isArrvWkdt
     * 설 명        : 도래영업일 - 입력된 날짜보다 작은 큰 최근 미래영업일
     * 메소드인수   : {String} pstWorkDt : 일자(yyyyMMdd)
     *                {String} pstrIncludeFlag : 1(Y)=당일포함, 0(N)=당일제외
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    public String isArrvWkdt(String pstWorkDt, String pstrIncludeFlag) throws Exception;

    /**
     * <pre>
     * 메소드명     : isMonthNWkDt
     * 설 명        : 월 n 번째 영업일 (말영업일은 -1)
     * 메소드인수   : {String} pstYearMm : 년월(yyyyMM)
     *                {String} pstrDay > 0 이면 번째 영업일, 0=말영업일
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    public String isMonthNWkDt(String pstYearMm, int pstrDay) throws Exception;

    /** 공통코드 Util ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■ */
	/**
	 * <p>메소드명	    : searchCommCd</p>
	 * <p>설　　명	    : 공통코드 조회</p>
	 * <p>메소드인수	: {String} pstrCdKindNo : 코드종류번호, {String} pstrCdDescNo : 코드상세번호
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getSearchCommCd() VO 객체는 조회된 공통코드 VO
	 */
	public SearchCommCdOutVO searchCommCd(String pstrCdKindNo, String pstrCdDescNo) throws Exception;

	/**
	 * <p>메소드명	    : searchCommCd</p>
	 * <p>설　　명	    : 공통코드 조회</p>
	 * <p>메소드인수	: {SearchCommCdVO} inVo : 코드조회 입력 항목 VO </p>
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getSearchCommCd() VO 객체는 조회된 공통코드 VO
	 */
	public SearchCommCdOutVO searchCommCd(SearchCommCdVO inVo) throws Exception;

	/**
	 * <p>메소드명	    : searchCommCdList</p>
	 * <p>설　　명	    : 코드종류번호에 따른 공통코드 목록조회</p>
	 * <p>메소드인수	: {String} pstrCdKindNo : 코드종류번호
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getListSearchCommCd() VO 객체는 조회된 공통코드목록 VO
	 */
	public SearchCommCdOutVO searchCommCdList(String pstrCdKindNo) throws Exception;

    /**
     * <p>메소드명   : getCodeNm</p>
     * <p>설　　명   : 해당 필드명의 공통코드 값을 구한다.</p>
     * <p>메소드인수 : {String} pstrCdKindNo : 코드종류번호, {String} pstrCdDescNo : 코드상세번호, {String} pstrColNm : 코드칼럼명
     * <p>리　턴　값 : String</p>
     */
    public String getCodeNm(String pstrCdKindNo, String pstrCdDescNo, String pstrColNm) throws Exception;

    /**
     * <p>메소드명   : getCodeNm</p>
     * <p>설　　명   : 해당 필드명의 공통코드 값을 구한다.</p>
     * <p>메소드인수 : SearchCommCdVO, pstrColNm</p>
     * <p>리　턴　값 : String</p>
     */
    public String getCodeNm(SearchCommCdVO inVo, String pstrColNm) throws Exception;

    /**
	 * <p>메소드명		: gvnoDsrcNo</p>
	 * <p>설명			: 예가수번호채번</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	public String gvnoDsrcNo(String acctDt) throws Exception;

	/**
	 * <p>메소드명		: gvnoLoanNo</p>
	 * <p>설명			: 미확인 대출번호 채번(입금인불명일때)
	 * 						U0601000001, 11자리, [U] + [YYMM] + [00000X]</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	public String gvnoLoanNo(String acctDt) throws Exception;

	/**
	 * <p>메소드명	: addWkdt</p>
	 * <p>설　　명	: 날짜계산 유틸(영업일, input이 휴일일경우 당일포함)</p>
	 * <p>메소드인수	: String baseDt, int addDayCnt</p>
	 * <p>리　턴　값	: String date</p>
	 */
	public String addWkdt(String baseDt, int addDayCnt) throws Exception;

	/**
	 * <p>메소드명	: isChk</p>
	 * <p>설　　명	: 체크값 조회</p>
	 * <p>메소드인수	: Connection, 업무코드코드, 내역번호</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public boolean isChk(String kindNo, String descNo)  throws Exception;

	/**
	 * <p>메소드명	: searchCommCdList</p>
	 * <p>설　　명	: 공통코드 조회</p>
	 * <p>메소드인수	: CommCdVO</p>
	 * <p>리　턴　값	: List</p>
	 */
	public List<CommCdVO> searchCommCdList(CommCdVO inVO) throws Exception;


    /**
     * <p>분류종류번호와 분류번호 1~6을 넣고 채번된 값을 반환한다.
     * @param clasKindNo 채번코드번호
     * @param clasNo1 분류번호1
     * @param clasNo2 분류번호2
     * @param clasNo3 분류번호3
     * @param clasNo4 분류번호4
     * @param clasNo5 분류번호5
     * @param clasNo6 분류번호6
     * @param empNo 채번을 요청한 담당자번호
     * @return
     * @throws Exception
     */
    public String getNextNumber(String clasKindNo,String clasNo1,String clasNo2,String clasNo3
        ,String clasNo4,String clasNo5,String clasNo6,String empNo) throws Exception;

    /**
     * 설정항목 여부 조회
     * @param cdKindNo
     * @param cdDescNo
     * @return boolean bRtn
     */
    public boolean isOk(String cdKindNo, String cdDescNo);

    /**
     * 청구입금배치부서코드 검색(처리사원/부서, 처리일자/시각을 조회)
     * @param cdKindNo
     * @param cdDescNo
     * @return boolean bRtn
     */
    public ProcObj getBatchProcInfo();

    /**
     * 운영시간 조회
     * @param cdKindNo
     * @param cdDescNo
     * @return Array [from, to]
     */
    public String[] getOprTm(String cdDescNo) throws Exception;

    /**
     * 고객 핸드폰번호
     * @param loanNo - 대출번호
     * @param loanSeq - 대출순번
     * @param custGb - 구분(1:계약자, 2:실납입자)
     * @return String []
     */
    public String[] getHpNo(String loanNo, String loanSeq, String custGb) throws Exception;
}
