package hanalife.c.co.util;

import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.SimpleTimeZone;

import hanalife.c.co.contants.DateConstants;

/**
 *
 * 개발자 : <a href="mailto:yhk1712@kico.co.kr">김윤환</a> 생성일자 : 2020. 7. 17.
 *
 */
public abstract class DateUtil implements DateConstants {

    // -------------------------------------------------------------------------
    // 현재 날짜 및 시간
    // -------------------------------------------------------------------------
	//private static String _dateFormat = "yyyy-MM-dd";
    public static final int YYYY = 1; // 연
    public static final int YYYYMM = 2; // 연월
    public static final int MMDD = 3; // 월일
    public static final int YYYYMMDD = 4; // 연월일
    public static final int YYYYMMDDHHMMSS = 5; // 연월일시분초
    public static final int YY = 6; // 연(2자리)
    public static final int YYMM = 7; // 연월
    public static final int YYMMDD = 8; // 연월일
    public static final int HHMMSS = 9; // 시분초
    public static final int YYYYMMDD_WITH_DELIMETER = 10; // 시분초
    public static final int HHMMSS_DELIMETER = 11; // 시분초

	public static final  String YYYYMMDD_FM = "yyyyMMdd";
	public static final  String MMDD_FM = "MMdd";
	
    //public static final String YYYY_MM_DD = "yyyy-MM-dd";
    /**
     * 기본일자형식({@link DateConstants#DF_DATE})으로 된 현재날짜를 반환한다.
     *
     * @return 현재날짜
     */
    public static Date getCurrentDate() {
        return getCurrentDateTime(DF_DATE); // 시간값은 무시됨
    }

    /**
     * 입력형식으로 된 현재날짜를 반환한다.
     *
     * @param dateFormat 날짜형식
     * @return 현재날짜
     */
    public static Date getCurrentDate(String dateFormat) {
        return getCurrentDateTime(dateFormat);
    }

    /**
     * 입력형식으로 된 현재날짜의 문자열을 반환한다.
     *
     * <pre>
     *  예)
     *      String dateTimeString = DateUtils.getCurrentDateString(DateUtils.DF_YYYYMMDDHHMMSS_DP);
     * </pre>
     *
     * @param dateFormat 날짜형식
     * @return 현재날짜에 대한 문자열
     */
    public static String getCurrentDateString(String dateFormat) {
        Date currentDate = Calendar.getInstance().getTime();
        SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
        return sdf.format(currentDate);
    }

    /**
     * 현재시각을 반환한다.
     *
     * @return 현재일시
     */
    public static Date getCurrentDateTime() {
        return Calendar.getInstance().getTime();
    }

    /**
     * 기본일자형식({@link DateConstants#DF_BASE})으로 된 현재일시를 반환한다.
     *
     * @return 현재일시
     */
    public static Date getCurrentBaseDateTime() {
        return getCurrentDateTime(DF_BASE); // 밀리세컨드는 무시됨.
    }

    /**
     * 입력형식으로 된 현재날짜 또는 일시를 반환한다.
     *
     * @param dateFormat 날짜형식
     * @return 현재날짜
     */
    public static Date getCurrentDateTime(String dateFormat) {
        Date currentDate = Calendar.getInstance().getTime();
        SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
        try {
            return sdf.parse(sdf.format(currentDate));
        } catch (Exception e) {
            return currentDate;
        }
    }

    /**
     * 입력받은 <code>java.util.Date</code>의 해당월 날짜를 1일로 설정하여 반환
     *
     * @param date 설정할 날짜
     * @return 입력된 날짜의 해당월 첫번째 날짜
     */
    public static Date getFirstDateOfMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DAY_OF_MONTH, 1);

        return calendar.getTime();
    }

    /**
     * 입력받은 <code>java.util.Date</code>의 해당월 마지막 날짜를 설정하여 반환
     *
     * @param date 설정할 날짜
     * @return 입력된 날짜의 해당월 마지막 날짜
     */
    public static Date getLastDateOfMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getActualMaximum(Calendar.DAY_OF_MONTH));

        return calendar.getTime();
    }

    /**
     * 입력받은 <code>java.util.Date</code>를 1월 1일로 설정하여 반환
     *
     * @param date 설정할 날짜
     * @return 입력일자의 1월 1일 날짜
     */
    public static Date getFirstDateOfYear(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.set(Calendar.MONTH, Calendar.JANUARY);

        return calendar.getTime();
    }

    /**
     * 입력받은 <code>java.util.Date</code>를 12월 31일로 설정하여 반환
     *
     * @param date 설정할 날짜
     * @return 입력일자의 12월 31일 날짜
     */
    public static Date getLastDateOfYear(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DAY_OF_MONTH, 31);
        calendar.set(Calendar.MONTH, Calendar.DECEMBER);

        return calendar.getTime();
    }

    // -------------------------------------------------------------------------
    // 문자열 --> 날짜 변경
    // -------------------------------------------------------------------------

    /**
     * 기본일자형식({@link DateConstants#DF_DATE})의 날짜문자열을 날짜로 변환하여 반환한다.
     * <p>
     * 내부에서 {@link #toDate(String, String) toDate(dateString, DF_DATE)} 를 호출한다.
     *
     * @param dateString 날짜문자열
     * @return 날짜
     */
    public static Date toDate(String dateString) {
        return toDate(dateString, DF_DATE);
    }

    /**
     * format형태인 String데이터를 java.util.Date로 변환
     * <p>
     * 다음과 같이 지정형식보다 많은 데이터값이 들어오면 오류가 발생한다. 단, 지정 형식과 다른 데이터가 입력되면 널을 반환한다.
     *
     * <pre>
     * <code>
     * DateUtils.toDate("20091223124040", "yyyyMMddHHmm"); // [Sat Dec 26 07:20:00 KST 2009]
     * DateUtils.toDate("20091223124040", "yyyyMMdd"); // [Wed May 21 00:00:00 KST 65321]
     * DateUtils.toDate("2009", "yyyy"); // [Fri Jan 01 00:00:00 KST 2009]
     * DateUtils.toDate("200912", "yyyy"); // [Fri Jan 01 00:00:00 KST 200912]
     * DateUtils.toDate("20091223", "yyyy-MM-dd"); // [null]
     * </code>
     * </pre>
     *
     * <b><strong><font color="red"> ※ 위의 결과에서 볼수 있듯이 지정형식과 같으면서 데이터가 많을 경우 원하는 결과값과 다른 결과를 반환하므로 사용시 주의해서 사용하도록 한다. </font></strong></b>
     *
     * @param dateString 변경대상이 되는 일자문자열
     * @param dateFormat 날짜형식
     * @return java.util.Date
     */
    public static Date toDate(String dateString, String dateFormat) {
        if (dateString == null || dateString.length() == 0)
            return null;

        try {
            SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
            return sdf.parse(dateString);
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * 변경전날짜형식의 날짜문자열을 변경후날짜형식의 날짜로 변환하여 반환한다.
     * <p>
     * 변경전날짜형식과 변경후날짜형식이 널이면 기본날짜형식({@link DateConstants#DF_DATE})을 적용한다.
     *
     * @param dateString       날짜문자열
     * @param beforeDateFormat 변경전날짜형식
     * @param afterDateFormat  변경후날짜형식
     * @return 변경후날짜형식으로 변환된 날짜. 만약 입력된 날짜문자열이 널이거나 형식이 유효하지 않을 경우 널을 반환한다.
     */
    public static Date toDate(String dateString, String beforeDateFormat, String afterDateFormat) {
        if (dateString == null || dateString.length() == 0)
            return null;
        // 변경전날짜형식과 변경후날짜형식이 널이면 기본날짜형식을 적용하고 형식이 같을 경우 날짜를 변경하지 않고 반환한다.
        if (beforeDateFormat == null)
            beforeDateFormat = DF_DATE;
        if (afterDateFormat == null)
            afterDateFormat = DF_DATE;

        try {
            SimpleDateFormat sdf = new SimpleDateFormat(beforeDateFormat);
            Date date = sdf.parse(dateString);
            if (beforeDateFormat == afterDateFormat || beforeDateFormat.equals(afterDateFormat)) {
                return date;
            }

            // 패턴변경후 날짜변환
            sdf.applyPattern(afterDateFormat); // 패턴변경
            return sdf.parse(sdf.format(date));
        } catch (Exception e) {
            return null;
        }
    }

    // -------------------------------------------------------------------------
    // 날짜 --> 문자열 변경
    // -------------------------------------------------------------------------

    /**
     * 기본일자형식({@link DateConstants#DF_DATE})으로 된 현재날짜를 문자열로 반환한다.
     *
     * @return 현재날짜(yyyyMMdd)
     */
    public static String getCurrentDateString() {
        Date currentDate = getCurrentDateTime();
        return toDateString(currentDate, DF_DATE);
    }

    /**
     * 기본형식({@link DateConstants#DF_BASE})으로 된 현재날짜를 문자열로 반환한다.
     *
     * @return 현재날짜(yyyyMMddHHmmss)
     */
    public static String getCurrentBaseDateString() {
        Date currentDate = getCurrentDateTime();
        return toDateString(currentDate, DF_BASE);
    }

    /**
     * <code>java.util.Date</code>인 데이터를 날짜형식에 맞게 <code>java.lang.String</code>으로 변환
     *
     * @param date       변경대상이 되는 일자
     * @param dateFormat 날짜형식
     * @return 입력된 날짜형식으로 변환된 날짜문자열
     */
    public static String toDateString(Date date, String dateFormat) {
        if (date == null)
            return null;
        SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
        return sdf.format(date);
    }

    /**
     * 입력받은 <code>java.util.Date</code>의 해당월 날짜를 1일로 설정하여 데이터를 날짜형식에 맞게 <code>java.lang.String</code>으로 변환
     *
     * @param date       설정할 날짜
     * @param dateFormat 날짜형식
     * @return 입력된 날짜형식으로 변환된 해당월 첫번째 날짜
     */
    public static String getFirstDateStringOfMonth(Date date, String dateFormat) {
        return toDateString(getFirstDateOfMonth(date), dateFormat);
    }

    /**
     * 입력받은 <code>java.util.Date</code>의 해당월 마지막 날짜를 설정하여 데이터를 날짜 형식에 맞게 <code>java.lang.String</code>으로 변환
     *
     * @param date       설정할 날짜
     * @param dateFormat 날짜형식
     * @return 입력된 날짜형식으로 변환된 해당월 마지막 날짜
     */
    public static String getLastDateStringOfMonth(Date date, String dateFormat) {
        return toDateString(getLastDateOfMonth(date), dateFormat);
    }

    /**
     * 입력받은 <code>java.util.Date</code>를 1월 1일로 설정하여 데이터를 날짜 형식에 맞게 <code>java.lang.String</code>으로 변환
     *
     * @param date       설정할 날짜
     * @param dateFormat 날짜형식
     * @return 입력된 날짜형식으로 변환된 입력일자의 1월 1일 날짜
     */
    public static String getFirstDateStringOfYear(Date date, String dateFormat) {
        return toDateString(getFirstDateOfYear(date), dateFormat);
    }

    /**
     * 입력받은 <code>java.util.Date</code>를 12월 31일로 설정하여 데이터를 날짜 형식에 맞게 <code>java.lang.String</code>으로 변환
     *
     * @param date       설정할 날짜
     * @param dateFormat 날짜형식
     * @return 입력된 날짜형식으로 변환된 입력일자의 12월 31일 날짜
     */
    public static String getLastDateStringOfYear(Date date, String dateFormat) {
        return toDateString(getLastDateOfYear(date), dateFormat);
    }

    // -------------------------------------------------------------------------
    // 문자열 --> 문자열 변경
    // -------------------------------------------------------------------------

    /**
     * 날짜형식변경
     * <p>
     * 변경전날짜형식과 변경후날짜형식이 널이면 기본날짜형식({@link DateConstants#DF_DATE})을 적용하고 형식이 같을 경우 날짜를 변경하지 않고 반환한다.
     *
     * @param dateString       변경대상이 되는 일자
     * @param beforeDateFormat 변경전날짜형식. 널이 입력되면 {@link DateConstants#DF_DATE}을 적용한다.
     * @param afterDateFormat  변경후날짜형식. 널이 입력되면 {@link DateConstants#DF_DATE}을 적용한다.
     * @return 변경후날짜형식으로 변환된 날짜문자열. 만약 입력된 날짜문자열이 널이거나 형식이 유효하지 않을 경우 널을 반환한다.
     */
    public static String convertDateFormat(String dateString, String beforeDateFormat, String afterDateFormat) {
        if (dateString == null)
            return null;
        // 변경전날짜형식과 변경후날짜형식이 널이면 기본날짜형식을 적용하고 형식이 같을 경우 날짜를 변경하지 않고 반환한다.
        if (beforeDateFormat == null)
            beforeDateFormat = DF_DATE;
        if (afterDateFormat == null)
            afterDateFormat = DF_DATE;
        if (beforeDateFormat == afterDateFormat || beforeDateFormat.equals(afterDateFormat))
            return dateString;

        SimpleDateFormat sdf = new SimpleDateFormat(beforeDateFormat);
        try {
            Date date = sdf.parse(dateString);
            sdf.applyPattern(afterDateFormat); // 패턴변경
            return sdf.format(date);
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * 기준일자가 해당월의 말일자인지 여부를 반환한다.
     *
     * @param basisDate 기준일자
     */
    public static boolean isLastDay(Date basisDate) {
        Calendar basisCal = Calendar.getInstance();
        basisCal.setTime(basisDate);
        return isLastDay(basisCal);
    }

    /**
     * 기준일자가 해당월의 말일자인지 여부를 반환한다.
     *
     * @param basisCal 기준달력
     */
    public static boolean isLastDay(Calendar basisCal) {
        return (basisCal.get(Calendar.DATE) == basisCal.getActualMaximum(Calendar.DATE));
    }

    /**
     * 해당일의 말일자 구하기
     *
     * <pre>
     * setLastDay("20100119", "yyyyMMdd") => "20100131" setLastDay("20100205", "yyyy-MM-dd") => "2010-02-28"
     *
     * @param dateString 기준일자 (yyyyMMdd)s
     * @param dateFormat 반환될 날짜형식
     * @return
     */
    public static String setLastDay(String dateString, String dateFormat) {
        Date date = toDate(dateString, DF_DATE);

        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DATE, calendar.getActualMaximum(Calendar.DAY_OF_MONTH));

        return toDateString(new Date(calendar.getTimeInMillis()), dateFormat);
    }

    /**
     * 일자의 요일을 반환
     *
     * <pre>
     * "20100117(일요일) ==> 1 "20080123(토요일) ==> 7
     *
     * @param date 일자
     * @return
     */
    public static int getDayOfWeek(Date date) {
        int result = 0;
        Calendar calendar = Calendar.getInstance(Locale.KOREAN);
        calendar.setTime(date);
        result = calendar.get(Calendar.DAY_OF_WEEK);
        return result;
    }

    /**
     * 입력받은 날짜에서 +/- N일의 날짜를 구한다.
     *
     * @param date 기준 일자
     * @param day  +/- N일
     * @return 결과 일자
     */
    public static String changeDateWithDayLevel(Date date, int day) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        cal.set(Calendar.DAY_OF_MONTH, cal.get(Calendar.DAY_OF_MONTH) + day);
        return toDateString(cal.getTime(), DF_DATE);
    }

    /**
     * 입력한 일자가 오늘일자 기준 이전일자인지 여부 (오늘일자 포함 안함)
     *
     * @param date 일자
     * @return 여부
     */
    public static boolean isBeforeDate(Date date) {
        String currentDate = getCurrentDateString();
        String compareDate = toDateString(date, DF_DATE);
        int compare = currentDate.compareTo(compareDate);
        if (compare > 0)
            return true;
        return false;
    }

    /**
     * 입력한 일자가 오늘일자 기준 이전일자인지 여부 (오늘일자 포함 안함)
     *
     * @param date 일자
     * @return 여부
     */
    public static boolean isBeforeDate(String compareDate) {
        String currentDate = getCurrentDateString();
        int compare = currentDate.compareTo(compareDate);
        if (compare > 0)
            return true;
        return false;
    }

    /**
     * 첫번째 입력한 일자가 두번째 입력한 비교일자 기준 이전 일자인지 여부
     *
     * @param date        일자
     * @param compareDate 비교일자
     * @return 여부
     */
    public static boolean isBeforeDate(String date, String compareDate) {
        int compare = compareDate.compareTo(date);
        if (compare >= 0)
            return true;
        return false;
    }

    /**
     * 입력한 일자가 오늘일자 기준 이후 일자인지 여부 (오늘일자 포함 안함)
     *
     * @param date 일자
     * @return 여부
     */
    public static boolean isAfterDate(Date date) {
        String currentDate = getCurrentDateString();
        String compareDate = toDateString(date, DF_DATE);
        int compare = currentDate.compareTo(compareDate);
        if (compare < 0)
            return true;
        return false;
    }

    /**
     * 입력한 일자가 오늘일자 기준 이후 일자인지 여부 (오늘일자 포함 안함)
     *
     * @param date 일자
     * @return 여부
     */
    public static boolean isAfterDate(String date) {
        String currentDate = getCurrentDateString();
        int compare = currentDate.compareTo(date);
        if (compare < 0)
            return true;
        return false;
    }

    /**
	 * <p>주어진 날짜 Date의 년수를 입력년수만큼 증감시킨다.
	 * @param dateString yyyyMMdd, yyyyMM, yyyy !!포맷엄수
	 * @param addYear 1 1년후, -2 2년전
	 * @return 3가지 입력Date포맷으로 리턴, !!포맷에러, nuu입력시 null리턴
	 */
	public static String addYear(String dateString, int addYear) {
		try {
			if (dateString == null) {
				return null;
			}

			int year = 0;
			int month = 2;
			int day = 1;
			String format = "yyyyMMdd";

			GregorianCalendar cal = new GregorianCalendar();

			if (dateString.length() == 8) {
				year = Integer.parseInt(dateString.substring(0, 4));
				month = Integer.parseInt(dateString.substring(4, 6));
				day = Integer.parseInt(dateString.substring(6));
			}
			else if (dateString.length() == 6) {
				year = Integer.parseInt(dateString.substring(0, 4));
				month = Integer.parseInt(dateString.substring(4));

				format = "yyyyMM";
			}
			else if (dateString.length() == 4) {
				year = Integer.parseInt(dateString.substring(0, 4));

				format = "yyyy";
			}
			else {
				return null;
			}

			//MONTH 는 0 ~ 11 이므로 실제 데이터의 마이너스 1
			cal.set(year, month - 1, day);
			cal.add(GregorianCalendar.YEAR, addYear);

			SimpleDateFormat formatter = new SimpleDateFormat(format);

			return formatter.format(cal.getTime());

		}catch (Exception e) {
			return null;
		}
	}

	/**
	 * <p>주어진 날짜 Date의 월수를 입력월수만큼 증감시킨다.
	 * @param dateString yyyyMMdd, yyyyMM !!포맷엄수
	 * @param addMonth 1 한달후, -2 두달전
	 * @return 2가지 입력Date포맷으로 리턴, !!포맷에러, nuu입력시 null리턴
	 */
	public static String addMonth(String dateString, int addMonth) {
		try {
			if (dateString == null) {
				return null;
			}

			int year = 0;
			int month = 2;
			int day = 1;
			String format = "yyyyMMdd";

			GregorianCalendar cal = new GregorianCalendar();

			if (dateString.length() == 8) {
				year = Integer.parseInt(dateString.substring(0, 4));
				month = Integer.parseInt(dateString.substring(4, 6));
				day = Integer.parseInt(dateString.substring(6));
			}
			else if (dateString.length() == 6) {
				year = Integer.parseInt(dateString.substring(0, 4));
				month = Integer.parseInt(dateString.substring(4));

				format = "yyyyMM";
			}
			else {
				return null;
			}

			//MONTH 는 0 ~ 11 이므로 실제 데이터의 마이너스 1
			cal.set(year, month - 1, day);
			cal.add(GregorianCalendar.MONTH, addMonth);

			SimpleDateFormat formatter = new SimpleDateFormat(format);

			return formatter.format(cal.getTime());
		}
		catch (Exception e) {
			return null;
		}
	}

	/**
	 * 주어진 날짜 DATE 의 일수를 입력일수 만큼 증감.
	 * @param dateString yyyyMMdd형식의 날짜
	 * @param addDay 증감시킬 일수
	 * @return 포맷엄수, 포맷에러,null입력시 null리턴
	 */
	public static String addDay(String dateString, int addDay) {
		try {

			if ( (dateString == null) || (dateString.length() != 8)) {
				return null;
			}

			int year = Integer.parseInt(dateString.substring(0, 4));
			int month = Integer.parseInt(dateString.substring(4, 6));
			int day = Integer.parseInt(dateString.substring(6, 8));

			GregorianCalendar cal = new GregorianCalendar();

			//MONTH 는 0 ~ 11 이므로 실제 데이터의 마이너스 1
			cal.set(year, month - 1, day);
			cal.add(GregorianCalendar.DAY_OF_YEAR, addDay);

			SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMdd");

			return formatter.format(cal.getTime());
		}
		catch (Exception e) {
			return null;
		}
	}

	/**
	 * 주어진 날짜 DATE(from, to) 의 기간 구하기
	 * @param from yyyyMMdd 형식
	 * @param to yyyyMMdd 형식
	 * @return 입력일자의 기간일수
	 */
	public static int daysBetween(String from, String to) {
		return daysBetween(from, to, "yyyyMMdd");
	}

	/**
	 * <p>주어진 날짜 DATE(from, to) 의 기간(일) 구하기 to - from
	 * <p>from, to 일자의 포맷은 일치해야한다.
	 * @param from 시작일자
	 * @param to 종료일자
	 * @param format 날짜포맷 ( yyyy-MM-dd, yyyyMMdd)
	 * @return
	 */
	public static int daysBetween(String from, String to, String format) {
		SimpleDateFormat formatter = new SimpleDateFormat(format,
			java.util.Locale.KOREA);
		Date d1 = null;
		Date d2 = null;

		try {
			d1 = formatter.parse(from);
			d2 = formatter.parse(to);
		}
		catch (ParseException e) {
			return -1;
		}

		if (!formatter.format(d1).equals(from)) {
			return -1;
		}

		if (!formatter.format(d2).equals(to)) {
			return -1;
		}

		long duration = d2.getTime() - d1.getTime();

		if (duration < 0) {
			return -1;
		}

		return (int) (duration / (1000 * 60 * 60 * 24));
	}

	/**
	 * <p>주어진 날짜 DATE(from, to) 의 기간(달) 구하기 to - from
	 * <p>from,to사이의 월수 구하기
	 * @param from yyyyMMdd포맷의 date
	 * @param to yyyyMMdd포맷의 date
	 * @return 월수
	 */
	public static int monthsBetween(String from, String to) {
		return monthsBetween(from, to, "yyyyMMdd");
	}

	/**
	 * <p>주어진 날짜 DATE(from, to) 의 기간(달) 구하기 to - from
	 * <p>from,to사이의 월수 구하기
	 * @param from 시작일자
	 * @param to 종료일자
	 * @param format 날짜포맷 ( yyyy-MM-dd, yyyyMMdd 등)
	 * @return 월수
	 */
	public static int monthsBetween(String from, String to, String format) {
		SimpleDateFormat formatter = new SimpleDateFormat(format, Locale.KOREA);
		Date fromDate = null;
		Date toDate = null;

		try {
			fromDate = formatter.parse(from);
			toDate = formatter.parse(to);
		}
		catch (ParseException e) {
			return -1;
		}

		// if two date are same, return 0.
		if (fromDate.compareTo(toDate) == 0) {
			return 0;
		}

		SimpleDateFormat yearFormat = new SimpleDateFormat("yyyy", Locale.KOREA);
		SimpleDateFormat monthFormat = new SimpleDateFormat("MM", Locale.KOREA);
		SimpleDateFormat dayFormat = new SimpleDateFormat("dd", Locale.KOREA);

		int fromYear = Integer.parseInt(yearFormat.format(fromDate));
		int toYear = Integer.parseInt(yearFormat.format(toDate));
		int fromMonth = Integer.parseInt(monthFormat.format(fromDate));
		int toMonth = Integer.parseInt(monthFormat.format(toDate));
		int fromDay = Integer.parseInt(dayFormat.format(fromDate));
		int toDay = Integer.parseInt(dayFormat.format(toDate));

		int result = 0;
		result += ( (toYear - fromYear) * 12);
		result += (toMonth - fromMonth);

		//        if (((toDay - fromDay) < 0) ) result += fromDate.compareTo(toDate);
		// ceil과 floor의 효과
		if ( ( (toDay - fromDay) > 0)) {
			result += toDate.compareTo(fromDate);
		}

		return result;
	}

	/**
	 * 주어진 날짜 달의 마지막 일자 구하기
	 * @param dateString yyyyMMdd포맷의 날짜
	 * @return 월말일
	 */
	public static String lastDayOfMonth(String dateString) {
		return lastDayOfMonth(dateString, "yyyyMMdd");
	}

	/**
	 * 주어진 날짜 달의 마지막 일자 구하기
	 * @param dateString 일자
	 * @param format yyyyMMdd, yyyy-MM-dd등의 날짜포맷
	 * @return format형식에 맞는 일자데이트
	 */
	public static String lastDayOfMonth(String dateString, String format) {
		SimpleDateFormat formatter = new SimpleDateFormat(format, Locale.KOREA);

		Date date = null;

		try {
			date = formatter.parse(dateString);

			SimpleDateFormat yearFormat = new SimpleDateFormat("yyyy",
				Locale.KOREA);
			SimpleDateFormat monthFormat = new SimpleDateFormat("MM",
				Locale.KOREA);

			int year = Integer.parseInt(yearFormat.format(date));
			int month = Integer.parseInt(monthFormat.format(date));
			int day = lastDay(year, month);

			DecimalFormat fourDf = new DecimalFormat("0000");
			DecimalFormat twoDf = new DecimalFormat("00");
			String tempDate = String.valueOf(fourDf.format(year)) +
				String.valueOf(twoDf.format(month)) +
				String.valueOf(twoDf.format(day));
			date = formatter.parse(tempDate);
		}
		catch (ParseException e) {
			return null;
		}

		return formatter.format(date);
	}

	/**
	 * 주어진 년 월의 마지막 일자(월말) 구하기
	 * @param year
	 * @param month
	 * @return 월말일
	 * @throws ParseException
	 */
	public static int lastDay(int year, int month) throws ParseException {
		int day = 0;

		switch (month) {
			case 1:
			case 3:
			case 5:
			case 7:
			case 8:
			case 10:
			case 12:
				day = 31;

				break;

			case 2:

				if ( (year % 4) == 0) {
					if ( ( (year % 100) == 0) && ( (year % 400) != 0)) {
						day = 28;
					}
					else {
						day = 29;
					}
				}
				else {
					day = 28;
				}

				break;

			default:
				day = 30;
		}

		return day;
	}

	/**
	 * <p>날짜포맷형식이 yyyyMMdd형식인지 여부리턴
	 * @param dateString 포맷검증할 date
	 * @return true - 날짜 형식이 맞고, 존재하는 날짜일 때. false - 날짜 형식이 맞지 않거나, 존재하지 않는 날짜일 때.
	 * @throws Exception
	 */
	public static boolean isValid(String dateString) throws Exception {
		return isValid(dateString, "yyyyMMdd");
	}

	/**
	 * <p>날짜포맷형식의 유효성 여부리턴
	 * @param dateString 포맷검증할 date
	 * @param format yyyyMMdd, yyyy-MM-dd 등의 날짜포맷
	 * @return - 날짜 형식이 맞고, 존재하는 날짜일 때. false - 날짜 형식이 맞지 않거나, 존재하지 않는 날짜일 때.
	 */
	public static boolean isValid(String dateString, String format) {
		SimpleDateFormat formatter = new SimpleDateFormat(format, Locale.KOREA);
		Date date = null;

		try {
			date = formatter.parse(dateString);
		}
		catch (ParseException e) {
			return false;
		}

		if (!formatter.format(date).equals(dateString)) {
			return false;
		}

		return true;
	}

	/**
	 * Gets a String version of the passed date in the format specified by dateFormat.
	 *
	 * @param date       the date to be converted to a string
	 * @return           a string version of the date passed in
	 */
	/* TODO 날자 "-" 미사용
	public static String getDateAsString(Date date) {
		SimpleDateFormat dateform = new SimpleDateFormat(_dateFormat);

		return dateform.format(date);
	}
	/*

	/**
	 * Gets a String version of the passed date in the format specified by dateFormat.
	 *
	 * @param date       the date to be converted to a string
	 * @param dateFormat date format
	 * @return           a string version of the date passed in
	 */
	public static String getDateAsString(Date date, String dateFormat) {
		SimpleDateFormat dateform = new SimpleDateFormat(dateFormat);

		return dateform.format(date);
	}

	/**
	 * 시작일부터 종료일까지의 날짜가 남긴 String 배열 리턴
	 * @param startDay 시작일
	 * @param endDay 종료일
	 * @param formatStr 날짜형식
	 * @return 처리된 String 배열
	 */
	public static String[] increaseDay(String startDay, String endDay,
									   String formatStr) {

		Calendar now = Calendar.getInstance();
		SimpleDateFormat formatter = new SimpleDateFormat(formatStr);
		Date startDate;
		Date endDate;
		long diff = 0;

		try {
			startDate = formatter.parse(startDay);
			endDate = formatter.parse(endDay);
			//시작일과 종료일의 날수를 구함
			diff = (endDate.getTime() - startDate.getTime()) /
				(1000 * 60 * 60 * 24);

			//시작일이 종료일보다 이후인 경우
			if (diff < 0) {
				return null;
			}

			now.setTime(startDate);
		}
		catch (ParseException ex) {
			ex.printStackTrace();
		}

		String[] days = new String[ (int) diff + 1];
		int count = (int) diff;
		days[0] = formatter.format(now.getTime());

		for (int k = 0; k < count; k++) {
			now.add(Calendar.DAY_OF_YEAR, +1);
			days[k + 1] = formatter.format(now.getTime());
		}
		return days;
	}

	/**
	 * <p>메소드명	: getWeeks</p>
	 * <p>설명		: 주차를 구하는 함수</p>
	 * <p>메소드인수1	: String setDate - 날짜</p>
	 * <p>메소드인수2	: String format - 날짜형식 (yyyyMMddHHmm or yyyy-MM-dd HH:mm) </p>
	 * <p>메소드인수3	: String dateGuboon - 주차 구분 (M:월주차, Y:연주차)</p>
	 * <p>메소드리턴값	: int rDateInfo - 해당주차</p>
	 */
	/**
	 * <p>주차를 구하는 함수
	 * @param setDate 날짜
	 * @param format 날짜포맷 ( yyyyMMdd, yyyy-MM-dd 등)
	 * @param dateGuboon 주차 구분 ( <b>M</b>:월주차, <b>Y</b>:연주차)
	 * @return
	 */
	public static int getWeeks(String setDate, String format, String dateGuboon) {
		int rDateInfo = 0;
		try {

			Calendar calendar = Calendar.getInstance();
			SimpleDateFormat formatter = new SimpleDateFormat(format);
			Date d = formatter.parse(setDate);
			calendar.setTime(d);

			//Calendar Class는 날짜를 0달부터 인식하므로 반드시 +1을 해주어야함
			int monadd = calendar.get(Calendar.MONTH) + 1;

			//해당년도의 달에 속하는 주차를 알고 싶은경우
			if (dateGuboon.toUpperCase().compareTo("M") == 0) {
				int rWeekInMonth = calendar.get(Calendar.WEEK_OF_MONTH);
				rDateInfo = rWeekInMonth;
			}
			//해당년도에 속하는 주차를 알고 싶을 경우
			else if (dateGuboon.toUpperCase().compareTo("Y") == 0) {
				int rWeekInYear = calendar.get(Calendar.WEEK_OF_YEAR);
				rDateInfo = rWeekInYear;
				if (monadd == 12 && rWeekInYear == 1) {
					rDateInfo = 53;
				}
			}

		}
		catch (Exception e) {
			e.printStackTrace();
		}

		return rDateInfo;

	}

	/**
	 * <p>입력된 날짜의 요일을 출력해 주는 함수
	 * @param dayStr 날짜
	 * @param format yyyyMMdd등의 포맷스트링
	 * @return 요일 스트링
	 */
	public static String getDayOfTheWeek(String dayStr, String format) {
		DateFormat df1 = new SimpleDateFormat(format);
		DateFormat df2 = new SimpleDateFormat("EEE");
		String yoil = df2.format(df1.parse(dayStr, new ParsePosition(0)));

		return yoil;
	}

	/**
	 * 시작일자 - 종료일자 의 차이인 리턴
	 * @param from 시작일자
	 * @param to 종료일자
	 * @param format 날짜포맷 String
	 * @return 0, -1, 1
	 */
	public static int compareDate(String from, String to, String format) {
		SimpleDateFormat formatter = new SimpleDateFormat(format,
			java.util.Locale.KOREA);
		Date d1 = null;
		Date d2 = null;
		int rtVal = 0;
		try {
			d1 = formatter.parse(from);
			d2 = formatter.parse(to);
		}
		catch (ParseException e) {
			return -1;
		}

		long duration = d2.getTime() - d1.getTime();

		if (duration < 0) {
			rtVal = -1;
		}
		if (duration == 0) {
			rtVal = 0;
		}
		if (duration > 0) {
			rtVal = 1;
		}

		return rtVal;
	}

	 /**
     * <p>메소드명      : getServerDate </p>
     * <p>설명         : 구분자에 따라 서버의 날짜를 가져온다 </p>
     * <p>메소드인수1   : int gubun </p>
     * <p>메소드리턴값  : String </p>
     * <p>특이사항 : jsp에서 서버 날짜를 얻어올 때 사용한다 </p>
     */
    public static String getServerDate(int gubun) {
        Calendar calendar = Calendar.getInstance();
        StringBuffer time = new StringBuffer();

        switch (gubun) {
        case 1:
            time.append(getYear(calendar));

            break;

        case 2:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));

            break;

        case 3:
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 4:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 5:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));
            time.append(getHour(calendar));
            time.append(getMinute(calendar));
            time.append(getSecond(calendar));

            break;

        case 6:
            time.append(getYear(calendar).substring(2, 4));

            break;

        case 7:
            time.append(getYear(calendar).substring(2, 4));
            time.append(getMonth(calendar));

            break;

        case 8:
            time.append(getYear(calendar).substring(2, 4));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 9:
            time.append(getHour(calendar));
            time.append(getMinute(calendar));
            time.append(getSecond(calendar));

            break;

        case 10: //"-" 날짜포맷 중간에 추가 2005.10.10
            time.append(getYear(calendar));
            time.append("-");
            time.append(getMonth(calendar));
            time.append("-");
            time.append(getDate(calendar));

            break;

        case 11: //":" 시간포맷 중간에 추가 2005.10.10
            time.append(getHour(calendar));
            time.append(":");
            time.append(getMinute(calendar));
            time.append(":");
            time.append(getSecond(calendar));

            break;

        default:
            break;
        }

        return time.toString();
    }

    private static String getYear(Calendar calendar) {
        int year = calendar.get(Calendar.YEAR);

        return year + "";
    }

    private static String getMonth(Calendar calendar) {
        int month = calendar.get(Calendar.MONTH) + 1;

        // 월을 두 자리로 표현하기 위해 (01, 02, ...)
        if (month < 10) {
            return "0" + month;
        } else {
            return month + "";
        }
    }

    private static String getDate(Calendar calendar) {
        int date = calendar.get(Calendar.DATE);

        // 일을 두 자리로 표현하기 위해 (01, 02, ...)
        if (date < 10) {
            return "0" + date;
        } else {
            return date + "";
        }
    }

    private static String getHour(Calendar calendar) {
        int hour = calendar.get(Calendar.HOUR_OF_DAY);

        // 시를 두 자리로 표현하기 위해 (01, 02, ...)
        if (hour < 10) {
            return "0" + hour;
        } else {
            return hour + "";
        }
    }

    private static String getMinute(Calendar calendar) {
        int minute = calendar.get(Calendar.MINUTE);

        // 분을 두 자리로 표현하기 위해 (01, 02, ...)
        if (minute < 10) {
            return "0" + minute;
        } else {
            return minute + "";
        }
    }

    private static String getSecond(Calendar calendar) {
        int second = calendar.get(Calendar.SECOND);

        // 초을 두 자리로 표현하기 위해 (01, 02, ...)
        if (second < 10) {
            return "0" + second;
        } else {
            return second + "";
        }
    }




	/**
	 * <p>메소드명	: getKSTDate</p>
	 * <p>설　　명	: 현재 일자값을 해당포맷으로 가져온다.</p>
	 * <p>메소드인수	: DateFormat (yyyyMMddHHmmss)</p>
	 * <p>리　턴　값	: String(Formatted Date)</p>
	 */
	public static String getKSTDate(String format) {
		int millisPerHour = 60 * 60 * 1000; // 1hour(ms) = 60s * 60m * 1000ms
		SimpleDateFormat fmt = new SimpleDateFormat(format);
		SimpleTimeZone timeZone = new SimpleTimeZone(9 * millisPerHour, "KST");
		fmt.setTimeZone(timeZone);

		long time = System.currentTimeMillis();
		String str = fmt.format(new java.util.Date(time));
		return str;
	}
	/* TODO 날자 "-" 미사용
	// Default (yyyy-MM-dd)
	public String getKSTDate() {
		SimpleDateFormat formatter = new SimpleDateFormat(YYYY_MM_DD);
		Date curDate = new Date();
		return formatter.format(curDate);
	}
	*/
}
