package hanalife.c.co.util;

import java.io.File;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.attribute.PosixFilePermissions;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.SimpleTimeZone;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import hanalife.c.cm.cm.service.HlflCmmDataService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;

/**
 * String 관련 Util 개발자 : <a href="mailto:yhk1712@kico.co.kr">김윤환</a> 생성일자 : 2020. 07. 24.
 */
@Component
public class StringUtil extends StringUtils {

	//상수 유틸 사용 선언
	private static HlflCmmDataService cmmDataService;

	@Autowired
	private StringUtil(HlflCmmDataService cmmDataService) {
		StringUtil.cmmDataService = cmmDataService;
	}

    private static final Logger LOGGER = LoggerFactory.getLogger(StringUtil.class);
	public final static String DT_DIV   = "";					// 표준 Date 구분자 (yyyy-MM-dd)
    /**
     * Object 파라미터 String 데이터가 null일 경우 입력한 문자열을 return
     *
     * @param str
     * @param replaceStr
     * @return
     */
    public static String nvl(Object str, String replaceStr) {
        // null 처리
        if (str == null) {
            return replaceStr;
        }

        // String 데이터 추출
        String rtnStr = String.valueOf(str).trim();

        if (rtnStr.length() == 0 || "null".equals(rtnStr)) {
            return replaceStr;
        } else {
            return rtnStr;
        }
    }

    /**
     * Object 파라미터 String 데이터가 null일 경우 빈문자로 변환해서 return
     *
     * @param str
     * @return
     */
    public static String nvl(Object str) {
        return nvl(str, "");
    }

    /**
     * BASE 64 인코딩
     *
     * @param String Base64 인코딩할 문자열
     * @return String Base64 인코딩 된 문자열
     */
    public static String encodeBase64String(String planText) {
        return encodeBase64String(planText.getBytes());
    }

    /**
     * BASE 64 인코딩
     *
     * @param byte[] Base64 인코딩할 문자의
     * @return String Base64 인코딩 된 문자열
     */
    public static String encodeBase64String(byte[] binaryData) {
        return Base64.encodeBase64String(binaryData);
    }

    /**
     * BASE 64 디코딩
     *
     * @param String Base64 디코딩할 문자열
     * @return String Base64 디코딩된 문자열
     */
    public static String decodeBase64String(String encodeString) {
        return new String(decodeBase64(encodeString));
    }

    /**
     * BASE 64 디코딩
     *
     * @param String Base64 디코딩할 문자열
     * @return byte[] Base64 디코딩된 byte[]형
     */
    public static byte[] decodeBase64(String encodeString) {
        return Base64.decodeBase64(encodeString);
    }

    /**
     * 대상 문자열이 null일 경우 또는 "null"인 경우 true
     *
     * @param 문자열
     * @return true false
     */
    public static boolean reqParamIsEmpty(Object str) {
        String resultStr = String.valueOf(str);
        if (isEmpty(resultStr) || "null".equalsIgnoreCase(resultStr)) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * 대상 String의 일반적이지 않은 공백을 제거하여 대상 String을 return
     *
     * @param 문자열
     * @return 문자열
     */
    public static String unicodeTrim(final String str) {
        return str == null ? null : str.trim().replaceAll("(^\\p{Z}+|\\p{Z}+$)", "");
    }

    /**
     * 2개의 데이터를 받아 길이가 긴 것 기준으로 작은 데이터를 포함하는 지 여부 비교 대상의 데이터가 둘다 Not Empty ex) 결제모듈에서 입력 된 DB데이터와 통신리턴받은 고객명 비교
     *
     * @param dataA
     * @param dataB
     * @return
     */
    public static boolean isDataEachContains(String dataA, String dataB) {

        if (dataA == null || dataB == null) {
            return false;
        }

        dataA = dataA.trim();
        dataB = dataB.trim();

        boolean isContains = false;
        // 값이 있다면
        if (StringUtils.isNotEmpty(dataA) && StringUtils.isNotEmpty(dataB)) {
            // 넘어온 값 그대로 체크
            isContains = isDataEachContains2(dataA, dataB);

            // 불일치 건중에 전각문자인 경우가 있어서 반각문자로 변환해서 한번 더 체크 - 두번째 값이 전각인 경우
            if (isContains == false) {
                isContains = isDataEachContains2(dataA, toHalfChar(dataB));
            }

            // 불일치 건중에 전각문자인 경우가 있어서 반각문자로 변환해서 한번 더 체크 - 첫번째 값이 전각인 경우
            if (isContains == false) {
                isContains = isDataEachContains2(toHalfChar(dataA), dataB);
            }
        }
        return isContains;
    }

    /**
     * 전각문자를 반각문자로 변환하는 함수
     *
     * <pre>
     * 설명      : 전각문자 넣으면 반각문자 나옴
     * 변경내역  :
     * </pre>
     *
     * @param src
     * @return
     */
    public static String toHalfChar(String src) {
        StringBuffer strBuf = new StringBuffer();
        char c = 0;
        int nSrcLength = src.length();
        for (int i = 0; i < nSrcLength; i++) {
            c = src.charAt(i);
            // 영문이거나 특수문자 일경우
            if (c >= '！' && c <= '～') {
                c -= 0xfee0;
            } else if (c == '　') {
                c = 0x20;
            }
            // 문자열 버퍼에 변환된 문자를 쌓는다.
            strBuf.append(c);
        }
        return strBuf.toString();
    }

    /**
     * <pre>
     * 설명      : 2개의 데이터를 받아 길이가 긴 것 기준으로 작은 데이터를 포함하는 지 여부
     * 비교 대상의 데이터가 둘다 Not Empty
     * ex) 결제모듈에서 입력 된 DB데이터와 통신리턴받은 고객명 비교
     * 변경내역  :
     * </pre>
     *
     * @param dataA : 자가청약 입력 고객명
     * @param dataB : 은행에서 받은 결과 고객명
     * @return
     */
    public static boolean isDataEachContains2(String dataA, String dataB) {
        boolean isContains = false;
        if (dataA.length() >= dataB.length()) {
            if (dataA.contains(dataB)) {
                isContains = true;
            }
        } else if (dataA.length() < dataB.length()) {
            if (dataB.contains(dataA)) {
                isContains = true;
            }
        }

        return isContains;
    }

    /**
     * 리소스(JS, CSS) 경로를 받아 jstl c:url 태그로 변경하여 리턴.
     *
     * @description :
     * @param resourcePath
     * @return
     */
    public static String showResPath(String resourcePath) {
        String rtnJsUrl = "";

        if (null != resourcePath && !"".equals(resourcePath)) {
            rtnJsUrl = resourcePath + "?id=" + DateUtil.getCurrentDateString("yyMMddHHmm");
        }

        return rtnJsUrl;
    }

    /**
     * 크로스 사이트 스크립팅 방지
     *
     * @param str
     * @return
     */
    public static String removeXSS(String str) {
        str = str.replaceAll("\"", "&gt;");
        str = str.replaceAll("&", "&amp;");
        str = str.replaceAll("<", "&lt;");
        str = str.replaceAll(">", "&gt;");
        str = str.replaceAll("%00", null);
        str = str.replaceAll("\"", "&#34;");
        str = str.replaceAll("\'", "&#39;");
        str = str.replaceAll("%", "&#37;");
        str = str.replaceAll("../", "");
        str = str.replaceAll("..\\\\", "");
        str = str.replaceAll("./", "");
        str = str.replaceAll("%2F", "");
        str = str.replaceAll("document", "");
        str = str.replaceAll("cookie", "");
        str = str.replaceAll("forms", "");

        return str;
    }

    /**
     * 2023.03.17 younghwe.kim - /hanalife/util/util.java 파일을 StringUtil 로 이관함.
     */

    /**
     * 입력문자열이 숫자로 변환가능한지
     * @param str 확인할문자열
     * @return 숫자여부
     */
    public static boolean isDigit(String str) {
        boolean isDigit = false;

        try {
            if (str != null) {
                Integer.parseInt(str.trim());
                isDigit = true;
            }
        } catch (NumberFormatException e) {
            isDigit = false;
        }

        return isDigit;
    }

    /**
     * <p>주어진 format의 길이에 맞춰 특정문자를 문자열의 왼쪽에 attach
     *
     * <pre><code>
     * format( "123", 4, '*' ) return "*123"
     * </code></pre>
     *
     * @param str 기준문자열
     * @param length 총길이
     * @param ch 채울문자
     * @return 포맷된문자열
     */
    public static String format(String str, int length, char ch) {
        if (str == null) {
            str = "";
        }

        if (str.length() > length) { // 처리하려는 문자열이 기준길이보다 길 경우

            //TODO 확인후 추가
        }

        StringBuffer buff = new StringBuffer(str);

        for (int i = buff.length(); i < length; i++) {
            buff.insert(0, ch);
        }

        return buff.toString();
    }

    /**
     * <p>주어진 format의 길이에 맞춰 특정문자를 문자열의 왼쪽에 attach
     * <pre><code>
     * format( 123, 4, '*' ) return "*123"
     * </code></pre>
     *
     * @param num 기준값
     * @param length 총길이
     * @param ch 채울문자
     * @return 포맷된문자열
     */
    public static String format(int num, int length, char ch) {
        return format(String.valueOf(num), length, ch);
    }

    /**
     * <p>주어진 format의 길이에 맞춰 특정문자를 문자열의 지정한 쪽에 attach
     *
     * <pre><code>
     * format( "123", 4, '*' , false) return "*123"
     * format( "123", 4, '*' , true) return "123*"
     * </code></pre>
     *
     * @param str format에 맞출 문자열
     * @param length format의 길이
     * @param ch 채울문자
     * @param fillRightYn 오른쪽에 채울것인지의 여부, true 오른쪽, false 왼쪽
     * @return format에 맞춰 변경된 문자열
     */
    public static String format(String str, int length, char ch,
        boolean fillRightYn) {
        String rsltStr = null;

        StringBuffer buff = new StringBuffer(str);

        if (str == null) {
            str = "";
        }

        if (str.length() > length) { // 처리하려는 문자열이 기준길이보다 길 경우

            // 문자열이 기준보다 길면 그대로 리턴
        }

        if (!fillRightYn) {
            rsltStr = format(str, length, ch);
        } else {
            for (int i = buff.length(); i < length; i++) {
                buff.append(ch);
            }

            rsltStr = buff.toString();
        }

        return rsltStr;
    }

    /**
     * <p>주어진 format의 길이에 맞춰 특정문자를 문자열의 지정한 쪽에 attach
     *
     * <pre><code>
     * format( 123, 4, '*' , false) return "*123"
     * format( 123, 4, '*' , true) return "123*"
     * </code></pre>
     *
     * @param num format에 맞출 숫자
     * @param length format의 길이
     * @param ch 채울문자
     * @param fillRightYn 오른쪽에 채울것인지의 여부, true 오른쪽, false 왼쪽
     * @return format에 맞춰 변경된 문자열
     */
    public static String format(int num, int length, char ch,
        boolean fillRightYn) {
        return format(String.valueOf(num), length, ch, fillRightYn);
    }

    /**
     * <p>공백제거
     * <pre><code>
     * trim( "abc ") return "abc"
     * trim( null ) return null
     * </code></pre>
     *
     * @param data 공백제거할 문자열
     * @return 공백제거된 문자열
     */
    public static String trim(String str) {
        // str.replaceAll("/(^\s*)|(\s*$)/", "0");
        return nvl(str).trim();
    }

    /**
     * <pre>
     * 왼쪽 공백 제거
     * </pre>
     */
    public static String ltrim(String str) {
        int i, j = 0;
        for (i = 0; i < str.length(); i++) {
            if (str.charAt(i) == ' ')
                j = j + 1;
            else
                break;
        }
        return str.substring(j, str.length());
    }

    /**
     * <pre>
     * 오른쪽 공백 제거
     * </pre>
     */
    public static String rtrim(String str) {
        int i, j = 0;
        for (i = str.length() - 1; i >= 0; i--) {
            if (str.charAt(i) == ' ')
                j = j + 1;
            else
                break;
        }
        return str.substring(0, str.length() - j);
    }

    /**
     * <p>공백제거
     * <pre><code>
     * trimToStr( "abc ") return "abc"
     * trimToStr( null ) return ""
     * </code></pre>
     *
     * @param data 공백제거할 문자열
     * @return 공백제거된 문자열
     */
    public static String trimToStr(String data) {
        String result = "";

        if (data != null) {
            result = data.trim();

            if(result.equals("")) {
                result = " ";
            }
        }

        return result;
    }

    /**
     * <p>공백제거
     * <pre><code>
     * trimToStr( "abc ") return "abc"
     * trimToStr( null ) return ""
     * </code></pre>
     *
     * @param data 공백제거할 문자열
     * @return 공백제거된 문자열
     */
    public static String trimString(String data) {
        String result = "";

        if (data != null) {
            result = data.trim();
        }

        return result;
    }


    /**
     * <p>메소드명                : replaceStr</p>
     * <p>설명                : 주어진 value(String)의 특정문자열을 대상문자열로 변환</p>
     * <p>메소드인수1        : String value - 주어진 문자열</p>
     * <p>메소드인수2        : String oldStr - 변환하고자 하는 특정 문자열</p>
     * <p>메소드인수3        : String newStr - 변환하고자 하는 대상 문자열</p>
     * <p>메소드리턴값        : String - 특정문자열이 변환된 값 리턴</p>
     */
    /**
     * <p>특정문자열을 대상문자열로 변환
     *
     * <pre><code>
     * replaceStr( "ab111c", "111", "*") return "ab***c"
     * replaceStr( null ) throw NullPointExcpeiton
     * </code></pre>
     *
     * @fixme 널처리추가
     *
     * @param value 원문자열
     * @param oldStr 변환하고자 하는 특정문자열
     * @param newStr 변환하고자 하는 대상문자열
     * @return 특정문자열이 변환된 값
     */
    public static String replaceStr(String value, String oldStr, String newStr) {
        int idx = 0;
        int curIdx = 0;
        StringBuffer result = new StringBuffer();

        curIdx = value.indexOf(oldStr, idx);

        while (curIdx >= 0) {
            // Replace string and append string.
            result.append(value.substring(idx, curIdx));
            result.append(newStr);

            // Increment search the string index.
            idx = curIdx + oldStr.length();
            curIdx = value.indexOf(oldStr, idx); // Add this line, this is the fixed point.
        }

        // After replace all of the oldStr, then if the string remains...
        // append it to result string.
        if (idx <= value.length()) {
            result.append(value.substring(idx, value.length())); // this..
        }

        return result.toString();
    }

    /**
     * 테스트를 위한 임시메소드
     * @param args
     */
    public static void main(String[] args) {
        System.out.println("getComma : " + getComma("-234567890.01"));

        System.out.println("getEmpNoCheckDgt : " + getEmpNoCheckDgt("1111"));
        System.out.println("getEmpNoCheckDgt : " + getEmpNoCheckDgt("456789"));
        System.out.println("getEmpNoCheckDgt : " + getEmpNoCheckDgt("AAAAAA"));

        System.out.println("dgtFormat : " + dgtFormat("1234.173", 1, 1));
        System.out.println("dgtFormat : " + dgtFormat("1234.173", 1, 2));
        System.out.println("dgtFormat : " + dgtFormat("1234.999", 1, 3));
        System.out.println("dgtFormat : " + dgtFormat("1234.173", 1, 4));

    }

    /**
     * <p>문자열에 금액단위 콤마추가
     *
     * <pre><code>
     * getComma( "1234") return "1,234"
     * getComma( null ) return null
     * getComma( "" ) return ""
     * getComma( "1,234") return "1,234"
     * </code></pre>
     *
     * @param str 숫자값 문자열
     * @return 콤마붙인 문자열
     */
    public static String getComma(String str) {
        String sj = str;

        if (str == null) {
            return null;
        }

        if (str.trim().equals("")) {
            return "";
        }

        if (str.indexOf(",") != -1) {
            return str;
        }

        if (sj.startsWith("0")) {
            for (int i = 0; i < str.length(); i++) {
                sj = str.substring(i);

                if (!sj.startsWith("0")) {
                    break;
                }
            }
        }

        if (str.equals("0")) {
            return "0";
        } else {
            double nu = Double.parseDouble(sj);
            NumberFormat nf = NumberFormat.getInstance();
            String no = nf.format(nu);

            return no;
        }
    }

    /**
     * <p>yyyyMMdd, yyyyMM -> yyyy-MM-dd, yyyy-MM 변환
     *
     * <pre>
     * <code>
     * "2018-08-01" return "2018-08-01"
     * "2018-08-01" return "2018-08-01"
     * "2018-08-01" return "2018-08-01"
     * null return null
     * </code>
     * </pre>
     *
     * @param dateStr yyyyMMdd, yyyyMM포맷 엄수
     * @return yyyy-MM-dd, yyyy-MM 변환값, 포맷이 틀리면 입력값그대로 리턴
     */
    public static String convertDateStr(String dateStr) {

        if ((dateStr == null) ||
                ((dateStr.length() != 6) && (dateStr.length() != 8))) {
            return dateStr;
        }

        String year = dateStr.substring(0, 4);
        String month = dateStr.substring(4, 6);

        if (dateStr.length() == 6) {
            return year + "-" + month;
        }

        String day = dateStr.substring(6);

        return year + "-" + month + "-" + day;
    }

    /**
     * <p>사원번호 checkDigit
     * <p>6자리 숫자값문자열 아닌 모든케이스는 null리턴
     * <p>null입력시 NullPointException
     *
     * @todo null처리
     * @param empNo 6자리 숫자값문자열
     * @return
     */
    public static String getEmpNoCheckDgt(String empNo) {
        if (empNo.length() != 6) {
            return null;
        }

        try {
            double sum = 0;

            for (int i = 0; i < 6; i++) {
                sum += (Integer.parseInt(empNo.substring(i, i + 1)) * (i + 1));
            }

            String stringvalue = String.valueOf(sum / 11);

            return stringvalue.substring(stringvalue.indexOf(".") + 1,
                stringvalue.indexOf(".") + 2);
        } catch (NumberFormatException ex) {
            return null;
        }
    }

    /**
     * <p>사원번호 유효성 검증 확인
     * <p>7자리숫자값 문자열 아닌경우 false
     * <p>null입력시 NullPointException
     *
     * @todo null처리
     * @param empNo 확인할사원번호(7자리)
     * @return true유효한사원번호, false 잘못된사원번호
     */
    public static boolean isEmpNo(String empNo) {
        if (empNo.length() != 7) {
            return false;
        }

        try {
            double sum = 0;

            for (int i = 0; i < 6; i++) {
                sum += (Integer.parseInt(empNo.substring(i, i + 1)) * (i + 1));
            }

            String stringvalue = String.valueOf(sum / 11);
            String digit = stringvalue.substring(stringvalue.indexOf(".") + 1,
                    stringvalue.indexOf(".") + 2);

            if (digit.equals(empNo.substring(6, 7))) {
                return true;
            } else {
                return false;
            }
        } catch (NumberFormatException ex) {
            return false;
        }
    }

    /**
     * <p>숫자형 문자값을 기준 소숫점 처리후 리턴
     *
     * @see BigDecimal
     * @param sDecimal 숫자값 문자열
     * @param iDgtCnt 기준소수점 자릿수
     * @param format BigDecimal상수값 ex) BigDecimal.ROUND_UP, BigDecimal.ROUND_DOWN
     * @param isNullToZero 값이 null인경우 "0"리턴할지 여부, "Y" -> "0"리턴, 이외 null
     * @return 처리된 결과값
     */
    public static String dgtFormat(String sDecimal, int iDgtCnt, int format, String isNullToZero) {
        String sRslt = null;

        if (sDecimal != null) {
            sDecimal = trim(sDecimal);

            if (sDecimal.length() > 0) {
                BigDecimal bd = new BigDecimal(sDecimal);
                bd = bd.setScale(iDgtCnt, format);
                sRslt = bd.toString();
            }
        }

        if (isNullToZero.equals("Y") && (sRslt == null)) {  // 널이면 0으로 바꾸어야 할 경우
            sRslt = "0";
        }

        return sRslt;
    }

    /**
     * <p>숫자형 문자값을 기준 소숫점 처리후 리턴
     *
     * @see BigDecimal
     * @param sDecimal 숫자값 문자열
     * @param iDgtCnt 기준소수점 자릿수
     * @param format BigDecimal상수값 ex) BigDecimal.ROUND_UP, BigDecimal.ROUND_DOWN
     * @return 처리된 결과값
     */
    public static String dgtFormat(String sDecimal, int iDgtCnt, int format) {
        return dgtFormat(sDecimal, iDgtCnt, format, "Y");
    }

    /**
     * <p>숫자형 문자값을 기준 소숫점 절사처리
     *
     * {@link #dgtFormat(String, int, int)}
     *
     * @param sDecimal 숫자값 문자열
     * @param iDgtCnt 기준소수점 자릿수
     * @return 절사된문자열
     */
    public static String ceil(String sDecimal, int iDgtCnt) {
        return dgtFormat(sDecimal, iDgtCnt, BigDecimal.ROUND_CEILING, "Y");
    }

    /**
     * <p>숫자형 문자값을 기준 소숫점 절사처리
     *
     * {@link #dgtFormat(String, int, int)}
     *
     * @param sDecimal 숫자값 문자열
     * @param iDgtCnt 기준소수점 자릿수
     * @return 절사된문자열
     */
    public static String round(String sDecimal, int iDgtCnt) {
        return dgtFormat(sDecimal, iDgtCnt, BigDecimal.ROUND_HALF_DOWN, "Y");
    }

    /**
     * <p>숫자형 문자값을 기준 소숫점 절사처리
     *
     * {@link #dgtFormat(String, int, int)}
     *
     * @param sDecimal 숫자값 문자열
     * @param iDgtCnt 기준소수점 자릿수
     * @return 절사된문자열
     */
    public static String floor(String sDecimal, int iDgtCnt) {
        return dgtFormat(sDecimal, iDgtCnt, BigDecimal.ROUND_FLOOR, "Y");
    }

    /**
     * <p>공백제거, 인수가 null 이거나 "" 일경우 "0"
     * @param data 공백제거 처리할값
     * @return null문자나 공백일경우 "0" 그외엔 공백제거 후 리턴
     */
    public static String nullToZero(String data) {
        String result = data;

        if (data == null) {
            result = "0";
        }else {
            result = data.trim();
            if (result.equals("") || result.equals("NULL")) {
                result = "0";
            }
        }
        return result;
    }

    /**
     * <p>공백제거
     * <p>인수가 ""이면 "NULL" 리턴
     *
     * <pre>
     * <code>
     *
     * nullToString(null) return "NULL"
     * nullToString(" 123 ") return "123"
     *
     * </code>
     * </pre>
     *
     * @param data
     * @return
     */
    public static String nullToString(String data) {
        String result = null;
        if (data != null) {
            result = data.trim();
        }else {
            result = "NULL";
        }
        return result;
    }
//
//    /** [DOBSCAP] 2018-08-01
//             두비스, 두비스
//             상수값 조회를 공통으로 사용하기 위해 추가함
//     * <p>메소드명                  : cnstStr</p>
//     * <p>설명                        : 상수명을 입력받아 조회하여 상수값을 반환</p>
//     * <p>메소드인수1            : String value - 주어진 문자열</p>
//     * <p>메소드인수2            : ITransaction tx - 변환하고자 하는 특정 문자열</p>
//     * <p>메소드리턴값                : String - 특정문자열이 변환된 값 리턴</p>
//     * @throws SQLException
//     */
//    public static String cnstStr(String value, Connection con) throws SQLException {
//        Statement stmt = null;
//        ResultSet rs = null;
//        String cnstCntn = "";
//        //맵에 담아서 리스트로 반환한다.
//        ResultSetMetaData rd;
//
//        StringBuffer sql = new StringBuffer();
//
//        sql.append("SELECT CNST_CNTN"+"\n");
//        sql.append("  FROM DBSCOMM.CT_CNST_INF"+"\n");
//        sql.append(" WHERE CNST_NM = '"+value+"'"+"\n");
//        sql.append("   "+"\n");
//
//        stmt = con.createStatement();
//        rs = stmt.executeQuery(sql.toString());
//        try{
//            rd = rs.getMetaData();
//            if(rs.next()) {
//                 cnstCntn = rs.getString(rd.getColumnName(1));
//            }
//        }catch(SQLException e){
//          e.printStackTrace();
//        }
//        return cnstCntn;
//    }

    // 2023-03-09 하나생명 요건에 맞춰 개발해야 됨. 일단 막음.
//    /**
//   *  @param
//   */
//  public static void custAuditTrail(String custNo, String custNm, String cnslNo, String loanNo, String loanSeq, ITransaction tx) {
//      log.info("■ 고객정보 조회이력 저장");
//      if (RUtil.isNull(custNo) || RUtil.isNull(custNm)) {
//          System.out.println("고객정보 Audit Trail Log 생성 필수값(custNo, custNm)이 없습니다.");
//          return;
//      }
//
//      // 세션정보를 받아온다.
//      ServletRequestAttributes attr = (ServletRequestAttributes) RequestContextHolder.currentRequestAttributes();
//      HttpSession session = attr.getRequest().getSession(true);
//      User user =  (User) session.getAttribute(DobsSysConst.CUSER);
//      // 프로그램정보를 받는다.
//      HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.currentRequestAttributes()).getRequest();
//
//
//      StCustInfoReadHistTDO tdo = new StCustInfoReadHistTDO();
//          tdo.setReadDt(DateTime.getDateString());
//          tdo.setReadTm(DateTime.getShortTimeString());
//          tdo.setReadEmpNo(user.getUserNo());
//          tdo.setReadDeptCd(user.getDeptCd());
//          tdo.setReadMenuNo(String.valueOf(request.getAttribute("classId")));
//          tdo.setCustNo(custNo);
//          tdo.setCustNm(custNm);
//          tdo.setCnslNo(cnslNo);
//          tdo.setLoanNo(loanNo);
//          tdo.setLoanSeq(loanSeq);
//          tdo.setFrstRegEmpNo(user.getUserNo());
//          tdo.setLastProcEmpNo(user.getUserNo());
//
//      try {
//          CustDAOImpl bc = new CustDAOImpl();
//          bc.insertCustAuditTrail(tdo, tx);
//      } catch (Exception e) {
//          e.printStackTrace();
//      }
//  }
//
//  /**
//   *  @param
//   */
//  public static void custAuditTrailList(String schCond, ITransaction tx) {
//      log.info("■ 고객정보 조회이력 저장(List)");
//      // 세션정보를 받아온다.
//      ServletRequestAttributes attr = (ServletRequestAttributes) RequestContextHolder.currentRequestAttributes();
//      HttpSession session = attr.getRequest().getSession(true);
//      User user =  (User) session.getAttribute(DobsSysConst.CUSER);
//      // 프로그램정보를 받는다.
//      HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.currentRequestAttributes()).getRequest();
//
//      StCustInfoReadHistTDO tdo = new StCustInfoReadHistTDO();
//          tdo.setReadDt(DateTime.getDateString());
//          tdo.setReadTm(DateTime.getShortTimeString());
//          tdo.setReadEmpNo(user.getUserNo());
//          tdo.setReadDeptCd(user.getDeptCd());
//          tdo.setReadMenuNo(String.valueOf(request.getAttribute("classId")));
//          tdo.setCustNo("");
//          tdo.setCustNm(schCond);
//          tdo.setCnslNo("");
//          tdo.setLoanNo("");
//          tdo.setLoanSeq("");
//          tdo.setFrstRegEmpNo(user.getUserNo());
//          tdo.setLastProcEmpNo(user.getUserNo());
//
//      try {
//          CustDAOImpl bc = new CustDAOImpl();
//          bc.insertCustAuditTrail(tdo, tx);
//      } catch (Exception e) {
//          e.printStackTrace();
//      }
//  }
//
//  /**
//   * 메소드명     : insertCustInfoSearchHist
//   * 설명           : 대출번호로 고객정보 조회이력 저장 (단건조회)
//   * 메소드인수1   : String loanNo
//   * 메소드인수2   : String loanSeq
//   * 메소드인수3   : ITransaction
//   * 메소드리턴값   : N/A
//   * 예외처리     : Exception, DAOException
//   */
//  public static void insertCustInfoSearchHist(String loanNo, String loanSeq, ITransaction tx)
//  throws Exception, DAOException {
//
//      // 대출번호로 고객번호, 고객명 조회
//      AbstractDAO bc = new DAOFactory().getDAO("com.dobscap.s.cs.cs.dao.CustDAOImpl");
//      StCustBaseTDO custInfo = ((CustDAO) bc).searchCustByLoanNo(new String[]{loanNo, loanSeq}, tx);
//
//      // 고객정보 조회이력 저장
//      custAuditTrail(custInfo.getCustNo(), custInfo.getCustNm(), "", loanNo, loanSeq, tx);
//  }
//
//  /**
//   * 메소드명     : insertCustInfoSearchHistList
//   * 설명           : 대출번호로 고객정보 조회이력 저장(리스트조회)
//   * 메소드인수1   : String schCond
//   * 메소드인수2   : ITransaction
//   * 메소드리턴값   : N/A
//   * 예외처리     : Exception, DAOException
//   */
//  public static void insertCustInfoSearchHistList(String schCond, ITransaction tx)
//  throws Exception, DAOException {
//
//      // 고객정보 조회이력 저장
//      custAuditTrailList(schCond, tx);
//  }


    /**
     * <p>주어진 Object의 변수값들을 변경함.
     *
     * @param obj 변수가 들어있는 Object
     * @return 없음
     * @throws IllegalAccessException
     * @throws IllegalArgumentException
     */
    public static void setNullChange(Object obj) throws IllegalArgumentException, IllegalAccessException {
        Class<? extends Object> cls = obj.getClass();

        Field[] fields = cls.getDeclaredFields();

        Object type = "";
        for(Field f:fields) {
            f.setAccessible(true);

            type = f.getType();

            //String 데이터들을 공백하나를 만들어준다.
            if(type == String.class) {
                if(f.get(obj) == null || f.get(obj).equals("")) {
                    f.set(obj, " ");
                }
            }
        }
    }

    public static String  nvl(String str) {
        if(str==null) {
            return "";
        }
        return str;
    }

    public static String  NVL(String str) {
        if(str==null) {
            return "";
        }
        return str;
    }

    /**
     * <pre>
     * 메소드명 : isNull
     * 설 명 : null 체크
     * 메소드인수 : String str
     * 리 턴 값 : boolean
     * </pre>
     */
    public static boolean isNull(String str) {
        boolean bool = false;
        if (nvl(str).equals("")) {
            bool = true;
        }
        return bool;
    }

    public static boolean isNullT(String str) {
        return isNull(trim(str));
    }

    /**
     * <pre>
     * 메소드명 : chkNull
     * 설 명 : null 체크 후 Exception 발생처리
     * 메소드인수 : String str, errMsg
     * 리 턴 값 : N/A
     * </pre>
     */
    public static void chkNull(String str, String errMsg) throws Exception {
        if (isNull(str)) {
            throw new Exception(errMsg);
        }
    }

    public static void chkNullT(String str, String errMsg) throws Exception {
        if (isNullT(str)) {
            throw new Exception(errMsg);
        }
    }

    public static void chkZero(long amt, String errMsg) throws Exception {
        if (amt == 0) {
            throw new Exception(errMsg);
        }
    }

    public static void chkZero(BigDecimal amt, String errMsg) throws Exception {
        if ( amt.equals(BigDecimal.ZERO) == true ) {
            throw new Exception(errMsg);
        }
    }

	/**
	 * <p>메소드명	: in</p>
	 * <p>설　　명	: Oracle의 in 기능</p>
	 * <p>메소드인수	: String str, Array cmpr</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public static boolean in(String str, String[] cmpr) {
		boolean flag = false;
		for (int i=0; i<cmpr.length; i++) {
			if (nvl(str, "").equals(cmpr[i])) {
				return true;
			}
		}
		return flag;
	}
	public static boolean in(String str, String cmpr) {
		return in(str, cmpr.split(","));
	}
	public static boolean in(String... arrStr) {
		if (size(arrStr)<2) {
			return false;
		}
		String source = arrStr[0];
		String[] targets = Arrays.copyOfRange(arrStr, 1, arrStr.length);
		return in(source, targets);
	}
	public static boolean in(int num, int[] cmpr) {
		boolean flag = false;
		for (int i=0; i<cmpr.length; i++) {
			if (num==cmpr[i]) {
				return true;
			}
		}
		return flag;
	}
	public static boolean in(int... arrInt) {
		if (size(arrInt)<2) {
			return false;
		}
		int source = arrInt[0];
		int[] targets = Arrays.copyOfRange(arrInt, 1, arrInt.length);
		return in(source, targets);
	}
	public static boolean in(long num, long... cmpr) {
		boolean flag = false;
		for (int i=0; i<cmpr.length; i++) {
			if (num==cmpr[i]) {
				return true;
			}
		}
		return flag;
	}


	/**
	 * <p>메소드명	: size</p>
	 * <p>설　　명	: Size of Object</p>
	 * <p>메소드인수 	: Object</p>
	 * <p>리　턴　값	: int</p>
	 */
	public static int size(Object[] arr) {
		return (arr==null) ? 0 : arr.length;
	}
	public static int size(String[] arr) {
		return (arr==null) ? 0 : arr.length;
	}
	public static int size(int[] arr) {
		return (arr==null) ? 0 : arr.length;
	}
	public static int size(long[] arr) {
		return (arr==null) ? 0 : arr.length;
	}
	public static int size(double[] arr) {
		return (arr==null) ? 0 : arr.length;
	}
	public static int size(List list) {
		return (list==null) ? 0 : list.size();
	}
	public static int size(Map map) {
		return (map==null) ? 0 : map.size();
	}

	/**
	 * <p>메소드명	: parseInt</p>
	 * <p>설　　명	: int 변환</p>
	 * <p>메소드인수	: Object</p>
	 * <p>리　턴　값	: int</p>
	 */
	public static int parseInt(Object obj) {
		String str = String.valueOf(obj);
		return parseInt(str);
	}
	public static int parseInt(String str) {
		str = nvlT(str, "0").replaceAll("[^0-9.-eE]", "");
		int idx = str.indexOf(".");
		if (idx>0) str = str.substring(0, idx);
		return Integer.parseInt(str);
	}

	// trim 후 nvl 처리
	public static String nvlT(String str, String rep) {
		return nvl(trim(str), rep);
	}
	public static String nvlT(String str) {
		return nvl(trim(str));
	}

	/**
	 * <p>메소드명	: parseNature</p>
	 * <p>설　　명	: 자연수로 변환 (0보다 작으면 0으로..)</p>
	 * <p>메소드인수	: Object num</p>
	 * <p>리　턴　값	: long</p>
	 */
	public static long parseNature(Object num) {
		if (num==null) return 0;

		String strNum = nvlT(String.valueOf(num), "0");
		strNum = nvlT(strNum.replaceAll("[^0-9.-]", ""), "0");

		long tmpNum = parseLong(strNum);
		if (tmpNum<0) tmpNum = 0;
		return tmpNum;
	}

	/**
	 * <p>메소드명	: parseLong</p>
	 * <p>설　　명	: long 변환</p>
	 * <p>메소드인수	: Object</p>
	 * <p>리　턴　값	: long</p>
	 */
	public static long parseLong(Object obj) {
		long num = 0;
		try {
			if (StringUtil.in(getClassNm(obj), "Integer", "Double", "Long", "BigInteger", "BigDecimal")) {
				num = new BigDecimal(String.valueOf(obj)).longValue();
			} else if (StringUtil.in(getClassNm(obj), "String")) {
				num = new BigDecimal(String.valueOf(obj)).longValue();
			} else {
				throw new Exception("Class Type is not Defined");
			}
		} catch (Exception e) {
			LOGGER.error("RUtil.parseLong] Error!");
		}
		return num;
	}
	public static long parseLong(String str) {
		str = nvlT(str, "0").replaceAll("[^0-9.-]", "");
		return Long.parseLong(str);
	}
	public static String parseLongStr(Object obj) {
		return String.valueOf(parseLong(obj));
	}
	/**
	 * <p>메소드명	: parseDouble</p>
	 * <p>설　　명	: double 변환</p>
	 * <p>메소드인수	: Object</p>
	 * <p>리　턴　값	: double</p>
	 */
	public static double parseDouble(Object obj) {
		double num = 0.0;
		try {
			if (StringUtil.in(getClassNm(obj), "Integer", "Double", "Long", "BigInteger", "BigDecimal")) {
				num = new BigDecimal(String.valueOf(obj)).doubleValue();
			} else if (StringUtil.in(getClassNm(obj), "String")) {
				num = new BigDecimal(String.valueOf(obj)).doubleValue();
			} else {
				throw new Exception("Class Type is not Defined");
			}
		} catch (Exception e) {
			LOGGER.error("parseDouble] Error!");
		}
		return num;
	}
	public static double parseDouble(String str) {
		str = nvlT(str, "0").replaceAll("[^0-9.-eE]", "");
		return Double.parseDouble(str);
	}
	public static String parseDoubleStr(Object obj) {
		return String.valueOf(parseDouble(obj));
	}

	/**
	 * <p>메소드　명	: getClassNm</p>
	 * <p>설　　　명	: Object TypeName</p>
	 * <p>메소드인수	: Object</p>
	 * <p>리　턴　값	: ClassName</p>
	 */
	public static String getClassNm(Object obj) {
		//log.info(obj.getClass().getSimpleName());
		return obj.getClass().getSimpleName();
	}

	/**
	 * <p>메소드명	: dateDiff</p>
	 * <p>설　　명	: 두 날짜의 차이를 구함</p>
	 * <p>메소드인수	: String sdt, String edt</p>
	 * <p>리　턴　값	: day Count</p>
	 */
	public static long dateDiff(String sdt, String edt) {
		// 숫자를 제외한 나머지 문자 제거
		sdt = trim(sdt).replaceAll("[^0-9]", "");
		edt = trim(edt).replaceAll("[^0-9]", "");
		if (isNull(sdt) || isNull(edt)) return 0;

		long diff = 0;
		try {
			SimpleDateFormat date = new SimpleDateFormat("yyyyMMdd");
			Date dt1 = date.parse(sdt);
			Date dt2 = date.parse(edt);
			diff = (dt2.getTime()-dt1.getTime()) / (1000*60*60*24);
		} catch(ParseException e) {
			System.out.println("ParseIng_Error : " + e.getMessage());
		}
		return diff;
	}

	/**
	 * <p>메소드명	: min</p>
	 * <p>설　　명	: Param 배열 중 작은값을 반환</p>
	 * <p>메소드인수	: Array[Object]</p>
	 * <p>리　턴　값	: minValue</p>
	 */
	public static long min(long... arr) {
		long minVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (minVal>arr[i]) minVal = arr[i];
		}
		return minVal;
	}
	public static int min(int... arr) {
		int minVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (minVal>arr[i]) minVal = arr[i];
		}
		return minVal;
	}
	public static double min(double... arr) {
		double minVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (minVal>arr[i]) minVal = arr[i];
		}
		return minVal;
	}
	public static String min(String... arr) {
		String minVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (minVal.compareTo(arr[i])>0) {
				minVal = arr[i];
			}
		}
		return minVal;
	}

	/**
	 * <p>메소드명	: max</p>
	 * <p>설　　명	: Param 배열 중 큰값을 반환</p>
	 * <p>메소드인수	: Array</p>
	 * <p>리　턴　값	: maxValue</p>
	 */
	public static int max(int... arr) {
		int maxVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (maxVal<arr[i]) maxVal = arr[i];
		}
		return maxVal;
	}
	public static long max(long... arr) {
		long maxVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (maxVal<arr[i]) maxVal = arr[i];
		}
		return maxVal;
	}
	public static double max(double... arr) {
		double maxVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (maxVal<arr[i]) maxVal = arr[i];
		}
		return maxVal;
	}
	public static String max(String... arr) {
		String maxVal = arr[0];
		for (int i=0; i<arr.length; i++) {
			if (arr[i].compareTo(maxVal)>0) {
				maxVal = arr[i];
			}
		}
		return maxVal;
	}

	/**
	 * <p>메소드명	: getFmtDt</p>
	 * <p>설　　명	: dv 패턴을 넣은 DATE FORMAT</p>
	 * <p>메소드인수	: String date, dv</p>
	 * <p>리　턴　값	: String(Formatted Date)</p>
	 */
	public static String fmtDt(String date) {
		return getFmtDt(date, DT_DIV);
	}
	public static String fmtDt(String date, String dv) {
		return getFmtDt(date, dv);
	}
	public static String getFmtDt(String date, String dv) {
		String formattedDate = "";
		if (isNull(date)) {
			formattedDate = "";
		} else {
			date = date.replaceAll("[^0-9]", "");	// 숫자를 제외한 나머지 문자 제거
			formattedDate = date.substring(0, 4)+dv+date.substring(4, 6);
			if (date.length()>=8) formattedDate += dv+date.substring(6, 8);
		}
		return formattedDate;
	}
	public static String getFmtDt(String date) {
		return getFmtDt(date, DT_DIV);
	}
	public static String getFormatDt(String date, String dv) {
		return getFmtDt(date, dv);
	}

	/**
	 * <p>메소드명	: lpad</p>
	 * <p>설　　명	: Oracle의 lpad 기능</p>
	 * <p>메소드인수	: String str, int len, String p</p>
	 * <p>리　턴　값	: String</p>
	 */
	public static String lpad(String obj, int len, String p) {
		String str = nvl(String.valueOf(obj));
		for (int i=str.length(); i<len; i++) {
			str = p+str;
		}
		return str;
	}
	public static String lpadB(String obj, int len, String p) {
		String str = nvl(String.valueOf(obj));
		str = lpad("", len-str.getBytes().length, p) + str;
		return str;
	}
	public static String lpadByte(String obj, int len, String p) {
		return lpadB(obj, len, p);
	}
	public static String lpad(int obj, int len, String p) {
		return lpad(String.valueOf(obj), len, p);
	}

	/**
	 * <p>메소드명	: rpad</p>
	 * <p>설　　명	: Oracle의 rpad 기능</p>
	 * <p>메소드인수	: String str, int len, String p</p>
	 * <p>리　턴　값	: String</p>
	 */
	public static String rpad(String obj, int len, String p) {
		String str = nvl(String.valueOf(obj));
		for (int i=str.length(); i<len; i++) {
			str = str+p;
		}
		return str;
	}
	public static String rpadB(String obj, int len, String p) {
		String str = nvl(String.valueOf(obj));
		str = str + rpad("", len-str.getBytes().length, p);
		return str;
	}
	public static String rpadByte(String obj, int len, String p) {
		return rpadB(obj, len, p);
	}
	public static String rpad(int obj, int len, String p) {
		return rpad(String.valueOf(obj), len, p);
	}

	/**
	 * 입력문자열이 null,balnk일때 0, 이외는 trim후 리턴
	 * <p><blockquote><pre>
	 * blankToZero(null); //"0"
	 * blankToZero(""); //"0"
	 * blankToZero(" 123  "); //"123"
	 * </pre></blockquote><p>
	 * @param inStr - numeric 문자열
	 * @return 입력문자열이 null,balnk일때 0, 이외는 trim후 리턴
	 */
	public static String blankToZero(String inStr ){
		inStr = null2Str(inStr);
		if( "".equals(inStr)){
			inStr = "0";
		}

		return inStr.trim();
	}

	/**
	 * null 또는 blank를 blank로 리턴<br>
	 * 일반 문자열은 trim후 리턴
	 * @param inStr - trim대상 문자열
	 * @return trim된 문자열,null/blank - >blank
	 */
	public static String null2Str( String inStr ){
		return inStr==null?"":inStr.trim();
	}

	/**
	 * <p>메소드명	: decode</p>
	 * <p>설　　명	: Oracle의 decode 기능</p>
	 * <p>메소드인수	: String str, String[] arr</p>
	 * <p>리　턴　값	: String</p>
	 */
	public static String decode(String str, String... arr) throws Exception {
		if (arr==null || arr.length<2) {
			throw new Exception ("[RUtil.decode] ERROR : not enough arguments");
		}
		for (int i=0; i<arr.length; i+=2) {
			if (i==arr.length-1) {
				str = arr[i];
				break;
			}
			if (str.equals(arr[i])) {
				str = arr[i+1];
				break;
			}
		}
		return str;
	}
	public static long decode(long num, long... arr) throws Exception {
		if (size(arr)<2) {
			throw new Exception ("[RUtil.decode] ERROR : not enough arguments");
		}
		for (int i=0; i<arr.length; i+=2) {
			if (i==arr.length-1) {
				num = arr[i]; break;
			}
			if (num==arr[i]) {
				num = arr[i+1]; break;
			}
		}
		return num;
	}

	/**
	 * <p>메소드　명	: isPath</p>
	 * <p>설　　　명	: path가 존재하는지 여부 (디렉토리 or 파일)</p>
	 * <p>메소드인수	: path</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public static boolean isPath(String path) {
		try {
			File file = new File(path);
			return file.exists();
		} catch(Exception e) {
			return false;
		}
	}
	// 디렉토리 존재여부
	public static boolean isDir(String dirPath) {
		File f = new File(dirPath);
		return f.exists() && f.isDirectory();
	}
	// 파일 존재여부
	public static boolean isFile(String fileFullNm) {
		File f = new File(fileFullNm);
		return f.exists() && !f.isDirectory();
	}

	/**
	 * <p>메소드　명	: mkDir</p>
	 * <p>설　　　명	: 디렉토리 미존재시 생성</p>
	 * <p>메소드인수	: fileNm</p>
	 * <p>리　턴　값	: bool</p>
	 */
	public static boolean mkDir(String dirPath) {
		boolean bool = true;
		if (!isDir(dirPath)) {
			bool = new File(dirPath).mkdirs();
		}
		return bool;
	}
	// Exception 필요할 경우 사용
	public static void makeDir(String dirPath) throws IOException {
		if (!isDir(dirPath)) {
			FileUtils.forceMkdir(new File(dirPath));
		}
	}

	public static void changefilePermission(String filePath ) {
		changefilePermission(filePath, "rwxrwxrwx");
	}
	public static void changefilePermission(String filePath, String permissionStr ) {
		try{
			Files.setPosixFilePermissions(Paths.get(filePath), PosixFilePermissions.fromString(permissionStr));
		} catch(Exception ignore) {
			ignore.getMessage();
		}
	}

	/**
	 * <p>메소드명	: lengthB</p>
	 * <p>설　　명	: Byte 수로 length를 구함</p>
	 * <p>메소드인수	: String st</p>
	 * <p>리　턴　값	: int</p>
	 */
	public static int lengthB(String str) {
		try {
			return str == null ? 0 : str.getBytes().length;
		} catch (Exception e) {
			return 0;
		}
	}

	public static String strCut(String strVal, int nLength) {
		return strCut(strVal, nLength, "UTF-8");
	}

	public static String strCutEucKr(String strVal, int nLength) {
		try{
			String result = strCut(strVal, nLength);
			byte[] eucKrStringBuffer = result.getBytes(Charset.forName("euc-kr"));
			return new String(eucKrStringBuffer, "euc-kr");
		} catch(Exception e) {
			return "";
		}
	}

	public static String strCut(String strVal, int nLength, String charsetName) {
		String result = strVal;

		int oF = 0, oL = 0, rF = 0, rL = 0;
		int nLengthPrev = 0;
		try {
			byte[] bytes = result.getBytes(charsetName); // 바이트로 보관
			// x부터 y길이만큼 잘라낸다. 한글안깨지게.
			int j = 0;
			if (nLengthPrev > 0)
				while (j < bytes.length) {
					if ((bytes[j] & 0x80) != 0) {
						oF += 2;
						rF += 3;
						if (oF + 2 > nLengthPrev) {
							break;
						}
						j += 3;
					} else {
						if (oF + 1 > nLengthPrev) {
							break;
						}
						++oF;
						++rF;
						++j;
					}
				}
			j = rF;
			while (j < bytes.length) {
				if ((bytes[j] & 0x80) != 0) {
					if (oL + 2 > nLength) {
						break;
					}
					oL += 2;
					rL += 3;
					j += 3;
				} else {
					if (oL + 1 > nLength) {
						break;
					}
					++oL;
					++rL;
					++j;
				}
			}
			result = new String(bytes, rF, rL, charsetName); // charset 옵션
		} catch (UnsupportedEncodingException ignore) {
			ignore.printStackTrace();
		}
		return result;
	}

	/**
	 * <p>메소드명	: toFullChar</p>
	 * <p>설　　명	: 전각문자로 변경</p>
	 * <p>메소드인수	: String str</p>
	 * <p>리　턴　값	: String</p>
	 */
	public static String toFullChar(String str) {
		// 입력된 스트링이 null 이면 null 을 리턴
		if (str==null) return null;

		// 변환된 문자들을 쌓아놓을 StringBuffer 를 마련한다
		StringBuffer strBuf = new StringBuffer();
		char c = 0;
		for (int i=0; i<str.length(); i++) {
			c = str.charAt(i);
			//영문이거나 특수 문자 일경우.
			if (c >= 0x21 && c <= 0x7e) {
				c += 0xfee0;
            }
			//공백일경우
			else if (c == 0x20) {
				c = 0x3000;
			}
			// 문자열 버퍼에 변환된 문자를 쌓는다
			strBuf.append(c);
		}
		return strBuf.toString();
	}

    //오른쪽 정렬, 모자라는 길이만큼 "0"을 채워넣는다.
    public static String fixEndZero(String s, int leng)  {
        return fillEnd(s, leng, "0");
    }

    //오른쪽 정렬, 모자라는 길이만큼  fillStr을 채워넣는다.
    //이때, 소수점두비스리 절삭.
    public static String fillEnd(String inStr, int size, String fillStr) {

    	String tmp = (inStr == null) ? "" : inStr.trim();
        byte[] inByte = tmp.getBytes();
        int inStrLen = inByte.length;
        if (inStrLen > size) {
        	return subString(inByte, 0, size );
        }

        StringBuilder buff = new StringBuilder(size);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        buff.append(tmp);
        return buff.toString();
    }

    public static String cnvNum(String s) throws Exception
    {
        BigInteger bi = new BigInteger("0");
        try{
            if(s==null || "".equals(s.trim())){
               s = "0";
            }
            bi = new BigInteger(s);
        }catch(Exception e){
            throw new Exception( "숫자포맷 에러 : " + s );
        }

    	return bi.toString();
    }

    public static String subString(byte[] cToBytes, int start, int end) {
        return subString(cToBytes, start, end, "");
    }

    public static String subString(byte[] cToBytes, int start, int end, String charSet) {
        String strRtn = "";
        byte[]   bOut = new byte[end - start];

        try {
            for (int i = start; i < end; i++) {
                bOut[i - start] = cToBytes[i];
            }

            if(StringUtils.isNotBlank(charSet)){
                strRtn = new String(bOut, charSet);
            } else {
                strRtn = new String(bOut);
            }

            return strRtn;
        } catch (Exception e) {
            throw new BizException("문자자르기 실패 (" + e.getMessage() + ")",e);
        }
    }

	//왼쪽정렬, 모자라는 길이만큼 스페이스를 채워넣는다.
    public static String fillSpace(String s, int leng)  {
    	if(s==null || s.equals("")){
    		s = " ";
    	}
    	return fill(s, leng, " ");
    }

    //왼쪽정렬, 모자라는 길이만큼 fillStr을 채워넣는다.
    public static String fill(String inStr, int size, String fillStr)  {

        String tmp = (inStr == null) ? "" : inStr.trim();
        byte[] inByte = tmp.getBytes();
        int inStrLen = inByte.length;
        if (inStrLen > size) {
        	return subString(inByte, 0, size );
        }

        StringBuilder buff = new StringBuilder(size);
        buff.append(tmp);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        return buff.toString();
    }

    /**
     * 전문을 자릿수로 잘라서 리스트를 만들어 리턴한다.
     * @param gram
     * @param size
     * @return
     */
    public static List<String> parseGram(String gram, int size){
        return parseGram(gram, size, "");
    }


    public static List<String> parseGram(String gram, int size, String charSet){
        List<String> strings = new ArrayList<>();
        int index = 0;
        byte[] gramByte = new byte[0];
        try {
            gramByte = StringUtils.isNotBlank(charSet) ?gram.getBytes(charSet) : gram.getBytes();
        } catch (UnsupportedEncodingException e) {
            throw new BizException("encode 실패("+e.getMessage()+")",e);
        }

        while (index < gramByte.length) {
            strings.add(subString(gramByte, index,  index + size, charSet ));
            index += size;
        }

        return strings;
    }

	/**
	 * <p>메소드명	: like</p>
	 * <p>설　　명	: Oracle의 like 기능</p>
	 * <p>메소드인수	: String str, String cmpr</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public static boolean like(String str, String cmpr) {
		boolean flag = false;

		if (isNull(str) || isNull(cmpr)) {
			flag = false;
		}
		// case : like '%cmpr%'
		else if (cmpr.substring(0, 1).equals("%") && cmpr.substring(cmpr.length()-1).equals("%")) {
			flag = (str.indexOf(cmpr.substring(1, cmpr.length()-1))==-1)?false:true;
		}
		// case : like 'cmpr%'
		else if (cmpr.substring(cmpr.length()-1).equals("%")) {
			flag = str.substring(0, cmpr.length()-1).equals(cmpr.substring(0, cmpr.length()-1));
		}
		// case : like '%cmpr'
		else if (cmpr.substring(0, 1).equals("%")) {
			flag = str.substring(str.length()- (cmpr.length()-1)).equals(cmpr.substring(1));
		}
		// case : like 'cmpr'
		else {
			flag = str.equals(cmpr);
		}
		return flag;
	}

	/**
	 * <p>메소드명	: yrDdCnt</p>
	 * <p>설　　명	: 연일수</p>
	 * <p>메소드인수	: String dt</p>
	 * <p>리　턴　값	: ddCnt</p>
	 */
	public static int yrDdCnt(String loanDt) {
		String dt = parseFdt(loanDt, "yyyyMMdd");
		if (lengthB(dt)!=8) {
			return 0;
		}
		return isLeapYr(dt)?366:365;
	}

	/**
	 * <p>메소드명	: parseFdt</p>
	 * <p>설　　명	: DATE FORMAT</p>
	 * <p>메소드인수	: String date, String format</p>
	 * <p>리　턴　값	: String(Formatted Date)</p>
	 */
	public static String parseFdt(String date, String format) {
		date = date.replaceAll("[^0-9]", "");	// 숫자를 제외한 나머지 문자 제거
		if (date.length()==6) date += "01";
		if (date.length()==8) {
			date += "000000";
		}
		if (date.length()!=14) {
			return "";
		}

		//yyyyMMddHHmmss
		SimpleDateFormat sdf1 = new SimpleDateFormat("yyyyMMddHHmmss");
		SimpleDateFormat sdf2 = new SimpleDateFormat(format);
		Date tmpDate = null;

		try {
			tmpDate = sdf1.parse(date);
		} catch (ParseException e) {
			return "";
		}
		return sdf2.format(tmpDate);
	}

	/**
	 * <p>메소드명	: isLeapYr</p>
	 * <p>설　　명	: 윤년 여부</p>
	 * <p>메소드인수	: String year</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public static boolean isLeapYr(String dt) {
		if (dt.length()<4) return false;

		// YYYY 이외 포맷으로 입력 했을 시 앞 4자리 'YYYY'만 사용
		dt = dt.substring(0, 4);
		int year = parseInt(dt);

		return ((year%4==0) && (year%100!=0) || (year%400==0));
    }
	/**
	 * <p>메소드명	: numFmt</p>
	 * <p>설　　명	: numberFormat</p>
	 * <p>메소드인수	: double amt, String pattern</p>
	 * <p>리　턴　값	: String</p>
	 */
	public static String numFmt(String amt) {
		return numFmt(parseDouble(amt), "INT");
	}
	public static String numFmt(long amt) {
		return numFmt(parseDouble(amt), "INT");
	}
	public static String numFmt(String amt, String pattern) {
		return numFmt(parseDouble(amt), pattern);
	}
	public static String numFmt(long amt, String pattern) {
		return numFmt(parseDouble(amt+""), pattern);
	}
	public static String numFmt(double amt, String pattern) {
		// default pattern (다른 패턴을 쓰고 싶으면 param 에 직접 패턴을 입력하여 쓸 수 있음)
		if ((pattern.toUpperCase()).equals("INT"))		pattern = "###,###,###,###,###,##0";
		if ((pattern.toUpperCase()).equals("DOUBLE"))	pattern = "###,###,###,###,###,##0.000";

		NumberFormat  nf = NumberFormat.getCurrencyInstance();
		DecimalFormat df = (DecimalFormat) nf;

        String formatStr = "";

		df.setMinimumFractionDigits(2);
		df.setMaximumFractionDigits(2);
		df.setDecimalSeparatorAlwaysShown(true);
		df.applyPattern(pattern);

		try {
			formatStr = df.format(amt);
		} catch (IllegalArgumentException e) {

		}
		return formatStr;
	}

	/**
	 * Trim후 subString
	 * <b>※ 주의 : 입력문자열을 Trim 한후 subString함.</b><br>
	 *
	 * null 입력은 길이와 상관없이 blank리턴 :
	 * <p><blockquote><pre>
	 * trimAfSubString(null, 0,4);   //return ""
	 * </pre></blockquote><p>
	 *
	 * 입력된 String의 길이가 subString범위밖이면 blank리턴
	 * <p><blockquote><pre>
	 * trimAfSubString("11", 0,4);   //return ""
	 * </pre></blockquote><p>
	 *
	 * trim후 <code>substring</code>임 으로 아래는 "1234"리턴
	 * <p><blockquote><pre>
	 * trimAfSubString(" 1234", 0,4); //return "1234"
	 * </pre></blockquote><p>
	 * @param inStr - subString대상 문자열
	 * @param strtIdx - 시작 index (String.substring()파라미터와 동일)
	 * @param endCnt - 자를문자열 index (String.substring()파라미터와 동일)
	 * @return 입력문자열을 Trim한후 자를 문자열 범위에서 벗어나면 blank리턴, 아니면 subString <br>
	 *
	 */
	public static String trimAfSubString(String inStr, int strtIdx, int endCnt){
		int size = sizeAfTrim( inStr );
		if( size <= strtIdx || size < endCnt ){
			return "";
		}
		return inStr.substring(strtIdx, endCnt);
	}

	/**
	 * trim한후의 문자열 길이 얻기
	 * <p><blockquote><pre>
	 * sizeAfTrim(null); //0
	 * sizeAfTrim(""); //0
	 * sizeAfTrim("   "); //0
	 * sizeAfTrim(" 123  "); //3
	 * </pre></blockquote><p>
	 * @param inStr
	 * @return int - trim한후의 문자열 길이
	 */
	public static int sizeAfTrim( String inStr ){
		return null2Str(inStr).length();
	}


    /**
     * 상수테이블에서 상수명 put하여 상수값을 가져온다..
     * @param cnstNm - 상수명
     * @return cnstCntn - 상수내용
     */
	public static String getCnstValue(String cnstNm) {
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("sqlId"  , "CT_CNST_INF");
		param.put("cnstNm" , cnstNm);
		String cnstCntn = "";
		try {
			cnstCntn = cmmDataService.selectCmmCnstInfo(param);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return cnstCntn;
	}


	/**
     * 실명번호를 받아와서 나이를 계산한다.
     *
     * @param String
     * @param null
     * @return String
     * @author 이은준
     * @since 2011-04-21
     */
    public static String getAge(String rrno)
    {
        int rstAge = 0;

        int flag = Integer.parseInt(rrno.substring(6, 7));
        int birthAge = 1900;
        if ( 3 == flag || 4 == flag || 7 == flag || 8 == flag )
        {
            birthAge = 2000;
        }

        String sCurrentDt = DateUtil.getCurrentDateString();
        int iCurrentYYYY = Integer.parseInt(sCurrentDt.substring(0, 4));    //yyyymmdd
        int iRrnoYY = Integer.parseInt(rrno.substring(0, 2));
        int iRrnoYYYY = birthAge + iRrnoYY;
        int tmpAge = iCurrentYYYY - iRrnoYYYY;

        int iCurrentMM = Integer.parseInt(sCurrentDt.substring(4, 6));  //yyyymmdd
        int iRrnoMM = Integer.parseInt(rrno.substring(2, 4));   //yymmdd

        if( iRrnoMM < iCurrentMM ){
            rstAge = tmpAge;
        } else {
            if( iRrnoMM == iCurrentMM ) {

                int iCurrentDD = Integer.parseInt(sCurrentDt.substring(6, 8));  //yyyymmdd
                int iRrnoDD = Integer.parseInt(rrno.substring(4, 6));   //yymmdd

                if( iRrnoDD < iCurrentDD ) {
                    rstAge = tmpAge;
                } else {
                    rstAge = tmpAge - 1;
                }
            } else {
                rstAge = tmpAge - 1;
            }
        }

        return String.valueOf(rstAge);
    }


	/**
     * 실명번호를 받아와서 외국인 여부 판단한다
     *
     * 실명번호 내국인/외국인 구분코드 값
     * 1, 2, 3, 4 -> 내국인 . N 응답
     * 5, 6, 7, 8 -> 외국인 . Y 응답
     * 그외 판단할 수 없음. Y 응답 (외국인 간주)
     * @param String
     * @param null
     * @return String
     * @since 2011-04-21
     */
    public static String getFornManYn(String rrno) {


        int flag = Integer.parseInt(rrno.substring(6, 7));

        if( 1 == flag || 2 == flag || 3 == flag || 4 == flag)
        {
            return "N"; // 내국인
        }
        else
        {
            return "Y"; // 외국인
        }
    }

    /**
     * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
     * <p>작성일자      : 2023. 4. 12.
     * <p>작성자(author): 70323 / HeoHyemi
     * <p>설명          : 성명 마스킹 처리 한다.</p>
     * <p>메소드인수    : String</p>
     * <p>메소드리턴값  : String</p>
     * <p>예외처리      : Exception</p>
     */
    public static String nameMasking(String strValue) {

        String maskName = "";

        // □ 입력 데이터 null 처리
        strValue = StringUtil.null2Str(strValue);

        // □ 이름 마스킹
        if(strValue.length() > 0) {
	        String fstName = strValue.substring(0, 1);                    // 성
	        String midName = strValue.substring(1, strValue.length() -1);     // 가운데 이름
	        String lstName = strValue.substring(strValue.length() -1);        // 마지막 글자

	        String midMask = "";    // 중간 마스킹 처리

	        for(int i = 0; i < midName.length(); i++) {
	            midMask += "*";
	        }

	        if(midName.equals("")) {    // 외자일 경우
	            maskName = fstName + "*";
	        }else {
	            maskName = fstName + midMask + lstName;
	        }
        }

        return maskName;
    }

    /**
     * <p>메소드명      : telNoMasking : 전화/휴대폰번호 마스킹 처리</p>
     * <p>작성일자      : 2023. 5. 15.
     * <p>작성자(author): 70319
     * <p>설명          : 전화/휴대폰번호 마스킹 처리 한다.</p>
     * <p>메소드인수    : String</p>
     * <p>메소드리턴값  : String</p>
     * <p>예외처리      : Exception</p>
     */
    public static String telNoMasking(String strValue) {

        String strMaskRtn = "";

        // □ 전화번호에 대한 정규식
        String regex = "(\\d{2,3})-?(\\d{3,4})-?(\\d{4})$";
        Matcher matcher = Pattern.compile(regex).matcher(strValue);

        if( matcher.find() ) {
            // □ 가운데 그룹을 타겟으로 지정
            String target = matcher.group(2);

            int length = target.length();
            char[] c = new char[length];

            Arrays.fill(c, '*');

            // □ 마지막 4자리를 뺀 중간 value : 02-999-9999 인 경우 '999'를 replace 하기 때문에 마지막 4자리를 빼고 substr 처리 한다
            String strMidNo = strValue.substring(0, strValue.length()-4);

            // □ 원하는 가운데만 마스킹
            strMaskRtn = strMidNo.replace(target, String.valueOf(c));

            // □ 마스킹 데이터 + 마지막 4자리
            strMaskRtn = strMaskRtn.concat(strValue.substring(strValue.length()-4, strValue.length()));
        }

        return strMaskRtn;
    }

    /**
     * <p>메소드명      : acctNoMasking : 계좌번호 마스킹 처리</p>
     * <p>작성일자      : 2023. 5. 15.
     * <p>작성자(author): 70329
     * <p>설명         : 계좌번호 마스킹 처리 한다. 길이 상관 없이 끝 4자리 마스킹</p>
     * <p>메소드인수    : String</p>
     * <p>메소드리턴값  : String</p>
     * <p>예외처리      : Exception</p>
     */
    public static String acctNoMasking(String strValue) {

        String strMaskRtn = "";

        if(strValue.length() <= 0 ) {
            return strMaskRtn;
        }

        // □ 계좌번호 숫자에 대한 정규식
        String regex = "(^[0-9]+)$";
        Matcher matcher = Pattern.compile(regex).matcher(strValue);

        if( matcher.find() ) {
            int length = strValue.length();
            if( length > 5 ) {
                char[] c = new char[4];

                Arrays.fill(c, '*');

                // □ 계좌번호 마지막 5자리 마스킹 처리
                strMaskRtn = strValue.replace(strValue, strValue.substring(0, length-5) + String.valueOf(c));
            }
        }

        return strMaskRtn;
    }

    /**
     * <p>메소드명      : addrMasking : 주소 마스킹 처리</p>
     * <p>작성일자      : 2023. 5. 15.
     * <p>작성자(author): 70329
     * <p>설명         : 주소마스킹 - 신주소, 구주소, 도로명 주소 숫자만 전부 마스킹 </p>
     * <p>메소드인수    : String</p>
     * <p>메소드리턴값  : String</p>
     * <p>예외처리      : Exception</p>
     */
    public static String addrMasking(String strValue) {

        String strMaskRtn = "";

	     // □ 입력 데이터 null 처리
	     strValue = StringUtil.null2Str(strValue);

        if(strValue.length() > 0 ) {
	        // □ 주소 정규식
	        String regex   = "(([가-힣]+(\\d{1,5}|\\d{1,5}(,|.)\\d{1,5}|)+(읍|면|동|가|리))(^구|)((\\d{1,5}(~|-)\\d{1,5}|\\d{1,5})(가|리|)|))([ ](산(\\d{1,5}(~|-)\\d{1,5}|\\d{1,5}))|)"
	                       + "|([가-힣]+(아파트|동))"
	                       + "|(\\d)+(동)|(\\d)+(호)";
	        String newRegx = "(([가-힣]|(\\d{1,5}(~|-)\\d{1,5})|\\d{1,5})+(로|길))" + "|(\\d)+(동)|(\\d)+(호)";

	        Matcher matcher    = Pattern.compile(regex).matcher(strValue);
	        Matcher newMatcher = Pattern.compile(newRegx).matcher(strValue);

	        // □ 주소 정보 중 숫자만 전부 마스킹
	        if( matcher.find() ) {
	            strMaskRtn = strValue.replaceAll("[0-9]", "*");
	        } else if( newMatcher.find() ) {
	            strMaskRtn = strValue.replaceAll("[0-9]", "*");
	        }
        }

        return strMaskRtn;
    }

    /**
     * <p>메소드명  : lastMdt</p>
     * <p>설　　명  : 월말일</p>
     * <p>메소드인수 : String dt (yyyyMM, yyyyMMdd 다 가능)</p>
     * <p>리　턴　값 : String dt</p>
     */
    public static String lastMdt(String dt) {
        dt = parseFdt(addMonth(dt, 1), "yyyyMM")+DT_DIV+"01";
        return addDate(dt, -1); // 다음달 1일을 구해서 하루 뺀다.
    }

    /**
     * <p>메소드명  : addMonth</p>
     * <p>설　　명  : 월계산 유틸(오라클의  addMonths)</p>
     * <p>메소드인수 : String yyyyMM/yyyyMMdd, int</p>
     * <p>리　턴　값 : String date</p>
     */
    public static String addMonth(String date, int add) {
        date = nvl(date).replaceAll("[^0-9]", "");  // 숫자를 제외한 나머지 문자 제거
        if (!in(date.length(), new int[]{6, 8})) return "";

        String format = "yyyyMM";

        try {
            int yy = parseInt(date.substring(0, 4));
            int mm = parseInt(date.substring(4, 6));
            int dd = 1;

            GregorianCalendar cal = new GregorianCalendar();

            if (date.length()==8) {
                dd = Integer.parseInt(date.substring(6));
                format = "yyyyMMdd";
            }

            cal.set(yy, mm - 1, dd);    // 자바의 월은 0~11이므로 실제 월에서 1을 빼준다
            cal.add(GregorianCalendar.MONTH, add);

            SimpleDateFormat formatter = new SimpleDateFormat(format);
            return formatter.format(cal.getTime());
        }
        catch (Exception e) {
            LOGGER.error("■ [RUtil.addMonth] Error !!");
            return "";
        }
    }

    /**
     * <p>메소드명  : addDate</p>
     * <p>설　　명  : 날짜계산 유틸</p>
     * <p>메소드인수 : String date, int</p>
     * <p>리　턴　값 : String date</p>
     */
    public static String addDate(String date, int cnt) {
        String ymd = "";
        date = getFmtDt(date, DT_DIV);

        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
            Date dt = sdf.parse(date);

            Calendar cal = Calendar.getInstance();
            cal.setTime(dt);
            cal.add(Calendar.DATE, cnt);
            ymd = sdf.format(cal.getTime());
        } catch (ParseException e) {
            e.printStackTrace();
            return "";
        }
        return ymd;
    }

    /**
     * <p>메소드명  : addQuote</p>
     * <p>설　　명  : String 'str' 처리</p>
     * <p>메소드인수     : str</p>
     * <p>리　턴　값 : String</p>
     */
    public static String addQuote(String str) {
        return "'"+nvl(str)+"'";
    }

    /**
     * <p>메소드명  : toCamel, unCamel</p>
     * <p>설　　명  : CAMEL_CASE <=> DB_COL_CASE 변환</p>
     * <p>메소드인수 : String str</p>
     * <p>리　턴　값 : String</p>
     */
    public static String toCamel(String str) {
        str = str.toLowerCase();

        Pattern ptn = Pattern.compile("\\_[a-z]{1}");
        Matcher mat = ptn.matcher(str);

        while (mat.find()) {
            str = mat.replaceFirst(mat.group().replaceAll("\\_","").toUpperCase());
            mat = ptn.matcher(str);
        }
        return str;
    }
    public static String unCamel(String str) {
        String regex = "([a-z])([A-Z])";
        String replacement = "$1_$2";
        return str.replaceAll(regex, replacement).toUpperCase();
    }

    /**
     * <p>메소드명  : log_SQL</p>
     * <p>설　　명  : preparedStatement SQL의 내용을 출력</p>
     * <p>메소드인수     : SQL, paramArr</p>
     * <p>리　턴　값 : N/A</p>
     */
    public static void log_SQL(String sql, Object... arr) {
        String query = "";
        try {
            String[] splt = sql.split("\\?");
            // 마지막이 '?'로 끝나는 경우 split 배열이 1개 빔
            if ("?".equals(substrB(sql, lengthB(sql)-1))) {
                splt = (sql+" ").split("\\?");
            }

            if (size(splt)==0) {
                query = sql;
            }
            else if (size(splt)-1!=size(arr)) {
                query = sql;
                throw new Exception("[SQL ParamCnt 불일치] - ? : "+(size(splt)-1)+" / param("+size(arr)+")");
            }
            else {
                for (int i=0; i<size(arr); i++) {
                    query += splt[i] + addQuote(String.valueOf(arr[i]));
                }
                query += splt[splt.length-1];
            }
        } catch(Exception e) {
            LOGGER.error("■ [RUtil.log_SQL] Error!!\n"+e.getMessage());
        } finally {
            LOGGER.info("■ [RUtil.log_SQL] Query Info ----------------------------");
            LOGGER.info(query);
        }
    }

    /**
     * <p>메소드명  : substrB</p>
     * <p>설　　명  : substrB byte로 substring</p>
     * <p>메소드인수 : String, start, end
     * <p>리　턴　값 : String</p>
     */
    public static String substrB(String str, int st, int en) {
        if (isNull(str) || lengthB(str)<st || lengthB(str)<en) {
            LOGGER.info("■ RUtil.substrB] Index is over! str.length("+str.length()+": "+st+"~"+en+")");
            return "";
        }

        byte[] strB = str.getBytes();
        byte[] rsStrB = new byte[en - st];
        String rsStr = "";

        try {
            for (int i=st; i<en; i++) {
                rsStrB[i-st] = strB[i];
            }
            rsStr = new String(rsStrB);
            return rsStr;

        } catch (NullPointerException ne) {
            ne.printStackTrace();
            return "";
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    public static String substrB(String str, int st) {
        int en = lengthB(str);
        return substrB(str, st, en);
    }

    public static String nvl2(String str, String val1, String val2) {
        if (!isNull(str)) {
            return val1;
        } else {
            return val2;
        }
    }

    public static String fillPkNumber(String str, int pkLen) {
        if (str == null) {
            return "";
        }

        if (str.length() >= pkLen) {
            return str;
        }

        String temp = "";

        for (int i = 0; i < (pkLen - str.length()); i++) {
            temp += "0";
        }

        return temp + str;
    }

    /**
     * <p>메소드명      : isLease</p>
     * <p>설명            : 리스여부</p>
     * <p>메소드인수1    : IamtUnrcvObjVO</p>
     * <p>메소드리턴값    : boolean</p>
     * <p>예외처리      : N/A</p>
     */
    public static boolean isLease(IamtUnrcvObjVO iamtUnrcvObjVO) {
        return isLease(iamtUnrcvObjVO.prdtLrgeClasCd);
    }
    public static boolean isLease(String prdtLrgeClasCd){
        if (in(prdtLrgeClasCd, new String[]{"3", "4"})) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * <p>메소드명      : equals</p>
     * <p>설명            : 문자열 동등비교</p>
     * <p>메소드인수1    : String left</p>
     * <p>메소드인수2    : String right</p>
     * <p>메소드리턴값    : int</p>
     * <p>예외처리      : N/A</p>
     */
    public static boolean equals(String left, String right) {
        return StringUtil.trim(left).equals(StringUtil.trim(right));
    }

    /**
     * <p>메소드명  : isNum</p>
     * <p>설　　명  : 숫자여부 확인</p>
     * <p>메소드인수 : Object obj</p>
     * <p>리　턴　값 : boolean</p>
     */
    public static boolean isNum(Object obj) {
        try {
            String str = trim(String.valueOf(obj));

            if (isNullT(str)) {
                return false;
            }
            // 음수 '-' 제거
            if ("-".equals(substrB(str, 0, 1))) {
                str = substrB(str, 1);
            }
            // 소수점 체크
            if (in(str.indexOf("."), 0, lengthB(str)-1)) {
                return false;   // 소수점으로 시작하거나 끝나면 에러
            }
            str = replace(str, ".", "");    // 소수점이 1개넘을 경우를 고려하여 1개만 없애고 체크

            for (int i=0; i<str.length(); ++i) {
                char chr = str.charAt(i);
                if (!(Character.isDigit(chr))) {
                    return false;
                }
            }
        } catch (Exception e) {
            return false;
        }
        return true;
    }

	/**
	 * <p>메소드명	: calcCorpBnkbPw</p>
	 * <p>설　　명	: ksnet 복기부호 계산 유틸</p>
	 * <p>메소드인수1   : String trYyMmDd(거래일자) </p>
	 * <p>메소드인수2   : String acntNo(입금계좌) </p>
	 * <p>메소드인수3   : long payAmt(거래금액) </p>
	 * <p>메소드인수4   : String bankCd(입금은행) </p>
	 * <p>메소드인수5   : String moAcntNo(출금계좌) </p>
	 * <p>리　턴　값	: String</p>
	 */
    public static String calcCorpBnkbPw(String trYyMmDd, String acntNo, long payAmt, String bankCd, String moAcntNo){
        String tempTrYyMmDd = StringUtil.right(StringUtil.remove(trYyMmDd,"-"), 6);
        String tempAcntNo = StringUtil.rpad(StringUtil.remove(acntNo,"-"),15,"0");
        String tempPayAmt = StringUtil.lpad(String.valueOf(payAmt),13,"0");
        String tempBankCd = bankCd;
        String tempMoAcnTNo = StringUtil.rpad(StringUtil.remove(moAcntNo,"-"),15,"0" );

        // 각 항목을 더함
        String tempTotal = tempTrYyMmDd +  tempAcntNo + tempPayAmt + tempBankCd + tempMoAcnTNo;
        int tottal = 0;
        for( int i=0,n=tempTotal.length();i < n;i++){
            tottal += Integer.parseInt(String.valueOf(tempTotal.charAt(i)));
        }

        return StringUtil.lpad(String.valueOf(tottal),3,"0") + StringUtil.lpad(String.valueOf(payAmt % tottal),3,"0");
    }

    /**
     * <p>메소드명  : getKSTDate</p>
     * <p>설　　명  : 현재 일자값을 해당포맷으로 가져온다.</p>
     * <p>메소드인수 : DateFormat (yyyyMMddHHmmss)</p>
     * <p>리　턴　값 : String(Formatted Date)</p>
     */
    public static String getKSTDate(String format) {
        int millisPerHour = 60 * 60 * 1000; // 1hour(ms) = 60s * 60m * 1000ms
        SimpleDateFormat fmt = new SimpleDateFormat(format);
        SimpleTimeZone timeZone = new SimpleTimeZone(9 * millisPerHour, "KST");
        fmt.setTimeZone(timeZone);

        long time = System.currentTimeMillis();
        String str = fmt.format(new java.util.Date(time));
        return str;
    }


    /**
     * <p>메소드명   : removeHtmlTagType1</p>
     * <p>설명       : HTML 태그 문자열 제거</p>
     * <p>메소드인수 : String</p>
     * <p>리턴값     : String</p>
     */
    public static String removeHtmlTagType1(String str)
    {
        if (isNull(str) == true)
        {
            return "";
        }

        return str.replaceAll("<(/)?([a-zA-Z]*)(\\s[a-zA-Z]*=[^>]*?(\\s)*(/)?>", "");
    }


    /**
     * <p>메소드명   : removeHtmlTagType2</p>
     * <p>설명       : HTML 태그 문자열 제거</p>
     * <p>메소드인수 : String</p>
     * <p>리턴값     : String</p>
     */
    public static String removeHtmlTagType2(String str)
    {
        if (isNull(str) == true)
        {
            return "";
        }

        return str.replaceAll("<[^>]*>", "");
    }

    public static String convertHtmlCharToPlainStr(String str)
    {
        if (isNull(str) == true)
        {
            return "";
        }

        String sHtmlStr = str;
        // sHtmlStr = sHtmlStr.replaceAll("&gt;",  ">");
        // sHtmlStr = sHtmlStr.replaceAll("&lt;",  "<");
        sHtmlStr = sHtmlStr.replaceAll("&quot;",  "\"");
        // sHtmlStr = sHtmlStr.replaceAll("&nbsp;",  " ");
        // sHtmlStr = sHtmlStr.replaceAll("&amp;",  "&");

        return sHtmlStr;
    }

    /**
     * <p>메소드명  : isBetween</p>
     * <p>설　　명  : From ~ To 사이에 존재하는지 비교</p>
     * <p>메소드인수     : str, from, to</p>
     * <p>리　턴　값 : boolean</p>
     */
    public static boolean isBetween(String str, String fr, String to) {
        if (isNull(str)) {
            LOGGER.warn("[RUtil.isBetween] input(str) is NULL!!"); return false;
        }
        if (isNull(fr)) {
            LOGGER.warn("[RUtil.isBetween] input(from) is NULL!!"); return false;
        }
        if (isNull(to)) {
            LOGGER.warn("[RUtil.isBetween] input(to) is NULL!!"); return false;
        }

        if (str.compareTo(fr)>0 && str.compareTo(to)<=0) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * <p>메소드명  : String</p>
     * <p>설　　명  : Array를 붙여서 String으로 변환</p>
     * <p>메소드인수 : Array, 구분자</p>
     * <p>리　턴　값 : String</p>
     */
    public static String concat(String... arr) {
        return concatDv("", arr);
    }
    public static String concatDv(String dv, String... arr) {
        if (size(arr)==0) return "";

        String str = arr[0];
        for (int i=1; i<arr.length; i++) {
            str += dv + StringUtil.nvl(arr[i]);
        }
        return str;
    }

    /**
     * <p>메소드명  : isValidDt</p>
     * <p>설　　명  : 날짜형식에 맞는지 검증</p>
     * <p>메소드인수 : String date</p>
     * <p>리　턴　값 : boolean</p>
     */
    public static boolean isValidDt(String strDt) {
        String format = "yyyyMMdd";
        if (strDt.length()==10) format = "yyyy-MM-dd";
        return isValidDt(strDt, format);
    }
    public static boolean isValidDt(String strDt, String format) {
        SimpleDateFormat formatter = new SimpleDateFormat(format, Locale.KOREA);
        Date date = null;

        try {
            date = formatter.parse(strDt);
        } catch (ParseException e) {
            return false;
        }
        if (!formatter.format(date).equals(strDt)) {
            return false;
        }
        return true;
    }

    /**
     * Replaces all the occurences of a substring found
     * within a StringBuffer by a
     * replacement string
     *
     * @param buffer the StringBuffer in where the replace will take place
     * @param find the substring to find and replace
     * @param replacement the replacement string for all occurences of find
     * @return the original StringBuffer where all the
     * occurences of find are replaced by replacement
     */
    public static StringBuffer replaceAll(StringBuffer buffer, String find,
        String replacement) {
        int bufidx = buffer.length() - 1;
        int offset = find.length();

        while (bufidx > -1) {
            int findidx = offset - 1;

            while (findidx > -1) {
                if (bufidx == -1) {
                    //Done
                    return buffer;
                }

                if (buffer.charAt(bufidx) == find.charAt(findidx)) {
                    findidx--; //Look for next char
                    bufidx--;
                } else {
                    findidx = offset - 1; //Start looking again
                    bufidx--;

                    if (bufidx == -1) {
                        //Done
                        return buffer;
                    }

                    continue;
                }
            }

            //Found
            //System.out.println( "replacing from " + (bufidx + 1) +
            //                    " to " + (bufidx + 1 + offset ) +
            //                    " with '" + replacement + "'" );
            buffer.replace(bufidx + 1, bufidx + 1 + offset, replacement);

            //start looking again
        }

        //No more matches
        return buffer;
    }

    /**
     * <p>메소드명     : intervalTime</p>
     * <p>설명        : 시작 - 종료 시간의 interval 구하기</p>
     * <p>메소드인수1  : long start 시작시간</p>
     * <p>메소드인수2  : long end 종료시간</p>
     * <p>메소드리턴값 : N/A</p>
     */
    public static String intervalTime(long start, long end) {
        long inteval = end - start;
        long minute = inteval / 1000L / 60L;
        long second = (inteval / 1000L) % 60L;
        long msec = inteval % 1000L;
        return minute + " M " + second + " S " + msec + " MS";
    }

    // Valid 이메일
    public static boolean isValidEmail(String email) {
        String emailRegex = "^[a-zA-Z0-9_+&*-]+(?:\\."+
                "[a-zA-Z0-9_+&*-]+)*@" +
                "(?:[a-zA-Z0-9-]+\\.)+[a-z" +
                "A-Z]{2,7}$";

        Pattern pat = Pattern.compile(emailRegex);
        if (email == null) {
            return false;
        }
        return pat.matcher(email).matches();
    }

    public static String merge(String[] arr) {
        String result = "";
        for(String str : arr) {
            result = result + nvl(str);
        }
        return result;
    }
}