package hanalife.c.co.util;

import java.util.List;
import java.util.Map;
import java.util.Vector;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.ui.ModelMap;

import hanalife.c.cm.cm.service.HlflCmmService;
import xdataset5.XDataSet5;
import xdataset5spring.XFrame5Util;
/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : XFrame5DataSetUtil.java Class
 * 클래스설명   : XFrame5 DataSet 관련 유틸리티
 * 작성일자     : 2023. 3. 16.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 16.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@Component
public class XFrame5DataSetUtil {
	
	
	private static HlflCmmService cmmService;
	
	@Autowired
	private XFrame5DataSetUtil(HlflCmmService cmmService) {
		XFrame5DataSetUtil.cmmService = cmmService;
	}

	
	private static Logger log = LoggerFactory.getLogger("Util");
	
	

    /**
     * XFrame5 UI 에서 전달된 특정 DataSet 값을 추출하여 Map<String, Object> 결과값으로 전달한다.
     *
     * @param {String} pstrDataSetId : 추출할 특정 DataSetId
     * @return {Map<String, Object>} 추출된 DataSet 정보
     */
    public static Map<String, Object> getXFrameDataSet(String pstrDataSetId, HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        Map<String, Object> requestMap = XFrame5Util.xFrame5Map(request, response, model);
        XFrame5Util.printMetaInfoMap(requestMap);

        // parameter로 활용할 dataset 정보를 가져온다.
        Map<String, Object> resultMap = XFrame5Util.getDataMap(requestMap, pstrDataSetId, 0);

        return resultMap;
    }

    /**
     * XFrame5 UI 에서 전달된 특정 DataSet 값을 추출하여 List<Map<String, Object>> 결과값으로 전달한다.
     *
     * @param {String} pstrDataSetId : 추출할 특정 DataSetId
     * @return {List<MapMap<String, Object>>} 추출된 DataSet 정보
     */
    public static List<Map<String, Object>> getXFrameDataSetList(String pstrDataSetId, HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

    	Map<String, Object> requestMap = XFrame5Util.xFrame5Map(request, response, model);
    	XFrame5Util.printMetaInfoMap(requestMap);

    	// parameter로 활용할 dataset 정보를 가져온다.
    	List<Map<String, Object>> resultMap = XFrame5Util.getDataMapList(requestMap, pstrDataSetId);

    	return resultMap;
    }
    
	/** 참고사항
	 * UI(xFrame5)에서 전달된 데이터 정보를 추출하는 예제.
	 * 데이터 MAP에서  XDATASET5 이름, 컬럼이름, 컬럼데이터를 출력한다.
	 */
	public static void printDataSetfromMap(Map<String, Object> reqMap) {
		
			try {
				log.debug("=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- Param Info Start  =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-");
				XDataSet5 xdataset5 = (XDataSet5)reqMap.get("XFRAME5_XDATASET5"); // Map에서 XDataset5 객체로 데이터 변환
				int				i, j;
				int				nRow, nCol;
	
				Vector vXDataSetNames = xdataset5.getDataSetNames();	// 데이터셋 이름을 구함 : getDataSetNames()
	
				// 데이터셋 수만큼 데이터를 출력
				for (i = 0; i < vXDataSetNames.size(); i++) {
					String 	sXDataSetName = (String)vXDataSetNames.get(i);
					System.out.println("DataSetName : " + sXDataSetName ); // 데이터셋 이름 출력
					
					Vector	vXDataColumnNames = xdataset5.getColumnNames(sXDataSetName); // 컬럼이름을 구함 : getColumnNames()
					int	nColumnCount = xdataset5.getColumnCount(sXDataSetName);	// 컬럼수를 구함 : getColumnCount()
					int	nRecordCount = xdataset5.getRecordCount(sXDataSetName);	// 레코드수를 구함 : getRecordCount()
					
					String	sbRecordData = "";
					for (nRow = 0; nRow < nRecordCount; nRow++) {
						sbRecordData +="\n"+ nRow+"] ";
						for (nCol = 0; nCol < nColumnCount; nCol++) {
							//sbRecordData += (String)vXDataColumnNames.get(j) +":"+ xdataset5.getData(sXDataSetName, (String)vXDataColumnNames.get(nCol), nRow) ;
							sbRecordData +=(String)vXDataColumnNames.get(nCol) +" : "+xdataset5.getData(sXDataSetName, (String)vXDataColumnNames.get(nCol), nRow)+" , " ;
						}
						sbRecordData = sbRecordData.substring(0, sbRecordData.length()-2) ;
					}
					
					
					log.debug(sbRecordData);	// 컬럼 데이터  출력
					log.debug("=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- Param Info End    =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-");
	
				}
			}catch (Exception e) {
				// TODO: handle exception
				System.out.println("printDataSetfromMap = " + e);
			}
	}
	
    /**
     * 세션에 롤코드에 해당되는 권한이 있는지 확인
     * @param session - 세션 
     * @param  roleNo - 권한번호 
     * @return roleGbn - 권한유무
     */
	public static boolean getUserRollGbn(HttpSession session, String roleNo) {
		boolean roleGbn = false;
		List<Map<String, Object>> userRole =(List<Map<String, Object>>)session.getAttribute("userRole");
		for(int i =0 ; i < userRole.size(); i++) {
			Map<String, Object> roleDetailMap = (Map<String, Object>)userRole.get(i);
			String seRoleNo = (String)roleDetailMap.get("roleNo");
			log.debug("SESSION USER ROLE >> "+seRoleNo);
			if(roleNo.equals(seRoleNo)) {
				roleGbn = true;
				break;
			}
		}
		return roleGbn;
	}
	
    /**
     * 파일 정보를 DB에 저장한다.
     * @param fileInfo - 파일정보 
     */	
	public static void insertFileInfo(Map<String, Object> param) {
		try {
			cmmService.insertFileInfo(param);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

}
