package hanalife.c.sc.pg.service;

import hanalife.c.sc.pg.vo.CSCPGM05I01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CSCPGM05Service.java Class
 * 클래스설명	: 상수리스트관리 (CSCPGM05) Service Interface
 * 작성일자	: 2023. 3. 27.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getCSCPGM01S01	: 상수리스트관리내역 조회
 * 			getCSCPGM01S02	: 상수리스트관리내역 전 조회
 * 			saveCSCPGM05I01 : 상수리스트관리내역 등록
 * 			updCSCPGM01U01	: 상수리스트관리내역 수정
 * 			delCSCPGM01D01	: 상수리스트관리내역 삭제
 * 			getCSCPGM01S03	: 상수리스트내역 상세조회_성관용부장님요청
 * </pre>
 */
public interface CSCPGM05Service {

	/**
	 * <p>메소드명			: getCSCPGM01S01 : 상수리스트관리 내역조회</p>
	 * <p>작성일자			: 2023. 3. 27.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트관리내역을 조회한다.</p>
	 * <p>메소드인수		: CSCPGM05S01InVo </p>
	 * <p>메소드리턴값		: CSCPGS01OutVo</p>
	 * <p>예외처리			: Exception</p>
	 */
	public CSCPGM05S01OutVO getCSCPGM05S01(CSCPGM05S01InVO inVo) throws Exception;


    /**
 	 * <p>메소드명			: getCSCPGM01S02 : 상수리스트관리 전 조회</p>
	 * <p>작성일자			: 2023.03.29.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트관리 저장 전 조회한다.</p>
	 * <p>메소드인수		: CSCPGM05I01InVo </p>
	 * <p>예외처리			: Exception</p>
     */
    public int getCSCPGM01S02(CSCPGM05I01InVO inVo) throws Exception;

    /**
     * <p>메소드명			: saveCCSROM05I01 : 상수리스트관리 저장</p>
	 * <p>작성일자			: 2023.03.29.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트관리 내역을 저장한다.</p>
	 * <p>메소드인수		: CSCPGM05I01InVo </p>
	 * <p>메소드리턴값		: CSCPGS01OutVo</p>
	 * <p>예외처리			: Exception</p>
     */
    public CSCPGM05S01OutVO saveCSCPGM05I01(CSCPGM05I01InVO inVo) throws Exception;

    /**
     * <p>메소드명			: updCCSROM05U01 : 상수리스트관리 저장</p>
	 * <p>작성일자			: 2023.03.31.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트관리 내역을 수정한다.</p>
	 * <p>메소드인수		: CSCPGM05I01InVo </p>
	 * <p>메소드리턴값		: CSCPGS01OutVo</p>
	 * <p>예외처리			: Exception</p>
	 */
    public CSCPGM05S01OutVO updCSCPGM05U01(CSCPGM05I01InVO inVo) throws Exception;

    /**
     * <p>메소드명			: delCSCPGM01D01 : 상수리스트관리 삭제</p>
	 * <p>작성일자			: 2023.03.31.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트관리 내역을 삭제한다.</p>
	 * <p>메소드인수		: CSCPGM05I01InVo </p>
	 * <p>메소드리턴값		: CSCPGS01OutVo</p>
	 * <p>예외처리			: Exception</p>
     */
    public CSCPGM05S01OutVO delCSCPGM05D01(CSCPGM05I01InVO inVo) throws Exception;

	/**
	 * <p>메소드명			: getCSCPGM01S03 : 상수리스트내역 상세조회</p>
	 * <p>작성일자			: 2023.04.05.
	 * <p>작성자(author)	: 70305 / KBS
	 * <p>설명			: 상수리스트내역을 상세조회한다.</p>
	 * <p>메소드인수		: CSCPGM05S01InVo </p>
	 * <p>메소드리턴값		: CSCPGS01OutVo</p>
	 * <p>예외처리			: Exception</p>
	 */
	public CSCPGM05S01OutVO getCSCPGM05S03(CSCPGM05S01InVO inVo) throws Exception;


}