package hanalife.c.sc.pg.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.sc.pg.mapper.CnstMngMapper;
import hanalife.c.sc.pg.mapper.dto.CnstMngDSSDDO01DTO;
import hanalife.c.sc.pg.mapper.dto.CnstMngDSSMDODTO;
import hanalife.c.sc.pg.service.CSCPGM05Service;
import hanalife.c.sc.pg.vo.CSCPGM05DSSDDO01VO;
import hanalife.c.sc.pg.vo.CSCPGM05I01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CSCPGM05ServiceImpl.java Class
 * 클래스설명	: 상수리스트관리 (CSCPGM05) Service Implements
 * 작성일자	: 2023. 3. 27.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :getCSCPGM01S01	: 상수리스트관리내역 조회
 * 			getCSCPGM01S02	: 상수리스트관리내역 전 조회
 * 			saveCSCPGM05I01 : 상수리스트관리내역 등록
 * 			updCSCPGM01U01	: 상수리스트관리내역 수정
 * 			delCSCPGM01D01	: 상수리스트관리내역 삭제
 * </pre>
 */

@Service("CSCPGM05Service")
public class CSCPGM05ServiceImpl implements CSCPGM05Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCPGM05ServiceImpl.class);

	@Autowired
	private CnstMngMapper cnstMngMapper;

	/**
	 * <p>메소드명			: getCSCPGM05S01 : 상수리스트관리내역_조회</p>
	 * <p>작성일자			: 2023.03.27.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트관리내역을 조회한다.</p>
	 * <p>메소드인수		: CSCPGM05S01InVO</p>
	 * <p>메소드리턴값		: CSCPGM05S01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CSCPGM05S01OutVO getCSCPGM05S01(CSCPGM05S01InVO inVo) throws Exception {

		LOGGER.debug("CSCPGM05ServiceImpl getCSCPGM05S01 Start");

	    // 상수리스트관리 내역 서비스 결과값 객체 생성
		CSCPGM05S01OutVO resultVo = new CSCPGM05S01OutVO();

	    // 상수리스트관리 내역조회 조건 입력값 객체 생성 및 대입 수행
	    CnstMngDSSMDODTO i01Dto = new CnstMngDSSMDODTO();

	    i01Dto.setDutyZonCd(inVo.getCSCPGM05DSSMDOVO().getDutyZonCd()); 	/* 업무영역 */
        LOGGER.info("##### 입력값::업무영역 = " + i01Dto.getDutyZonCd() );

        // 상수리스트관리 내역조회 쿼리 Mapper 호출 수행
        List<CnstMngDSSDDO01DTO> resultDTO = cnstMngMapper.searchCnstMngList(i01Dto);

        // 상수리스트관리 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CSCPGM05DSSDDO01VO> resultList = new ArrayList<CSCPGM05DSSDDO01VO>();
        for (CnstMngDSSDDO01DTO sourceIO : resultDTO) {

        	// 상수리스트관리 내역조회 VO에 조회된 Mapper DTO 값을 대입
        	CSCPGM05DSSDDO01VO targetIO = new CSCPGM05DSSDDO01VO();

        	targetIO.setDutyZonCd(sourceIO.getDutyZonCd()); 	/** 업무영역 */
        	targetIO.setCnstNm(sourceIO.getCnstNm()); 			/** 상수명 */
        	targetIO.setCnstCntn(sourceIO.getCnstCntn()); 		/** 상수값 */
        	targetIO.setDescCntn(sourceIO.getDescCntn()); 	    /** 상수설명 */

            // 상수리스트관리 내역조회 List 객체에 추가
            resultList.add(targetIO);
		}

        // 상수리스트관리내역조회 화면 출력 결과값 대입
        resultVo.setListCSCPGM05DSSDDO01VO(resultList);

        return resultVo;
	}

    /**
     * <p>메소드명			: getCSCPGM05S02 : 상수리스트관리내역_전 조회</p>
	 * <p>작성일자			: 2023.03.29.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트관리내역을 전 조회한다.</p>
	 * <p>메소드인수		: CSCPGM05I01InVO </p>
	 * <p>예외처리			: Exception</p>
     */
	@Override
	public int getCSCPGM01S02(CSCPGM05I01InVO inVo) throws Exception {

		LOGGER.debug("CSCPGM05ServiceImpl getCSCPGM01S02 Start");

		int iVal = 0;

        // 검색조건 체크
//        String strDutyZonCd = inVo.getCSCPGM05DSSDDO01VO().getDutyZonCd().toString();	// 업무영역
        String strCnstNm = inVo.getCSCPGM05DSSDDO01VO().getCnstNm().toString();			// 상수명

        // 상수리스트관리 조회
        CnstMngDSSMDODTO inDto = new CnstMngDSSMDODTO();
//        inDto.setDutyZonCd(strDutyZonCd);
        inDto.setCnstNm(strCnstNm);

        LOGGER.debug("CSCPGM05ServiceImpl getCSCPGM01S02 Start");

        String strRtnVal = cnstMngMapper.selectCnstMngCount(inDto);

        iVal = Integer.parseInt(strRtnVal);

        return iVal;
    }

    /**
     * <p>메소드명			: saveCSCPGM05I01 : 상수리스트관리등록</p>
	 * <p>작성일자			: 2023.03.30.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트관리내역을 등록한다.</p>
	 * <p>메소드인수		: CSCPGM0501InVO </p>
	 * <p>메소드리턴값		: CSCPGM05OutVO</p>
	 * <p>예외처리			: Exception</p>
     */
	@Override
	public CSCPGM05S01OutVO saveCSCPGM05I01(CSCPGM05I01InVO inVO) throws Exception{

		LOGGER.debug("CSCPGM05ServiceImpl saveCSCPGM05I01 Start");

		// 결과값 출력 객체 VO 선언 및 정상 초기값 설정
		CSCPGM05S01OutVO resultVo = new CSCPGM05S01OutVO();
		resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

      	// 검색조건 체크
		String strDutyZonCd = inVO.getCSCPGM05DSSDDO01VO().getDutyZonCd().toString();   // 업무영역
		String strCnstNm    = inVO.getCSCPGM05DSSDDO01VO().getCnstNm().toString();      // 상수명
		String strCnstCntn  = inVO.getCSCPGM05DSSDDO01VO().getCnstCntn().toString();    // 상수값
		String strDescCntn  = inVO.getCSCPGM05DSSDDO01VO().getDescCntn().toString();    // 설명
		String StrFrstRegEmpNo  = inVO.getCSCPGM05DSSDDO01VO().getFrstRegEmpNo(); // 최초등록사원번호
		String StrLastProcEmpNo = inVO.getCSCPGM05DSSDDO01VO().getLastProcEmpNo(); // 최종변경사원번호

		// key값 체크(업무영역 & 상수명)
		if( StringUtils.isEmpty(strDutyZonCd) ) {
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}
		if( StringUtils.isEmpty(strCnstNm) ) {
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

		try {

        	// 상수리스트 등록
			CnstMngDSSDDO01DTO inDto = new CnstMngDSSDDO01DTO();

    		inDto.setDutyZonCd(strDutyZonCd);
    		inDto.setCnstNm(strCnstNm);
    		inDto.setCnstCntn(strCnstCntn);
    		inDto.setDescCntn(strDescCntn);
    		inDto.setFrstRegEmpNo(StrFrstRegEmpNo);
    		inDto.setLastProcEmpNo(StrLastProcEmpNo);

    		LOGGER.info("상수리스트관리" + "최초등록사원번호 = inDto.getFrstRegEmpNo  : " + inDto.getFrstRegEmpNo());
    		LOGGER.info("상수리스트관리" + "최종변경사원번호 = inDto.getLastProcEmpNo : " + inDto.getLastProcEmpNo());


    		cnstMngMapper.insertCnstMng(inDto);

        }  catch (Exception e) {

            LOGGER.error("[상수리스트관리 등록오류] : 상수리스트 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }


    /**
	 * <p>메소드명			: updCSCPGM01U01 : 상수리스트관리 수정</p>
	 * <p>작성일자			: 2023.03.31.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트관리내역을 수정한다.</p>
	 * <p>메소드인수		: CSCPGM0501InVO </p>
	 * <p>메소드리턴값		: CSCPGM05S01OutVO</p>
	 * <p>예외처리			: Exception</p>
     */
    @Override
    public CSCPGM05S01OutVO updCSCPGM05U01(CSCPGM05I01InVO inVO) throws Exception{

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
    	CSCPGM05S01OutVO resultVo = new CSCPGM05S01OutVO();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        /*************************************************
         * ■ 조건 체크
         *************************************************/

      	// 검색조건 체크
		String strDutyZonCd 	= inVO.getCSCPGM05DSSDDO01VO().getDutyZonCd().toString();   // 업무영역
		String strCnstNm    	= inVO.getCSCPGM05DSSDDO01VO().getCnstNm().toString();      // 상수명
		String strCnstCntn  	= inVO.getCSCPGM05DSSDDO01VO().getCnstCntn().toString();    // 상수값
		String strDescCntn  	= inVO.getCSCPGM05DSSDDO01VO().getDescCntn().toString();    // 설명
		String StrFrstRegEmpNo  = inVO.getCSCPGM05DSSDDO01VO().getFrstRegEmpNo(); 			// 최초등록사원번호
		String StrLastProcEmpNo = inVO.getCSCPGM05DSSDDO01VO().getLastProcEmpNo(); 			// 최종변경사원번호

		// key값 체크(업무영역 & 상수명)
		if( StringUtils.isEmpty(strDutyZonCd) ) {
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

		if( StringUtils.isEmpty(strCnstNm) ) {
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

        try {

			// 상수리스트 수정
			CnstMngDSSDDO01DTO inDto = new CnstMngDSSDDO01DTO();

    		inDto.setDutyZonCd(strDutyZonCd);
    		inDto.setCnstNm(strCnstNm);
    		inDto.setCnstCntn(strCnstCntn);
    		inDto.setDescCntn(strDescCntn);
    		inDto.setFrstRegEmpNo(StrFrstRegEmpNo);
    		inDto.setLastProcEmpNo(StrLastProcEmpNo);

    		cnstMngMapper.updateCnstMng(inDto);

        }  catch (Exception e) {

            LOGGER.error("[상수리스트관리 수정 오류] : 상수리스트 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

    /**
	 * <p>메소드명			: delCSCPGM01D01 : 상수리스트관리 삭제</p>
	 * <p>작성일자			: 2023.03.31.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트관리내역을 삭제한다.</p>
	 * <p>메소드인수		: CSCPGM0501InVO </p>
	 * <p>메소드리턴값		: CSCPGM05S01OutVO</p>
	 * <p>예외처리			: Exception</p>
     */
    @Override
    public CSCPGM05S01OutVO delCSCPGM05D01(CSCPGM05I01InVO inVO) throws Exception {

        // ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
    	CSCPGM05S01OutVO resultVo = new CSCPGM05S01OutVO();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // ■ 조건 체크
		String strDutyZonCd = inVO.getCSCPGM05DSSDDO01VO().getDutyZonCd().toString();   // 업무영역
		String strCnstNm    = inVO.getCSCPGM05DSSDDO01VO().getCnstNm().toString();      // 상수명

        if( StringUtils.isEmpty(strDutyZonCd) ) {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }
        if( StringUtils.isEmpty(strCnstNm) ) {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }


        try {

        	// ■ 역할정보 삭제
			CnstMngDSSDDO01DTO inDto = new CnstMngDSSDDO01DTO();

    		inDto.setDutyZonCd(strDutyZonCd);
    		inDto.setCnstNm(strCnstNm);

    		cnstMngMapper.deleteCnstMng(inDto);

        }  catch (Exception e) {

            LOGGER.error("[상수리스트삭제오류] : 상수리스트 삭제 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

	/**
	 * <p>메소드명			: getCSCPGM05S03 : 상수리스트내역_상세조회</p>
	 * <p>작성일자			: 2023.04.05.</p>
	 * <p>작성자(author)	: 70305 / kbs</p>
	 * <p>설명			: 상수리스트내역을 상세조회한다.</p>
	 * <p>메소드인수		: CSCPGM05S01InVO</p>
	 * <p>메소드리턴값		: CSCPGM05S01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public CSCPGM05S01OutVO getCSCPGM05S03(CSCPGM05S01InVO inVo) throws Exception {

		LOGGER.debug("CSCPGM05ServiceImpl getCSCPGM05S03 Start");

	    // 상수리스트관리 내역 서비스 결과값 객체 생성
		CSCPGM05S01OutVO resultVo = new CSCPGM05S01OutVO();

	    // 상수리스트관리 내역조회 조건 입력값 객체 생성 및 대입 수행
	    CnstMngDSSMDODTO i01Dto = new CnstMngDSSMDODTO();

	    i01Dto.setDutyZonCd(inVo.getCSCPGM05DSSMDOVO().getDutyZonCd()); 	/* 업무영역 */
	    i01Dto.setCnstNm(inVo.getCSCPGM05DSSMDOVO().getCnstNm()); 			/* 상수명 */
        LOGGER.info("##### 입력값::업무영역 = " + i01Dto.getDutyZonCd() );
        LOGGER.info("##### 입력값::상수명 = " + i01Dto.getCnstNm() );

        // 상수리스트관리 내역조회 쿼리 Mapper 호출 수행
        List<CnstMngDSSDDO01DTO> resultDTO = cnstMngMapper.searchCnstDesc(i01Dto);

        // 상수리스트관리 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<CSCPGM05DSSDDO01VO> resultList = new ArrayList<CSCPGM05DSSDDO01VO>();
        for (CnstMngDSSDDO01DTO sourceIO : resultDTO) {

        	// 상수리스트관리 내역조회 VO에 조회된 Mapper DTO 값을 대입
        	CSCPGM05DSSDDO01VO targetIO = new CSCPGM05DSSDDO01VO();

        	targetIO.setDutyZonCd(sourceIO.getDutyZonCd()); 	/** 업무영역 */
        	targetIO.setCnstNm(sourceIO.getCnstNm()); 			/** 상수명 */
        	targetIO.setCnstCntn(sourceIO.getCnstCntn()); 		/** 상수값 */
        	targetIO.setDescCntn(sourceIO.getDescCntn()); 	    /** 상수설명 */

            // 상수리스트관리 내역조회 List 객체에 추가
            resultList.add(targetIO);
		}

        // 상수리스트관리내역조회 화면 출력 결과값 대입
        resultVo.setListCSCPGM05DSSDDO01VO(resultList);

        return resultVo;
	}

}