package hanalife.c.sc.ro.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.sc.ro.mapper.dto.CtRoleDTO;

/**
 * <pre>
 * 클래스명    : CtRoleMapper.java Class
 * 클래스설명  : 역할관리 Mapper
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 24.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 24.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 * @param <RRCRCM02DSSDDO01DTO>
 */

@Mapper("ctRoleMapper")
public interface CtRoleMapper {

    /**
     * <p>메소드명      : selectRoleList</p>
     * <p>설명          : 역할관리 목록을 조회 한다.</p>
     * <p>메소드인수1   : 역할관리 조회 CtRoleDTO </p>
     * <p>메소드리턴값  : 역할관리 조회 결과 CtRoleDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<CtRoleDTO> selectRoleList(CtRoleDTO inDto) throws Exception;

    /**
     * <p>메소드명      : selectRoleCount</p>
     * <p>설명          : 역할번호에 대해 count 한다.</p>
     * <p>메소드인수1   : 역할관리 조회 CtRoleDTO </p>
     * <p>메소드리턴값  : String </p>
     * <p>예외처리      : Exception</p>
     */
    public String selectRoleCount(CtRoleDTO inDto) throws Exception;

    /**
     * <p>메소드명      : insertRole</p>
     * <p>설명          : 역할관리를 등록 한다.</p>
     * <p>메소드인수1   : 역할관리 등록 CtRoleDTO </p>
     * <p>메소드리턴값  : void </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertRole(CtRoleDTO inDto) throws Exception;

    /**
     * <p>메소드명      : updateRole</p>
     * <p>설명          : 역할관리를 수정 한다.</p>
     * <p>메소드인수1   : 역할관리 수정 CtRoleDTO </p>
     * <p>메소드리턴값  : void </p>
     * <p>예외처리      : Exception</p>
     */
    public void updateRole(CtRoleDTO inDto) throws Exception;

    /**
     * <p>메소드명      : deleteRole</p>
     * <p>설명          : 역할관리를 삭제 한다.</p>
     * <p>메소드인수1   : 역할관리 삭제 CtRoleDTO </p>
     * <p>메소드리턴값  : void </p>
     * <p>예외처리      : Exception</p>
     */
    public void deleteRole(CtRoleDTO inDto) throws Exception;
}