package hanalife.c.sc.ro.service;

import hanalife.c.sc.ro.vo.CSCROM03S01InVO;
import hanalife.c.sc.ro.vo.CSCROM03S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM03U01InVO;
import hanalife.c.sc.ro.vo.CSCROM03U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM03Service.java Class
 * 클래스설명   : 프로그램역할관리 (CSCROM03) Service Interface
 * 작성일자     : 2023. 5. 4.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 4.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getPrgmRoleCnt : 프로그램건수조회
 * 			 	getCSCROM03S01 : 프로그램조회
 * 			 	getCSCROM03S02 : 프로그램역할조회
 * 			 	registerCSCROM03I01 : 프로그램역할관리등록
 * 			 	modifyCSCROM03U01 : 프로그램역할관리수정
 * 			 	deleteCSCROM03U01 : 프로그램역할관리삭제
 * </pre>
 */

public interface CSCROM03Service {

	/**
	 * <p>메소드명      : getPrgmRoleCnt : 프로그램건수조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램건수조회 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public int getPrgmRoleCnt(CSCROM03U01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : getCSCROM03S01 : 프로그램조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public CSCROM03S01OutVO getCSCROM03S01(CSCROM03S01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : getCSCROM03S02 : 프로그램역할관리</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public CSCROM03S01OutVO getCSCROM03S02(CSCROM03S01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : registerCSCROM03U01 : 프로그램역할조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 등록한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM03U01OutVO registerCSCROM03U01(CSCROM03U01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : modifyCSCROM03U01 : 프로그램역할관리수정</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 수정한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM03U01OutVO modifyCSCROM03U01(CSCROM03U01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : deleteCSCROM03U01 : 프로그램역할관리삭제</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 삭제한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM03U01OutVO deleteCSCROM03U01(CSCROM03U01InVO inVo) throws Exception;

}
