package hanalife.c.sc.ro.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.sc.ro.mapper.CtRoleMapper;
import hanalife.c.sc.ro.mapper.dto.CtRoleDTO;
import hanalife.c.sc.ro.service.CCSROM01Service;
import hanalife.c.sc.ro.vo.CSCROM01DSSDDO01VO;
import hanalife.c.sc.ro.vo.CSCROM01I01InVO;
import hanalife.c.sc.ro.vo.CSCROM01InVO;
import hanalife.c.sc.ro.vo.CSCROM01OutVO;

/**
 * <pre>
 * 클래스명    : CCSROM01ServiceImpl.java Class
 * 클래스설명  : 역할관리 (CCSROM01) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 24
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 24.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("CSCROM01Service")
public class CCSROM01ServiceImpl implements CCSROM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(CCSROM01ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private CtRoleMapper ctRoleMapper;

    /**
     * <p>메소드명      : getCCSROM01S01 : 역할관리목록조회</p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할관리목록을 조회 한다.</p>
     * <p>메소드인수    : CSCROM01InVO </p>
     * <p>메소드리턴값  : CSCROM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings({ "unchecked", "static-access" })
    @Override
    public CSCROM01OutVO getCCSROM01S01(CSCROM01InVO inVo) throws Exception {

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
        CSCROM01OutVO resultVo = new CSCROM01OutVO();
        resultVo.setRsltCd  (msgEnum.SUCCESS.getErrorCd()    );
        resultVo.setRsltCntn(msgEnum.SUCCESS.getDescription());

        /*************************************************
         * ■ 검색조건 체크
         *************************************************/
        String strCond   = inVo.getCSCROM01DSSMVO().getCond().toString();      // 검색조건 기준
        String strRoleNo = inVo.getCSCROM01DSSMVO().getRoleNo().toString();    // 역할번호
        String strRoleNm = inVo.getCSCROM01DSSMVO().getRoleNm().toString();    // 역할명

        /*************************************************
         * ■ 검색조건 셋팅
         *************************************************/
        CtRoleDTO inDto = new CtRoleDTO();
        if( strCond.equals("") ) {
            inDto.setRoleNm(strRoleNm);
        } else {
            if( strCond.equals("cd") ) {
                if( !StringUtils.isEmpty(strRoleNm) ) {
                    inDto.setRoleNo(strRoleNm);
                }
            } else {
                if( !StringUtils.isEmpty(strRoleNm) ) {
                    inDto.setRoleNm(strRoleNm);
                }
            }
        }

        List<CtRoleDTO> roleListDto = null;
        try {
            /*************************************************
             * ■ 역할정보 조회
             *************************************************/
            List<CSCROM01DSSDDO01VO> resultList01 = new ArrayList<CSCROM01DSSDDO01VO>();
            roleListDto = ctRoleMapper.selectRoleList(inDto);

            if( roleListDto.size() > 0 ) {
                for( CtRoleDTO outDto : roleListDto ) {
                    CSCROM01DSSDDO01VO targetIO = new CSCROM01DSSDDO01VO();

                    targetIO.setRoleNo(outDto.getRoleNo());
                    targetIO.setRoleNm(outDto.getRoleNm());
                    targetIO.setRoleDesc(outDto.getRoleDesc());

                    /*************************************************
                     * ■ 역할정보조회 List 객체에 추가하도록 수행
                     *************************************************/
                    resultList01.add(targetIO);
                }
            }

            resultVo.setCSCROM01DSSDDO01VO(resultList01);

        }  catch (Exception e) {
            LOGGER.error("[역할정보조회오류] : 역할정보조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : getCCSROM01S02 : 역할번호에 대한 count를 조회 한다.</p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할번호에 대한 count를 조회 한다. </p>
     * <p>메소드인수    : CSCROM01InVO </p>
     * <p>메소드리턴값  : CSCROM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public int getCCSROM01S02(CSCROM01I01InVO inVo) throws Exception {

        /*************************************************
         * ■ 역할번호에 대한 count value
         *************************************************/
        int iVal = 0;

        /*************************************************
         * ■ 검색조건 체크
         *************************************************/
        String strRoleNo = inVo.getCSCROM01DSSDDO01VO().getRoleNo().toString();    // 역할번호

        /*************************************************
         * ■ 역할번호에 대한 count를 조회
         *************************************************/
        CtRoleDTO inDto = new CtRoleDTO();
        inDto.setRoleNo(strRoleNo);

        String strRtnVal = ctRoleMapper.selectRoleCount(inDto);

        /*************************************************
         * ■ 역할번호에 대한 count 결과값 return
         *************************************************/
        iVal = Integer.parseInt(strRtnVal);

        return iVal;
    }

    /**
     * <p>메소드명      : saveCCSROM01I01 : 역할관리 등록 </p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할관리를 등록 한다.</p>
     * <p>메소드인수    : CSCROM01InVO </p>
     * <p>메소드리턴값  : CSCROM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("static-access")
    public CSCROM01OutVO saveCCSROM01I01(CSCROM01I01InVO inVo) throws Exception {

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
        CSCROM01OutVO resultVo = new CSCROM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /*************************************************
         * ■ 등록조건 체크
         *************************************************/
        String strRoleNo   = inVo.getCSCROM01DSSDDO01VO().getRoleNo().toString();      // 역할번호
        String strRoleNm   = inVo.getCSCROM01DSSDDO01VO().getRoleNm().toString();      // 역할명
        String strRoleDesc = inVo.getCSCROM01DSSDDO01VO().getRoleDesc().toString();    // 설명

        if( StringUtils.isEmpty(strRoleNo) ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }
        if( StringUtils.isEmpty(strRoleNm) ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        try {
            /*************************************************
             * ■ 역할정보 등록
             *************************************************/
            CtRoleDTO inDto = new CtRoleDTO();

            inDto.setRoleNo(strRoleNo);
            inDto.setRoleNm(strRoleNm);
            inDto.setRoleDesc(strRoleDesc);

            ctRoleMapper.insertRole(inDto);

        }  catch (Exception e) {
            LOGGER.error("[역할정보등록오류] : 역할정보 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : updCCSROM01U01 : 역할관리 수정 </p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할관리를 수정 한다.</p>
     * <p>메소드인수    : CSCROM01InVO </p>
     * <p>메소드리턴값  : CSCROM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("static-access")
    public CSCROM01OutVO updCCSROM01U01(CSCROM01I01InVO inVo) throws Exception {

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
        CSCROM01OutVO resultVo = new CSCROM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /*************************************************
         * ■ 조건 체크
         *************************************************/
        String strRoleNo   = inVo.getCSCROM01DSSDDO01VO().getRoleNo().toString();      // 역할번호
        String strRoleNm   = inVo.getCSCROM01DSSDDO01VO().getRoleNm().toString();      // 역할명
        String strRoleDesc = inVo.getCSCROM01DSSDDO01VO().getRoleDesc().toString();    // 설명

        if( StringUtils.isEmpty(strRoleNm) ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        try {
            /*************************************************
             * ■ 역할정보 수정
             *************************************************/
            CtRoleDTO inDto = new CtRoleDTO();

            inDto.setRoleNo(strRoleNo);
            inDto.setRoleNm(strRoleNm);
            inDto.setRoleDesc(strRoleDesc);

            ctRoleMapper.updateRole(inDto);
        }  catch (Exception e) {
            LOGGER.error("[역할정보수정오류] : 역할정보 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : delCCSROM01D01 : 역할관리 삭제 </p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할관리를 삭제 한다.</p>
     * <p>메소드인수    : CSCROM01InVO </p>
     * <p>메소드리턴값  : CSCROM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("static-access")
    public CSCROM01OutVO delCCSROM01D01(CSCROM01I01InVO inVo) throws Exception {

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
        CSCROM01OutVO resultVo = new CSCROM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /*************************************************
         * ■ 조건 체크
         *************************************************/
        String strRoleNo   = inVo.getCSCROM01DSSDDO01VO().getRoleNo().toString();      // 역할번호

        if( StringUtils.isEmpty(strRoleNo) ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }

        try {
            /*************************************************
             * ■ 역할정보 삭제
             *************************************************/
            CtRoleDTO inDto = new CtRoleDTO();

            inDto.setRoleNo(strRoleNo);

            ctRoleMapper.deleteRole(inDto);
        }  catch (Exception e) {
            LOGGER.error("[역할정보삭제오류] : 역할정보 삭제 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }
}