package hanalife.c.sc.ro.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.ro.service.CCSROM01Service;
import hanalife.c.sc.ro.service.CSCROM02Service;
import hanalife.c.sc.ro.vo.CSCROM01DSSMVO;
import hanalife.c.sc.ro.vo.CSCROM01InVO;
import hanalife.c.sc.ro.vo.CSCROM01OutVO;
import hanalife.c.sc.ro.vo.CSCROM02DSSDCVO;
import hanalife.c.sc.ro.vo.CSCROM02DSSDDVO;
import hanalife.c.sc.ro.vo.CSCROM02DSSMVO;
import hanalife.c.sc.ro.vo.CSCROM02S01InVO;
import hanalife.c.sc.ro.vo.CSCROM02S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM02U01InVO;
import hanalife.c.sc.ro.vo.CSCROM02U01OutVO;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM02Controller.java Class
 *
 * 클래스설명   : 사용자역할관리 (CSCROM02) Controller
 * 작성일자     : 2023. 4. 19.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 19.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/sc/ro")
@Controller
public class CSCROM02Controller {

	@Resource(name = "CSCROM01Service")
	private CCSROM01Service CSCROM01;

	@Resource(name = "CSCROM02Service")
	private CSCROM02Service CSCROM02;

	private MsgEnum msgEnum;

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCROM02Controller.class);

	/**
	 * <p>메소드명      : 사용자역할관리 /CSCROM02S01.do </p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323
	 * <p>설명          : 사용자역할관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM02S01.do")
	public String CSCROM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM02Controller CSCROM02S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 사용자역할관리내역조회 업무 서비스 호출 입력값 대입 */
			CSCROM02S01InVO targetVo = new CSCROM02S01InVO();
			CSCROM02DSSMVO smVo = new CSCROM02DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setCSCROM02DSSMVO(smVo);

			/** 사용자역할관리내역조회 업무 서비스 호출 수행 */
			CSCROM02S01OutVO resultCSCROM02S01 = CSCROM02.getCSCROM02S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultCSCROM02S01.getCSCROM02DSSDVO(), model);		/** 사용자역할관리목록 */

			String rsltCd = resultCSCROM02S01.getRsltCd();	/** 결과코드 */
			//결과코드가 성공인 경우에만 역할목록 세팅
			if(msgEnum.SUCCESS.getErrorCd().equals(rsltCd)) {
				CSCROM01DSSMVO targetVo2 = new CSCROM01DSSMVO();
				CSCROM01InVO InVO = new CSCROM01InVO();

				//역할목록 검색용
				targetVo2.setRoleNo(""); 	/** 역할번호 */
				targetVo2.setRoleNm(""); 	/** 역할명 */
				targetVo2.setCond(""); 		/** 조회조건구분 */

				InVO.setCSCROM01DSSMVO(targetVo2);

				CSCROM01OutVO resultCSCROM01S01 = CSCROM01.getCCSROM01S01(InVO);

				XFrame5Util.setOutputData("DS_SD_R", resultCSCROM01S01.getCSCROM01DSSDDO01VO(), model);	/** 역할관리목록 */
			}

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM02S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM02S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### CSCROM02Controller CSCROM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM02Controller CSCROM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 사용자역할관리 입력, 수정, 삭제 /CSCROM02U01.do </p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323
	 * <p>설명          : 사용자역할관리 입력, 수정, 삭제 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM02U01.do")
	public String CSCROM02U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM02Controller CSCROM02U01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			//parameter로 활용할 dataset 정보를 가져온다.
			List<Map<String,Object>> insList = XFrame5Util.getDataMapList(reqMap, "DS_SD_C");
			List<Map<String,Object>> delList = XFrame5Util.getDataMapList(reqMap, "DS_SD_D");

			CSCROM02U01InVO targetVo = new CSCROM02U01InVO();

			CSCROM02DSSDCVO sdcVo = new CSCROM02DSSDCVO();
			CSCROM02DSSDDVO sddVo = new CSCROM02DSSDDVO();

			// 등록, 수정
			if(insList != null && !insList.isEmpty()) {

				for(int i=0; i < insList.size(); i++) {
					String operation = insList.get(i).get("operation").toString();				/** I:등록, U:수정, D:삭제 */

					sdcVo.setUserNo(insList.get(i).get("userNo").toString());					/** 사용자번호 */
					sdcVo.setRoleNo(insList.get(i).get("roleNo").toString());					/** 역할번호 */
					sdcVo.setLogInUserNo(insList.get(i).get("logInUserNo").toString());			/** 로그인사용자번호 */
					sdcVo.setLogInEmpNo(insList.get(i).get("logInEmpNo").toString());			/** 로그인사원번호 */

					targetVo.setCSCROM02DSSDCVO(sdcVo);

					// operation값에 따라 등록, 수정 분기
					if("I".equals(operation)) {
						CSCROM02U01OutVO resultCSCROM02I01 = CSCROM02.registerCSCROM02U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM02I01.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM02I01.getRsltCntn());	/** 결과메세지 */
					}else {
						CSCROM02U01OutVO resultCSCROM02U02 = CSCROM02.modifyCSCROM02U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM02U02.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM02U02.getRsltCntn());	/** 결과메세지 */
					}
				}

			}

			// 삭제
			if(delList != null && !delList.isEmpty()) {

				for(int i=0; i < delList.size(); i++) {
					String operationD = delList.get(i).get("operation").toString();			/** I:등록, U:수정, D:삭제 */

					sddVo.setUserNo(delList.get(i).get("userNo").toString());	/** 사용자번호 */
					sddVo.setRoleNo(delList.get(i).get("roleNo").toString());	/** 역할번호 */

					targetVo.setCSCROM02DSSDDVO(sddVo);

					if("D".equals(operationD)) {
						CSCROM02U01OutVO resultCSCROM02D01 = CSCROM02.deleteCSCROM02U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM02D01.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM02D01.getRsltCntn());	/** 결과메세지 */
					}
				}
			}

			LOGGER.info("##### CSCROM02Controller CSCROM02U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM02Controller CSCROM02U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
