package hanalife.framework.comm.exception.manager;

import java.util.Locale;

import javax.annotation.Resource;

import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.egovframe.rte.fdl.cmmn.exception.BaseException;
import org.egovframe.rte.fdl.cmmn.exception.FdlException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.MessageSource;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.dao.DataAccessException;
import org.springframework.util.AntPathMatcher;
import org.springframework.util.PathMatcher;

import hanalife.framework.comm.exception.HLFLException;

public class ExceptionTransfer {
	private final Logger logger = LoggerFactory.getLogger(ExceptionTransfer.class);

	@Resource(name="messageSource")
	private MessageSource messageSource;
	private ExceptionHandlerService[] exceptionHandlerServices;
	private PathMatcher pm;

	public ExceptionTransfer() {
		this.pm = new AntPathMatcher();
	}

	public void setExceptionHandlerService(ExceptionHandlerService[] exceptionHandlerServices) {
		this.exceptionHandlerServices = exceptionHandlerServices;
		if (this.exceptionHandlerServices != null) {
			logger.debug("count of ExceptionHandlerServices = {}", Integer.valueOf(exceptionHandlerServices.length));
		}
	}

	public int countOfTheExceptionHandlerService() {
		return this.exceptionHandlerServices != null ? this.exceptionHandlerServices.length : 0;
	}

	public void transfer(JoinPoint thisJoinPoint, Exception exception) throws Exception {
		logger.debug("execute ExceptionTransfer.transfer ");

		Class<?> clazz = thisJoinPoint.getTarget().getClass();
		Signature signature = thisJoinPoint.getSignature();

		Locale locale = LocaleContextHolder.getLocale();
		if ((exception instanceof RuntimeException))
		{
			logger.debug("RuntimeException case :: RuntimeException ");

			RuntimeException be = (RuntimeException)exception;
			getLog(clazz).error(be.getMessage(), be.getCause());


			processHandling(clazz, signature.getName(), exception, this.pm, this.exceptionHandlerServices);
			if ((be instanceof DataAccessException))
			{
				logger.debug("RuntimeException case :: DataAccessException ");
				DataAccessException sqlEx = (DataAccessException)be;
				throw sqlEx;
			}
			throw be;
		}

		if ((exception instanceof FdlException)) {
			logger.debug("FdlException case :: FdlException ");

			FdlException fe = (FdlException)exception;
			getLog(clazz).error(fe.getMessage(), fe.getCause());

			throw fe;
		} if ((exception instanceof HLFLException)) {
			logger.debug("HLFLException case :: HlflException ");
		}
		logger.debug("case :: Exception ");

		getLog(clazz).error(exception.getMessage(), exception.getCause());

		throw processException(clazz, "fail.common.msg", new String[0], exception, locale);
	}

	protected Exception processException(Class<?> clazz, String msgKey, String[] msgArgs, Exception e, Locale locale) {
		return processException(clazz, msgKey, msgArgs, e, locale, null);
	}

	protected Exception processException(Class<?> clazz, final String msgKey, final String[] msgArgs, final Exception e, final Locale locale, ExceptionCreator exceptionCreator) {
		getLog(clazz).error(this.messageSource.getMessage(msgKey, msgArgs, locale), e);
		ExceptionCreator eC = null;

		if (exceptionCreator == null) {
			eC = new ExceptionCreator() {
				@Override
				public Exception processException(MessageSource messageSource) {
					return new BaseException(messageSource, msgKey, msgArgs, locale, e);
				}
			};
		}

		return eC.processException(this.messageSource);
	}

	protected Logger getLog(Class<?> clazz) {
		return LoggerFactory.getLogger(clazz);
	}

	protected void processHandling(Class<?> clazz, String methodName, Exception exception, PathMatcher pm, ExceptionHandlerService[] exceptionHandlerServices) throws Exception {
		try{
			for(ExceptionHandlerService ehm : exceptionHandlerServices){
				if(!ehm.hasReqExpMatcher()){
					ehm.setReqExpMatcher(pm);
				}

				ehm.setPackageName(clazz.getCanonicalName() + "." + methodName);
				ehm.run(exception);
			}
		}catch (Exception e) { throw e;}

	}

	protected static abstract interface ExceptionCreator {
		public abstract Exception processException(MessageSource paramMessageSource);
	}

}
