package hanalife.framework.comm.exception.resolver;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.MessageSource;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.SimpleMappingExceptionResolver;

import hanalife.framework.comm.contants.Constants;
import hanalife.framework.comm.exception.HLFLException;

public class CustomSimpleMappingExceptionResolver extends SimpleMappingExceptionResolver {
	private static Logger logger = LoggerFactory.getLogger(CustomSimpleMappingExceptionResolver.class);

	@Autowired
	private MessageSource messageSource;

	@Override
	protected ModelAndView doResolveException(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) {


		String viewName = determineViewName(ex, request);
		String ajaxHeader = request.getHeader("X-Requested-With");
		boolean isAjax = "XMLHttpRequest".equals(ajaxHeader);

		String view = "common/error/error";
		String errorCode = "";
		String errorMessage = "시스템 에러";

		//비동기 통신일 경우
		if(isAjax) {
			response.setCharacterEncoding("UTF-8");
			response.setContentType("text/json");

			view = Constants.JSON_VIEW;
		}

		if( ex instanceof HLFLException ){
			HLFLException hlflException = (HLFLException) ex;
			errorMessage = getExceptionSendMessage(hlflException);
		}

		Map<String, Object> retMap = new HashMap<String, Object>();
		retMap.put("rsMsg", errorMessage);
		// JSON 에러일 경우
		Integer statusCode = determineStatusCode(request, viewName);
        if (statusCode != null) {
            applyStatusCodeIfPossible(request, response, statusCode);
        }

		logger.error(errorMessage, ex);
		return getModelAndView(view, null, request).addAllObjects(retMap);
        //getModelAndView(view, null, request) null 로 해야 클라이언트 단에 stack trace 같은 서버 에러정보가 안넘어간다.
		//client (browser) 에는 errorCode, errorMessage 만 넘어가는 것이 맞다.
	}

	private String getExceptionSendMessage(HLFLException exception) {
		String exceptionMessage = getLocalizedMessage(exception);
		return exceptionMessage;
	}

	private String getLocalizedMessage(HLFLException exception) {
		String message = this.messageSource.getMessage(exception.getMessage(), exception.getParams() , exception.getMessage(), LocaleContextHolder.getLocale());
		return message;
	}

}
