package hanalife.framework.comm.filter;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import hanalife.framework.comm.util.CommUtil;

public class RequestBodyXSSFilter implements Filter {

	private static final Logger LOGGER = LoggerFactory.getLogger(RequestBodyXSSFilter.class);
	
	private List<String> extUrl;

	@Override
	public void doFilter(ServletRequest req, ServletResponse res, FilterChain chain) throws IOException, ServletException {

		HttpServletRequest request = (HttpServletRequest) req;
		HttpServletResponse response = (HttpServletResponse) res;
		
		String contentType = request.getContentType();
		LOGGER.debug("RequestBodyXSSFilter.doFilter - contentType="+contentType);
		if (contentType == null || contentType.indexOf("json") == -1) {
			LOGGER.debug("RequestBodyXSSFilter.doFilter - form");
			chain.doFilter(request, response);
			
		} else {
			LOGGER.debug("RequestBodyXSSFilter.doFilter - json");
		
			RequestWrapper reqWrapper = null;
			String path = ((HttpServletRequest) req).getServletPath();
	
			try {
				if (!extUrl.contains(path)) {
					reqWrapper = new RequestWrapper(request);
					chain.doFilter(reqWrapper, response);
				} else {
					chain.doFilter(request, response);
				}
	
			} catch (Exception e) {
				LOGGER.error("[!] "+e.getMessage());
				LOGGER.error(CommUtil.printStackTraceForLog4j(e));
			}
		}
	}

	@Override
	public void init(FilterConfig filterConfig) throws ServletException {
		String excludePattern = filterConfig.getInitParameter("extUrls");
		extUrl = Arrays.asList(excludePattern.split(","));
	}

	@Override
	public void destroy() {
	}
}
