package hanalife.framework.comm.filter;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import javax.servlet.ReadListener;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletRequestWrapper;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.nhncorp.lucy.security.xss.LucyXssFilter;
import com.nhncorp.lucy.security.xss.XssSaxFilter;

import hanalife.framework.comm.util.CommUtil;

public class RequestWrapper extends HttpServletRequestWrapper {
	
	private static final Logger LOGGER = LoggerFactory.getLogger(RequestWrapper.class);
	
	private byte[] byteString;

	public RequestWrapper(HttpServletRequest request) throws IOException {
		super(request);
		LucyXssFilter filter = XssSaxFilter.getInstance("lucy-xss-sax.xml");

		String originalBody = getBody(request);
		String filteredBody = filter.doFilter(originalBody);
		LOGGER.debug("LucyXssFilter.doFilter - filtered body="+filteredBody);
		if (originalBody==null) {
		} else if (originalBody.equals(filteredBody)) {
			LOGGER.debug("[o] originalBody==filteredBody");
		} else {
			LOGGER.debug("[x] originalBody!=filteredBody");
		}

		byteString = new String(filteredBody).getBytes("UTF-8");
	}

	@Override
	public ServletInputStream getInputStream() throws IOException {
		final ByteArrayInputStream bis = new ByteArrayInputStream(byteString);
		return new ServletInputStreamImpl(bis);
	}

	class ServletInputStreamImpl extends ServletInputStream {
		private InputStream is;

		public ServletInputStreamImpl(InputStream bis) {
			is = bis;
		}

		@Override
		public int read() throws IOException {
			return is.read();
		}

		@Override
		public int read(byte[] b) throws IOException {
			return is.read(b);
		}

		@Override
		public boolean isFinished() {
			return false;
		}

		@Override
		public boolean isReady() {
			return false;
		}

		@Override
		public void setReadListener(ReadListener readListener) {
		}
	}

	public static String getBody(HttpServletRequest request) throws IOException {
		
		String body = null;
		BufferedReader br = null;
		StringBuilder sb = new StringBuilder();
		try {
			//방법1
			{
				InputStream inputStream = request.getInputStream();
				LOGGER.debug("inputStream is "+(inputStream==null?"null":"not null"));
				if (inputStream != null) {
					br = new BufferedReader(new InputStreamReader(inputStream, "UTF-8"));
					char[] charBuffer = new char[128];
					int bytesRead = -1;
					while ((bytesRead = br.read(charBuffer)) > 0) {
						sb.append(charBuffer, 0, bytesRead);
						//LOGGER.debug("\r\n[!!] charBuffer="+new String(charBuffer, 0, bytesRead));
					}

				} else {
					sb.append("");
				}
			}
			
			//방법2
//			{
//				byte[] rawData = new byte[128];
//				InputStream inputStream = request.getInputStream();
//				rawData = org.apache.commons.io.IOUtils.toByteArray(inputStream);
//				sb.append(new String(rawData));
//			}
			
			LOGGER.debug("while ... finished");
			
		} catch (IOException ex) {
			LOGGER.error("[!] "+ex.getMessage());
			LOGGER.error(CommUtil.printStackTraceForLog4j(ex));
			throw ex;
		} finally {
			if (br != null) {
				try {
					br.close();
				} catch (IOException ex) {
					throw ex;
				}
			}
		}
		body = sb.toString();
		LOGGER.debug("RequestWrapper.getBody - original body="+body);
		
		return body;
	}
}