package hanalife.framework.comm.interceptor;

import java.util.Iterator;
import java.util.Set;
import java.util.regex.Pattern;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.servlet.HandlerInterceptor;

import hanalife.framework.comm.exception.HLFLException;
import hanalife.framework.comm.util.SessionUtil;
import hanalife.framework.comm.vo.UserSessionVO;

public class AuthenticationInterceptor implements HandlerInterceptor {

	private static final Logger LOGGER = LoggerFactory.getLogger(AuthenticationInterceptor.class);
	

	private String loginPage = ""; //로그인 페이지

	public String getLoginPage() {
		return loginPage;
	}
	public void setLoginPage(String loginPage) {
		this.loginPage = loginPage;
	}

	private Set<String> permittedURL;

	public void setPermittedURL(Set<String> permittedURL) {
		this.permittedURL = permittedURL;
	}

	/**
	 * 세션정보 체크하여 인증여부 판단.
	 * 인증되지 않은 세션이라면 로그인 페이지로 이동
	 */
	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler)
			throws Exception {

		// String serverMode = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
		// if("LOCAL".equals(serverMode)) { return true; }

		String requestURI = request.getRequestURI();
		
		boolean isPermittedURL = false;
		UserSessionVO usersession = null;

		try {
			HttpSession session = request.getSession();
			usersession = (UserSessionVO)session.getAttribute("UserSessionVO");
		} catch (HLFLException e)	{
			usersession = null;
		}

		for(Iterator<String> it = permittedURL.iterator(); it.hasNext();) {
			String urlPattern = request.getContextPath() + it.next();
			if(Pattern.matches(requestURI, urlPattern)) {
				isPermittedURL = true;
				break;
			}else {
				if(requestURI.startsWith(urlPattern)) {
					isPermittedURL = true;
					break;
				}
			}
		}
		
		LOGGER.info(">> requestURI: " + requestURI);
		// 허가 구분자가 없고 리스트에 작성되지 않은 url이면
		// permit URL은 해당 이름으로 값들을 가져와서 set해주는 것 뿐이라 /.**같은 경로설정은 안될 것 같음
		
		if(!requestURI.contains("permittedURI") && !isPermittedURL) {
			//TODO 정해지면 수정
			if(usersession == null) {
				LOGGER.info("=-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-=");
				LOGGER.info(">> AuthenticationInterceptor loginPage = " + loginPage);
				LOGGER.info(">> AuthenticationInterceptor Start!");
				LOGGER.info(">> requestURI: " + requestURI);
				LOGGER.info(">> isPermittedURL: ");
				LOGGER.info(">> 인증이 필요한 URL이므로 로그인 페이지로 리다이렉트!");
				LOGGER.info("http://localhost:8080" + loginPage);
				LOGGER.info("=-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-==-=-=-=-=-=-=-=-=-=-=");
				response.sendRedirect(loginPage);	//PC 로그인 화면
				return false;
			}else {
				return true;
			}
			

		}else {
			LOGGER.info(">> 인증이 필요없는 URL!");
			return true;
		}

	}

}
