package hanalife.framework.comm.util;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.servlet.support.RequestContextUtils;

import hanalife.c.co.util.StringUtil;

/**
 * {tags}
 * 개발자 : <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
 * 생성일자 : 2020. 7. 14.
*/

public class BeanUtil {
	
	private static final Logger loger = LoggerFactory.getLogger("Util");

	public static Object getBean(String beanName){
		WebApplicationContext webApplicationContext;

		ServletRequestAttributes servletRequestAttribute = (ServletRequestAttributes)RequestContextHolder.currentRequestAttributes();
		HttpServletRequest request = servletRequestAttribute.getRequest();

		// DispatcherServlet으로 로딩된 context를 가져 온다.
		//webApplicationContext = RequestContextUtils.getWebApplicationContext((ServletRequest) request);
		// 2020.05.12 사용하지 않는 메서드라 대체
		webApplicationContext = RequestContextUtils.findWebApplicationContext(request);


		return webApplicationContext.getBean(beanName);
	}
	
	/**
	 * VO 을 Map 로 변환하기
	 * @param bean Map으로 변환하고자 하는 VO
	 * @return String
	 */
	public static Map<String, String> beanToMap(Object bean){
		Map<String, String> map = null;
		try {
			map = BeanUtils.describe(bean);
		} catch (IllegalAccessException | InvocationTargetException | NoSuchMethodException e) {
			e.printStackTrace();
		}
		return map;
	}

	/**
	 * List<VO>를 List<Map> 으로 변환
	 * @param bean Map으로 변환하고자 하는 VO
	 * @return String
	 */
	public static List<Map<String, String>> listVoToListMap(List<?> list, Object vo){
		List<Map<String, String>> returnList = new  ArrayList<Map<String, String>>();
		for(int i=0; i< list.size();i++) {
			Map<String, String> map = beanToMap(list.get(i));
			returnList.add(map);
		}
		return returnList;
	}
	
	/**
	 * Map 을 Vo 로 변환하기
	 * @param map 원본 Map 
	 * bean 변환하고자 하는 VO
	 * @return String
	 */
	public static Object mapToBean(Map<String, Object> map, Object bean){
			Class cls = bean.getClass();
		
			//System.out.println( "map.size() : "+map.size());
			for( Map.Entry<String, Object> entrySet : map.entrySet() ) {
				
//				System.out.println(   " entrySet : "+entrySet.getKey() );
//				System.out.println(   " entrySet.getValue() : "+entrySet.getValue());
				
	 			for(Field field:cls.getDeclaredFields()) {
	 				
	 				field.setAccessible(true);
	 				String fldName = StringUtil.NVL(field.getName());
	 				
	 				if( fldName.equals( (entrySet.getKey()) )  ) {
	 					
	 					//boolean typeGbn =  entrySet.getValue().getClass().equals(field.getType());
		 				boolean nameGbn =  entrySet.getKey().equals(fldName);
		 				
		 				//loger.debug("#########################################################");
		 				//loger.debug(fldName);
		 				//loger.debug(field.getType().getTypeName() );
		 				//loger.debug(entrySet.getValue().getClass().getTypeName() );
		 				//loger.debug("#########################################################");
		 				
		 				//if(typeGbn && nameGbn) {
		 				if(nameGbn) {
							Method[] mt = bean.getClass().getDeclaredMethods();
							for(int i=0; i < mt.length ;i++) {
								String methodNm = "set"+ StringUtils.capitalize(fldName);
								try {
										
										String valDataType = entrySet.getValue().getClass().getTypeName();
										
										//loger.debug("########################"+valDataType+"################################");
										
										// 숫자의 경유 dataType 이 BigDecimal로 넘어오기 때문에 자료형에 맞게 캐스팅 해준다.
										if( mt[i].getName().equals(methodNm) && valDataType.equals("java.math.BigDecimal") ) {
											//loger.debug("### valDataType.equals(\"java.math.BigDecimal\")");
							 				if(field.getType() !=null && (field.getType().getTypeName()).equals("long")) {
							 					mt[i].invoke(bean , ((BigDecimal)entrySet.getValue()).longValue());
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("double")) {
							 					mt[i].invoke(bean , ((BigDecimal)entrySet.getValue()).doubleValue());
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("float")) {
							 					mt[i].invoke(bean , ((BigDecimal)entrySet.getValue()).floatValue());
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("int")) {
							 					mt[i].invoke(bean , ((BigDecimal)entrySet.getValue()).intValue());
												break;
							 				}else{
							 					mt[i].invoke(bean , entrySet.getValue());
												break;
							 				}
										}else if( mt[i].getName().equals(methodNm) && valDataType.equals("java.lang.String") ) {
											//loger.debug("### valDataType.equals(\"java.lang.String\") ) {");
							 				if(field.getType() !=null && (field.getType().getTypeName()).equals("long")) {
							 					mt[i].invoke(bean , Long.parseLong((String) entrySet.getValue()) );
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("double")) {
							 					mt[i].invoke(bean ,  Double.parseDouble((String) entrySet.getValue()) );
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("float")) {
							 					mt[i].invoke(bean ,  Float.parseFloat((String) entrySet.getValue()) );
												break;
							 				}else if( field.getType() !=null && (field.getType().getTypeName()).equals("int")) {
							 					mt[i].invoke(bean ,  Integer.parseInt((String) entrySet.getValue()) );
												break;
							 				}else{
							 					mt[i].invoke(bean , entrySet.getValue());
												break;
							 				}
										}else if( mt[i].getName().equals(methodNm)){
											//loger.debug("###$$$$$ ");
						 					mt[i].invoke(bean , entrySet.getValue());
											break;
										}
						 				
								} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
									// TODO Auto-generated catch block
									e.printStackTrace();
								}
							}
						}
	 				}
				}
 			}
		return bean;
	}
	
	private static void putValues(Object bean, Map<String, Object> map) {
		Class<?> cls = bean.getClass();
		
		//System.out.println("VO NAME : "+cls.getName());
		
		for(Field field:cls.getDeclaredFields()) {
			field.setAccessible(true);
			
			Object value = null;
			String key ; 
			
			try {
				value = field.get(bean);
			} catch (IllegalArgumentException | IllegalAccessException e) {
				loger.debug(e.getMessage());
			}
			
			//key = field.toGenericString();
			key = field.getName();
			
//			System.out.println("###################################@@@@@@@@@@@@@@@@@@@@@@@@@");
//			System.out.println("key >>>> "+key);
//			System.out.println("value >>>> "+value);
//			System.out.println("###################################@@@@@@@@@@@@@@@@@@@@@@@@@");
			map.put(key, value);
		}
		
	}
	private static final Set<Class<?>> valueClasses 
	 = (Collections.unmodifiableSet(new HashSet<>(Arrays.asList(Object.class , String.class , Boolean.class , Character.class, Byte.class, Short.class, Integer.class, Long.class, Double.class ))));
	
	private static boolean isValue(Object value) {
		return value  == null || valueClasses.contains(value.getClass());
	}

}
