package hanalife.framework.comm.util;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import hanalife.c.co.util.StringUtil;
import hanalife.framework.comm.contants.Constants;
import hanalife.framework.comm.exception.factory.HLFLExceptionFactory;

/**
 *
 * SFTP Util
 *
 * @author 70114
 * @since
 * @version 1.0
 */
public class SFTPUtil {

	private static final Logger LOGGER = LoggerFactory.getLogger(SFTPUtil.class);


	/**
	 * SFtp를 통해 파일 전송
	 * @description :
	 * @param localFilePath 원본파일경로
	 * @param remotePath 전송할 원격경로
	 */
	public static void putSftp(String localFilePath, String remotePath){
		//TODO 정해지면 수정
		final String[] ftpHosts = PropertiesHandler.getInstance().getArrayProperty("server.sfa.sFTP.IP");
		final int port = Integer.parseInt(PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Port"));
		final String userName = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.ID");
		final String password = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Passwd");


		final String server = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");

		if(StringUtil.equals(server, Constants.PROD)) {
			InetAddress local = null;
			try {
				local = InetAddress.getLocalHost();
			} catch (UnknownHostException e) {
				//e.printStackTrace();
				throw HLFLExceptionFactory.create("fail.common.msg");
			}
			String hostIp = local.getHostAddress();
			LOGGER.debug("hostIp :" + hostIp );
			for(String ftpHost : ftpHosts) {
				if(StringUtil.equals(ftpHost, hostIp) == false) {
					putSftp(localFilePath, remotePath, ftpHost, port, userName, password);
				}
			}
		}else if(StringUtil.equals(server, Constants.UAT)) { //FIXME test
			//putSftp(localFilePath, remotePath+"test/", ftpHosts[0], port, userName, password);
		}
	}

	/**
	 * SFtp를 통해 파일 전송
	 * @description : 접속정보 입력용
	 * @param localFilePath 원본파일경로
	 * @param remotePath 전송할 원격경로
	 * @param host
	 * @param port
	 * @param userName
	 * @param password
	 */
	public static void putSftp(String localFilePath, String remotePath, String host, int port, String userName, String password) {
		SFTPClient sFTPClient = new SFTPClient();
		sFTPClient.putSftp(localFilePath, remotePath, host, port, userName, password);
	}

	/**
	 * SFtp를 통해 원격지 파일 삭제
	 * @description : server.sfa.sFTP.IP 접근용
	 * @param remoteFilePath 삭제할 원격파일경로
	 */
	public static void removeSftp(String remoteFilePath) {
		//TODO 정해지면 수정
		final String[] ftpHosts = PropertiesHandler.getInstance().getArrayProperty("server.sfa.sFTP.IP");
		final int port = Integer.parseInt(PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Port"));
		final String userName = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.ID");
		final String password = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Passwd");

		final String server = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");

		if(StringUtil.equals(server, Constants.PROD)) {
			InetAddress local = null;
			try {
				local = InetAddress.getLocalHost();
			} catch (UnknownHostException e) {
				//e.printStackTrace();
				throw HLFLExceptionFactory.create("fail.common.msg");
			}
			String hostIp = local.getHostAddress();
			LOGGER.debug("hostIp :" + hostIp );
			for(String ftpHost : ftpHosts) {
				if(StringUtil.equals(ftpHost, hostIp) == false) {
					removeSftp(remoteFilePath, ftpHost, port, userName, password);
				}
			}
		}else if(StringUtil.equals(server, Constants.UAT)) { //FIXME test
			LOGGER.debug("remoteFilePath : " + remoteFilePath);
			String remotepPath = remoteFilePath.substring(0, remoteFilePath.lastIndexOf('/')+1);
			String filename = remoteFilePath.substring(remoteFilePath.lastIndexOf('/')+1);
			LOGGER.debug("remotepPath : " + remotepPath);
			LOGGER.debug("filename : " + filename);
			removeSftp(remotepPath + "test/"+ filename ,ftpHosts[0], port, userName, password);

		}
	}

	/**
	 * SFtp를 통해 원격지 파일 삭제
	 * @description : 접속정보 입력용
	 * @param remoteFilePath 삭제할 원격파일경로
	 * @param host
	 * @param port
	 * @param userName
	 * @param password
	 */
	public static void removeSftp(String remoteFilePath, String host, int port, String userName, String password) {
		SFTPClient sFTPClient = new SFTPClient();
		sFTPClient.removeSftp(remoteFilePath, host, port, userName, password);
	}


	public static void putSftpTest(String localFilePath, String remotePath){
		//TODO 정해지면 수정
		final String[] ftpHosts = PropertiesHandler.getInstance().getArrayProperty("server.sfa.sFTP.IP");
		final int port = Integer.parseInt(PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Port"));
		final String userName = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.ID");
		final String password = PropertiesHandler.getInstance().getProperty("server.sfa.sFTP.Passwd");


		final String server = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");

		if(StringUtil.equals(server, Constants.UAT)) { //FIXME test
			putSftp(localFilePath, remotePath+"test/", ftpHosts[0], port, userName, password);
		}
	}
}
