package hanalife.framework.comm.web;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import hanalife.framework.comm.contants.Constants;
/**
 *
 * 파일 설명
 * BaseController :: 모든 컨트롤러의 부모객체
 * <pre>
 * 컨트롤러에서 공통으로 사용할 클래스
 * </pre>
 *
 * @author 70121
 * @since  2022.07.08
 * @version 1.0
 */
public class BaseController {

	private static final Logger LOGGER = LoggerFactory.getLogger(BaseController.class);

	/**
	 * 로그인 페이지 호출용
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getLoginViewName(String viewName) {
		return this.getViewName(viewName, "login");
	}

	/**
	 * 화면 페이지 호출
	 * html 내 body #container 구현페이지 호출
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getPageViewName(String viewName) {
		return this.getViewName(viewName, "page");
	}

	/**
	 * iframe 페이지 호출용 (TOP / FOOTER 존재하지 않음)
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getIframeViewName(String viewName) {
		return this.getViewName(viewName, "iframe");
	}

	/**
	 * 모바일 Landing 페이지 호출용
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getLandingViewName(String viewName) {
		return this.getViewName(viewName, "landing");
	}

	/**
	 * 모바일 스마트청약 페이지 호출용
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getSmartViewName(String viewName) {
		return this.getViewName(viewName, "smart");
	}

	/**
	 * jsonView, excelView 호출 시 사용
	 * 허나, 두개의 내용은 각 컨트롤러에서 직접 호출하여도 됨.(Constants.JSON_VIEW, Constants.EXCEL_VIEW)
	 * @description :
	 * @param viewName
	 * @return
	 */
	public String getOtherViewName(String viewName) {
		return this.getViewName(viewName, "");
	}

	/**
	 * 타일즈에 선언한 패턴 핸들링하기 위한 메소드
	 * tiles.xml에 선언된 패턴 종류
	 * 확장자 없음 : login view
	 * .pgv : page view
	 * .ifv : iframe view
	 *
	 * jsonview, excelview에 관련한 내용도 선언해두었지만, 두개의 내용은 각 컨트롤러에서 직접 호출하여도 됨.
	 * @description :
	 * @param viewName
	 * @param viewType
	 * @return
	 */
	public String getViewName(String viewName, String viewType) {
		//TODO 정해지면 수정
		String rtnViewName = viewName;

		LOGGER.debug("getViewName[viewName:"+viewName+"][viewType:"+viewType+"]");

		if (Constants.EXCEL_VIEW.equals(rtnViewName) || Constants.JSON_VIEW.equals(rtnViewName)) {
			return rtnViewName;
		} else {
			if (rtnViewName.indexOf(Constants.MO_VIEW) >= 0) {	//MOBILE
				if ("landing".equals(viewType)) {
					rtnViewName = rtnViewName + ".ldv";
				} else if ("page".equals(viewType)) {
					rtnViewName = rtnViewName + ".pgv";
				} else if ("smart".equals(viewType)) {
					rtnViewName = rtnViewName + ".ssv";
				} else if ("iframe".equals(viewType)){
					rtnViewName = rtnViewName + ".ifv";
				} else if ("login".equals(viewType)){
					rtnViewName = rtnViewName + ".lgv";
				}
			}
		}
		LOGGER.debug("getViewName[rtnViewName:"+rtnViewName+"]");

		return rtnViewName;
	}
}