package hanalife.r.at.ad.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.DbsBatchException;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.ad.mapper.AutoTranAdMapper;
import hanalife.r.at.ad.mapper.dto.SearchAttrPlanInDTO;
import hanalife.r.at.ad.mapper.dto.SearchAttrPlanOutDTO;
import hanalife.r.at.ad.mapper.dto.SearchJobPlanInDTO;
import hanalife.r.at.ad.mapper.dto.SearchJobPlanOutDTO;
import hanalife.r.at.ad.service.AutoTranAdService;
import hanalife.r.at.vo.bat.AttrJobVO;
import hanalife.r.at.vo.bat.AttrPlanVO;
import hanalife.util.BizException;
import hanalife.util.PagedArrayList;

@Service("AutoTranAdService")
public class AutoTranAdServiceImpl implements AutoTranAdService {

	private static final Logger LOGGER = LoggerFactory.getLogger(AutoTranAdServiceImpl.class);

	@Autowired
	private AutoTranAdMapper autoTranAdMapper;

	/**
	 * 마감일에 자동이체 마감계획이 존재하는지 체크
	 * @param clsDt
	 * @param con
	 * @return
	 * @throws Exception
	 */
	@Override
	public boolean searchAutoTranPlan(String clsDt) throws Exception {
		boolean bRtn = false;

		try {
			SearchAttrPlanInDTO inDTO = new SearchAttrPlanInDTO();

			inDTO.setClsDt(clsDt);

			int iCnt = autoTranAdMapper.searchAutoTranPlan(inDTO);

			if(iCnt > 0) {
				bRtn = true;
			}

		} catch (Exception se) {
			throw new BizException("마감일에 자동이체 마감계획 조회 오류", se);
		}


		return bRtn;
	}

	/**
	 * 자동이체 JobPlan정보 조회
	 * @param AttrJobVO
	 * @param Connection
	 * @return PagedArrayList (AttrJobVO)
	 * @throws Exception
	 */
	@Override
	public AttrJobVO searchJobPlan(AttrJobVO param) throws Exception {
		PagedArrayList list = searchJobPlanList(param);
		if (list.size() == 0) {
			throw new DbsBatchException("　☞ [RT_JOB_PLAN_BASE] 청구작업계획 데이터가 존재하지 않습니다.(RGNDL0101 선행필요)");
		}
		if (list.size() >1) {
			throw new DbsBatchException("　☞ [RT_JOB_PLAN_BASE] 청구작업계획 데이터가 비정상임.(RGNDL0101 선행배치 확인)");
		}
		return (AttrJobVO)list.get(0);
	}


	private PagedArrayList searchJobPlanList(AttrJobVO param) throws Exception {
		PagedArrayList outList = new PagedArrayList();

		try {
			SearchJobPlanInDTO inDTO = new SearchJobPlanInDTO();
			inDTO.setJobDt(param.jobDt);
			inDTO.setJobId(param.jobId);
			inDTO.setSnum(param.snum);

			List<SearchJobPlanOutDTO> outDTO = autoTranAdMapper.searchJobPlanList(inDTO);

			for (SearchJobPlanOutDTO sourceIO : outDTO) {
				AttrJobVO vo = new AttrJobVO();

				vo.jobDt = sourceIO.getJobDt();
				vo.jobId = sourceIO.getJobId();
				vo.snum = sourceIO.getSnum();
				vo.jobStatCd = sourceIO.getJobStatCd();
				vo.strtLoanNo = sourceIO.getStrtLoanNo();
				vo.endLoanNo = sourceIO.getEndLoanNo();
				vo.jobLoanNo = sourceIO.getJobLoanNo();
				vo.isrtDeptCd = sourceIO.getIsrtDeptCd();
				vo.isrtEmpNo = sourceIO.getIsrtEmpNo();
				vo.fetchCnt = sourceIO.getFetchCnt();
				vo.procDt = sourceIO.getProcDt();
				vo.procTm = sourceIO.getProcTm();

				outList.add(vo);
			}

		} catch (Exception e) {
			throw new BizException("자동이체 JobPlan정보 조회실패");
		}

		return outList;

	}

	/**
	 * 자동이체 계획정보 조회
	 * @param AttrPlanVO
	 * @param Connection
	 * @return PagedArrayList (AttrPlanVO)
	 * @throws Exception
	 */
	@Override
	public AttrPlanVO searchAttrPlan(AttrPlanVO param) throws Exception {
		PagedArrayList list = searchAttrPlanList(param);
		if (list.size()==0) {
			throw new Exception("AutoTranDAOImpl.searchAttrPlan　☞ 자동이체 계획정보가 없습니다.");
		}
		if (list.size() >1) {
			throw new Exception("AutoTranDAOImpl.searchAttrPlan　☞ 자동이체 계획정보가 1건이 아닙니다.");
		}
		return (AttrPlanVO)list.get(0);
	}

	private PagedArrayList searchAttrPlanList(AttrPlanVO param) throws Exception {
		PagedArrayList outList = new PagedArrayList();

		try {
			SearchAttrPlanInDTO inDTO = new SearchAttrPlanInDTO();

			inDTO.setRlDueDt(param.rlDueDt);
			inDTO.setTrOrgCd(param.trOrgCd);
			inDTO.setClsDt(param.clsDt);
			inDTO.setTrsmDt(param.trsmDt);
			inDTO.setAcctDt(param.acctDt);
			inDTO.setCyclCd(param.cyclCd);
			inDTO.setPrgmId(param.prgmId);
			inDTO.setClas1(param.clas1);
			inDTO.setClas2(param.clas2);

			List<SearchAttrPlanOutDTO> outDTO = autoTranAdMapper.searchAttrPlanList(inDTO);

			for (SearchAttrPlanOutDTO sourceIO : outDTO) {
				AttrPlanVO vo = new AttrPlanVO();

				vo.trOrgCd = sourceIO.getTrOrgCd();
				vo.trOrgNm = sourceIO.getTrOrgNm();
				vo.acctUnitCd = sourceIO.getAcctUnitCd();
				vo.rcptTpCd = sourceIO.getRcptTpCd();
				vo.cyclCd = sourceIO.getCyclCd();
				vo.vndrCd = sourceIO.getVndrCd();
				vo.moBankCd = sourceIO.getMoBankCd();
				vo.moAcntNo = sourceIO.getMoAcntNo();
				vo.rlDueDt = sourceIO.getRlDueDt();
				vo.clsDt = sourceIO.getClsDt();
				vo.trsmDt = sourceIO.getTrsmDt();
				vo.recvDt = sourceIO.getRecvDt();
				vo.acctDt = sourceIO.getAcctDt();
				vo.askStatCd = sourceIO.getAskStatCd();
				vo.askStatNm = sourceIO.getAskStatNm();
				vo.procStatCd = sourceIO.getProcStatCd();
				vo.procStatNm = sourceIO.getProcStatNm();
				vo.askCnt = sourceIO.getAskCnt();
				vo.askAmt = sourceIO.getAskAmt();
				vo.intgAskCnt = sourceIO.getIntgAskCnt();
				vo.intgAskAmt = sourceIO.getIntgAskAmt();
				vo.setlCnt = sourceIO.getSetlCnt();
				vo.setlAmt = sourceIO.getSetlAmt();
				vo.feeAcctDt = sourceIO.getFeeAcctDt();
				vo.feeTranNo = sourceIO.getFeeTranNo();
				vo.attrFeeAmt = sourceIO.getAttrFeeAmt();
				vo.filePath = sourceIO.getFilePath();
				vo.fileNm = sourceIO.getFileNm();
				vo.rlFileNm = sourceIO.getRlFileNm();
				vo.clas1 = sourceIO.getClas1();
				vo.clas2 = sourceIO.getClas2();

				vo.iamtSeq    = StringUtil.in(vo.clas2, new String[]{"A13","B04","B14","B44"})?"4":"1";
				vo.prgmId     = param.prgmId;

				outList.add(vo);
			}

		} catch (Exception e) {
			throw new BizException("자동이체 계획정보 조회실패");
		}

		return outList;
	}
}
