package hanalife.r.at.ad.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.DbsBatchSkipException;
import hanalife.c.co.mapper.dto.RtAutoTranTrDescDTO;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.ad.bat.CmsCode;
import hanalife.r.at.ad.cms.AutoTranCmsProcVO;
import hanalife.r.at.ad.cms.AutoTranPlanOrg;
import hanalife.r.at.ad.cms.AutoTranRecvDesc;
import hanalife.r.at.ad.cms.AutoTranTrDesc;
import hanalife.r.at.ad.mapper.AutoTranCmsMapper;
import hanalife.r.at.ad.mapper.dto.AutoTranCmsProcDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranPlanOrgDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranRecvDescDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranTrDescDTO;
import hanalife.r.at.ad.mapper.dto.SearchAttrPlanStatOutDTO;
import hanalife.r.at.ad.service.AutoTranCmsService;
import hanalife.r.at.vo.bat.AttrOrgVO;
import hanalife.r.co.vo.vo.ClsTrDescVO;
import hanalife.util.BizException;

@Service("AutoTranCmsService")
public class AutoTranCmsServiceImpl implements AutoTranCmsService{

	private static final Logger log = LoggerFactory.getLogger(AutoTranCmsServiceImpl.class);

	@Autowired
	private AutoTranCmsMapper autoTranCmsMapper;

	@Override
	public AutoTranPlanOrg searchAutoTranPlanOrgDesc(AutoTranPlanOrg searchAutoTranPlanOrg) {
		log.info("searchAutoTranPlanOrgDesc start");
		// DTO 세팅
		AutoTranPlanOrgDTO inDTO  = new AutoTranPlanOrgDTO();
		AutoTranPlanOrgDTO outDTO = new AutoTranPlanOrgDTO();
		AutoTranPlanOrg    outVO  = new AutoTranPlanOrg();

		try {
			// INPUT 값 세팅
			inDTO.setTrOrgCd(searchAutoTranPlanOrg.getTrOrgCd());
			inDTO.setRcptTpCd("A1");
			inDTO.setPrgmId(searchAutoTranPlanOrg.getPrgmId());

			outDTO = autoTranCmsMapper.searchAutoTranPlanOrgDesc(inDTO);

			if(outDTO != null) {

				outVO.setRlDueDt(StringUtil.trim(outDTO.getRlDueDt()));                       //실납입일자
	            outVO.setTrOrgCd(StringUtil.trim(outDTO.getTrOrgCd()));                       //거래기관코드
	            outVO.setMinSetlDd(StringUtil.trim(outDTO.getMinSetlDd()));    	              //최소결제일
	            outVO.setMaxSetlDd(StringUtil.trim(outDTO.getMaxSetlDd()));                   //최대결제일
	            outVO.setMinDueDt(StringUtil.trim(outDTO.getMinDueDt()));                     //최소납입일자
	            outVO.setMaxDueDt(StringUtil.trim(outDTO.getMaxDueDt()));                     //최대납입일자
	            outVO.setAskStatCd(StringUtil.trim(outDTO.getAskStatCd()));                   //청구상태코드
	            outVO.setProcStatCd(StringUtil.trim(outDTO.getProcStatCd()));                 //처리상태코드
	            outVO.setClsDt(StringUtil.trim(outDTO.getClsDt()));                           //마감일자
	            outVO.setTrsmDt(StringUtil.trim(outDTO.getTrsmDt()));                         //송신일자
	            outVO.setRecvDt(StringUtil.trim(outDTO.getRecvDt()));                         //수취일자
	            outVO.setSetlDt(StringUtil.trim(outDTO.getSetlDt()));                         //결제일자
	            outVO.setAcctDt(StringUtil.trim(outDTO.getAcctDt()));                         //회계일자
	            outVO.setClsCnt(outDTO.getClsCnt());                                          //마감건수
	            outVO.setClsAmt(outDTO.getClsAmt());                                          //마감금액
	            outVO.setSlctCnt(outDTO.getSlctCnt());                                        //선정건수
	            outVO.setSlctAmt(outDTO.getSlctAmt());                                        //선정금액
	            outVO.setAskCnt(outDTO.getAskCnt());                                          //청구건수
	            outVO.setAskAmt(outDTO.getAskAmt());                                          //청구금액
	            outVO.setIntgAskCnt(outDTO.getIntgAskCnt());                                  //통합청구건수
	            outVO.setIntgAskAmt(outDTO.getIntgAskAmt());                                  //통합청구금액
	            outVO.setIntgSetlCnt(outDTO.getIntgSetlCnt());                                //통합결제건수
	            outVO.setIntgSetlAmt(outDTO.getIntgSetlAmt());                                //통합결제금액
	            outVO.setSetlCnt(outDTO.getSetlCnt());                                        //결제건수
	            outVO.setSetlAmt(outDTO.getSetlAmt());                                        //결제금액
	            outVO.setClsFg(StringUtil.trim(outDTO.getClsFg()));                           //마감여부
	            outVO.setFeeAcctDt(StringUtil.trim(outDTO.getFeeAcctDt()));                   //수수료회계일자
	            outVO.setFeeTranNo(outDTO.getFeeTranNo());                                    //수수료이체번호
	            outVO.setTrOrgNm(StringUtil.trim(outDTO.getTrOrgNm()));                       //거래부서명
	            outVO.setAcctUnitCd(StringUtil.trim(outDTO.getAcctUnitCd()));                 //회계단위코드
	            outVO.setRcptTpCd(StringUtil.trim(outDTO.getRcptTpCd()));                     //수납유형코드
	            outVO.setCyclCd(StringUtil.trim(outDTO.getCyclCd()));                         //주기코드
	            outVO.setBankCd(StringUtil.trim(outDTO.getBankCd()));                         //은행코드
	            outVO.setMoAcntNo(StringUtil.trim(outDTO.getMoAcntNo()));                     //지급모계좌계좌번호
	            outVO.setVndrCd(StringUtil.trim(outDTO.getVndrCd()));                         //업체코드
	            outVO.setFeeSetlMethCd(StringUtil.trim(outDTO.getFeeSetlMethCd()));           //수수료결제방법코드
	            outVO.setAskFee(outDTO.getAskFee());                                          //청구수수료
	            outVO.setOamtFee(outDTO.getOamtFee());                                        //출금수수료
	            outVO.setStrtDueDt(StringUtil.trim(outDTO.getStrtDueDt()));                   //시작납입일자
	            outVO.setEndDueDt(StringUtil.trim(outDTO.getEndDueDt()));                     //종료납입일자
	            outVO.setAutoTranOamtTpCd(StringUtil.trim(outDTO.getAutoTranOamtTpCd()));     //자동이체출금유형코드
	            outVO.setAutoTranRsltTpCd(StringUtil.trim(outDTO.getAutoTranRsltTpCd()));     //자동이체결과유형코드
	            outVO.setTrsmSchdDd(outDTO.getTrsmSchdDd());                                  //송신예정일
	            outVO.setRecvSchdDd(outDTO.getRecvSchdDd());                                  //수신예정일
	            outVO.setSetlSchdDd(outDTO.getSetlSchdDd());                                  //결제예정일
	            outVO.setAcctSchdDd(outDTO.getAcctSchdDd());                                  //회계예정일
	            outVO.setFrstRegDt(StringUtil.trim(outDTO.getFrstRegDt()));                   //최초등록일자
	            outVO.setFrstRegTm(StringUtil.trim(outDTO.getFrstRegTm()));                   //최초등록시각
	            outVO.setFrstRegEmpNo(StringUtil.trim(outDTO.getFrstRegEmpNo()));             //최초등록자사번
	            outVO.setLastProcDt(StringUtil.trim(outDTO.getLastProcDt()));                 //최종처리일자
	            outVO.setLastProcTm(StringUtil.trim(outDTO.getLastProcTm()));                 //최종처리시각
	            outVO.setLastProcEmpNo(StringUtil.trim(outDTO.getLastProcEmpNo()));           //최종처리사번
	            outVO.setBankBrnchCd(StringUtil.trim(outDTO.getBankBrnchCd()));               //은행지점코드
	            outVO.setDupAcntPrmsFg(StringUtil.trim(outDTO.getDupAcntPrmsFg()));           //중복계좌허용여부
	            outVO.setOamtAcntRegFg(StringUtil.trim(outDTO.getOamtAcntRegFg()));           //출금계좌등록여부
	            outVO.setBaseFee(outDTO.getBaseFee());                                        //기본수수료
	            outVO.setAblIzeDivCd(StringUtil.trim(outDTO.getAblIzeDivCd()));               //ABL환매구분코드
	            outVO.setAblIzeSeq(StringUtil.trim(outDTO.getAblIzeSeq()));                   //ABL환매순번
	            outVO.setMoBankCd(StringUtil.trim(outDTO.getMoBankCd()));                     //지급모계좌은행코드
	            outVO.setServerFileFullPath(StringUtil.trim(outDTO.getServerFileFullPath())); //null
	            outVO.setFilePrefix(StringUtil.trim(outDTO.getFilePrefix()));                 //null
			}
			log.info("searchAutoTranPlanOrgDesc End");
			return outVO;

		} catch (Exception e) {
			log.error("searchAutoTranPlanOrgDesc Exception");
			throw new BizException("자동이체 계획 또는 거래기관 정보 조회 실패",e);
		}
	}

	@Override
	public int updateAutoTranAskJobClos(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateAutoTranAskJobClos start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskStatCd(CmsCode.ASK_STAT_SLCT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_WAIT);
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setTrOrgCd(autoTranCmsProcVO.getTrOrgCd());
			inDTO.setJobId("RATDL02");

			cnt = autoTranCmsMapper.updateAutoTranAskJobClos(inDTO);
			log.info("updateAutoTranAskJobClos cnt : " + cnt);

			return cnt;

        } catch (Exception e) {
        	log.info("updateAutoTranAskJobClos Exception");
            throw new BizException("청구 작업 상태 변경 실패", e);
        }
	}

	@Override
	public int updateJobPlanProcStat(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateJobPlanProcStat start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setTrOrgCd(autoTranCmsProcVO.getTrOrgCd());
			// 선정처리중 -> 확정대기
			inDTO.setAskStatCd(CmsCode.ASK_STAT_SLCT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setAfAskStatCd(CmsCode.ASK_STAT_DCSN);
			inDTO.setAfProcStatCd(CmsCode.PROC_STAT_WAIT);

			cnt = autoTranCmsMapper.updateJobPlanProcStat(inDTO);

			log.info("updateJobPlanProcStat cnt : " + cnt);

			return cnt;

        } catch (Exception e) {
        	log.error("updateJobPlanProcStat Exception");
        	throw new BizException("청구 제외후 청구대상 선정결과 업데이트 실패", e);
        }
	}

	@Override
	public int updateAutoTranPlanProcStat(String trOrgCd, String trsmDt, String clsDt, String recvDt,
			                              String bfAskStatCd, String bfProcStatCd, String afAskStatCd, String afProcStatCd) {
		log.info("updateAutoTranPlanProcStat start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAfAskStatCd(afAskStatCd);
			inDTO.setAfProcStatCd(afProcStatCd);
			inDTO.setTrsmDt(trsmDt);
			inDTO.setRecvDt(recvDt);
			inDTO.setClsDt(clsDt);
			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setBfAskStatCd(bfAskStatCd);
			inDTO.setBfProcStatCd(bfProcStatCd);

			cnt = autoTranCmsMapper.updateAutoTranPlanProcStat(inDTO);

			log.info("updateAutoTranPlanProcStat cnt : " + cnt);

			return cnt;

        } catch (Exception e) {
        	log.error("updateAutoTranPlanProcStat Exception");
        	throw new BizException("수정반영 실패", e);
        }
	}

	@Override
	public int createAutoTranIntg(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("createAutoTranIntg start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setFrstRegEmpNo(autoTranPlanOrg.getFrstRegEmpNo());
			inDTO.setLastProcEmpNo(autoTranPlanOrg.getLastProcEmpNo());
			inDTO.setTrsmDt(autoTranPlanOrg.getTrsmDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setIntgAskFg("1");
			inDTO.setAskDivCd("00");

			cnt = autoTranCmsMapper.createAutoTranIntg(inDTO);

			log.info("createAutoTranIntg cnt : " + cnt);

			return cnt;

        } catch (Exception e) {
        	log.error("createAutoTranIntg Exception");
        	throw new BizException("통합청구내역 생성실패", e);
        }
	}

	@Override
	public int updateAutoTranAskTot(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranAskTot start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAfAskStatCd(CmsCode.ASK_STAT_ASK_TOT);
			inDTO.setAfProcStatCd(CmsCode.PROC_STAT_WAIT);
			inDTO.setAskDivCd("00"); // 정상청구
			inDTO.setTrsmDt(autoTranPlanOrg.getTrsmDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setAskStatCd(CmsCode.ASK_STAT_DCSN);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);

			cnt = autoTranCmsMapper.updateAutoTranAskTot(inDTO);

			log.info("updateAutoTranAskTot cnt : " + cnt);

			return cnt;

        } catch (Exception e) {
        	log.error("updateAutoTranAskTot Exception");
        	throw new BizException("통합청구내역 생성실패", e);
        }
	}

	@Override
	public int updateAutoTranAskTot(String trOrgCd, String trsmDt) {

		log.info("updateAutoTranAskTot1 start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setAskDivCd("00"); // 정상청구
			inDTO.setTrsmDt(trsmDt);

			cnt = autoTranCmsMapper.updateAutoTranAskTot1(inDTO);

			log.info("updateAutoTranAskTot1 cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranAskTot1 Exception");
        	throw new BizException("청구 건수, 금액 집계 변경 실패", e);
        }
	}

	@Override
	public int deleteAutoTranLoanTotDesc(String trOrgCd, String trsmDt) {
		log.info("deleteAutoTranLoanTotDesc start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setTrsmDt(trsmDt);
			inDTO.setAskStatCd(CmsCode.ASK_STAT_ASK_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);

			cnt = autoTranCmsMapper.deleteAutoTranLoanTotDesc(inDTO);

			log.info("deleteAutoTranLoanTotDesc cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("deleteAutoTranLoanTotDesc Exception");
        	throw new BizException("청구 대출집계 테이블 초기화 실패", e);
        }
	}

	@Override
	public int createAutoTranLoanTotDesc(String trOrgCd, String trsmDt, String empNo) {

		log.info("createAutoTranLoanTotDesc start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setFrstRegEmpNo(empNo);
			inDTO.setLastProcEmpNo(empNo);
			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setTrsmDt(trsmDt);
			inDTO.setAskStatCd(CmsCode.ASK_STAT_ASK_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setAskDivCd("00");

			cnt = autoTranCmsMapper.createAutoTranLoanTotDesc(inDTO);

			log.info("createAutoTranLoanTotDesc cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("createAutoTranLoanTotDesc Exception");
        	throw new BizException("청구 대출집계 생성 실패", e);
        }
	}

	@Override
	public int deleteAutoTranTotDesc(String trOrgCd, String trsmDt) {

		log.info("deleteAutoTranTotDesc start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setTrsmDt(trsmDt);
			inDTO.setAskStatCd(CmsCode.ASK_STAT_ASK_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);

			cnt = autoTranCmsMapper.deleteAutoTranTotDesc(inDTO);

			log.info("deleteAutoTranTotDesc cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("deleteAutoTranTotDesc Exception");
        	throw new BizException("자동이체 청구 집계내역 삭제 실패", e);
        }
	}

	@Override
	public int createAutoTranTotDesc(String trOrgCd, String trsmDt, String empNo) {
		log.info("createAutoTranTotDesc start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setEmpNo(empNo);
			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setTrsmDt(trsmDt);
			inDTO.setAskStatCd(CmsCode.ASK_STAT_ASK_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setAskDivCd("00");

			cnt = autoTranCmsMapper.createAutoTranTotDesc(inDTO);

			log.info("createAutoTranTotDesc cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("createAutoTranTotDesc Exception");
        	throw new BizException("자동이체 청구 집계 생성 실패", e);
        }
	}

	@Override
	public List<AutoTranTrDesc> searchAutoTranDesc(AutoTranPlanOrg searchAutoTranPlanOrg) {

		List<AutoTranTrDescDTO> result = new ArrayList<AutoTranTrDescDTO>();
		List<AutoTranTrDesc>    list   = new ArrayList<AutoTranTrDesc>();

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setRlDueDt(searchAutoTranPlanOrg.getRlDueDt());
			inDTO.setTrOrgCd(searchAutoTranPlanOrg.getTrOrgCd());
			inDTO.setAskDivCd("00");

			result = autoTranCmsMapper.searchAutoTranDesc(inDTO);

			if(result != null) {

				for(AutoTranTrDescDTO rs : result) {
					AutoTranTrDesc vo = new AutoTranTrDesc();

                    vo.setRlDueDt(StringUtil.trim(rs.getRlDueDt()));    //출금일자
                    vo.setTrOrgCd(StringUtil.trim(rs.getTrOrgCd()));    //거래기관코드
                    vo.setLoanNo(StringUtil.trim(rs.getIntgLoanNo()));    //대출번호
                    vo.setLoanSeq(StringUtil.trim(rs.getLoanSeq()));    //대출순번
                    vo.setBankCd(StringUtil.trim(rs.getBankCd()));    // 은행코드
                    vo.setAcntNo(StringUtil.trim(rs.getAcntNo()));    //계좌번호
                    vo.setDepoOwnNo(StringUtil.trim(rs.getDepoOwnNo()));    //예금주번호
                    vo.setAskAmt(rs.getAskAmt());    //청구금액
                    vo.setAskTims(rs.getAskTims());    //청구회차
                    vo.setDepoOwnnm(StringUtil.trim(rs.getDepoOwnnm()));

                    list.add(vo);
				}
			}

		} catch (Exception e) {
			log.error("searchAutoTranDesc Exception");
			throw new BizException("자동이체 계획 또는 거래기관 정보 조회 실패",e);
		}

		return list;
	}

	@Override
	public long searchTotAskCnt(String trOrgCd, String recvDt) {

		log.info("searchTotAskCnt start");
		long askCnt = 0 ;

		try {

			AutoTranPlanOrgDTO inDTO  = new AutoTranPlanOrgDTO();
			AutoTranPlanOrgDTO outDTO = new AutoTranPlanOrgDTO();

			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setRecvDt(recvDt);

			outDTO = autoTranCmsMapper.searchTotAskCnt(inDTO);

			if(outDTO != null) {
				askCnt = outDTO.getAskCnt();
			}

			log.info("searchTotAskCnt cnt : " + askCnt);
			return askCnt;
        } catch (Exception e) {
        	log.error("searchTotAskCnt Exception");
        	throw new BizException("자동이체 계획 또는 거래기관 정보 조회 실패",e);
        }

	}

	@Override
	public int updateLoanStatAskObj(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateLoanStatAskObj start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("26");                       // 대출상태확인
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중
			inDTO.setCdKindNo("R00051");                   // 청구대출상태(21,22)

			cnt = autoTranCmsMapper.updateLoanStatAskObj(inDTO);

			log.info("updateLoanStatAskObj cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateLoanStatAskObj Exception");
        	throw new BizException("대출상태 제외 조건 업데이트 실패", e);
        }
	}

	@Override
	public int updateLoanStatAskFbidFg(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateLoanStatAskFbidFg start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("20");                       // 청구금지여부
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중

			cnt = autoTranCmsMapper.updateLoanStatAskFbidFg(inDTO);

			log.info("updateLoanStatAskFbidFg cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateLoanStatAskFbidFg Exception");
        	throw new BizException("청구제외 - 청구금지 대출건 업데이트 실패", e);
        }
	}

	@Override
	public int updateCyclAskObjExcl(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateCyclAskObjExcl start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("25");                       // 주기청구대상제외
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중

			cnt = autoTranCmsMapper.updateCyclAskObjExcl(inDTO);

			log.info("updateCyclAskObjExcl cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateCyclAskObjExcl Exception");
        	throw new BizException("청구제외 - 청구수신전 주기청구될 대상에 대해 제외 업데이트 실패", e);
        }
	}

	@Override
	public int updateUnRecvAskExcl(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateUnRecvAskExcl start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("27");                       // 미수신청구분제외
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중

			cnt = autoTranCmsMapper.updateUnRecvAskExcl(inDTO);

			log.info("updateUnRecvAskExcl cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateUnRecvAskExcl Exception");
        	throw new BizException("청구제외 - 미수신청 청구제외 업데이트 실패", e);
        }
	}

	@Override
	public int updateChkAcntStat(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateChkAcntStat start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("21");                       // 자동이체계좌미등록
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중
			inDTO.setCdKindNo("R00006");                   // 계좌상태코드
			inDTO.setClas1("X");

			cnt = autoTranCmsMapper.updateChkAcntStat(inDTO);

			log.info("updateChkAcntStat cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateChkAcntStat Exception");
        	throw new BizException("청구제외 - 자동이체 계좌 상태 확인 업데이트 실패", e);
        }
	}

	@Override
	public int updateMinAskAmtChk(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateMinAskAmtChk start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("23");                       // 최소금액
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중
			inDTO.setCdKindNo("R00026");                   // 최소금액
			inDTO.setCdDescNo("23");

			cnt = autoTranCmsMapper.updateMinAskAmtChk(inDTO);

			log.info("updateMinAskAmtChk cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateMinAskAmtChk Exception");
        	throw new BizException("청구제외 - 자동이체 최소 청구금액 제외 업데이트 실패", e);
        }
	}

	@Override
	public int updateMaxAskAmtChk(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateMaxAskAmtChk start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("32");                       // 최대금액
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중
			inDTO.setCdKindNo("R00026");                   // 최대금액
			inDTO.setCdDescNo("32");

			cnt = autoTranCmsMapper.updateMaxAskAmtChk(inDTO);

			log.info("updateMaxAskAmtChk cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateMaxAskAmtChk Exception");
        	throw new BizException("청구제외 - 자동이체 최대 청구금액 제외 업데이트 실패", e);
        }
	}

	@Override
	public int updateDlyTcntChk(AutoTranCmsProcVO autoTranCmsProcVO) {
		log.info("updateDlyTcntChk start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("22");                       // 연체횟수초과
			inDTO.setEmpNo(autoTranCmsProcVO.getEmpNo());
			inDTO.setClsDt(autoTranCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중
			inDTO.setCdKindNo("R00026");                   // 연체횟수초과
			inDTO.setCdDescNo("22");

			cnt = autoTranCmsMapper.updateDlyTcntChk(inDTO);

			log.info("updateDlyTcntChk cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateDlyTcntChk Exception");
        	throw new BizException("청구제외 - 자동이체 연체 횟수 초과 제외 업데이트 실패", e);
        }
	}

	@Override
	public int updateIvltClosObj(AutoTranCmsProcVO attrCmsProcVO) {
		log.info("updateIvltClosObj start");
		int cnt = 0;

		try {

			AutoTranCmsProcDTO inDTO = new AutoTranCmsProcDTO();

			inDTO.setAskDivCd("15");                       // 강제해지 제외
			inDTO.setEmpNo(attrCmsProcVO.getEmpNo());
			inDTO.setClsDt(attrCmsProcVO.getClsDt());
			inDTO.setAskStatCd("2");                       // 선정
			inDTO.setProcStatCd("1");                      // 작업중

//			Connection con;
//
//			// 사용여부
//	        String useYn = CUtil.getCodeNm(con,"R00026", "15", "clas1");
//	        if (!"Y".equals(useYn)) {
//	        	return 0;
//	        }
			cnt = autoTranCmsMapper.updateIvltClosObj(inDTO);

			log.info("updateIvltClosObj cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateIvltClosObj Exception");
        	throw new BizException("대출상태 제외 조건 업데이트 실패", e);
        }
	}

	@Override
	public int deleteAutoTranRecv(String rlDueDt, String trOrgCd) {
		log.info("deleteAutoTranRecv start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setRlDueDt(rlDueDt);
			inDTO.setTrOrgCd(trOrgCd);

			cnt = autoTranCmsMapper.deleteAutoTranRecv(inDTO);

			log.info("deleteAutoTranRecv cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("deleteAutoTranRecv Exception");
        	throw new BizException("자동이체 입금전문 내역 삭제실패", e);
        }
	}

	@Override
	public int insertAutoTranRecv(AutoTranRecvDesc autoTranRecvDesc) {
		log.info("insertAutoTranRecv start");
		int cnt = 0;

		try {

			AutoTranRecvDescDTO inDTO = new AutoTranRecvDescDTO();

			inDTO.setRlDueDt(autoTranRecvDesc.getRlDueDt());
			inDTO.setTrOrgCd(autoTranRecvDesc.getTrOrgCd());
			inDTO.setSendSnum(autoTranRecvDesc.getSendSnum());
			inDTO.setLoanNo(autoTranRecvDesc.getLoanNo());
            inDTO.setRsltAmt(autoTranRecvDesc.getRsltAmt());
            inDTO.setOamtErrCd(autoTranRecvDesc.getOamtErrCd());
            inDTO.setRecvDt(autoTranRecvDesc.getRecvDt());
            inDTO.setFrstRegEmpNo(autoTranRecvDesc.getFrstRegEmpNo());
            inDTO.setOamtCd(autoTranRecvDesc.getOamtCd());
            inDTO.setLoanSeq(autoTranRecvDesc.getLoanSeq());
            inDTO.setOamtErrNm(autoTranRecvDesc.getOamtErrNm());

			cnt = autoTranCmsMapper.insertAutoTranRecv(inDTO);

			log.info("insertAutoTranRecv cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("insertAutoTranRecv Exception");
        	throw new BizException("자동이체 수신내역 생성 실패", e);
        }
	}

	@Override
	public int updateAutoTranTrIamtRank(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranTrIamtRank start");
		int cnt = 0;

		try {

			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setLoanLastFg("1");
			inDTO.setIntgAskFg("1");
			inDTO.setAskDivCd("00");
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());

			cnt = autoTranCmsMapper.updateAutoTranTrIamtRank(inDTO);

			log.info("updateAutoTranTrIamtRank cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranTrIamtRank Exception");
        	throw new BizException("자동이체 입금 우선순위 변경 실패", e);
        }
	}

	@Override
	public int updateAutoTranIntgDescRslt(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranIntgDescRslt start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAskStatCd(CmsCode.ASK_STAT_RSLT_REFL);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());

			cnt = autoTranCmsMapper.updateAutoTranIntgDescRslt(inDTO);

			log.info("updateAutoTranIntgDescRslt cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranIntgDescRslt Exception");
        	throw new BizException("자동이체 결과 통합내역에 변경 실패", e);
        }
	}

	@Override
	public int updateAutoTranTrRslt(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranTrRslt start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAskStatCd(CmsCode.ASK_STAT_RSLT_REFL);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setAskDivCd("00");

			cnt = autoTranCmsMapper.updateAutoTranTrRslt(inDTO);

			log.info("updateAutoTranTrRslt cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranTrRslt Exception");
        	throw new BizException("자동이체결과 거래내역에 반영 실패", e);
        }
	}

	@Override
	public int updateAutoTranTotRslt(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranTotRslt start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAskDivCd("00");
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setAskStatCd(CmsCode.ASK_STAT_IAMT_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);

			cnt = autoTranCmsMapper.updateAutoTranTotRslt(inDTO);

			log.info("updateAutoTranTotRslt cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranTotRslt Exception");
        	throw new BizException("자동이체 거래 집계 결과 업데이트 실패", e);
        }
	}

	@Override
	public int updateAutoTranLaonTotRslt(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranLaonTotRslt start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAskDivCd("00");
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setAskStatCd(CmsCode.ASK_STAT_IAMT_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);

			cnt = autoTranCmsMapper.updateAutoTranLaonTotRslt(inDTO);

			log.info("updateAutoTranLaonTotRslt cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranLaonTotRslt Exception");
        	throw new BizException("자동이체 대출건별 집계내역 결과 업데이트 실패", e);
        }
	}

	@Override
	public int updateAutoTranPlanIamtWait(AutoTranPlanOrg autoTranPlanOrg) {
		log.info("updateAutoTranPlanIamtWait start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setAskDivCd("00");
			inDTO.setRecvDt(autoTranPlanOrg.getRecvDt());
			inDTO.setTrOrgCd(autoTranPlanOrg.getTrOrgCd());
			inDTO.setAskStatCd(CmsCode.ASK_STAT_IAMT_TOT);
			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_MID);
			inDTO.setAfAskStatCd(CmsCode.ASK_STAT_IAMT);
			inDTO.setAfProcStatCd(CmsCode.PROC_STAT_WAIT);

			cnt = autoTranCmsMapper.updateAutoTranPlanIamtWait(inDTO);

			log.info("updateAutoTranPlanIamtWait cnt : " + cnt);
			return cnt;
        } catch (Exception e) {
        	log.error("updateAutoTranPlanIamtWait Exception");
        	throw new BizException("자동이체 계획 입금대기 수정 오류", e);
        }
	}

	@Override
	public void chkAutoTranAskStatus(String rlDueDt, String trOrgCd) {

		log.info("chkAutoTranAskStatus start");

		try {
			AutoTranPlanOrgDTO inDTO  = new AutoTranPlanOrgDTO();
			AutoTranPlanOrgDTO outDTO = new AutoTranPlanOrgDTO();

			inDTO.setRlDueDt(rlDueDt);
			inDTO.setTrOrgCd(trOrgCd);

			outDTO = autoTranCmsMapper.chkAutoTranAskStatus(inDTO);

			if(outDTO != null) {
				if(outDTO.getAskCnt() > 0) {
					if(outDTO.getUnRecvCnt() > 0) {
						throw new BizException("자동이체 EC22 수신 결과처리가 되어있지 않습니다.(" + rlDueDt + ")");
					}
				}else {
					throw new DbsBatchSkipException("자동이체 청구건이 없습니다.(" + rlDueDt + ")");
				}
			}else {
				log.info("자동이체 청구건이 없습니다.(" + rlDueDt + ")");
            	return;
			}
        } catch (Exception e) {
        	log.error("chkAutoTranAskStatus Exception");
        	throw new BizException("자동이체 청구/수신 결과 확인 실패(" + e.getMessage() +")",e);
        }
	}

	@Override
	public void chkJobCompl(String rlDueDt) {
		log.info("chkJobCompl start");

		try {
			AutoTranPlanOrgDTO inDTO  = new AutoTranPlanOrgDTO();
			AutoTranPlanOrgDTO rs = new AutoTranPlanOrgDTO();

			inDTO.setJobDt(rlDueDt);

			rs = autoTranCmsMapper.chkJobCompl(inDTO);

			if(rs != null) {
				if(rs.getCnt() > 0) {
					if(rs.getCnt() != rs.getComplCnt()) {
						throw new BizException("자동이체 입금반영 처리중 입니다.(" + rlDueDt + ")");
					}
				} else {
                    throw new BizException("자동이체 입금반영 작업내용이 존재하지 않습니다.(" + rlDueDt + ")");
                }
			}else {
				throw new BizException("자동이체 입금반영 작업내용이 존재하지 않습니다.(" + rlDueDt + ")");
			}
        } catch (Exception e) {
        	log.error("chkJobCompl Exception");
        	throw new BizException("자동이체 청구/수신 결과 확인 실패(" + e.getMessage() +")",e);
        }
	}

	@Override
	public void updateIamtCompl(String jobDt, String empNo, String trOrgCd) {

		log.info("updateIamtCompl start");
		int cnt = 0;

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setProcStatCd(CmsCode.PROC_STAT_JOB_END);
			inDTO.setProcEmpNo(empNo);
			inDTO.setJobDt(jobDt);
			inDTO.setTrOrgCd(trOrgCd);
			inDTO.setJobId("RATDL04");

			cnt = autoTranCmsMapper.updateIamtCompl(inDTO);

			if(cnt != 1) {
				throw new BizException("자동이체 입금작업 완료상태 변경실패(" + jobDt + ")");
			}
			log.info("updateIamtCompl cnt : " + cnt);

        } catch (Exception e) {
        	log.error("updateIamtCompl Exception");
        	throw new BizException("자동이체 입금작업 완료상태 변경실패(" + e.getMessage() + ")", e);
        }

	}

	@Override
	public List<AutoTranCmsProcVO> getTrOrgCd(AttrOrgVO attrOrgVO) {

		log.info("getTrOrgCd start");

		List<AutoTranCmsProcVO> list = new ArrayList<AutoTranCmsProcVO>();
		List<AutoTranCmsProcDTO> rs = new ArrayList<AutoTranCmsProcDTO>();

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setRcptTpCd(attrOrgVO.rcptTpCd);

			rs = autoTranCmsMapper.getTrOrgCd(inDTO);

			if(rs != null) {
				for(AutoTranCmsProcDTO result : rs) {
					AutoTranCmsProcVO vo = new AutoTranCmsProcVO();

					vo.setTrOrgCd(StringUtil.trim(result.getTrOrgCd()));
					vo.setVndrCd(StringUtil.trim(result.getVndrCd()));

					list.add(vo);
				}
			}

			log.info("getTrOrgCd End");
			return list;

        } catch (Exception e) {
        	log.error("getTrOrgCd Exception");
        	throw new BizException("거래기관코드 목록 조회실패",e );
        }
	}

	@Override
	public List<AutoTranCmsProcVO> getTrOrgEB22(String recvDt) {
		log.info("getTrOrg_EB22 start");

		List<AutoTranCmsProcVO> list = new ArrayList<AutoTranCmsProcVO>();
		List<AutoTranCmsProcDTO> rs = new ArrayList<AutoTranCmsProcDTO>();

		try {
			AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

			inDTO.setRecvDt(recvDt);

			rs = autoTranCmsMapper.getTrOrgEB22(inDTO);

			if(rs != null) {
				for(AutoTranCmsProcDTO result : rs) {
					AutoTranCmsProcVO vo = new AutoTranCmsProcVO();

					vo.setTrOrgCd(StringUtil.trim(result.getTrOrgCd()));
					vo.setVndrCd(StringUtil.trim(result.getVndrCd()));

					list.add(vo);
				}
			}

			log.info("getTrOrg_EB22 End");
			return list;

        } catch (Exception e) {
        	log.error("getTrOrg_EB22 Exception");
        	throw new BizException("거래기관코드 목록 조회실패",e );
        }
	}


    /**
     * <p>메소드명  : searchTrOrgList</p>
     * <p>설　　명  : 거래기관 조회</P>
     * <p>메소드인수 : Connection, AttrOrgVO</p>
     * <p>리 턴 값 : List(AttrOrgVO)</p>
     */
	@Override
    public List<AttrOrgVO> searchTrOrgList(AttrOrgVO inVo) throws Exception {
	    List<AttrOrgVO> outVo = null;
	    try {
	        outVo = autoTranCmsMapper.getTrOrgBase(inVo);
        } catch (Exception e) {
            log.error("searchTrOrgList Exception");
            throw new BizException("거래기관코드 목록 조회실패",e );
        }
	    return outVo;
    }

	/**
     * <p>메소드명  : searchAttrPlanStat</p>
     * <p>설　　명  : 자동이체입금 작업상태 조회</p>
     * <p>메소드인수 : AttrOrgVO</p>
     * <p>리　턴　값 : N/A</p>
     */
	@Override
	public String searchAttrPlanStat(AttrOrgVO orgVO) throws Exception {
        String attrStat = "";

        try {
            AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

            inDTO.setTrOrgCd(orgVO.trOrgCd);
            inDTO.setRecvDt(orgVO.jobDt);

            attrStat = autoTranCmsMapper.searchAttrPlanStat(inDTO);

        } catch (Exception e) {
            throw new BizException("작업상태 조회실패");
        }


        return attrStat;
    }

    /**
     * <p>메소드명  : procAutoJobChk</p>
     * <p>설　　명  : 자동이체 미수금대상 조회</p>
     * <p>메소드인수 : Connection, AttrOrgVO</p>
     * <p>리　턴　값 : List(RMap)</p>
     */
	@Override
	public List<ClsTrDescVO> searchAttrUnrcvList(AttrOrgVO orgVO) throws Exception {

       List<ClsTrDescVO> outList = new ArrayList<ClsTrDescVO>();

        try {
            AutoTranPlanOrgDTO inDTO = new AutoTranPlanOrgDTO();

            inDTO.setRlDueDt(orgVO.jobDt);
            inDTO.setTrOrgCd(orgVO.trOrgCd);

            List<SearchAttrPlanStatOutDTO> outDTO = autoTranCmsMapper.searchAttrUnrcvList(inDTO);;


            for (SearchAttrPlanStatOutDTO sourceIO : outDTO) {
                ClsTrDescVO vo = new ClsTrDescVO();

                vo.setLoanNo(sourceIO.getLoanNo());         // 대출_번호
                vo.setLoanSeq(sourceIO.getLoanSeq());       // 대출_순번
                vo.setPrdtLrgeClasCd(sourceIO.getPrdtLcd());// 상품_대분류_코드
                vo.setPrdtMidClasCd(sourceIO.getPrdtMcd()); // 상품_중분류_코드
                vo.setMngDeptCd(sourceIO.getMngDeptCd());   // 관리_부서_코드  (필수, 자동결제여부가 아닐때)
                vo.setBankCd(sourceIO.getMoBankCd());       // 모계좌은행
                vo.setAcntNo(sourceIO.getMoAcntNo());       // 모계좌번호
                vo.setSetlAmt(sourceIO.getSetlAmt());       // 금액

                outList.add(vo);
            }

        } catch (Exception e) {
            throw new BizException("자동이체 미수금대상 조회실패");
        }

        return outList;




    }

    /**
     * <p>메소드명  : updateUnrcvAdjFg</p>
     * <p>설　　명  : 미수금정산여부 수정</p>
     * <p>메소드인수 : Connection, AttrOrgVO, RATDL0403VO</p>
     * <p>리　턴　값 : int</p>
     */
	@Override
	public int updateUnrcvAdjFg(AttrOrgVO orgVO, ClsTrDescVO trDescVO) throws Exception {

	    int exeCnt = 0;

	    try {
	        RtAutoTranTrDescDTO inDTO = new RtAutoTranTrDescDTO();

	        inDTO.setTrOrgCd(orgVO.trOrgCd);
	        inDTO.setRlDueDt(orgVO.jobDt);
	        inDTO.setLoanNo(trDescVO.getLoanNo());
	        inDTO.setLoanSeq(trDescVO.getLoanSeq());

	        exeCnt = autoTranCmsMapper.updateUnrcvAdjFg(inDTO);

        } catch (Exception se) {
            throw new BizException("UPDATE 미수금 정산여부 ", se);
        }

        return exeCnt;


    }
}
