package hanalife.r.at.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.StringUtil;
import hanalife.r.at.dl.mapper.AutoTranAskMapper;
import hanalife.r.at.dl.mapper.dto.AttrJobDTO;
import hanalife.r.at.dl.mapper.dto.AutoTranAskInDTO;
import hanalife.r.at.dl.mapper.dto.AutoTranAskOutDTO;
import hanalife.r.at.dl.service.AutoTranAskService;
import hanalife.r.at.dl.vo.AutoTranAskObj;
import hanalife.r.at.vo.bat.AttrJobVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.util.BizException;

@Service("AutoTranAskService")
public class AutoTranAskServiceImpl implements AutoTranAskService {

	private static final Logger log = LoggerFactory.getLogger(AutoTranAskServiceImpl.class);

	@Autowired
	private AutoTranAskMapper autoTranAskMapper;


	/**
	 * <p>메소드명 	: searchAutoTranAskObj		</p>
	 * <p>설명     	: 자동이체청구 대상을 조회한다. 		</p>
	 * <p>메소드인수1	: AttrJobVO                	</p>
	 * <p>메소드리턴값  : List<AutoTranAskOutVO>  	</p>
	 * <p>예외처리  	: Exception					</p>
	 */
	@Override
	public List<AutoTranAskObj> searchAutoTranAskObj(AttrJobVO inVO) throws Exception {

		List<AutoTranAskObj> resultVo = new ArrayList<AutoTranAskObj>();

		AttrJobDTO inDTO = new AttrJobDTO();

		inDTO.jobDt = inVO.jobDt;
		inDTO.trOrgCd = inVO.trOrgCd;
		inDTO.strtLoanNo = inVO.strtLoanNo;
		inDTO.endLoanNo = inVO.endLoanNo;

		List<AutoTranAskOutDTO> result = autoTranAskMapper.searchAutoTranAskObj(inDTO);

		if(result != null) {

			for(AutoTranAskOutDTO auto : result) {
				AutoTranAskObj rs = new AutoTranAskObj();

				rs.setRlDueDt(auto.getRlDueDt());                  /** 실납입일자 */
				rs.setTrOrgCd(auto.getTrOrgCd());                  /** 거래기관코드 */
				rs.setLoanNo(auto.getLoanNo());                    /** 대출번호 */
				rs.setLoanSeq(auto.getLoanSeq());                  /** 대출순번 */
				rs.setSetlDd(auto.getSetlDd());                    /** 결제일 */
				rs.setPrdtCd(auto.getPrdtCd());                    /** 상품코드 */
				rs.setPrdtLrgeClasCd(auto.getPrdtLrgeClasCd());    /** 상품대분류코드 */
				rs.setPrdtMidClasCd(auto.getPrdtMidClasCd());      /** 상품중분류코드 */
				rs.setPrdtSmClasCd(auto.getPrdtSmClasCd());        /** 상품소분류코드 */
				rs.setMngDeptCd(auto.getMngDeptCd());              /** 관리부서코드 */
				rs.setCustNo(auto.getCustNo());                    /** 계약자번호 */
				rs.setCustNm(auto.getCustNm());                    /** 계약자명 */
				rs.setBankCd(auto.getBankCd());                    /** 결제은행코드 */
				rs.setAcntNo(auto.getAcntNo());                    /** 결제계좌번호 */
				rs.setAcntSnum(auto.getAcntSnum());                /** 계좌일련번호 */
				rs.setDepoOwnNo(auto.getDepoOwnNo());              /** 예금주번호 */
				rs.setDepoOwnnm(auto.getDepoOwnnm());              /** 예금주명 */
				rs.setDepoOwnRelcd(auto.getDepoOwnRelcd());        /** 예금주관계코드 */
				rs.setAcntStatCd(auto.getAcntStatCd());            /** 계좌상태코드 */
				rs.setBndStatCd(auto.getBndStatCd());              /** 채권상태코드 */
				rs.setLoanStatCd(auto.getLoanStatCd());            /** 대출상태코드 */
				rs.setAutoTranIntgFg(auto.getAutoTranIntgFg());    /** */
				rs.setRlDueManNo(auto.getRlDueManNo());            /** */
				rs.setEprtAskMethCd(auto.getEprtAskMethCd());      /** */
				rs.setAskExclDt(auto.getAskExclDt());              /** */
				rs.setAskExDamt(auto.getAskExDamt());              /** */

				resultVo.add(rs);
			}
		}

		log.info("rs : " + resultVo);

		return resultVo;
	}

	/**
	 * <p>메소드명 	: updateJobPlan								</p>
	 * <p>설명     	: 작업계획기본에 작업대상(대출)에 대한 작업상태를 수정한다. 	</p>
	 * <p>메소드인수1	: jobStatCd(1:준비, 2:처리중, 3:완료), AttrJobVO	</p>
	 * <p>메소드리턴값  : int 										</p>
	 * <p>예외처리  	: Exception									</p>
	 */
	@Override
	public int updateJobPlan(String jobStatCd, AttrJobVO inVO) throws Exception {

		int updateCnt = 0;

		try {
			AttrJobDTO inDTO = new AttrJobDTO();

			inDTO.jobStatCd = jobStatCd;
			inDTO.jobDt = inVO.jobDt;
			inDTO.trOrgCd = inVO.trOrgCd;
			inDTO.strtLoanNo = inVO.strtLoanNo;
			inDTO.endLoanNo = inVO.endLoanNo;

			updateCnt = autoTranAskMapper.updateJobPlan(inDTO);
		} finally {

		}

		return updateCnt;
	}

	/**
	 * <p>메소드명 	: updateAutoTranPlanBase			</p>
	 * <p>설명     	: 자동이체계획기본의 처리상태코드를 수정한다. 	</p>
	 * <p>메소드인수1	: AttrJobVO	                    	</p>
	 * <p>메소드리턴값  : int 								</p>
	 * <p>예외처리  	: Exception							</p>
	 */
	@Override
	public int updateAutoTranPlanBase(AttrJobVO inVO) throws Exception {

		int updateCnt = 0;
		try {
			AttrJobDTO inDTO = new AttrJobDTO();

			inDTO.jobDt = inVO.jobDt;
			inDTO.trOrgCd = inVO.trOrgCd;
			inDTO.strtLoanNo = inVO.strtLoanNo;
			inDTO.endLoanNo = inVO.endLoanNo;

			updateCnt = autoTranAskMapper.updateAutoTranPlanBase(inDTO);
		} finally {

		}

		return updateCnt;
	}

	/**
	 * <p>메소드명 	: updateJobPlanBase			                </p>
	 * <p>설명     	: 작업계획기본테이블에 작업완료된 대출번호를 update한다. 	</p>
	 * <p>메소드인수1	: AttrJobVO	                    	</p>
	 * <p>메소드리턴값  : int 								</p>
	 * <p>예외처리  	: Exception							</p>
	 */
	@Override
	public int createAutoTranTrDesc(AskUnrcvVO askUnrcvVO, List autoTranAskObjList, AttrJobVO jobVO) throws Exception {

		String errLoanNum = "";
		int insertCnt = 0;

		try {

			int regCnt  = 0;
			int skipCnt = 0;


			for (int idx=0, i=1, n=autoTranAskObjList.size(); idx<n; idx++, i=1) {

				AutoTranAskInDTO inDTO = new AutoTranAskInDTO();

				AutoTranAskObj autoTranAskObj = (AutoTranAskObj) autoTranAskObjList.get(idx);
				errLoanNum = autoTranAskObj.getLoanNo() + "-" + autoTranAskObj.getLoanSeq();
				//log.info("▶"+autoTranAskObj);

				BndVO bndVO = askUnrcvVO.getBndVO(autoTranAskObj.getLoanNo(), autoTranAskObj.getLoanSeq());

				if (bndVO == null) {
					skipCnt++;
					log.info( "■ 청구제외 - 채권없음 [" + autoTranAskObj.getLoanNo() + ", " + autoTranAskObj.getLoanSeq() + "]");
					continue;
				}

				// 청구금액이 0보다 큰 경우만  insert
				if (bndVO.askAmt <= 0 || (bndVO.thmmRlDueDt.compareTo(autoTranAskObj.getRlDueDt()) > 0 && bndVO.dlyAmt <= 0)) {
					log.info("■ 청구제외 - 청구금없음 [" + autoTranAskObj.getLoanNo() + ", " + autoTranAskObj.getLoanSeq() + "]");
					skipCnt++;
					continue;
				}

				// (우리카드) 3일청구 EB21만 사용
				///** 금결원 3일청구는 정상/당일청구는 연체만 **/
				/*
				// 연체이면 3일청구 제외
				if (autoTranAskObj.getTrOrgCd().equals("A1001") && bndVO.dlyDdcnt > 0) {
					skipCnt++;
					continue;
				}
				// 연체 아니면 당일청구 제외
				if (autoTranAskObj.getTrOrgCd().equals("A2001") && bndVO.dlyDdcnt == 0) {
					skipCnt++;
					continue;
				}
				*/

				// Kcar, 마스턴캐피탈 EC21만 사용

				inDTO.setRlDueDt(autoTranAskObj.getRlDueDt());
				inDTO.setTrOrgCd(autoTranAskObj.getTrOrgCd());
				inDTO.setLoanNo(autoTranAskObj.getLoanNo());
				inDTO.setLoanSeq(autoTranAskObj.getLoanSeq());
				inDTO.setStndDueDt(((bndVO.stndDueDt != null) && (bndVO.stndDueDt.length()>7)) ? bndVO.stndDueDt.substring(8) : "");
				inDTO.setPrdtCd(autoTranAskObj.getPrdtCd());
				inDTO.setPrdtLrgeClasCd(autoTranAskObj.getPrdtLrgeClasCd());
				inDTO.setPrdtMidClasCd(autoTranAskObj.getPrdtMidClasCd());
				inDTO.setPrdtSmClasCd(autoTranAskObj.getPrdtSmClasCd());
				inDTO.setMngDeptCd(autoTranAskObj.getMngDeptCd());
				inDTO.setCustNo(autoTranAskObj.getCustNo());
				inDTO.setCustNm(StringUtil.strCutEucKr(autoTranAskObj.getCustNm(), 30));
				inDTO.setBankCd(autoTranAskObj.getBankCd());
				inDTO.setAcntNo(autoTranAskObj.getAcntNo());
				inDTO.setAcntSnum(autoTranAskObj.getAcntSnum());
				inDTO.setDepoOwnNo(autoTranAskObj.getDepoOwnNo());
				inDTO.setDepoOwnnm(StringUtil.strCutEucKr(autoTranAskObj.getDepoOwnnm(), 30));
				inDTO.setDepoOwnRelcd(autoTranAskObj.getDepoOwnRelcd());
				inDTO.setAcntStatCd(autoTranAskObj.getAcntStatCd());
				inDTO.setAskExclDt(autoTranAskObj.getAskExclDt());
				inDTO.setAskDivCd("00");

				//연체일때
				if (bndVO.thmmRlDueDt.compareTo(autoTranAskObj.getRlDueDt()) > 0) {
					long askAmt = bndVO.dlyAmt;

					if (autoTranAskObj.getPrdtLrgeClasCd().equals("4")) {	//운용리스일때
						//만기시 보증금 (AS-IS에 없어서 제거함)
//						if(autoTranAskObj.getEprtAskMethCd().equals("0") && bndVO.thmmDueTims == bndVO.totTims){
//							askAmt = askAmt - bndVO.guarAmt;
//						}

						//선수금리스료
						if (askAmt > 0 && bndVO.brcvAmtLeasfeeRamt > 0) {
							askAmt = askAmt - bndVO.brcvAmtLeasfeeRamt;
						}
					}

					// (2018-08-01) 가수잔액 제외 청구
					//askAmt = askAmt - bndVO.srcpRamt;
					// (2020-01-30) 가수잔액 제외 청구
					askAmt = askAmt - autoTranAskObj.getAskExDamt();

					if ( askAmt < 0) {
						askAmt = 0;
					}

					inDTO.setAskTims(bndVO.dlyEndTims);
					inDTO.setAskAmt(askAmt);
					inDTO.setBrcvAmtLeasfeeRamt(bndVO.brcvAmtLeasfeeRamt);
					inDTO.setExecGuarAmtRamt(0);
					inDTO.setAskPamt(bndVO.dlyPamt);
					inDTO.setAskInt(bndVO.dlyInt);
					inDTO.setAskTrtFee(bndVO.dlyTrtFee);
					inDTO.setAskPpayInt(bndVO.dlyPpayInt);
					inDTO.setAskAddCartax(bndVO.dlyAddCartax);
					inDTO.setAskAddEnvImprBrdnamt(bndVO.dlyAddEnvImprBrdnamt);
					inDTO.setAskAddInsuFee(bndVO.dlyAddInsuFee);
					inDTO.setAskAddAsfee(bndVO.dlyAddAsfee);
					inDTO.setAskVtax(bndVO.dlyVtax);
					inDTO.setAskIpayCartax(bndVO.dlyIpayCartax);
					inDTO.setAskIpayEnvImprBrdnamt(bndVO.dlyIpayEnvImprBrdnamt);
					inDTO.setAskIpayInsuFee(bndVO.dlyIpayInsuFee);
					inDTO.setAskIpayPnltAmt(bndVO.dlyIpayPnltAmt);
					inDTO.setAskIpayEtc(bndVO.dlyIpayEtc);
					inDTO.setAskLtrmBrcvAmt(bndVO.dlyLtrmBrcvAmt);
					inDTO.setAskDfee(bndVO.dfee);
					inDTO.setAskLeglActnCost(bndVO.leglActnCostRamt);
					inDTO.setAskNormAmt(0);
					inDTO.setAskNormPamt(0);
					inDTO.setAskNormInt(0);
					inDTO.setAskNormTrtFee(0);
					inDTO.setAskNormPpayIntRamt(0);
					inDTO.setAskNormAddCartax(0);
					inDTO.setAskNormAddEnvImprBrdnamt(0);
					inDTO.setAskNormAddInsuFee(0);
					inDTO.setAskNormAddAsfee(0);
					inDTO.setAskNormVtax(0);
					inDTO.setAskNormIpayCartax(0);
					inDTO.setAskNormIpayEnvImprBrdnamt(0);
					inDTO.setAskNormIpayInsuFee(0);
					inDTO.setAskNormIpayPnltAmt(0);
					inDTO.setAskNormIpayEtc(0);
					inDTO.setAskNormLtrmBrcvAmt(0);
                    inDTO.setAskDlyAmt(bndVO.dlyAmt);
					inDTO.setAskDlyPamt(bndVO.dlyPamt);
					inDTO.setAskDlyInt(bndVO.dlyInt);
					inDTO.setAskDlyTrtFee(bndVO.dlyTrtFee);
					inDTO.setAskDlyPpayInt(bndVO.dlyPpayInt);
					inDTO.setAskDlyAddCartax(bndVO.dlyAddCartax);
					inDTO.setAskDlyAddEnvImprBrdnamt(bndVO.dlyAddEnvImprBrdnamt);
					inDTO.setAskDlyAddInsuFee(bndVO.dlyAddInsuFee);
					inDTO.setAskDlyAddAsfee(bndVO.dlyAddAsfee);
					inDTO.setAskDlyVtax(bndVO.dlyVtax);
					inDTO.setAskDlyIpayCartax(bndVO.dlyIpayCartax);
					inDTO.setAskDlyIpayEnvImprBrdnamt(bndVO.dlyIpayEnvImprBrdnamt);
					inDTO.setAskDlyIpayInsuFee(bndVO.dlyIpayInsuFee);
					inDTO.setAskDlyIpayPnltAmt(bndVO.dlyIpayPnltAmt);
					inDTO.setAskDlyIpayEtc(bndVO.dlyIpayEtc);
					inDTO.setAskDlyLtrmBrcvAmt(bndVO.dlyLtrmBrcvAmt);
					inDTO.setAskDlyDfee(bndVO.dfee);

				}
				//정상청구일때
				else {
					long askAmt = bndVO.askAmt;

					if (autoTranAskObj.getPrdtLrgeClasCd().equals("4")) {	//운용리스일때
						//만기시 보증금 (AS-IS에 없어서 제거함)
//						if(autoTranAskObj.getEprtAskMethCd().equals("0") && bndVO.thmmDueTims == bndVO.totTims){
//							askAmt = askAmt - bndVO.guarAmt;
//						}

						//선수금리스료
						if (askAmt > 0 && bndVO.brcvAmtLeasfeeRamt > 0) {
							askAmt = askAmt - bndVO.brcvAmtLeasfeeRamt;
						}
					}

					// (2018-08-01) 가수잔액 제외 청구
					//askAmt = askAmt - bndVO.srcpRamt;
					// (2020-01-30) 가수잔액 제외 청구
					askAmt = askAmt - autoTranAskObj.getAskExDamt();

					if (askAmt < 0) {
						askAmt = 0;
					}

                    inDTO.setAskTims(bndVO.thmmDueTims);
					inDTO.setAskAmt(askAmt);
					inDTO.setBrcvAmtLeasfeeRamt(bndVO.brcvAmtLeasfeeRamt);
					inDTO.setExecGuarAmtRamt(bndVO.guarAmt);
					inDTO.setAskPamt(bndVO.askPamt);
					inDTO.setAskInt(bndVO.askInt);
					inDTO.setAskTrtFee(bndVO.askTrtFee);
					inDTO.setAskPpayInt(bndVO.askPpayInt);
					inDTO.setAskAddCartax(bndVO.askAddCartax);
					inDTO.setAskAddEnvImprBrdnamt(bndVO.askAddEnvImprBrdnamt);
					inDTO.setAskAddInsuFee(bndVO.askAddInsuFee);
					inDTO.setAskAddAsfee(bndVO.askAddAsfee);
					inDTO.setAskVtax(bndVO.askVtax);
					inDTO.setAskIpayCartax(bndVO.askIpayCartax);
					inDTO.setAskIpayEnvImprBrdnamt(bndVO.askIpayEnvImprBrdnamt);
					inDTO.setAskIpayInsuFee(bndVO.askIpayInsuFee);
					inDTO.setAskIpayPnltAmt(bndVO.askIpayPnltAmt);
					inDTO.setAskIpayEtc(bndVO.askIpayEtc);
					inDTO.setAskLtrmBrcvAmt(bndVO.askLtrmBrcvAmt);
					inDTO.setAskDfee(bndVO.askDfee);
					inDTO.setAskLeglActnCost(bndVO.leglActnCostRamt);
					inDTO.setAskNormAmt(bndVO.normAmt);
					inDTO.setAskNormPamt(bndVO.normPamt);
					inDTO.setAskNormInt(bndVO.normInt);
					inDTO.setAskNormTrtFee(bndVO.normTrtFee);
					inDTO.setAskNormPpayIntRamt(bndVO.normPpayInt);
					inDTO.setAskNormAddCartax(bndVO.normAddCartax);
					inDTO.setAskNormAddEnvImprBrdnamt(bndVO.normAddEnvImprBrdnamt);
					inDTO.setAskNormAddInsuFee(bndVO.normAddInsuFee);
					inDTO.setAskNormAddAsfee(bndVO.normAddAsfee);
					inDTO.setAskNormVtax(bndVO.normVtax);
					inDTO.setAskNormIpayCartax(bndVO.normIpayCartax);
					inDTO.setAskNormIpayEnvImprBrdnamt(bndVO.normIpayEnvImprBrdnamt);
					inDTO.setAskNormIpayInsuFee(bndVO.normIpayInsuFee);
					inDTO.setAskNormIpayPnltAmt(bndVO.normIpayPnltAmt);
					inDTO.setAskNormIpayEtc(bndVO.normIpayEtc);
					inDTO.setAskNormLtrmBrcvAmt(bndVO.normLtrmBrcvAmt);
                    inDTO.setAskDlyAmt(bndVO.dlyAmt);
					inDTO.setAskDlyPamt(bndVO.dlyPamt);
					inDTO.setAskDlyInt(bndVO.dlyInt);
					inDTO.setAskDlyTrtFee(bndVO.dlyTrtFee);
					inDTO.setAskDlyPpayInt(bndVO.dlyPpayInt);
					inDTO.setAskDlyAddCartax(bndVO.dlyAddCartax);
					inDTO.setAskDlyAddEnvImprBrdnamt(bndVO.dlyAddEnvImprBrdnamt);
					inDTO.setAskDlyAddInsuFee(bndVO.dlyAddInsuFee);
					inDTO.setAskDlyAddAsfee(bndVO.dlyAddAsfee);
					inDTO.setAskDlyVtax(bndVO.dlyVtax);
					inDTO.setAskDlyIpayCartax(bndVO.dlyIpayCartax);
					inDTO.setAskDlyIpayEnvImprBrdnamt(bndVO.dlyIpayEnvImprBrdnamt);
					inDTO.setAskDlyIpayInsuFee(bndVO.dlyIpayInsuFee);
					inDTO.setAskDlyIpayPnltAmt(bndVO.dlyIpayPnltAmt);
					inDTO.setAskDlyIpayEtc(bndVO.dlyIpayEtc);
					inDTO.setAskDlyLtrmBrcvAmt(bndVO.dlyLtrmBrcvAmt);
					inDTO.setAskDlyDfee(bndVO.dfee);

				}	//end of if 정상회차 or 연체회차

				inDTO.setDlyDdcnt(bndVO.dlyDdcnt);
				inDTO.setDlyTcnt(bndVO.dlyTcnt);
				inDTO.setSetlAmt(0);
				inDTO.setSetlNo(0);
				inDTO.setOamtErrCd(" ");
				inDTO.setBndStatCd(autoTranAskObj.getBndStatCd());
				inDTO.setLoanStatCd(autoTranAskObj.getLoanStatCd());
				inDTO.setAutoTranIntgFg(autoTranAskObj.getAutoTranIntgFg());
				inDTO.setIntgLoanNo(autoTranAskObj.getLoanNo());
				inDTO.setRlDueManNo(autoTranAskObj.getRlDueManNo());
				inDTO.setFrstRegEmpNo(jobVO.isrtEmpNo);
				inDTO.setLastProcEmpNo(jobVO.isrtEmpNo);
				inDTO.setTotTims(bndVO.totTims);
				inDTO.setEprtAskMethCd(autoTranAskObj.getEprtAskMethCd());
				inDTO.setRcptDsrcRamt(autoTranAskObj.getAskExDamt());
				inDTO.setStmpFeeRamt(bndVO.stmpFeeRamt);

				autoTranAskMapper.createAutoTranTrDesc(inDTO);
				regCnt++;
			}
			log.info("등록 : "+regCnt+" / 제외 : "+skipCnt);
			return skipCnt;


		} catch (Exception e) {

			log.error(e.getMessage(), e);
			log.info("■■■■■ 에러 대출번호 = "+errLoanNum);
			throw new BizException(e.getMessage(), e);

		} finally {

		}

	}


	/**
	 * <p>메소드명 	: updateJobPlanBase			                </p>
	 * <p>설명     	: 작업계획기본테이블에 작업완료된 대출번호를 update한다. 	</p>
	 * <p>메소드인수1	: AttrJobVO	                    	</p>
	 * <p>메소드리턴값  : int 								</p>
	 * <p>예외처리  	: Exception							</p>
	 */
	@Override
	public int updateJobPlanBase(int addNo, String loanNo, AttrJobVO inVO) throws Exception {

		int updateCnt = 0;
		try {
			AttrJobDTO inDTO = new AttrJobDTO();
			// set
			inDTO.loanNo    = loanNo;
			inDTO.addNo     = addNo;
			inDTO.procDt    = inVO.procDt;
			inDTO.procTm    = inVO.procTm;
			inDTO.isrtEmpNo = inVO.isrtEmpNo;
			// where
			inDTO.jobDt     = inVO.jobDt;
			inDTO.jobId     = inVO.jobId;
			inDTO.snum      = inVO.snum;

			updateCnt = autoTranAskMapper.updateJobPlanBase(inDTO);

		}catch (Exception e) {
			throw new BizException("작업시작 대출번호 변경실패(" + e.getMessage() +")", e);
		}

		return updateCnt;
	}


}
