package hanalife.r.at.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.ProcObj;
import hanalife.r.at.dl.mapper.AutoTranIamtMapper;
import hanalife.r.at.dl.mapper.dto.AutoTranIamtInDTO;
import hanalife.r.at.dl.mapper.dto.AutoTranIamtOutDTO;
import hanalife.r.at.dl.service.AutoTranIamtService;
import hanalife.r.at.dl.vo.AutoTranIamtOutVO;
import hanalife.r.at.vo.bat.AutoTranIamtObj;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;

@Service("AutoTranIamtService")
public class AutoTranIamtServiceImpl implements AutoTranIamtService{

	private static final Logger log = LoggerFactory.getLogger(AutoTranIamtServiceImpl.class);

	@Autowired
	private AutoTranIamtMapper autoTranIamtMapper;

	@Override
	public List<AutoTranIamtOutVO> chkIamtCond(ProcObj inVO) throws Exception {

		List<AutoTranIamtOutVO> list = new ArrayList<AutoTranIamtOutVO>();
		List<AutoTranIamtOutDTO> dtoList = new ArrayList<AutoTranIamtOutDTO>();

		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setJobDt(inVO.getJobDt());
			inDTO.setJobId(inVO.getJobId());

			dtoList = autoTranIamtMapper.chkIamtCond(inDTO);

			if(dtoList != null) {
				for(AutoTranIamtOutDTO rs : dtoList) {
					AutoTranIamtOutVO result = new AutoTranIamtOutVO();
					result.setRlDueDt(rs.getRlDueDt());
					result.setTrOrgCd(rs.getTrOrgCd());
					result.setAskCnt(rs.getAskCnt());
					result.setIamtCnt(rs.getIamtCnt());
					result.setRecvCnt(rs.getRecvCnt());
					result.setTotPlanCnt(rs.getTotPlanCnt());
					result.setPlanErrStatCnt(rs.getPlanErrStatCnt());
					result.setJobCnt(rs.getJobCnt());

					list.add(result);
				}
			}

		} catch (Exception e) {
			throw new BizException("청구작업 사전조건 체크 실패(" + e.getMessage() + ")", e);
		}

		return list;
	}

	@Override
	public ProcObj searchJobPlan(ProcObj inVO) throws Exception {
		log.info("searchJobPlan start");
		try {

			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setJobDt(inVO.getJobDt());
			inDTO.setJobId(inVO.getJobId());       /** "RATDL04" */
			inDTO.setJobSnum(inVO.getJobSnum());
			inDTO.setJobStatCd1("1");              /** 작업상태코드(준비-1) */
			inDTO.setJobStatCd2("2");              /** 작업상태코드(작업중-2) */
			inDTO.setAskStatCd("9");               /** 청구구분코드(R00027) : 9-입금 */
			inDTO.setProcStatCd1("0");             /** 처리상태코드(R00025) : 0	대기 */
			inDTO.setProcStatCd2("1");             /** 처리상태코드(R00025) : 1	작업중 */

			AutoTranIamtOutDTO outDTO = autoTranIamtMapper.searchJobPlan(inDTO);

			if(outDTO != null) {
				inVO.setStrtLoanNo(outDTO.getStrtLoanNo());
				inVO.setEndLoanNo(outDTO.getEndLoanNo());
			}else {
				log.info("자동이체입금처리 대상이 없습니다. ( " + inVO.getJobDt() + ", " + inVO.getJobId() + ", " + inVO.getJobSnum() + " )");
			}

		} catch (Exception e) {
			throw new BizException("자동이체입금처리 대상조회 실패(" + e.getMessage() + ")", e);
		}

		return inVO;
	}

	@Override
	public List<AutoTranIamtObj> searchAutoTranIamtObj(ProcObj inVO) throws Exception {

		List<AutoTranIamtObj> rtnList = new ArrayList<AutoTranIamtObj>();
		List<AutoTranIamtOutDTO> outList = new ArrayList<AutoTranIamtOutDTO>();
		
		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setJobDt(inVO.getJobDt());
			inDTO.setStrtLoanNo(inVO.getStrtLoanNo());
			inDTO.setEndLoanNo(inVO.getEndLoanNo());

			outList = autoTranIamtMapper.searchAutoTranIamtObj(inDTO);

			for(AutoTranIamtOutDTO rs : outList) {
				AutoTranIamtObj result = new AutoTranIamtObj();
				
				result.setLoanNo(rs.getLoanNo());
				result.setLoanSeq(rs.getLoanSeq());
				result.setSetlNo(rs.getSetlNo());
				result.setOccrAcctUnitCd(rs.getAcctUnitCd());
				result.setAcctDt(rs.getAcctDt());
				result.setSetlDt(rs.getSetlDt());
				result.setSetlDivCd(rs.getSetlDivCd());
				result.setBankCd(rs.getMoBankCd());
				result.setAcntNo(rs.getMoAcntNo());
				result.setSetlAmt(rs.getSetlAmt());
				result.setRcptAmt(rs.getRcptAmt());
				result.setCashAmt(rs.getCashAmt());
				result.setRcptTpCd(rs.getRcptTpCd());

				rtnList.add(result);
			}

		} catch (Exception e) {
			throw new BizException("자동이체입금 대상을 조회 실패(" + e.getMessage() + ")", e);
		}

		return rtnList;
	}

	@Override
	public int updateJobPlan(String jobStatCd, ProcObj procObj) throws Exception {

		int objCnt = 0;

		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setJobStatCd(jobStatCd);
			inDTO.setIsrtEmpNo(procObj.getIsrtEmpNo());
			inDTO.setJobDt(procObj.getJobDt());
			inDTO.setJobId(procObj.getJobId());
			inDTO.setJobSnum(procObj.getJobSnum());

			objCnt = autoTranIamtMapper.updateJobPlan(inDTO);

		} catch (Exception e) {
			throw new BizException("작업계획기본에 작업대상(대출)에 대한 작업상태를 수정 실패(" + e.getMessage() + ")", e);
		}

		return objCnt;
	}

	@Override
	public int updateAutoTranPlanBase(ProcObj procObj) throws Exception {

		int objCnt = 0;

		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setProcStatCd("1");
			inDTO.setIsrtEmpNo(procObj.getIsrtEmpNo());
			inDTO.setJobDt(procObj.getJobDt());
			inDTO.setAskStatCd("9");
			inDTO.setProcStatCd1("0");
			inDTO.setProcStatCd2("1");

			objCnt = autoTranIamtMapper.updateJobPlan(inDTO);

		} catch (Exception e) {
			throw new BizException("작업계획기본에 작업대상(대출)에 대한 작업상태를 수정 실패(" + e.getMessage() + ")", e);
		}

		return objCnt;
	}

	@Override
	public int updateAutoTranTrDesc(List iamtUnrcvVOList, ProcObj procObj) throws Exception {

		try {
			if(iamtUnrcvVOList.size() < 1) {
				throw new BizException("입금처리후 결제번호를 업데이트시 입금미수대상 리스트가 입력되지 않았습니다.");
			}

			for (int idx = 0, i = 1, n = iamtUnrcvVOList.size(); idx < n; idx++, i = 1) {
				IamtUnrcvObjVO iamtUnrcvObjVO = (IamtUnrcvObjVO) iamtUnrcvVOList.get(idx);

				AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

				inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);        //입금미수.대상.결제_번호
				inDTO.setProcDt(procObj.getProcDt());
				inDTO.setProcTm(procObj.getProcTm());
				inDTO.setIsrtEmpNo(procObj.getIsrtEmpNo());

				inDTO.setJobDt(procObj.getJobDt());
				inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);        //입금미수.대상.대출_번호

				autoTranIamtMapper.updateAutoTranTrDesc(inDTO);
			}

			return iamtUnrcvVOList.size();

		} catch (Exception e) {
			throw new BizException("자동이체 입금처리 결제번호 업데이트 실패(" + e.getMessage() + ")", e);
		} finally {

		}

	}

	@Override
	public int updateJobPlanBase(int addNo, String loanNo, ProcObj procObj) throws Exception {

		int updateCnt = 0;

		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			//set
			inDTO.setLoanNo(loanNo);
			inDTO.setAddNo(addNo);
			inDTO.setProcDt(procObj.getProcDt());
			inDTO.setProcTm(procObj.getProcTm());
			inDTO.setIsrtEmpNo(procObj.getIsrtEmpNo());
			// where
			inDTO.setJobDt(procObj.getJobDt());
			inDTO.setJobId(procObj.getJobId());
			inDTO.setJobSnum(procObj.getJobSnum());

			updateCnt = autoTranIamtMapper.updateJobPlanBase(inDTO);

			return updateCnt;

		}catch (Exception e) {
			throw new BizException("자동이체 입금처리 시작대출번호 업데이트 실패(" + e.getMessage() +")",e);
		} finally {

		}
	}

	@Override
	public int updateJobPlanProcStat(ProcObj procObj) throws Exception {
		int updateCnt = 0;

		try {
			AutoTranIamtInDTO inDTO = new AutoTranIamtInDTO();

			inDTO.setProcStatCd("2");
			inDTO.setProcDt(procObj.getProcDt());
			inDTO.setProcTm(procObj.getProcTm());
			inDTO.setIsrtEmpNo(procObj.getIsrtEmpNo());
			inDTO.setJobDt(procObj.getJobDt());
			inDTO.setJobId(procObj.getJobId());

			updateCnt = autoTranIamtMapper.updateJobPlanBase(inDTO);

			return updateCnt;

		} catch (Exception e) {
			throw new BizException("작업계획기본테이블에 작업완료된 대출번호를 update 실패(" + e.getMessage() + ")", e);
		}
	}
}
