package hanalife.r.at.dl.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.DbsBatchException;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.ad.service.AutoTranCmsService;
import hanalife.r.at.dl.service.RATDL0403Service;
import hanalife.r.at.dl.vo.RATDLInDTO;
import hanalife.r.at.dl.vo.RATDLOutDTO;
import hanalife.r.at.vo.bat.AttrOrgVO;
import hanalife.r.co.vo.service.VochCCService;
import hanalife.r.co.vo.vo.ClsTrDescVO;
import hanalife.r.co.vo.vo.VochVO;
import hanalife.util.BizException;
import hanalife.util.IamtUtil;

@Service("RATDL0403Service")
public class RATDL0403ServiceImpl implements RATDL0403Service{

	private static final Logger log = LoggerFactory.getLogger(RATDL0403ServiceImpl.class);

	@Autowired
    private CommBizService commBiz;

	@Autowired
    private AutoTranCmsService autoTranCms;

	@Autowired
    private VochCCService VochCC;

    private static MsgEnum msgEnum;

    private String jobId; //작업ID
    private String jobDt;
    private static String feeDt  = "";
    private static String rcptTp = "";

    @Override
    public RATDLOutDTO getRATDL0403(RATDLInDTO reqInVO) throws Exception {

        RATDLOutDTO rtnDTO = new RATDLOutDTO();
        rtnDTO.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        rtnDTO.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        jobId = reqInVO.getJobId(); //작업ID
        jobDt = reqInVO.getJobDt();
        rcptTp =  reqInVO.getRcptTp();

        if (!commBiz.isWorkDt(jobDt)) {
            throw new BizException(jobDt + " 영업일이 아닙니다.");
        }

        feeDt = commBiz.addWkdt(jobDt, 1); // (EC21 당일입금이지만 미수금정산, 수수료전표는 익영업일로 처리함)

        try {

            log.info("■ 1. rcptTp : "+rcptTp+" 자동이체 기관정보 조회");
            AttrOrgVO param = new AttrOrgVO();
            param.jobDt    = jobDt;
            param.rcptTpCd = rcptTp;

            List<AttrOrgVO> list = autoTranCms.searchTrOrgList(param);

            log.info("■ 2. 자동이체기관("+list.size()+"건) 자동이체 미수금 정산처리 시작 ==========");
            for (int i=0; i<list.size(); i++) {
                AttrOrgVO orgVO = list.get(i);
                orgVO.empNo = jobId;

                log.info("■ 2-1) "+orgVO.trOrgCd+"("+orgVO.trOrgNm+"), RECV_DT : "+orgVO.jobDt+" 자동이체 수납완료 체크");
                String attrStat = autoTranCms.searchAttrPlanStat(orgVO);
                if (!StringUtil.like(attrStat, "9%")) {
                    throw new DbsBatchException("■ 자동이체 입금작업이 완료되지 않았습니다. 자동이체계획상태 : "+attrStat);
                }

                log.info("■ 2-2) "+orgVO.trOrgCd+"("+orgVO.trOrgNm+") 자동이체미수금 정산처리 시작 ==========");
                this.adjAttrUnrcvAmt(orgVO);

                // TODO 커밋가능여부확인
                // QUtil.commit(con);
            }

        } catch (Exception e) {
            /// TODO 에러시 자동롤백
            //QUtil.rollback(con);
            log.error(e.getMessage());
            throw e;
        }

        return rtnDTO;
    }

    /**
     * <p>메소드명  : adjAttrUnrcvAmt</p>
     * <p>설　　명  : 자동이체미수금 정산 전표처리</p>
     * <p>메소드인수 : AttrOrgVO</p>
     * <p>리　턴　값 : N/A</p>
     */
    private void adjAttrUnrcvAmt(AttrOrgVO orgVO) throws Exception {
        try {
            List<ClsTrDescVO> outList = autoTranCms.searchAttrUnrcvList(orgVO);
            log.info("■ 자동이체 수납 건 조회 : "+outList.size()+"건");

            VochVO vochVO = null;
            String acctDt = feeDt;
            String isrtDeptCd = orgVO.deptCd;   log.info(isrtDeptCd);
            String procEmpNo  = orgVO.empNo;

            int subCnt = 0;
            //for (int i=0; i<outList.size(); i++) {
            for (ClsTrDescVO sourceIO : outList) {
                if (vochVO==null) {
                    vochVO = new VochVO();
                }

                ClsTrDescVO trDescVO = new ClsTrDescVO();
                    trDescVO.setIsrtDt  (DateUtil.getCurrentDateString());       //입력_일자
                    trDescVO.setAcctDt  (acctDt);                   //회계_일자
                    trDescVO.setTrTpCd  ("R0021");                  //거래_유형_코드(자동이체미수금정산)
                    trDescVO.setTrStagCd(("W01".equals(orgVO.acctUnitCd))?"020":"120");

                    trDescVO.setLoanNo  (sourceIO.getLoanNo());             //대출_번호
                    trDescVO.setLoanSeq (sourceIO.getLoanSeq());            //대출_순번
                    trDescVO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());      //상품_대분류_코드
                    trDescVO.setPrdtMidClasCd (sourceIO.getPrdtMidClasCd());      //상품_중분류_코드
                    trDescVO.setAcctUnitCd    (orgVO.acctUnitCd);   //회계_단위_코드(필수)
                    trDescVO.setOccrDeptCd    (isrtDeptCd);         //발생_부서_코드
                    trDescVO.setMngDeptCd     (sourceIO.getMngDeptCd());    //관리_부서_코드  (필수, 자동결제여부가 아닐때)
                    trDescVO.setBankCd        (sourceIO.getMoBankCd());     //모계좌은행
                    trDescVO.setAcntNo        (sourceIO.getMoAcntNo());     //모계좌번호
                    trDescVO.setTrDescRmk     ("자동이체 미수금정산");
                    // 금액
                    trDescVO.setSetlAmt       (sourceIO.getSetlAmt());
                vochVO.addClsTrDesc(trDescVO);

                autoTranCms.updateUnrcvAdjFg(orgVO, sourceIO);
                subCnt++;

                // 전표처리대상이 있을때 500건마다 전표처리
                if (subCnt==500 && vochVO != null) {
                    vochVO.setAcctDt    (acctDt);
                    vochVO.setAutoClsFg (Constants.YES);
                    vochVO.setIsrtDeptCd(isrtDeptCd);
                    vochVO.setIsrtEmpNo (procEmpNo);

                    try {
                        vochVO = VochCC.procVochWithAcctUnit(vochVO);
                        if (!IamtUtil.equals(Constants.SUCCESS, vochVO.getRsltCd())) {
                            throw new BizException("[자동전표에러]"+ vochVO.getRsltCntn());
                        }
                    } catch (Exception e) {
                        log.error(e.getMessage(), e);
                        throw new BizException("[자동전표에러]" + e.getMessage());
                    }
                    vochVO = null;
                    subCnt = 0;
                }
            }

            // 500건 씩 처리 후 나머지 건 전표처리
            if (subCnt>0 && vochVO != null) {
                vochVO.setAcctDt    (acctDt);
                vochVO.setAutoClsFg (Constants.YES);
                vochVO.setIsrtDeptCd(isrtDeptCd);
                vochVO.setIsrtEmpNo (procEmpNo);

                try {
                    vochVO = VochCC.procVochWithAcctUnit(vochVO);
                    if (!IamtUtil.equals(Constants.SUCCESS, vochVO.getRsltCd())) {
                        throw new BizException("[자동전표에러]"+ vochVO.getRsltCntn());
                    }
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                    throw new BizException("[자동전표에러]" + e.getMessage());
                }
            }
            // TODO 커밋가능여부확인
            // QUtil.commit(con);

        } catch (Exception e) {
            //QUtil.rollback(con);
            log.error(e.getMessage(), e);
            throw e;
        }
    }
}
