package hanalife.r.at.dl.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.dto.RtAutoTranPlanBaseDTO;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.ad.mapper.AutoTranCmsMapper;
import hanalife.r.at.ad.mapper.dto.SearchAutoTranTotDescOutDTO;
import hanalife.r.at.ad.mapper.dto.SelectAutoTranPlanBaseOutDTO;
import hanalife.r.at.ad.service.AutoTranCmsService;
import hanalife.r.at.dl.service.RATDL0501Service;
import hanalife.r.at.dl.vo.RATDL0501VO;
import hanalife.r.at.dl.vo.RATDLInDTO;
import hanalife.r.at.dl.vo.RATDLOutDTO;
import hanalife.r.at.vo.bat.AttrOrgVO;
import hanalife.r.co.vo.service.VochCCService;
import hanalife.r.co.vo.vo.ClsTrDescVO;
import hanalife.r.co.vo.vo.VochVO;
import hanalife.util.BizException;
import hanalife.util.IamtUtil;

@Service("RATDL0501Service")
public class RATDL0501ServiceImpl implements RATDL0501Service{

	private static final Logger log = LoggerFactory.getLogger(RATDL0501ServiceImpl.class);

    @Autowired
    private CommBizService commBiz;

    @Autowired
    private AutoTranCmsService AutoTranCmsService;

    @Autowired
    private AutoTranCmsMapper autoTranCmsMapper;

    @Autowired
    private VochCCService VochCC;

    private static MsgEnum msgEnum;

    private String jobId; //작업ID
    private String jobDt;
    private static String rcptTp = "";

    @Override
    public RATDLOutDTO getRATDL0501(RATDLInDTO reqInVO) throws Exception {

        RATDLOutDTO rtnDTO = new RATDLOutDTO();
        rtnDTO.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        rtnDTO.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        jobId = reqInVO.getJobId(); //작업ID
        jobDt = reqInVO.getJobDt();

        if (!commBiz.isWorkDt(jobDt)) {
            throw new BizException(jobDt + " 영업일이 아닙니다.");
        }

        try {
            AttrOrgVO param = new AttrOrgVO();
                param.rcptTpCd = rcptTp;
                List<AttrOrgVO> list = AutoTranCmsService.searchTrOrgList(param);

                for (int i=0; i<list.size(); i++) {
                AttrOrgVO orgVO = list.get(i);
                orgVO.empNo = jobId;

                RATDL0501VO feeVO = new RATDL0501VO();
                    feeVO.trOrgCd = orgVO.trOrgCd;
                    feeVO.recvDt  = jobDt;
                    feeVO.acctDt  = commBiz.addWkdt(jobDt, StringUtil.parseInt(orgVO.feeSchdDd)); // Kcar (EC21 당일입금이지만 수수료전표는 익영업일로 처리함)

                log.info("■ 1. "+orgVO.trOrgCd+"("+orgVO.trOrgNm+") 청구 건수 체크");
                int askCnt = this.selectAskCntChk(feeVO.trOrgCd, feeVO.recvDt);
                if (askCnt==0) {
                    log.warn("자동이체 청구 건이 없습니다. ( jobDt : " + jobDt + ") ");
                    continue;
                }

                log.info("■ 2. "+orgVO.trOrgCd+"("+orgVO.trOrgNm+") 자동이체수수료 전표처리 시작 ==========");
                this.procAttrFee(orgVO, feeVO);
                if (!feeVO.rsltCd.equals("00")) {
                    throw new Exception(feeVO.rsltCntn);
                }
                // TODO 커밋가능여부확인
                // QUtil.commit(con);
            }
        } catch (Exception e) {
            log.error(e.getMessage());
            throw e;
        }

        return rtnDTO;

    }

    /**
     * <p>메소드명  : procAttrFee
     * <p>설    명    : CMS 청구 수수료 작업 유효성 체크 및 전표 처리
     * <p>메소드인수 : ProcObj, RATDL0501VO
     * <p>리 턴 값 : RATDL0501VO
     */
    private RATDL0501VO procAttrFee(AttrOrgVO orgVO, RATDL0501VO feeVO) throws Exception {

        try {
            log.info("■ 수수료 전표 발생여부 확인");
            procAutoJobChk(feeVO);
            if (!StringUtil.isNullT(feeVO.vochDt)) {
                feeVO.rsltCd   = "99";
                feeVO.rsltCntn = feeVO.trOrgCd+") 수수료전표가 이미 발생하였습니다.[RECV_DT : " +feeVO.recvDt + ", 회계일자 : " + feeVO.vochDt + "]";
                return feeVO;
            }

            log.info("■ 수수료 처리 대상 확인");
            if (feeVO.totCnt==0) {
                feeVO.rsltCd   = "00";
                log.info(feeVO.trOrgCd+") 수수료 전표처리 대상건이 없습니다. 수납일자[" + feeVO.recvDt + "]");
                return feeVO;
            } else if (feeVO.procCnt != feeVO.totCnt) {
                feeVO.rsltCd   = "99";
                feeVO.rsltCntn = feeVO.trOrgCd+") 자동이체 수납 미완료. 수납여부 ["+feeVO.totCnt+"], 대상건수["+feeVO.procCnt+"]";
                return feeVO;
            }

            log.info("■ 자동이체 수수료 전표 처리");
            procAutoTranFeeVoch(orgVO, feeVO);

            log.info("■ 자동이체 수수료 전표처리 결과반영");
            int cnt = updateFeeAcctDt(feeVO);
            if (cnt<1) {
                log.error("자동이체 수수료 전표처리 결과반영 오류.");
                feeVO.rsltCd   = "99";
                feeVO.rsltCntn = "자동이체 수수료 전표처리 결과반영 오류.";
                return feeVO;
            }
            log.info("■ UPDATE_CNT = "+cnt+" 건");
            // TODO 커밋가능여부확인
            // QUtil.commit(con);

        } catch (Exception e) {
            // QUtil.rollback(con);
            log.error(e.getMessage(), e);
            throw e;
        }
        return feeVO;
    }

    /**
     * <p>메소드명  : procAutoJobChk
     * <p>설    명    : CMS 수수료 전표처리 대상 유무 확인
     * <p>메소드인수 : RATDL0501VO
     * <p>리 턴 값 : N/A
     */
    private RATDL0501VO procAutoJobChk(RATDL0501VO feeVO) throws Exception {

        try {

            RtAutoTranPlanBaseDTO inDTO = new RtAutoTranPlanBaseDTO();
            inDTO.setRecvDt(feeVO.recvDt);
            inDTO.setTrOrgCd(feeVO.trOrgCd);

            SelectAutoTranPlanBaseOutDTO outDTO = autoTranCmsMapper.selectAutoTranPlanBase(inDTO);

            if(outDTO != null) {

                feeVO.totCnt  = outDTO.getTotCnt();     //총건수
                feeVO.procCnt = outDTO.getProcCnt();    //처리건수
                feeVO.vochDt  = outDTO.getFeeAcctDt();  //수수료_회계일자
            }

        } catch (Exception e) {
            throw new Exception("전표처리 유무 조회 [" + e.getMessage() + "]");
        }

        return feeVO;
    }

    /**
     * <p>메소드명  : procAutoTranFeeVoch
     * <p>설    명    : CMS 청구 수수료 전표처리
     * <p>메소드인수 : ProcObj, RATDL0501VO
     * <p>리 턴 값 : N/A
     */
    private void procAutoTranFeeVoch(AttrOrgVO orgVO, RATDL0501VO feeVO) throws Exception {

        int cnt = 0;
        try {
            //자동이체수수료 전표처리 대상을 조회한다.
            RtAutoTranPlanBaseDTO inDTO = new RtAutoTranPlanBaseDTO();
            inDTO.setAcctDt(feeVO.recvDt);
            inDTO.setTrOrgCd(feeVO.trOrgCd);

            List<SearchAutoTranTotDescOutDTO> outList = autoTranCmsMapper.searchAutoTranTotDesc(inDTO);

            for (SearchAutoTranTotDescOutDTO sourceIO : outList) {

                cnt++;
                String acctUnit = sourceIO.getAcctUnitCd();     // 회계단위
                String mngDept  = sourceIO.getMngDeptCd();      // 관리부서
                String bankCd   = sourceIO.getBankCd();         // 은행코드
                String acntNo   = sourceIO.getAcntNo();         // 계좌번호
                long   attrFee  = sourceIO.getAutoTranFee();    // 자동이체수수료
                String vochRmk  = sourceIO.getTrDescRmk();      // 적요

                ClsTrDescVO trDescVO = new ClsTrDescVO();
                    trDescVO.setAcctDt   (feeVO.acctDt);    //회계_일자
                    trDescVO.setIsrtDt   (feeVO.recvDt);    //입력_일자
                    trDescVO.setTrTpCd   ("R0120");         //거래_유형_코드
                if ("W01".equals(acctUnit)) {
                    trDescVO.setTrStagCd ("020");
                } else {
                    trDescVO.setTrStagCd ("120");
                }
                    trDescVO.setAcctUnitCd   (acctUnit);    //발생회계단위
                    trDescVO.setMngAcctUnitCd(acctUnit);    //관리회계단위
                    trDescVO.setOccrDeptCd   (orgVO.deptCd);//발생부서
                    trDescVO.setMngDeptCd    (mngDept);     //관리부서
                    trDescVO.setBankCd       (bankCd);      //은행코드
                    trDescVO.setAcntNo       (acntNo);      //계좌번호
                    trDescVO.setEtcFee       (attrFee);     //자동이체수수료
                    trDescVO.setTrDescRmk    (vochRmk);     //적요

                VochVO vochVO = new VochVO();
                    vochVO.setAcctDt     (feeVO.acctDt);
                    vochVO.setAutoClsFg  ("1");
                    vochVO.setIsrtDeptCd (orgVO.deptCd);
                    vochVO.setIsrtEmpNo  (orgVO.empNo);
                    vochVO.addClsTrDesc  (trDescVO);

                vochVO = VochCC.procVochWithAcctUnit(vochVO);
                if (!IamtUtil.equals(Constants.SUCCESS, vochVO.getRsltCd())) {
                    throw new BizException("[자동전표에러]"+ vochVO.getRsltCntn());
                }
                log.info("전표처리 내역번호[" + vochVO.getTrDescNo()+"]");
            }
            log.info("■ 전표처리 건수 = "+cnt);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new BizException("[자동전표에러]" + e.getMessage());
        }
    }

    /**
     * <p>메소드명  : updateFeeAcctDt
     * <p>설    명    : CMS 청구 수수료 전표처리 결과 반영
     * <p>메소드인수 : RATDL0501VO
     * <p>리 턴 값 : UPDATE CNT
     */
    public int updateFeeAcctDt(RATDL0501VO feeVO) throws Exception {
        int exeCnt = 0;

        try {
            RtAutoTranPlanBaseDTO inDTO = new RtAutoTranPlanBaseDTO();

            inDTO.setFeeAcctDt(feeVO.acctDt);
            inDTO.setAcctDt(feeVO.recvDt);
            inDTO.setTrOrgCd(feeVO.trOrgCd);

            exeCnt = autoTranCmsMapper.updateFeeAcctDt(inDTO);

        } catch (Exception se) {
            throw new BizException("CMS 청구 수수료 전표처리 결과 반영 오류", se);
        }

        return exeCnt;
    }

    /**
     * <p>메소드명  : selectAskCntChk
     * <p>설    명    : CMS 요청건수 조회
     * <p>메소드인수 : trOrgCd, recvDt
     * <p>리 턴 값 : int
     */
    private int selectAskCntChk(String trOrgCd, String recvDt) throws Exception {

        int iCnt = 0;

        try {

            RtAutoTranPlanBaseDTO inDTO = new RtAutoTranPlanBaseDTO();
            inDTO.setRecvDt(recvDt);
            inDTO.setTrOrgCd(trOrgCd);

            iCnt = autoTranCmsMapper.selectAskCnt(inDTO);

        } catch (Exception e) {
            throw new Exception("전표처리 유무 조회 [" + e.getMessage() + "]");
        }

        return iCnt;
    }

}
