package hanalife.r.at.mn.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.at.mn.mapper.AutoTranAcntApplReadMapper;
import hanalife.r.at.mn.mapper.dto.AutoTranAcntApplReadDSSD01DTO;
import hanalife.r.at.mn.mapper.dto.AutoTranAcntApplReadDSSEARCHDTO;
import hanalife.r.at.mn.service.RATMNM02Service;
import hanalife.r.at.mn.vo.RATMNM02DSSD01VO;
import hanalife.r.at.mn.vo.RATMNM02S01InVO;
import hanalife.r.at.mn.vo.RATMNM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM02ServiceImpl.java Class
 * 클래스설명   : 자동이체계좌신청조회 (RATMNM02) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRATMNM02S01 : 자동이체계좌신청조회목록조회

 * </pre>
 */
@Service("RATMNM02Service")
public class RATMNM02ServiceImpl implements RATMNM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM02ServiceImpl.class);

	@Autowired
	private AutoTranAcntApplReadMapper autoTranAcntApplRead;

	/**
	 * <p>메소드명      : getRATMNM02S01 : 자동이체계좌신청조회</p>
	 * <p>작성일자      : 2023. 3. 7.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 자동이체계좌신청조회 한다.</p>
	 * <p>메소드인수    : RATMNM02S01InVo </p>
	 * <p>메소드리턴값  : RATMNM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RATMNM02S01OutVO getRATMNM02S01(RATMNM02S01InVO inVo) throws Exception {

		RATMNM02S01OutVO resultVo = new RATMNM02S01OutVO();

		AutoTranAcntApplReadDSSEARCHDTO inDto = new AutoTranAcntApplReadDSSEARCHDTO();

		inDto.setLoanNo(inVo.getRATMNM02DSSEARCHVO().getLoanNo()); /** 대출번호 */
		inDto.setLoanSeq(inVo.getRATMNM02DSSEARCHVO().getLoanSeq()); /** 대출순번 */
		inDto.setSendDtFr(inVo.getRATMNM02DSSEARCHVO().getSendDtFr()); /** 전송일자시작 */
		inDto.setSendDtTo(inVo.getRATMNM02DSSEARCHVO().getSendDtTo()); /** 전송일자종료 */
		inDto.setAcntNo(inVo.getRATMNM02DSSEARCHVO().getAcntNo()); /** 계좌번호 */
		inDto.setTrOrgCd(inVo.getRATMNM02DSSEARCHVO().getTrOrgCd()); /** 거래기관코드 */
		inDto.setAcntOccrCd(inVo.getRATMNM02DSSEARCHVO().getAcntOccrCd()); /** 계좌발생코드 */
		inDto.setApplDivCd(inVo.getRATMNM02DSSEARCHVO().getApplDivCd()); /** 신청구분코드 */
		inDto.setAcntStatCd(inVo.getRATMNM02DSSEARCHVO().getAcntStatCd()); /** 계좌상태코드 */
		inDto.setAcntRsltCd(inVo.getRATMNM02DSSEARCHVO().getAcntRsltCd()); /** 계좌결과코드 */
		inDto.setMngDeptCd(inVo.getRATMNM02DSSEARCHVO().getMngDeptCd()); /** 관리부서코드 */
		inDto.setMngDeptNm(inVo.getRATMNM02DSSEARCHVO().getMngDeptNm()); /** 관리부서명 */
//      LOGGER.info("#############LOAN NO ##############" + inDto.getLoanNo());
		List<AutoTranAcntApplReadDSSD01DTO> resultDTO = autoTranAcntApplRead.searchDescList(inDto);	/** 자동이체계좌신청조회리스트*/

		List<RATMNM02DSSD01VO> resultList = new ArrayList<RATMNM02DSSD01VO>();

		for (AutoTranAcntApplReadDSSD01DTO sourceIO : resultDTO) {
			RATMNM02DSSD01VO targetIO = new RATMNM02DSSD01VO();
			targetIO.setSendDt(sourceIO.getSendDt()); /** 전송일자 */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서 */
			targetIO.setTrOrgNm(sourceIO.getTrOrgNm()); /** 거래기관 */
			targetIO.setAcntOccrNm(sourceIO.getAcntOccrNm()); /** 계좌발생 */
			targetIO.setAcntApplDivNm(sourceIO.getAcntApplDivNm()); /** 신청구분 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 계좌번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 계좌순번 */
			targetIO.setCustNm(sourceIO.getCustNm()); /** 고객명 */
			targetIO.setBankNm(sourceIO.getBankNm()); /** 은행명 */
			targetIO.setAcntNo(sourceIO.getAcntNo()); /** 계좌번호 */
			targetIO.setDepoOwnNo(sourceIO.getDepoOwnNo()); /** 예금주번호 */
			targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm()); /** 예금주명 */
			targetIO.setAcntStatNm(sourceIO.getAcntStatNm()); /** 계좌상태 */
			targetIO.setAcntErrCd(sourceIO.getAcntErrCd()); /** 계좌오류코드 */
			targetIO.setAcntErrNm(sourceIO.getAcntErrNm()); /** 계좌오류명 */
			targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); /** 입력사번 */
			targetIO.setFrstRegEmpNm(sourceIO.getFrstRegEmpNm()); /** 입력자명 */

			resultList.add(targetIO);
		}

		resultVo.setRATMNM02DSSD01VO(resultList);	/** 자동이체계좌신청조회리스트 */

		return resultVo;
	}

}
