package hanalife.r.at.mn.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.at.mn.mapper.AutoTranTrReptReadMapper;
import hanalife.r.at.mn.mapper.dto.AutoTranTrReptReadDSSD01DTO;
import hanalife.r.at.mn.mapper.dto.AutoTranTrReptReadDSSEARCHBANKDTO;
import hanalife.r.at.mn.service.RATMNM04Service;
import hanalife.r.at.mn.vo.RATMNM04DSSD01VO;
import hanalife.r.at.mn.vo.RATMNM04S01InVO;
import hanalife.r.at.mn.vo.RATMNM04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM04ServiceImpl.java Class
 * 클래스설명   : 자동이체거래현황 (RATMNM04) Service Implements
 * 작성일자     : 2023. 3. 15.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 15.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRATMNM04S01 : 자동이체거래현황목록조회
 * </pre>
 */
@Service("RATMNM04Service")
public class RATMNM04ServiceImpl implements RATMNM04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM04ServiceImpl.class);

	@Autowired
	private AutoTranTrReptReadMapper autoTranTrReptReadMapper;

	/**
	 * <p>메소드명      : getRATMNM04S01 : 자동이체거래현황목록조회</p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 자동이체거래현황목록을 조회 한다.</p>
	 * <p>메소드인수    : RATMNM04S01InVo </p>
	 * <p>메소드리턴값  : RATMNM04S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RATMNM04S01OutVO getRATMNM04S01(RATMNM04S01InVO inVo) throws Exception {

		/** 자동이체거래현황 조회 서비스 결과값 객체 생성 */
		RATMNM04S01OutVO resultVo = new RATMNM04S01OutVO();

		/** 자동이체거래현황에 대한 조회 조건 입력값 객체 생성 및 대입 수행 */
		AutoTranTrReptReadDSSEARCHBANKDTO targetDto = new AutoTranTrReptReadDSSEARCHBANKDTO();

		targetDto.setRlDueDtFr(inVo.getRATMNM04DSSEARCHVO().getRlDueDtFr()); /** 납입시작일자 */
		targetDto.setRlDueDtTo(inVo.getRATMNM04DSSEARCHVO().getRlDueDtTo()); /** 납입종료일자 */
		targetDto.setTrOrgCd(inVo.getRATMNM04DSSEARCHVO().getTrOrgCd()); /** 거래기관 */
		targetDto.setMngDeptCd(inVo.getRATMNM04DSSEARCHVO().getMngDeptCd()); /** 관리부서코드 */
		targetDto.setMngDeptNm(inVo.getRATMNM04DSSEARCHVO().getMngDeptNm()); /** 관리부서이름 */
		targetDto.setBankCd(inVo.getRATMNM04DSSEARCHVO().getBankCd()); /** 은행코드 */
		targetDto.setPrdtLrgeClasCd(inVo.getRATMNM04DSSEARCHVO().getPrdtLrgeClasCd()); /** 상품대분류코드 */
		targetDto.setPrdtMidClasCd(inVo.getRATMNM04DSSEARCHVO().getPrdtMidClasCd()); /** 상품중분류코드 */
		targetDto.setChkRlDueDt(inVo.getRATMNM04DSSEARCHVO().getChkRlDueDt()); /** 납입일자체크 */
		targetDto.setChkTrOrgCd(inVo.getRATMNM04DSSEARCHVO().getChkTrOrgCd()); /** 거래기관체크 */
		targetDto.setChkMngDeptCd(inVo.getRATMNM04DSSEARCHVO().getChkMngDeptCd()); /** 관리부서체크 */
		targetDto.setChkBankCd(inVo.getRATMNM04DSSEARCHVO().getChkBankCd()); /** 은행체크 */
		targetDto.setChkPrdtClasCd(inVo.getRATMNM04DSSEARCHVO().getChkPrdtClasCd()); /** 상품체크 */

		/** 자동이체거래현황에 대한 조회 쿼리 Mapper 호출 수행 */
		List<AutoTranTrReptReadDSSD01DTO> resultDTO = autoTranTrReptReadMapper.search(targetDto);

		/** 자동이체거래현황 조회 화면 출력을 위한 결과값 List VO 객체 생성 */
		List<RATMNM04DSSD01VO> resultList = new ArrayList<RATMNM04DSSD01VO>();

		for (AutoTranTrReptReadDSSD01DTO sourceIO : resultDTO) {
			/** 자동이체거래현황 VO에 조회된 Mapper DTO 값을 대입 */
			RATMNM04DSSD01VO targetIO = new RATMNM04DSSD01VO();

			targetIO.setRlDueDt(sourceIO.getRlDueDt()); /** 납입일자 */
			targetIO.setTrOrgNm(sourceIO.getTrOrgNm()); /** 거래기관이름 */
			targetIO.setTrOrgCd(sourceIO.getTrOrgCd()); /** 거래기관코드 */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서이름 */
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
			targetIO.setBankNm(sourceIO.getBankNm()); /** 은행이름 */
			targetIO.setBankCd(sourceIO.getBankCd()); /** 은행코드 */
			targetIO.setPrdtClasNm(sourceIO.getPrdtClasNm()); /** 상품이름 */
			targetIO.setPrdtClasCd(sourceIO.getPrdtClasCd()); /** 상품코드 */
			targetIO.setAskCnt(sourceIO.getAskCnt()); /** 청구건수 */
			targetIO.setAskAmt(sourceIO.getAskAmt()); /** 청구금액 */
			targetIO.setOamtCnt(sourceIO.getOamtCnt()); /** 결제건수 */
			targetIO.setOamtAmt(sourceIO.getOamtAmt()); /** 결제금액 */
			targetIO.setTamtOamtCnt(sourceIO.getTamtOamtCnt()); /** 전액출금건수 */
			targetIO.setTamtOamt(sourceIO.getTamtOamt()); /** 전액출금금액 */
			targetIO.setPartOamtCnt(sourceIO.getPartOamtCnt()); /** 부분출금건수 */
			targetIO.setPartOamt(sourceIO.getPartOamt()); /** 부분출금금액 */
			targetIO.setUnOamtCnt(sourceIO.getUnOamtCnt()); /** 미출금건수 */
			targetIO.setUnOamtAmt(sourceIO.getUnOamtAmt()); /** 미출금금액 */
			targetIO.setBadAcntCnt(sourceIO.getBadAcntCnt()); /** 불량계좌건수 */
			targetIO.setBadAcntAmt(sourceIO.getBadAcntAmt()); /** 불량계좌금액 */
			targetIO.setAskErrCnt(sourceIO.getAskErrCnt()); /**  */
			targetIO.setAskFee(sourceIO.getAskFee()); /**  */
			targetIO.setAskErrFee(sourceIO.getAskErrFee()); /**  */
			targetIO.setOamtFee(sourceIO.getOamtFee()); /**  */
			targetIO.setAutoFee(sourceIO.getAutoFee()); /**  */

			/** 상단의 자동이체거래현황 조회 결과 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
		}

		/** 자동이체거래현황 조회 서비스 결과값 객체에 조회 결과 List 추가 */
		resultVo.setListRATMNM04DSSD01VO(resultList);

		return resultVo;

	}

}
