package hanalife.r.at.mn.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.at.mn.mapper.AutoTranAcntStatReadMapper;
import hanalife.r.at.mn.mapper.dto.AutoTranAcntStatReadDSSD01DTO;
import hanalife.r.at.mn.mapper.dto.AutoTranAcntStatReadDSSEARCHDTO;
import hanalife.r.at.mn.service.RATMNM05Service;
import hanalife.r.at.mn.vo.RATMNM05DSSD01VO;
import hanalife.r.at.mn.vo.RATMNM05S01InVO;
import hanalife.r.at.mn.vo.RATMNM05S01OutVo;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM05ServiceImpl.java Class
 * 클래스설명   : 자동이체거래현황 (RATMNM04) Service Implements
 * 작성일자     : 2023. 4. 18.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 18.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRATMNM05S01 : 자동이체계좌상태조회
 * </pre>
 */
@Service("RATMNM05Service")
public class RATMNM05ServiceImpl implements RATMNM05Service {

    private static final Logger log = LoggerFactory.getLogger(RATMNM04ServiceImpl.class);

    @Autowired
    private AutoTranAcntStatReadMapper autoTranAcntStatReadMapper;

    /**
     * <p>메소드명      : getRATMNM05S01 : 자동이체계좌상태목록조회</p>
     * <p>작성일자      : 2023. 4. 18.
     * <p>작성자(author): 70366 / KangMinhyeok
     * <p>설명          : 자동이체계좌상태목록을 조회 한다.</p>
     * <p>메소드인수    : RATMNM05S01InVO </p>
     * <p>메소드리턴값  : RATMNM05S01OutVo</p>
     * <p>예외처리      : Exception</p>
     */

    @Override
    public RATMNM05S01OutVo getRATMNM05S01(RATMNM05S01InVO inVo)throws Exception {

        RATMNM05S01OutVo resultVo = new RATMNM05S01OutVo();

        AutoTranAcntStatReadDSSEARCHDTO targetDto  = new AutoTranAcntStatReadDSSEARCHDTO();
        targetDto.setAcntStatCd(inVo.getRATMNM05DSSEARCHVO().getAcntStatCd());     /** 계좌_상태_코드*/
        targetDto.setLoanDtFr(inVo.getRATMNM05DSSEARCHVO().getLoanDtFr());         /** 대출_전송_일자_시작*/
        targetDto.setLoanDtTo(inVo.getRATMNM05DSSEARCHVO().getLoanDtTo());        /** 대출_전송_일자_종료*/
        targetDto.setLoanNo(inVo.getRATMNM05DSSEARCHVO().getLoanNo());            /** 대출_번호 */
        targetDto.setLoanSeq(inVo.getRATMNM05DSSEARCHVO().getLoanSeq());          /** 대출_순번*/

        List<AutoTranAcntStatReadDSSD01DTO> resultDTO  = autoTranAcntStatReadMapper.searchDescList(targetDto);

        List<RATMNM05DSSD01VO> resultList = new ArrayList<>();

        log.info("serviceImpl resultDTO SIZE : " + resultDTO.size());
        for(AutoTranAcntStatReadDSSD01DTO sourceIO : resultDTO) {
            RATMNM05DSSD01VO targetIO = new RATMNM05DSSD01VO();

            targetIO.setLoanNo(sourceIO.getLoanNo());              /**대출_번호*/
            targetIO.setLoanSeq(sourceIO.getLoanSeq());            /**대출_순서*/
            targetIO.setMngDeptNm(sourceIO.getMngDeptNm());       /**부서명*/
            targetIO.setContManNo(sourceIO.getContManNo());        /**계약자_번호*/
            targetIO.setContManNm(sourceIO.getContManNm());       /**고객명*/
            targetIO.setBankCd(sourceIO.getBankCd());   /**은행_코드*/
            targetIO.setBankNm(sourceIO.getBankNm());   /**은행_이름*/
            targetIO.setAcntNo(sourceIO.getAcntNo());           /**계좌번호*/
            targetIO.setAcntStatCd(sourceIO.getAcntStatCd());      /**계좌_상태_코드*/
            targetIO.setAcntStatNm(sourceIO.getAcntStatNm());     /**계좌_상태_이름*/
            targetIO.setAcntErrNm(sourceIO.getAcntErrNm());       /**계좌_에러_명*/
            targetIO.setApplDt(sourceIO.getApplDt());           /**신청_일자*/
            targetIO.setDepoOwnNo(sourceIO.getDepoOwnNo());      /**예금주_번호*/
            targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm());     /**예금주명*/
            targetIO.setDepoOwnRelCd(sourceIO.getDepoOwnRelCd());     /**예금주_관계코드*/
            targetIO.setDepoOwnRelNm(sourceIO.getDepoOwnRelNm());    /**예금주_관계이름*/
            targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo());      /**최초_등록_사원번호*/
            targetIO.setFrstRegEmpNm(sourceIO.getFrstRegEmpNm());     /**최초_등록_사원이름*/
            targetIO.setTrOrgCd(sourceIO.getTrOrgCd());       /**거래_기관_코드*/


           resultList.add(targetIO);
        }

        log.info("SERVICEIMPL FLAG --------------------------------------------------- " );

        if(resultList.size() > 0) {
            resultVo.setListRATMN05DSSD01VO(resultList);
        }
        log.info("serviceImpl 대출번호 : " + resultVo);

        return resultVo;
    }

}
