package hanalife.r.bm.gm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.bm.gm.mapper.CyclClsMngMapper;
import hanalife.r.bm.gm.mapper.dto.CyclClsMngDSCYCLCLSSM01DTO;
import hanalife.r.bm.gm.mapper.dto.CyclClsMngDSCYCLCLSSMDTO;
import hanalife.r.bm.gm.service.RBMGMM05Service;
import hanalife.r.bm.gm.vo.RBMGMM05DSCYCLCLSSMVO;
import hanalife.r.bm.gm.vo.RBMGMM05S01InVO;
import hanalife.r.bm.gm.vo.RBMGMM05S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RBMGMM05ServiceImpl.java Class
 * 클래스설명   : todo1 (RBMGMM05) Service Implements
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRBMGMM05S01 : todo1목록조회
 *              registerRBMGMM05I01 : todo1등록
 *              modifyRBMGMM05U01 : todo1수정
 *              removeRBMGMM05U01 : todo1삭제
 * </pre>
 */
@Service("RBMGMM05Service")
public class RBMGMM05ServiceImpl implements RBMGMM05Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RBMGMM05ServiceImpl.class);

	@Autowired
	private CyclClsMngMapper cyclClsMngMapper;

	/**
	 * <p>메소드명      : getRBMGMM05S01 : 주소발송물마감관리목록조회</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70324 / younghwe.kim
	 * <p>설명          : 주소발송물마감관리목록을 조회 한다.</p>
	 * <p>메소드인수    : RBMGMM05S01InVo </p>
	 * <p>메소드리턴값  : RBMGMM05S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RBMGMM05S01OutVO getRBMGMM05S01(RBMGMM05S01InVO inVo) throws Exception {

        /** 주소발송물마감관리목록조회 서비스 결과값 객체 생성 */
		RBMGMM05S01OutVO resultVo = new RBMGMM05S01OutVO();

		/** 주소발송물마감관리목록조회 조건 입력값 객체 생성 및 대입 수행 */
		CyclClsMngDSCYCLCLSSM01DTO dsSndiDto = new CyclClsMngDSCYCLCLSSM01DTO();
		dsSndiDto.setCyclClsCd(inVo.getRBMGMM05DSCYCLCLSSM01VO().getCyclClsCd());       // 주기마감코드
		dsSndiDto.setCyclCd(inVo.getRBMGMM05DSCYCLCLSSM01VO().getCyclCd());             // 주기코드

        /** 주소발송물마감관리목록조회 쿼리 Mapper 호출 수행 */
        List<CyclClsMngDSCYCLCLSSMDTO> resultDTO = cyclClsMngMapper.searchList(dsSndiDto);

        /** 주소발송물마감관리목록조회 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<RBMGMM05DSCYCLCLSSMVO> resultList = new ArrayList<RBMGMM05DSCYCLCLSSMVO>();

        for (CyclClsMngDSCYCLCLSSMDTO sourceIO : resultDTO) {
            /** 주소발송물마감관리목록조회 VO에 조회된 Mapper DTO 값을 대입 */
        	RBMGMM05DSCYCLCLSSMVO targetIO = new RBMGMM05DSCYCLCLSSMVO();
            targetIO.setCyclClsCd(sourceIO.getCyclClsCd());
            targetIO.setCyclClsNm(sourceIO.getCyclClsNm());
            targetIO.setCyclClsDesc(sourceIO.getCyclClsDesc());
            targetIO.setCyclCd(sourceIO.getCyclCd());
            targetIO.setCyclNm(sourceIO.getCyclNm());
            targetIO.setClsSchdDd(sourceIO.getClsSchdDd());
            targetIO.setDlvrSchdDd(sourceIO.getDlvrSchdDd());
            targetIO.setLastProcEmpNo(sourceIO.getLastProcEmpNo());
            targetIO.setLastProcEmpNm(sourceIO.getLastProcEmpNm());
            targetIO.setDueSchdDd(sourceIO.getDueSchdDd());

            /** 주소발송물마감관리목록조회 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 주소발송물마감관리목록조회 화면 출력 결과값 대입 */
        resultVo.setRBMGMM05DSCYCLCLSSMVO(resultList);

		return resultVo;

	}


	/**
	 * <p>메소드명      : registerRBMGMM05I01 - todo1등록</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70324 / younghwe.kim
	 * <p>설명          : todo1등록</p>
	 * <p>메소드인수    : RBMGMM05I01InVo </p>
	 * <p>메소드리턴값  : RBMGMM05I01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@Override
//	public RBMGMM05I01OutVO registerRBMGMM05I01(RBMGMM05I01InVO inVo) throws Exception {
//
//		RBMGMM05I01OutVO resultVo = new RBMGMM05I01OutVO();
//
//		return resultVo;
//
//	}

	/**
	 * <p>메소드명      : modifyRBMGMM05U01 - todo1수정</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70324 / younghwe.kim
	 * <p>설명          : todo1수정</p>
	 * <p>메소드인수    : RBMGMM05U01InVo </p>
	 * <p>메소드리턴값  : RBMGMM05U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@Override
//	public RBMGMM05U01OutVO modifyRBMGMM05U01(RBMGMM05U01InVO inVo) throws Exception {
//
//		RBMGMM05U01OutVO resultVo = new RBMGMM05U01OutVO();
//
//		return resultVo;
//
//	}

	/**
	 * <p>메소드명      : removeRBMGMM05D01 - todo1삭제</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70324 / younghwe.kim
	 * <p>설명          : todo1삭제</p>
	 * <p>메소드인수    : RBMGMM05D01InVo </p>
	 * <p>메소드리턴값  : RBMGMM05D01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@Override
//	public RBMGMM05D01OutVO removeRBMGMM05D01(RBMGMM05D01InVO inVo) throws Exception {
//
//		RBMGMM05D01OutVO resultVo = new RBMGMM05D01OutVO();
//
//		return resultVo;
//
//	}

}
