package hanalife.r.bm.gm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.bm.gm.service.RBMGMM05Service;
import hanalife.r.bm.gm.vo.RBMGMM05DSCYCLCLSSM01VO;
import hanalife.r.bm.gm.vo.RBMGMM05DSCYCLCLSSMCVO;
import hanalife.r.bm.gm.vo.RBMGMM05S01InVO;
import hanalife.r.bm.gm.vo.RBMGMM05S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RBMGMM05Controller.java Class
 * 클래스설명   : todo1 (RBMGMM05) Controller
 * 작성일자     : 2023. 3. 9.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 9.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/bm/gm")
@Controller
public class RBMGMM05Controller {

	@Resource(name = "RBMGMM05Service")
	private RBMGMM05Service RBMGMM05;

	private static final Logger LOGGER = LoggerFactory.getLogger(RBMGMM05Controller.class);

	/**
	 * <p>메소드명      : 주소발송물마감관리조회 /RBMGMM05S01.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): 70324
	 * <p>설명          : todo1조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RBMGMM05S01.do")
	public String RBMGMM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RBMGMM05Controller RBMGMM05S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CYCL_CLS_SM01", request, response, model);

			/** 주소발송물마감관리조회 업무 서비스 호출 입력값 대입 */
			RBMGMM05DSCYCLCLSSM01VO dsCyclClsSmInVo = new RBMGMM05DSCYCLCLSSM01VO();
			dsCyclClsSmInVo.setCyclClsCd((String) sourceMap.get("cyclClsCd"));       // 주기마감코드
			dsCyclClsSmInVo.setCyclCd((String) sourceMap.get("cyclCd"));             // 주기코드

			/** Service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RBMGMM05S01InVO InVO = new RBMGMM05S01InVO();
			InVO.setRBMGMM05DSCYCLCLSSM01VO(dsCyclClsSmInVo); /** 주소발송물마감관리목록조회 DS_SMDO 입력값 VO 객체 대입 */
			/** 주소발송물마감관리목록조회 업무 서비스 호출 수행 */
			RBMGMM05S01OutVO resultListVo = RBMGMM05.getRBMGMM05S01(InVO);
            /** 주소발송물마감관리목록조회 DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_CYCL_CLS_SM", resultListVo.getRBMGMM05DSCYCLCLSSMVO(), model);

			LOGGER.info("##### RBMGMM05Controller RBMGMM05S01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RBMGMM05Controller RBMGMM05S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : todo1등록 /RBMGMM05I01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RBMGMM05I01.do")
	public String RBMGMM05I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RBMGMM05Controller RBMGMM05I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CYCL_CLS_SM_C", request, response, model);

			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
			RBMGMM05DSCYCLCLSSMCVO targetVo = new RBMGMM05DSCYCLCLSSMCVO();
			targetVo.setCyclClsCd((String) sourceMap.get("cyclClsCd"));
			targetVo.setCyclClsNm((String) sourceMap.get("cyclClsNm"));
			targetVo.setCyclClsDesc((String) sourceMap.get("cyclClsDesc"));
			targetVo.setCyclCd((String) sourceMap.get("cyclCd"));
			targetVo.setClsSchdDd((String) sourceMap.get("clsSchdDd"));
			targetVo.setDlvrSchdDd((String) sourceMap.get("dlvrSchdDd"));

//			targetVo.setFrstRegEmpNo((String) sourceMap.get("frstRegEmpNo"));
//			targetVo.setLastProcEmpNo((String) sourceMap.get("lastProcEmpNo"));

			/** todo1내역조회 업무 서비스 호출 수행 */
//			RBMGMM05S01OutVO resultRBMGMM05I01 = RBMGMM05.registerRBMGMM05I01(targetVo);

//			XFrame5Util.setOutputData("DS_SD01", resultRBMGMM05I01.getRBMGMM05I0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultRBMGMM05I01.getRBMGMM05I0102VO(), model); /** 수납목록조회 */

			LOGGER.info("##### RBMGMM05Controller RBMGMM05I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RBMGMM05Controller RBMGMM05I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : todo1수정 /RBMGMM05U01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RBMGMM05U01.do")
	public String RBMGMM05U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RBMGMM05Controller RBMGMM05U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
//			RBMGMM05U01InVO targetVo = new RBMGMM05U01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */

			/** todo1내역조회 업무 서비스 호출 수행 */
//			RBMGMM05S01OutVO resultRBMGMM05U01 = RBMGMM05.modifyRBMGMM05U01(targetVo);

//			XFrame5Util.setOutputData("DS_SD01", resultRBMGMM05U01.getRBMGMM05U0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultRBMGMM05U01.getRBMGMM05U0102VO(), model); /** 수납목록조회 */

			LOGGER.info("##### RBMGMM05Controller RBMGMM05U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RBMGMM05Controller RBMGMM05U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : todo1삭제 /RBMGMM05D01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1삭제 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RBMGMM05D01.do")
	public String RBMGMM05D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RBMGMM05Controller RBMGMM05D01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
//			RBMGMM05D01InVO targetVo = new RBMGMM05D01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */

			/** todo1내역조회 업무 서비스 호출 수행 */
//			RBMGMM05S01OutVO resultRBMGMM05D01 = RBMGMM05.removeRBMGMM05D01(targetVo);

//			XFrame5Util.setOutputData("DS_SD01", resultRBMGMM05D01.getRBMGMM05D0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultRBMGMM05D01.getRBMGMM05D0102VO(), model); /** 수납목록조회 */

			LOGGER.info("##### RBMGMM05Controller RBMGMM05D01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RBMGMM05Controller RBMGMM05D01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
