package hanalife.r.ch.pl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.ch.pl.mapper.AskPlcChngMapper;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSD01DTO;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSD02DTO;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSD03DTO;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSD04DTO;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSD05DTO;
import hanalife.r.ch.pl.mapper.dto.AskPlcChngDSASKPLCCHNGSMDTO;
import hanalife.r.ch.pl.service.RCHPLM01Service;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSD01VO;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSD02VO;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSD03VO;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSD04VO;
import hanalife.r.ch.pl.vo.RCHPLM01S01InVO;
import hanalife.r.ch.pl.vo.RCHPLM01S01OutVO;
import hanalife.r.ch.pl.vo.RCHPLM01S02InVO;
import hanalife.r.ch.pl.vo.RCHPLM01S02OutVO;
import hanalife.r.ch.pl.vo.RCHPLM01U01InVO;
import hanalife.r.ch.pl.vo.RCHPLM01U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RCHPLM01ServiceImpl.java Class
 * 클래스설명   : 청구지변경관리 (RCHPLM01) Service Implements
 * 작성일자     : 2023. 3. 15.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRCHPLM01S01 : 청구지변경관리
 *              getRCHPLM01S02 : 예/가수환불현황상세조회
 * </pre>
 */
@Service("RCHPLM01Service")
public class RCHPLM01ServiceImpl implements RCHPLM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RCHPLM01ServiceImpl.class);

	@Autowired
	private AskPlcChngMapper askPlcChngMapper;

	/**
	 * <p>메소드명      : getRCHPLM01S01 : 청구지변경관리</p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 청구지변경관리 한다.</p>
	 * <p>메소드인수    : RCHPLM01S01InVo </p>
	 * <p>메소드리턴값  : RCHPLM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RCHPLM01S01OutVO getRCHPLM01S01(RCHPLM01S01InVO inVo) throws Exception {

		RCHPLM01S01OutVO resultVo = new RCHPLM01S01OutVO();

		AskPlcChngDSASKPLCCHNGSMDTO inDto = new AskPlcChngDSASKPLCCHNGSMDTO();
		AskPlcChngDSASKPLCCHNGSD03DTO sd03Dto = new AskPlcChngDSASKPLCCHNGSD03DTO();

		//대출번호 최종여부 체크 : !! 김영휘 이사님 소스 불러오기 !!
		/*
		 * String[] arrRtn = SearchLoanSeq.checkLoanseq(arrParam, tx);
		 *
		 * if ( (arrRtn[0]).equals("E")) { throw new Exception(arrRtn[2]); }
		 *
		 * smdo.set(AskPlcChngSMDO.loanNo, arrRtn[1]); smdo.set(AskPlcChngSMDO.loanSeq,
		 * arrRtn[2]);
		 */

		String custNo = inVo.getRCHPLM01DSASKPLCCHNGSMVO().getCustNo();
		String searchCustNo = "";

		//고객번호 입력 후 조회 시 화면 값 세팅
		if(!"".equals(custNo) && custNo != null) {
			searchCustNo = custNo;
		//대출번호 입력만으로 조회 시 : 대출번호에 해당하는 실납입자 조회
		}else {
			sd03Dto.setLoanNo(inVo.getRCHPLM01DSASKPLCCHNGSMVO().getLoanNo());	/** 대출번호 */
			sd03Dto.setLoanSeq(inVo.getRCHPLM01DSASKPLCCHNGSMVO().getLoanSeq());	/** 대출순번 */

			searchCustNo = askPlcChngMapper.searchLoanRelMan(sd03Dto);	/** 실납입자 고객정보 */
			//List<AskPlcChngDSASKPLCCHNGSD03DTO> resultSd03Dto = askPlcChngMapper.searchLoanRelMan(sd03Dto);	/** 실납입자 고객정보 */
//			for (AskPlcChngDSASKPLCCHNGSD03DTO sourceIO : resultSd03Dto) {
//				searchCustNo = sourceIO.getCustNo();
//			}
		}

		inDto.setCustNo(searchCustNo);		/** 고객번호 */
		inDto.setCustNm(inVo.getRCHPLM01DSASKPLCCHNGSMVO().getCustNm());		/** 고객명 */
		inDto.setLoanNo(inVo.getRCHPLM01DSASKPLCCHNGSMVO().getLoanNo());	/** 대출번호 */
		inDto.setLoanSeq(inVo.getRCHPLM01DSASKPLCCHNGSMVO().getLoanSeq());	/** 대출순번 */

		List<AskPlcChngDSASKPLCCHNGSD01DTO> resultDTO  = askPlcChngMapper.searchAskPlcChngCustDetail(inDto);	/** 고객정보*/
		List<AskPlcChngDSASKPLCCHNGSD02DTO> resultDTO2 = askPlcChngMapper.searchAskPlcChngCustAddr(inDto);	/** 고객주소정보 */
		List<AskPlcChngDSASKPLCCHNGSD03DTO> resultDTO3 = askPlcChngMapper.searchAskPlcChng(inDto);	/** 대출정보 */

		List<RCHPLM01DSASKPLCCHNGSD01VO> resultList = new ArrayList<RCHPLM01DSASKPLCCHNGSD01VO>();
		List<RCHPLM01DSASKPLCCHNGSD02VO> resultList2 = new ArrayList<RCHPLM01DSASKPLCCHNGSD02VO>();
		List<RCHPLM01DSASKPLCCHNGSD03VO> resultList3 = new ArrayList<RCHPLM01DSASKPLCCHNGSD03VO>();

		for (AskPlcChngDSASKPLCCHNGSD01DTO sourceIO : resultDTO) {
			RCHPLM01DSASKPLCCHNGSD01VO targetIO = new RCHPLM01DSASKPLCCHNGSD01VO();
			targetIO.setCustTpCd(sourceIO.getCustTpCd()); /** 고객구분코드 */
			targetIO.setCustTpNm(sourceIO.getCustTpNm()); /** 고객구분 */
			targetIO.setCorpRegNo(sourceIO.getCorpRegNo()); /** 법인번호 */
			targetIO.setComFrmlNm(sourceIO.getComFrmlNm()); /** 법인명 */
			targetIO.setReprCustNo(sourceIO.getReprCustNo()); /** 대표자번호 */
			targetIO.setReprNm(sourceIO.getReprNm()); /** 대표자명 */
			targetIO.setReprFg(sourceIO.getReprFg()); /** 공동대표여부 */
			targetIO.setEmal(sourceIO.getEmal()); /** 전자메일 */
			targetIO.setHpNumber(sourceIO.getHpNumber()); /** 휴대폰번호 */

			resultList.add(targetIO);
		}

		for (AskPlcChngDSASKPLCCHNGSD02DTO sourceIO : resultDTO2) {
			RCHPLM01DSASKPLCCHNGSD02VO targetIO = new RCHPLM01DSASKPLCCHNGSD02VO();
			targetIO.setAddrDivCd(sourceIO.getAddrDivCd()); /** 주소구분코드 */
			targetIO.setZipCd(sourceIO.getZipCd()); /** 우편번호 */
			targetIO.setAddrCi(sourceIO.getAddrCi()); /** 시/도 */
			targetIO.setAddrGu(sourceIO.getAddrGu()); /** 구/군 */
			targetIO.setAddrDong(sourceIO.getAddrDong()); /** 동/읍/면 */
			targetIO.setAddrSpec(sourceIO.getAddrSpec()); /** 상세주소 */
			targetIO.setRsndRsnCd(sourceIO.getRsndRsnCd()); /**  */

			resultList2.add(targetIO);
		}

		// !! 대출정보 리스트 VO에 담기 전에 청구미수 계산 후 연체여부 세팅할 것 !!
		for (AskPlcChngDSASKPLCCHNGSD03DTO sourceIO : resultDTO3) {
			RCHPLM01DSASKPLCCHNGSD03VO targetIO = new RCHPLM01DSASKPLCCHNGSD03VO();
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 대출순번 */
			targetIO.setCustNo(sourceIO.getCustNo()); /** 고객번호 */
			targetIO.setPrdtNm(sourceIO.getPrdtNm()); /** 상품명 */
			targetIO.setPrdtCd(sourceIO.getPrdtCd()); /** 상품코드 */
			targetIO.setLoanPamt(sourceIO.getLoanPamt()); /** 대출원금 */
			targetIO.setLoanTerm(sourceIO.getLoanTerm()); /** 대출기간 */
			targetIO.setLoanStatCd(sourceIO.getLoanStatCd()); /** 대출상태코드 */
			targetIO.setRlDueManFg(sourceIO.getRlDueManFg()); /** 실납입여부 */
			targetIO.setAskPlcDivCd(sourceIO.getAskPlcDivCd()); /** 청구지 */
			targetIO.setEmalAskFg(sourceIO.getEmalAskFg()); /** 청구방법 */
			targetIO.setDueMethCd(sourceIO.getDueMethCd()); /** 납입방법코드 */
			targetIO.setSetlDd(sourceIO.getSetlDd()); /** 결재일 */
			targetIO.setDlyFg(sourceIO.getDlyFg()); /** 연체여부 */
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서명 */
			targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd()); /** 상품대분류코드 */
			targetIO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd()); /** 상품중분류코드 */
			targetIO.setMngPlcDivCd(sourceIO.getMngPlcDivCd()); /**  */

			resultList3.add(targetIO);
		}

		resultVo.setRCHPLM01DSASKPLCCHNGSD01VO(resultList);	/** 고객정보*/
		resultVo.setRCHPLM01DSASKPLCCHNGSD02VO(resultList2);	/** 고객주소정보 */
		resultVo.setRCHPLM01DSASKPLCCHNGSD03VO(resultList3);	/** 대출정보 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : getRCHPLM01S02 : 청구지변경이력조회</p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 청구지변경이력조회 한다.</p>
	 * <p>메소드인수    : RCHPLM01S02InVo </p>
	 * <p>메소드리턴값  : RCHPLM01S02OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RCHPLM01S02OutVO getRCHPLM01S02(RCHPLM01S02InVO inVo) throws Exception {

		RCHPLM01S02OutVO resultVo = new RCHPLM01S02OutVO();

		AskPlcChngDSASKPLCCHNGSD03DTO inDto = new AskPlcChngDSASKPLCCHNGSD03DTO();

		inDto.setCustNo(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getCustNo());		/** 고객번호 */
		inDto.setLoanNo(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanNo());	/** 대출번호 */
		inDto.setLoanSeq(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanSeq());	/** 대출순번 */

		List<AskPlcChngDSASKPLCCHNGSD04DTO> resultDTO  = askPlcChngMapper.searchAskPlcChngLoanRlDueMan(inDto);	/** 청구지변경이력*/

		List<RCHPLM01DSASKPLCCHNGSD04VO> resultList = new ArrayList<RCHPLM01DSASKPLCCHNGSD04VO>();

		for (AskPlcChngDSASKPLCCHNGSD04DTO sourceIO : resultDTO) {
			RCHPLM01DSASKPLCCHNGSD04VO targetIO = new RCHPLM01DSASKPLCCHNGSD04VO();
			targetIO.setLastProcDt(sourceIO.getLastProcDt()); /** 변경일 */
			targetIO.setLastProcTm(sourceIO.getLastProcTm()); /** 변경시간 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 대출순번 */
			targetIO.setSnum(sourceIO.getSnum()); /** 일련번호 */
			targetIO.setCdDescKorNm(sourceIO.getCdDescKorNm()); /**  */
			targetIO.setAskPlcDivCd(sourceIO.getAskPlcDivCd()); /** 청구지 */
			targetIO.setEmalAskFg(sourceIO.getEmalAskFg()); /** 청구방법 */
			targetIO.setUserNm(sourceIO.getUserNm()); /** 담당자 */
			targetIO.setLastProcEmpNo(sourceIO.getLastProcEmpNo()); /** 변경사원번호 */
			targetIO.setDueMethCd(sourceIO.getDueMethCd()); /** 납입방법 */

			resultList.add(targetIO);
		}

		resultVo.setRCHPLM01DSASKPLCCHNGSD04VO(resultList);	/** 청구지변경이력*/

		return resultVo;
	}

	/**
	 * <p>메소드명      : getRCHPLM01U01 : 청구지변경</p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 청구지변경이력 한다.</p>
	 * <p>메소드인수    : RCHPLM01U01InVo </p>
	 * <p>메소드리턴값  : RCHPLM01U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RCHPLM01U01OutVO getRCHPLM01U01(RCHPLM01U01InVO inVo) throws Exception {

		RCHPLM01U01OutVO resultVo = new RCHPLM01U01OutVO();

		AskPlcChngDSASKPLCCHNGSD03DTO inDto = new AskPlcChngDSASKPLCCHNGSD03DTO();	// 화면에서 받아온 정보
		String loanNo = inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanNo();
		String loanSeq = inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanSeq();
		String prdtCd = inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getPrdtCd();
		String dueMethCd = inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getDueMethCd();

		// !! 추후 공통 사원번호 넣기 !!
		String empNo = "";
		inDto.setLoanNo(loanNo);	/** 대출번호 */
		inDto.setLoanSeq(loanSeq);	/** 대출순번 */
		inDto.setCustNo(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getCustNo());		/** 고객번호 */
		inDto.setAskPlcDivCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getAskPlcDivCd());		/** 청구지 */
		inDto.setEmalAskFg(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getEmalAskFg());		/** 청구방법 */
		inDto.setDueMethCd(dueMethCd);		/** 납입방법코드 */
		inDto.setLastProcEmpNo(empNo);	/** 최종등록사원번호 */
		/** 변경전 정보 조회 : inDto */
		List<AskPlcChngDSASKPLCCHNGSD05DTO> sd05DTO  = askPlcChngMapper.searchAskPlcChngLoanRlDueManGetValue(inDto);	/** 변경전정보조회*/

		String OrgdueMethCd = "";
		AskPlcChngDSASKPLCCHNGSD03DTO dbDto = new AskPlcChngDSASKPLCCHNGSD03DTO();	// DB에서 받아온 정보
		for (AskPlcChngDSASKPLCCHNGSD05DTO sourceIO : sd05DTO) {
			//AskPlcChngDSASKPLCCHNGSD05DTO targetIO = new AskPlcChngDSASKPLCCHNGSD05DTO();
			dbDto.setMainContManRelCd(sourceIO.getMainContManRelCd()); /** 주계약자관계코드 */
			dbDto.setRelMtr(sourceIO.getRelMtr()); /** 관계사항 */
			OrgdueMethCd = sourceIO.getDueMethCd();
		}

		if("WL0040".equals(prdtCd)){
			if(!OrgdueMethCd.equals(dueMethCd)){
				throw new Exception(prdtCd + "코드일 경우 납입방법을 변경하실수 없습니다");
			}
		}

		/** 변경후 정보 조회 : dbDto */
		dbDto.setLoanNo(loanNo);	/** 대출번호 */
		dbDto.setLoanSeq(loanSeq);	/** 대출순번 */
		dbDto.setCustNo(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getCustNo());		/** 고객번호 */
		dbDto.setPrdtNm(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getPrdtNm());		/** 상품명 */
		dbDto.setPrdtCd(prdtCd);		/** 상품코드 */
		dbDto.setLoanPamt(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanPamt());		/** 대출원금 */
		dbDto.setLoanTerm(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanTerm());		/** 대출기간 */
		dbDto.setLoanStatCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getLoanStatCd());		/** 대출상태코드 */
		dbDto.setRlDueManFg(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getRlDueManFg());		/** 실납입여부 */
		dbDto.setSetlDd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getSetlDd());		/** 결재일 */
		dbDto.setDlyFg(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getDlyFg());		/** 연체여부 */
		dbDto.setMngDeptCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getMngDeptCd());		/** 관리부서코드 */
		dbDto.setMngDeptNm(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getMngDeptNm());		/** 관리부서명 */
		dbDto.setPrdtLrgeClasCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getPrdtLrgeClasCd());		/** 상품대분류코드 */
		dbDto.setPrdtMidClasCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getPrdtMidClasCd());		/** 상품중분류코드 */
		dbDto.setMngPlcDivCd(inVo.getRCHPLM01DSASKPLCCHNGSD03VO().getMngPlcDivCd());		/**  */
		dbDto.setFrstRegEmpNo(empNo);	/** 최초등록사원번호 */
		dbDto.setLastProcEmpNo(empNo);	/** 최종등록사원번호 */

		// !! AS-IS 일련번호 생성 !! 추후 필요한지 여부 확인 후 추가할 것
		//String strSnum = com.dobscap.util.GenerateKey.getNextNumber("S006", loanNo, loanSeq, event.getEmpNo(), tx);
		//inDto.setSnum(strSnum);

		// 변경된 대출관계자 등록 (ST_LOAN_REL_MAN)
		int insResult = askPlcChngMapper.insertAskPlcChngStLoanRelMan(dbDto);
		if(insResult < 0) {
			throw new Exception("데이터 송신중 오류가 발생하였습니다.");
		}

		// 변경전 대출관계자 수정의 최종등록자 변경
		int updRelResult = askPlcChngMapper.updateAskPlcChngStLoanRelMan(inDto);
		if(updRelResult < 0) {
			throw new Exception("데이터 송신중 오류가 발생하였습니다.");
		}

		// 대출기본 원장에 대출관계변경정보를 수정
		int updResult = askPlcChngMapper.updateAskPlcChng(inDto);
		if(updResult < 0) {
			throw new Exception("데이터 송신중 오류가 발생하였습니다.");
		}

		/** 변경전 대출관계자 수정 이력과 변경후 대출관계자 내역에 대한 이력 조회 */
		List<AskPlcChngDSASKPLCCHNGSD04DTO> resultDTO  = askPlcChngMapper.searchAskPlcChngLoanRlDueMan(inDto);	/* 청구지변경이력*/

		List<RCHPLM01DSASKPLCCHNGSD04VO> resultList = new ArrayList<RCHPLM01DSASKPLCCHNGSD04VO>();
		for (AskPlcChngDSASKPLCCHNGSD04DTO sourceIO : resultDTO) {
			RCHPLM01DSASKPLCCHNGSD04VO targetIO = new RCHPLM01DSASKPLCCHNGSD04VO();
			targetIO.setLastProcDt(sourceIO.getLastProcDt()); /* 변경일 */
			targetIO.setLastProcTm(sourceIO.getLastProcTm()); /* 변경시간 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /* 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /* 대출순번 */
			targetIO.setSnum(sourceIO.getSnum()); /* 일련번호 */
			targetIO.setCdDescKorNm(sourceIO.getCdDescKorNm()); /*  */
			targetIO.setAskPlcDivCd(sourceIO.getAskPlcDivCd()); /* 청구지 */
			targetIO.setEmalAskFg(sourceIO.getEmalAskFg()); /* 청구방법 */
			targetIO.setUserNm(sourceIO.getUserNm()); /* 담당자 */
			targetIO.setLastProcEmpNo(sourceIO.getLastProcEmpNo()); /* 변경사원번호 */
			targetIO.setDueMethCd(sourceIO.getDueMethCd()); /* 납입방법 */
			resultList.add(targetIO);
		}

		resultVo.setRCHPLM01DSASKPLCCHNGSD04VO(resultList);	/* 청구지변경이력*/

		return resultVo;
	}

}
