package hanalife.r.ch.pl.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.ch.pl.service.RCHPLM01Service;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSD03VO;
import hanalife.r.ch.pl.vo.RCHPLM01DSASKPLCCHNGSMVO;
import hanalife.r.ch.pl.vo.RCHPLM01S01InVO;
import hanalife.r.ch.pl.vo.RCHPLM01S01OutVO;
import hanalife.r.ch.pl.vo.RCHPLM01S02InVO;
import hanalife.r.ch.pl.vo.RCHPLM01S02OutVO;
import hanalife.r.ch.pl.vo.RCHPLM01U01InVO;
import hanalife.r.ch.pl.vo.RCHPLM01U01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RCHPLM01Controller.java Class
 *
 * 클래스설명   : 청구지변경관리 (RCHPLM01) Controller
 * 작성일자     : 2023. 3. 15.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/ch/pl")
@Controller
public class RCHPLM01Controller {

	@Resource(name = "RCHPLM01Service")
	private RCHPLM01Service RCHPLM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(RCHPLM01Controller.class);

	/**
	 * <p>메소드명      : 청구지변경관리조회 /RCHPLM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70317
	 * <p>설명          : 청구지변경관리 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RCHPLM01S01.do")
	public String RCHPLM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RCHPLM01Controller RCHPLM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ASK_PLC_CHNG_SM", request, response, model);

			/** 청구지변경관리내역조회 업무 서비스 호출 입력값 대입 */
			RCHPLM01S01InVO targetVo = new RCHPLM01S01InVO();
			RCHPLM01DSASKPLCCHNGSMVO smVo = new RCHPLM01DSASKPLCCHNGSMVO();

			smVo.setCustNo((String) sourceMap.get("custNo"));		/** 고객번호 */
			smVo.setCustNm((String) sourceMap.get("custNm"));		/** 고객명 */
			smVo.setLoanNo((String) sourceMap.get("loanNo"));	/** 대출번호 */
			smVo.setLoanSeq((String) sourceMap.get("loanSeq"));	/** 대출순번 */

			targetVo.setRCHPLM01DSASKPLCCHNGSMVO(smVo);

			/** 청구지변경관리내역조회 업무 서비스 호출 수행 */
			RCHPLM01S01OutVO resultRCHPLM01S01 = RCHPLM01.getRCHPLM01S01(targetVo);

			XFrame5Util.setOutputData("DS_ASK_PLC_CHNG_SD01", resultRCHPLM01S01.getRCHPLM01DSASKPLCCHNGSD01VO(), model);
			XFrame5Util.setOutputData("DS_ASK_PLC_CHNG_SD02", resultRCHPLM01S01.getRCHPLM01DSASKPLCCHNGSD02VO(), model);
			XFrame5Util.setOutputData("DS_ASK_PLC_CHNG_SD03", resultRCHPLM01S01.getRCHPLM01DSASKPLCCHNGSD03VO(), model);

			LOGGER.info("##### RCHPLM01Controller RCHPLM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RCHPLM01Controller RCHPLM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 청구지변경이력조회 /RCHPLM01S02.do </p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70317
	 * <p>설명          : 청구지변경이력 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RCHPLM01S02.do")
	public String RCHPLM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RCHPLM01Controller RCHPLM01S02 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ASK_PLC_CHNG_SD03", request, response, model);

			/** 청구지변경관리내역조회 업무 서비스 호출 입력값 대입 */
			RCHPLM01S02InVO targetVo = new RCHPLM01S02InVO();
			RCHPLM01DSASKPLCCHNGSD03VO sd03Vo = new RCHPLM01DSASKPLCCHNGSD03VO();

			sd03Vo.setCustNo((String) sourceMap.get("custNo"));		/** 고객번호 */
			sd03Vo.setLoanNo((String) sourceMap.get("loanNo"));	/** 대출번호 */
			sd03Vo.setLoanSeq((String) sourceMap.get("loanSeq"));	/** 대출순번 */

			targetVo.setRCHPLM01DSASKPLCCHNGSD03VO(sd03Vo);

			/** 청구지변경관리내역조회 업무 서비스 호출 수행 */
			RCHPLM01S02OutVO resultRCHPLM01S02 = RCHPLM01.getRCHPLM01S02(targetVo);

			XFrame5Util.setOutputData("DS_ASK_PLC_CHNG_SD04", resultRCHPLM01S02.getRCHPLM01DSASKPLCCHNGSD04VO(), model);


			LOGGER.info("##### RCHPLM01Controller RCHPLM01S02 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RCHPLM01Controller RCHPLM01S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 청구지변경 /RCHPLM01U01.do </p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70317
	 * <p>설명          : 청구지변경 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RCHPLM01U01.do")
	public String RCHPLM01U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RCHPLM01Controller RCHPLM01U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ASK_PLC_CHNG_SD03", request, response, model);

			/** 청구지변경관리내역조회 업무 서비스 호출 입력값 대입 */
			RCHPLM01U01InVO targetVo = new RCHPLM01U01InVO();
			RCHPLM01DSASKPLCCHNGSD03VO sd03Vo = new RCHPLM01DSASKPLCCHNGSD03VO();

			sd03Vo.setLoanNo((String) sourceMap.get("loanNo"));	/** 대출번호 */
			sd03Vo.setLoanSeq((String) sourceMap.get("loanSeq"));	/** 대출순번 */
			sd03Vo.setCustNo((String) sourceMap.get("custNo"));		/** 고객번호 */
			sd03Vo.setPrdtNm((String) sourceMap.get("prdtNm"));	/** 상품명 */
			sd03Vo.setPrdtCd((String) sourceMap.get("prdtCd"));	/** 상품코드 */
			sd03Vo.setLoanPamt((String) sourceMap.get("loanPamt"));	/** 대출원금 */
			sd03Vo.setLoanTerm((String) sourceMap.get("loanTerm"));	/** 대출기간 */
			sd03Vo.setLoanStatCd((String) sourceMap.get("loanStatCd"));	/** 대출상태코드 */
			sd03Vo.setRlDueManFg((String) sourceMap.get("rlDueManFg"));	/** 실납입여부 */
			sd03Vo.setAskPlcDivCd((String) sourceMap.get("askPlcDivCd"));	/** 청구지 */
			sd03Vo.setEmalAskFg((String) sourceMap.get("emalAskFg"));	/** 청구방법 */
			sd03Vo.setDueMethCd((String) sourceMap.get("dueMethCd"));	/** 납입방법코드 */
			sd03Vo.setSetlDd((String) sourceMap.get("setlDd"));	/** 결재일 */
			sd03Vo.setDlyFg((String) sourceMap.get("dlyFg"));	/** 연체여부 */
			sd03Vo.setMngDeptCd((String) sourceMap.get("mngDeptCd"));	/** 관리부서코드 */
			sd03Vo.setMngDeptNm((String) sourceMap.get("mngDeptNm"));	/** 관리부서명 */
			sd03Vo.setPrdtLrgeClasCd((String) sourceMap.get("prdtLrgeClasCd"));	/** 상품대분류코드 */
			sd03Vo.setPrdtMidClasCd((String) sourceMap.get("prdtMidClasCd"));	/** 상품중분류코드 */
			sd03Vo.setMngPlcDivCd((String) sourceMap.get("mngPlcDivCd"));	/**  */

			targetVo.setRCHPLM01DSASKPLCCHNGSD03VO(sd03Vo);

			/** 청구지변경관리내역조회 업무 서비스 호출 수행 */
			RCHPLM01U01OutVO resultRCHPLM01U01 = RCHPLM01.getRCHPLM01U01(targetVo);

			XFrame5Util.setOutputData("DS_ASK_PLC_CHNG_SD04", resultRCHPLM01U01.getRCHPLM01DSASKPLCCHNGSD04VO(), model);

			LOGGER.info("##### RCHPLM01Controller RCHPLM01U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RCHPLM01Controller RCHPLM01U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
