package hanalife.r.co.as.service;

import java.util.List;

import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.DlyCalcVO;


/**
 * <pre>
 * 클래스　명 : AskUnrcvService
 * 클래스설명 : 청구미수계산Service
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2018-08-01
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [변경 일자][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [18.08.01][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface AskUnrcvService {

	/**
	 * <p>메소드명      : searchLoanBaseForBatch </p>
	 * <p>작성일자      : 2023. 3. 16.
	 * <p>작성자(author): 70279
	 * <p>설명         : 대상객체의 필요속성 추가 셋팅([대출_기본]을 조회한다.)</p>
	 * <p>메소드인수    : AskUnrcvVO </p>
	 * <p>메소드리턴값   : AskUnrcvVO</p>
	 * <p>예외처리      : N/A</p>
	 */
	public AskUnrcvVO searchLoanBaseForBatch(AskUnrcvVO askUnrcvVO);

	/**
	 * @deprecated
	 * <p>메소드명      : createAskUnrcvObj </p>
	 * <p>작성일자      : 2023. 3. 16.
	 * <p>작성자(author): 70279
	 * <p>설명         : 대상객체를 임시테이블에 insert한다.</p>
	 * <p>메소드인수    : list </p>
	 * <p>메소드리턴값   : int</p>
	 * <p>예외처리      : Exception</p>
	 */
	//int createAskUnrcvObj(List askUnrcvObjVOList) throws Exception;

	/**
     * <p>메소드명	: createAskUnrcvObjForBatch</p>
     * <p>설    명	: 대상객체를 임시테이블에 insert한다.</p>
     * <p>메소드인수	: List askUnrcvObjVOList</p>
     * <p>리 턴 값	: int</p>
     */
    void createAskUnrcvObjForBatch(List askUnrcvObjVOList);

	/**
     * <p>메소드명	: deleteAskUnrcvObj</p>
     * <p>설    명	: 임시테이블 클리어</p>
     * <p>메소드인수	: List, Connection</p>
     * <p>리 턴 값	: int</p>
     */
    void deleteAskUnrcvObj() throws Exception;

	/**
	 * <p>메소드명	: calcDfee</p>
	 * <p>설　　명	: 연체료계산</p>
	 * <p>메소드인수	: DlyCalcVO(대출번호, 대출순번, 결제일자, 결제계산일자), Connection</p>
	 * <p>리 턴 값	: DlyCalcVO</p>
	 */
	DlyCalcVO calcDfee(DlyCalcVO dlyCalcVO);

	/**
	 * <p>메소드명	: searchPreLose</p>
	 * <p>설    명	: 이전 연체수납건중 기한이익상실 수납건이 존재하는지 확인</p>
	 * <p>메소드인수	: DlyCalcVO dlyCalcVO, Connection </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	DlyCalcVO searchPreLose(DlyCalcVO dlyCalcVO) throws Exception;

	/**
	 * <p>메소드명	: searchLoseDueDt</p>
	 * <p>설    명	: 기한상실 일자 조회</p>
	 * <p>메소드인수	: loanNo, loanSeq </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	DlyCalcVO searchLoseDueDt(String loanNo, String loanSeq, int tims) throws Exception;

	/**
	 * <p>메소드명	: searchLoseDueDt</p>
	 * <p>설    명	: 기한상실 회차 추가 몇회차 이후</p>
	 * <p>메소드인수	: loanNo, loanSeq, addtims </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	DlyCalcVO searchLoseDueDtAddTims(String loanNo, String loanSeq, int addtims) throws Exception;

	/**
	 * <p>메소드명	: searchLoseDueDt</p>
	 * <p>설    명	: 기한상실납입일</p>
	 * <p>메소드인수	: loanNo, loanSeq, rlDueDt </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */

	DlyCalcVO searchLoseDueDt(String loanNo, String loanSeq, String rlDueDt) throws Exception;

}
