package hanalife.r.co.as.service.impl;

import java.text.NumberFormat;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.mapper.AskUnrcvProcMapper;
import hanalife.r.co.as.mapper.dto.MainSqlOUTDTO;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.service.AskUnrcvService;
import hanalife.r.co.as.service.RcptASService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.as.vo.DlyCalcVO;
import hanalife.r.co.as.vo.RmbrPlanVO;
import hanalife.r.co.as.vo.TimsUnrcvVO;
import hanalife.r.co.rc.vo.RcptMainVO;
import hanalife.util.BizException;


/**
 * <pre>
 * 클래스명    : AskUnrcvProcImpl
 * 클래스설명  : 청구미수Impl
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("AskUnrcvProcService")
public class AskUnrcvProcServiceImpl implements AskUnrcvProcService {

	private static final Logger log = LoggerFactory.getLogger(AskUnrcvProcServiceImpl.class);

	@Autowired
	private AskUnrcvProcMapper askUnrcvProcMapper;
	@Autowired
	private RcptASService rcptService;
	@Autowired
	private AskUnrcvService askUnrcvService;
	@Autowired
	private CommBizService commBizService;

	@Override
	public AskUnrcvVO calcAskUnrcv(String loanNo, String loanSeq, String setlDt) throws Exception {

		AskUnrcvObjVO askUnrcvObjVO = new AskUnrcvObjVO();

		askUnrcvObjVO.loanNo  = loanNo;
		askUnrcvObjVO.loanSeq = loanSeq;
		askUnrcvObjVO.setlDt  = setlDt;

		AskUnrcvVO askUnrcvVO = new AskUnrcvVO();

		askUnrcvVO.addAskUnrcvObj(askUnrcvObjVO);

		return calcAskUnrcv(askUnrcvVO);
	}

	@Override
	public AskUnrcvVO calcAskUnrcv(final AskUnrcvVO askUnrcvInVO) throws Exception {

		long startTime = System.nanoTime();

		askUnrcvInVO.isrtDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);

		AskUnrcvVO askUnrcvOutVO = initAskUnrcvForBatch(askUnrcvInVO);	// 청구미수 계산 대상 준비 JCBSC.RT_TEMP_UNRCV_OBJ_DESC 등록

		// ■ 대상에 대한 미수정보를 구하기 위해 청구미수조회 한다.
		askUnrcvOutVO = calcUnrcvInfo(askUnrcvOutVO);

		double endTime = (((double)System.nanoTime() - startTime) / 1_000_000_000.0);
		if (askUnrcvInVO.sizeAskUnrcvObjList()>1) {
			log.info("[청구미수처리] 계산 소요시간 : " + endTime);
		}
		askUnrcvOutVO.free();

		return askUnrcvOutVO;
	}

	/**
	 * <p>메소드명	: calcDsrcRamt</p>
	 * <p>설　　명	: 대출의 예가수정보를 조회하여 BndVO에 결과를 담아 리턴한다.</p>
	 * <p>메소드인수	: AskUnrcvVO</p>
	 * 					AskUnrcvObjVO는 대출번호, 순번을 필수로, 예가수번호는 optional이다. (대출번호 순서대로 add해야하며 중복 추가 불가)
	 * <p>리　턴　값	: AskUnrcvVO - 예가수정보가 BndVO에 대상객체와 1:1로 담긴다.</p>
	 */
	@Override
	public AskUnrcvVO calcDsrcRamt(AskUnrcvVO askUnrcvVO) throws Exception {
		int size = askUnrcvVO.sizeAskUnrcvObjList();
		if (size < 1) {
			askUnrcvVO.rsltCd 	= "9999";
			askUnrcvVO.rsltCntn = "예가수잔액조회에 필요한 요청정보가 입력되지 않았습니다.";
		} else {
			for (int i = 0; i < size; i++) {
				AskUnrcvObjVO askObj = askUnrcvVO.getAskUnrcvObj(i);

				// 조회조건셋팅
				BndVO bndVO = new BndVO();
					bndVO.loanNo  = askObj.loanNo;
					bndVO.loanSeq = askObj.loanSeq;
					bndVO.dsrcNo  = askObj.dsrcNo;
				askUnrcvVO.addBndVO(rcptService.calcDsrc(bndVO));
			}
		}
		return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: calcUnrcvInfo</p>
	 * <p>설　　명	: 미수정보계산 - 호출전 temp table에 대상객체가 등록되어있어야 한다.</p>
	 * <p>메소드인수	: AskUnrcv</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	private AskUnrcvVO calcUnrcvInfo(AskUnrcvVO askUnrcvVO) throws Exception {


		RcptMainVO rcptMainVO = new RcptMainVO();

		List<MainSqlOUTDTO> outMainSqlODTO = askUnrcvProcMapper.mainSql();

		// 대출별 첫row는 채권정보(sum), 이후 연체회차, 정상회차, 미도래회차가 row에 조회된다.
		for(MainSqlOUTDTO sourceIO : outMainSqlODTO) {

			// 조회결과를 청구미수.상환계획객체에 SET한다.
			RmbrPlanVO rmbrPlanVO = getRmbrPlanVO(sourceIO);

			// 청구미수객체.상환계획개체 리스트 (내부계산용) add
			askUnrcvVO.addRmbrPlan(rmbrPlanVO);

			// 0회차 일때 대출번호,대출순번별 채권 정보를 구성한다.
			if (rmbrPlanVO.tims == 0) {
				askUnrcvVO = setBndWithFirstRow(askUnrcvVO);	// 채권 객체(bndVO)를 구성
				continue;
			}

			// 대출상태가 2%가 아니면 (정상대출을 상태코드 2%로 확인한다.)
			// 리스상품인 경우 종료 수납계산을 위해 계속 진행을 한다.
			if (rmbrPlanVO.loanStatCd.charAt(0) != '2' && !rmbrPlanVO.endDivCd.equals(Constants.YES)) {
				continue;
			}

			// 회차별 정보를 세팅한다.
			askUnrcvVO = setAskUnrcvWithTims(askUnrcvVO);

		} // 조회된 미수정보를 순차적으로 처리하는 while-loop 끝

		if (1 > askUnrcvVO.sizeBndVOList()) {
			// 상환계획이 수립되어 있지 않은경우 에러처리하지 않고 워닝만 한다.
			log.warn("상환계획이 수립되어 있지 않습니다.[" + askUnrcvVO.getAskUnrcvObj(0) + "]");
			return askUnrcvVO;
		}

		// 중도상환처리 - 중도상환미계산여부(1:중도상환 계산안함, 0:중도상환 계산(default))
		if (Constants.NO.equals(askUnrcvVO.midRmbrUnCalcFg)) {
			log.info("중도상환 계산처리함");
			askUnrcvVO = calcMidRmbr(askUnrcvVO);
		}

		// 상실예정계산
		if (Constants.YES.equals(askUnrcvVO.loseExptCalcFg)) {
			askUnrcvVO = calcLoseExpt(askUnrcvVO);
		}

		return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: calcLoseExpt</p>
	 * <p>설　　명	: 기한상실 예상</p>
	 * <p>메소드인수	: AskUnrcvVO</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	private AskUnrcvVO calcLoseExpt(AskUnrcvVO askUnrcvVO) throws Exception {
		//log.info("■ 상실예정계산");
		List askUnrcvObjList = askUnrcvVO.getAskUnrcvObjList();
		for (int i=0, cnt = StringUtil.size(askUnrcvObjList); i< cnt; i++) {

			BndVO bndVO = askUnrcvVO.getBndVO(i);

			if (bndVO == null || !bndVO.isDly()) {
				continue;
			}

			if (bndVO.isLose()) {
				bndVO.exptLoseFg = Constants.YES;
				continue;
			}

			String loseCalcCd  = bndVO.loseCalcCd; 	// 상실계산구분(1:회차, 2:일수)
			int    loseCalcVal = bndVO.loseCalcVal;	// 상실계산값
			String calcSdt = bndVO.dlyStrtDueDt;	// 계산시작일 (청구미수 시작회차 일자)

			String stndDt5 = commBizService.addWkdt( bndVO.setlDt, bndVO.exptLoseDcnt);	// 5영업일 후

			String loseExptDt;	// 상실예정일
			// TODO 오류처리
			log.info("################## JJH 1 ");
			if (Constants.LOSE_CALC_CD_1.equals(loseCalcCd)) {
				log.info("################## JJH 1-1 ");
				loseExptDt = commBizService.isArrvWkdt(DateUtil.addMonth(calcSdt, loseCalcVal), "1");	//상실예정일(회차계산)
			} else {
				log.info("################## JJH 1-2 ");
				loseExptDt = commBizService.isArrvWkdt(DateUtil.addDay(calcSdt, loseCalcVal), "1");	//상실예정일(일수계산)
			}
			log.info("################## JJH 2 ");

			bndVO.loseExptDt = loseExptDt;

			// 상실일자와 상실시작일이 하루 차이가 나므로 0보다 커야함
			if (stndDt5.compareTo(loseExptDt)>0) {
				bndVO.exptLoseFg = Constants.YES;
			}

			askUnrcvVO.setBndVOList(i, bndVO);
		}

		return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: setBndWithFirstRow</p>
	 * <p>설　　명	: 채권정보 셋팅</p>
	 * <p>메소드인수	: AskUnrcvVO</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	private AskUnrcvVO setBndWithFirstRow(AskUnrcvVO askUnrcvVO) throws Exception {
		log.info("::: setBndWithFirstRow :::");
		// 청구미수대상 은 채권과 1:1관계, 상환계획이 없더라도 예가수정보를 담은 채권객체 하나를 가진다.
		// 대상객체.대출번호,순번 <= 상환계획 <= 대상객체.대출번호,순번 관계가 성립되어야 한다.
		RmbrPlanVO rmbrPlanVO = null; // 상환계획
		BndVO bndVO 		  = null; // 채권객체

		int objCnt = askUnrcvVO.sizeAskUnrcvObjList(); //청구미수 대상정보 건수

		while (true) { // 상환계획의 대출번호 대출순번에 해당하는 대상 정보 검색

			askUnrcvVO.askUnrcvObjIdx++; 	//대상_인덱스(내부용)
			askUnrcvVO.bndIdx++;			//채권_인덱스(내부용)
			askUnrcvVO.bndCnt++;			//채권_건수(내부용, ※ 외부용 : sizeBndVOList())

			// 미수정보건수와 대상정보 건수 비교
			if (askUnrcvVO.askUnrcvObjIdx >= objCnt) {
				askUnrcvVO.rsltCd 	= "S001";
				askUnrcvVO.rsltCntn = "대상과 미수정보가 일치하지 않습니다.(전산실문의) / 조회("+askUnrcvVO.askUnrcvObjIdx+") >= 세팅("+objCnt+")";
				throw new Exception("대상과 미수정보가 일치하지 않습니다.(전산실문의) "+askUnrcvVO.askUnrcvObjIdx+">="+objCnt);
			}

			// 대상에 대한 채권정보의 위치 SET
			AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(askUnrcvVO.askUnrcvObjIdx);
			askUnrcvObjVO.bndIdx = askUnrcvVO.bndIdx;

			// 채권정보 세팅(요청정보+대출기본정보+예가수정보)
			bndVO = createBnd(askUnrcvObjVO);

			// 상환계획 객체의 대출번호,대출순번 으로 정렬된 대상에서 대상객체 확인
			rmbrPlanVO = askUnrcvVO.getRmbrPlan(askUnrcvVO.rmbrPlanIdx);

			if (!rmbrPlanVO.loanNo.equals(askUnrcvObjVO.loanNo) || !rmbrPlanVO.loanSeq.equals(askUnrcvObjVO.loanSeq)) {
				// 상환계획 수립전등으로 상환계획이 없는 대출건이 존재함.
				// 이 경우 대출에 대한 예가수정보만 셋팅하고 이후 계산은 하지 않고 loop을 coninue한다.
				askUnrcvObjVO.rsltCd 	= "A001";
				askUnrcvObjVO.rsltCntn 	= "대출번호에 대한 청구대상이 없습니다.";

				// 예가수 잔액 조회결과를 세팅한 채권정보 add
				askUnrcvVO.addBndVO(bndVO);

				continue;
			}

			break;
		}

		// 상환계획 객체를 채권 객체에 설정한다.(회차미수정보(SUM))
		bndVO = convertRmbrPlanVO2BndVO(askUnrcvVO, bndVO, rmbrPlanVO);

		// 선납할인연체료잔액조회(리스가 아닐때)
		if (!isLease(bndVO.prdtLrgeClasCd)) {
			// bndVO = RcptDao.calcPdueDiscDfeeRamt(bndVO, con);
		}

		// 마감여부 가 '1' 일때 한다.
		if (Constants.YES.equals(bndVO.clsFg)) {
			bndVO = rcptService.calcLngsDlyDdcnt(bndVO);	// 최장연체일수 계산
			bndVO = rcptService.calcTotDlyDdcnt(bndVO);	// 누적연체일수 계산
		}

		// 대출상태가 2%가 아니면(대출이 정상대출건이 아닌경우)
		if (rmbrPlanVO.loanStatCd.charAt(0) != '2') {
			bndVO.pamtRamt 	 = 0;
			bndVO.intRamt 	 = 0;
			bndVO.trtFeeRamt = 0;
		}

		// 채권객체 구성
		askUnrcvVO.addBndVO(bndVO);

		return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: createBnd</p>
	 * <p>설　　명	: 대출에 해당하는 채권정보를 생성한다.</p>
	 * <p>메소드인수	: AskUnrcvObjVO, Connection</p>
	 * <p>리　턴　값	: AskUnrcvVO - 미수정보 객체가 setting된 청구미수 객체</p>
	 */
	private BndVO createBnd(AskUnrcvObjVO askUnrcvObjVO) throws Exception {

		BndVO bndVO = new BndVO();
		bndVO.loanNo          = askUnrcvObjVO.loanNo;				// 대출번호
		bndVO.loanSeq         = askUnrcvObjVO.loanSeq;				// 대출순번
		bndVO.prdtLcd         = askUnrcvObjVO.prdtLrgeClasCd; 		// 상품대분류코드
		bndVO.prdtMcd         = askUnrcvObjVO.prdtMidClasCd; 		// 상품중분류코드
		bndVO.prdtScd         = askUnrcvObjVO.prdtSmClasCd; 		// 상품소분류코드
		bndVO.prdtCd          = askUnrcvObjVO.prdtCd; 				// 상품코드
		bndVO.prdtClas        = bndVO.prdtLcd+bndVO.prdtMcd; 		// 상품대중분류코드

		bndVO.setlDt          = askUnrcvObjVO.setlDt; 				// 결제일자
		bndVO.loanDt          = askUnrcvObjVO.loanDt; 				// 대출일자
		bndVO.loanStatCd      = askUnrcvObjVO.loanStatCd;			// 대출상태코드
		bndVO.dsrcNo          = askUnrcvObjVO.dsrcNo; 				// 예가수번호
		bndVO.partRmbrPamt    = askUnrcvObjVO.partRmbrPamt; 		// 부분_상환_원금

		bndVO.loseCalcFg      = askUnrcvObjVO.loseCalcFg; 			// 상실_계산여부
		bndVO.loseCalcCd      = askUnrcvObjVO.loseCalcCd; 			// 상실_계산구분
		bndVO.loseCalcVal     = askUnrcvObjVO.loseCalcVal; 			// 상실_계산구분값

		bndVO.loanAmt         = askUnrcvObjVO.loanAmt; 				// 대출원금
		bndVO.loanAmt10       = (long)Math.floor(bndVO.loanAmt/10);	// 대출원금10%

		bndVO.prdtLrgeClasCd  = askUnrcvObjVO.prdtLrgeClasCd; 		// 상품대분류코드
		bndVO.prdtMidClasCd   = askUnrcvObjVO.prdtMidClasCd; 		// 상품중분류코드
		bndVO.prdtSmClasCd    = askUnrcvObjVO.prdtSmClasCd; 		// 상품소분류코드
		bndVO.asymmAcctFg     = askUnrcvObjVO.asymmAcctFg;			// 비대칭회계여부

		bndVO.loanIntRt       = askUnrcvObjVO.loanIntRt; 			// 대출_이자율
		bndVO.dfeeRt          = 0;//askUnrcvObjVO.dfeeRt; 			// 연체료_율(연체일수별 연체율이 뒷쪽에서 세팅됨)
		bndVO.mainEndTims     = askUnrcvObjVO.mainEndTims; 			// mainEndTims
		bndVO.clsFg           = askUnrcvObjVO.clsFg; 				// 마감여부
		bndVO.trtFee          = askUnrcvObjVO.trtFee; 				// trtFee
		bndVO.addClosGuarAmt  = askUnrcvObjVO.addClosGuarAmt; 		// 추가해지보증금
		bndVO.reSetlDt        = askUnrcvObjVO.reSetlDt; 			// 지연결제일자추가

		// 법적조치비용 조회
		if (askUnrcvObjVO.leglUnCalcFg.equals(Constants.YES)) { //가지급금미계산여부
			// 가지급금미계산
			bndVO.unAdjLeglActnCost   = askUnrcvObjVO.adjLeglActnCost; 		//정산_법적조치비용(미계산)
			bndVO.unLeglActnCostRamt  = askUnrcvObjVO.leglActnCostRamt; 	//법적조치비용_잔액(미계산)
			bndVO.unOccrLeglActnCost  = askUnrcvObjVO.occrLeglActnCost; 	//발생_법적조치비용(미계산)
		} else {
			bndVO.adjLeglActnCost     = askUnrcvObjVO.adjLeglActnCost; 		//정산_법적_조치_비용
			bndVO.leglActnCostRamt    = askUnrcvObjVO.leglActnCostRamt; 	//법적_조치_비용_잔액
			bndVO.occrLeglActnCost    = askUnrcvObjVO.occrLeglActnCost; 	//발생_법적_조치_비용
		}

		bndVO.crdtRcvrUnrcvAmt      = askUnrcvObjVO.crdtRcvrUnrcvAmt; 		//신용_회복_미수금
		bndVO.rmbrCrdtRcvrUnrcvAmt  = askUnrcvObjVO.rmbrCrdtRcvrUnrcvAmt; 	//상환_신용_회복_미수금
		bndVO.crdtRcvrUnrcvAmtRamt  = askUnrcvObjVO.crdtRcvrUnrcvAmtRamt; 	//신용_회복_미수금_잔액

        bndVO.stmpFeeUnrcvNo = askUnrcvObjVO.stmpFeeUnrcvNo;
        bndVO.stmpFeeOccrAmt = askUnrcvObjVO.stmpFeeOccrAmt;
        bndVO.stmpFeeAdjAmt  = askUnrcvObjVO.stmpFeeAdjAmt;
        bndVO.stmpFeeRamt    = askUnrcvObjVO.stmpFeeRamt;

		// 공탁금잔액 셋팅
		bndVO.depsRamt = askUnrcvObjVO.depsRamt;

		// 예가수 잔액계산 계산하여 bndVO에 세팅한다.
		return rcptService.calcDsrc(bndVO);
	}

	/**
	 * <p>메소드명	: getRmbrPlanVO</p>
	 * <p>설　　명	: 상환계획조회결과를 상환객체에 셋팅한다.</p>
	 * <p>메소드인수	: ResultSet</p>
	 * <p>리　턴　값	: RmbrPlanVO</p>
	 */
    private RmbrPlanVO getRmbrPlanVO(MainSqlOUTDTO inMainSqlOUTDTO) throws Exception {

        RmbrPlanVO rmbrPlanVO = new RmbrPlanVO();

        rmbrPlanVO.loanNo                 = inMainSqlOUTDTO.getLoanNo();             // 대출_번호
        rmbrPlanVO.loanSeq                = StringUtil.trim(inMainSqlOUTDTO.getLoanSeq());       // 대출_순번
        rmbrPlanVO.endDivCd               = StringUtil.trim(inMainSqlOUTDTO.getEndDivCd());      // 종료구분코드
        rmbrPlanVO.tims                   = inMainSqlOUTDTO.getTims();          // 회차
        rmbrPlanVO.curTims                = inMainSqlOUTDTO.getCurTims();       // 현재_회차(결제일자기준)
        rmbrPlanVO.thmmDueTims            = inMainSqlOUTDTO.getThmmDueTims();   // 당월_납입_회차(실결제기준)
        rmbrPlanVO.bfmmDueTims            = inMainSqlOUTDTO.getBfmmDueTims();   // 전월_납입_회차(실결제기준)
        rmbrPlanVO.totTims                = inMainSqlOUTDTO.getTotTims();       // 총_회차
        rmbrPlanVO.prdtCd                 = StringUtil.trim(inMainSqlOUTDTO.getPrdtCd());        // 상품_코드
        rmbrPlanVO.rmbrFrmlCd             = StringUtil.trim(inMainSqlOUTDTO.getRmbrFrmlCd());    // 상환_방식_코드
        rmbrPlanVO.dueDt                  = StringUtil.trim(inMainSqlOUTDTO.getDueDt());         // 납입_일자
        rmbrPlanVO.rlDueDt                = StringUtil.trim(inMainSqlOUTDTO.getRlDueDt());       // 실_납입_일자
        rmbrPlanVO.lastSetlDt             = StringUtil.trim(inMainSqlOUTDTO.getLastSetlDt());    // 최종_결제_일자
        rmbrPlanVO.lastSetlTims           = inMainSqlOUTDTO.getLastSetlTims();  // 최종_결제_회차
        rmbrPlanVO.loanEprtDt             = StringUtil.trim(inMainSqlOUTDTO.getLoanEprtDt());    // 대출_만기_일자
        rmbrPlanVO.loanRlEprtDt           = StringUtil.trim(inMainSqlOUTDTO.getLoanRlEprtDt());  // 대출_실_만기_일자
        rmbrPlanVO.loanEprtTims           = inMainSqlOUTDTO.getLoanEprtTims();  // 대출_만기_회차
        rmbrPlanVO.setlDt                 = StringUtil.trim(inMainSqlOUTDTO.getSetlDt());        // 결제_일자
        rmbrPlanVO.askDivCd               = StringUtil.trim(inMainSqlOUTDTO.getAskDivCd());      // 청구_구분_코드
        rmbrPlanVO.timsBfPamtRamt         = inMainSqlOUTDTO.getTimsBfPamtRamt();// 회차_전_원금_잔액
        rmbrPlanVO.timsBfIntRamt          = inMainSqlOUTDTO.getTimsBfIntRamt(); // 회차_전_이자_잔액
        rmbrPlanVO.timsAfPamtRamt         = inMainSqlOUTDTO.getTimsAfPamtRamt();// 회차_후_원금_잔액
        rmbrPlanVO.timsAfIntRamt          = inMainSqlOUTDTO.getTimsAfIntRamt(); // 회차_후_이자_잔액
        rmbrPlanVO.pamt                   = inMainSqlOUTDTO.getPamt();          // 원금
        rmbrPlanVO.intt                   = inMainSqlOUTDTO.getIntt();          // 이자
        rmbrPlanVO.trtFee                 = inMainSqlOUTDTO.getTrtFee();        // 취급수수료

        //리스 관련 금액 주석처리 되어있던거 삭제 [2022-10-13 김형도] 시작
        rmbrPlanVO.ppayInt                = inMainSqlOUTDTO.getPpayInt();                     // 선급이자
        rmbrPlanVO.vtax                   = inMainSqlOUTDTO.getVtax();                        // 부가세
        rmbrPlanVO.addInsuFee             = inMainSqlOUTDTO.getAddInsuFee();                  // 가산보험료
        rmbrPlanVO.addCartax              = inMainSqlOUTDTO.getAddCartax();                   // 가산자동차세
        rmbrPlanVO.addEnvImprBrdnamt      = inMainSqlOUTDTO.getAddEnvImprBrdnamt();           // 가산환개금
        rmbrPlanVO.addAsfee               = inMainSqlOUTDTO.getAddAsfee();                    // 가산정비료
        rmbrPlanVO.ipayInsuFee            = inMainSqlOUTDTO.getIpayInsuFee();                 // 대지급보험료
        rmbrPlanVO.ipayCartax             = inMainSqlOUTDTO.getIpayCartax();                  // 대지급자동차세
        rmbrPlanVO.ipayEnvImprBrdnamt     = inMainSqlOUTDTO.getIpayEnvImprBrdnamt();          // 대지급환개금
        rmbrPlanVO.ipayPnltAmt            = inMainSqlOUTDTO.getIpayPnltAmt();                 // 대지급범칙금
        rmbrPlanVO.ipayEtc                = inMainSqlOUTDTO.getIpayEtc();                     // 대지급기타
        rmbrPlanVO.ltrmBrcvAmt            = inMainSqlOUTDTO.getLtrmBrcvAmt();                 // 장기선수금
        //리스 관련 금액 주석처리 되어있던거 삭제 [2022-10-13 김형도] 종료

        rmbrPlanVO.setlPamt               = inMainSqlOUTDTO.getSetlPamt();                    // 결제_원금
        rmbrPlanVO.setlInt                = inMainSqlOUTDTO.getSetlInt();                     // 결제_이자

        //리스 관련 금액 주석처리 되어있던거 삭제 [2022-10-13 김형도] 시작
        rmbrPlanVO.setlPpayInt            = inMainSqlOUTDTO.getSetlPpayInt();                 // 결제선급이자
        rmbrPlanVO.setlVtax               = inMainSqlOUTDTO.getSetlVtax();                    // 결제부가세
        rmbrPlanVO.setlAddInsuFee         = inMainSqlOUTDTO.getSetlAddInsuFee();              // 결제가산보험료
        rmbrPlanVO.setlAddCartax          = inMainSqlOUTDTO.getSetlAddCartax();               // 결제가산자동차세
        rmbrPlanVO.setlAddEnvImprBrdnamt  = inMainSqlOUTDTO.getSetlAddEnvImprBrdnamt();       // 결제가산환개금
        rmbrPlanVO.setlAddAsfee           = inMainSqlOUTDTO.getSetlAddAsfee();                // 결제가산정비료
        rmbrPlanVO.setlIpayInsuFee        = inMainSqlOUTDTO.getSetlIpayInsuFee();             // 결제대지급보험료
        rmbrPlanVO.setlIpayCartax         = inMainSqlOUTDTO.getSetlIpayCartax();              // 결제대지급자동차세
        rmbrPlanVO.setlIpayEnvImprBrdnamt = inMainSqlOUTDTO.getSetlIpayEnvImprBrdnamt();      // 결제대지급환개금
        rmbrPlanVO.setlIpayPnltAmt        = inMainSqlOUTDTO.getSetlIpayPnltAmt();             // 결제대지급보험료
        rmbrPlanVO.setlIpayEtc            = inMainSqlOUTDTO.getSetlIpayEtc();                 // 결제재지급기타
        rmbrPlanVO.setlLtrmBrcvAmt        = inMainSqlOUTDTO.getSetlLtrmBrcvAmt();             // 결제장기선수금
        rmbrPlanVO.setlRamtAmt            = inMainSqlOUTDTO.getSetlRamtAmt();                 // 잔가금액
        rmbrPlanVO.setlGuarAmt            = inMainSqlOUTDTO.getSetlGuarAmt();                 // 보증금액
        //리스 관련 금액 주석처리 되어있던거 삭제 [2022-10-13 김형도] 종료

        rmbrPlanVO.setlDfee               = inMainSqlOUTDTO.getSetlDfee();                    // 결제_연체_료
        rmbrPlanVO.occrDfee               = inMainSqlOUTDTO.getOccrDfee();                    // 발생_연체_료
        rmbrPlanVO.preOccrDfee            = inMainSqlOUTDTO.getPreOccrDfee();                 // 기_발생_연체_료
        rmbrPlanVO.pdueDfee               = inMainSqlOUTDTO.getPdueDfee();                    // 선납_연체_료
        rmbrPlanVO.exmpDfee               = inMainSqlOUTDTO.getExmpDfee();                    // 면제_연체_료
        rmbrPlanVO.intStrtDt              = StringUtil.trim(inMainSqlOUTDTO.getIntStrtDt());       // 이자_시작_일자
        rmbrPlanVO.intEndDt               = StringUtil.trim(inMainSqlOUTDTO.getIntEndDt());        // 이자_종료_일자

        rmbrPlanVO.dlyFg                  = inMainSqlOUTDTO.getDlyFg();                       // 연체_여부(상환계획납입일자의실납입일자가결제일보다작으면연체임)
        rmbrPlanVO.dlyDt                  = StringUtil.trim(inMainSqlOUTDTO.getDlyDt());           // 연체_일자
        rmbrPlanVO.dlyCalcDt              = StringUtil.trim(inMainSqlOUTDTO.getDlyCalcDt());       // 연체_계산_일자
        rmbrPlanVO.dlyStrtTims            = inMainSqlOUTDTO.getDlyStrtTims();                 // 연체_시작_회차

        rmbrPlanVO.loanStatCd             = StringUtil.trim(inMainSqlOUTDTO.getLoanStatCd());     // 대출상태코드
        rmbrPlanVO.loseCalcDueDt          = StringUtil.trim(inMainSqlOUTDTO.getLoseCalcDueDt());  // 상실.상실이자계산일
        rmbrPlanVO.loseCalcRlDueDt        = StringUtil.trim(inMainSqlOUTDTO.getLoseCalcRlDueDt());// 상실.상실이자계산일
        rmbrPlanVO.timsBfAskPamt          = inMainSqlOUTDTO.getTimsBfAskPamt();              // 회차전청구원금
        rmbrPlanVO.loseObjPsgInt          = inMainSqlOUTDTO.getLoseObjPsgInt();              // 상실.경과이자대상금액
        rmbrPlanVO.loseIntStrtDt          = StringUtil.trim(inMainSqlOUTDTO.getLoseIntStrtDt());  // 상실.경과이자계산시작일
        rmbrPlanVO.loseIntEndDt           = StringUtil.trim(inMainSqlOUTDTO.getLoseIntEndDt());   // 상실.경과이자계산종료일
        rmbrPlanVO.termPartFg             = getFg(inMainSqlOUTDTO.getTermPartFg());          // 거치분할여부
        rmbrPlanVO.termPartIntEndDt       = StringUtil.trim(inMainSqlOUTDTO.getTermPartIntEndDt());	// 거치분할이자종료일자
        rmbrPlanVO.termPartInt            = inMainSqlOUTDTO.getTermPartInt();                // 거치이자
        rmbrPlanVO.midTermPartInt         = inMainSqlOUTDTO.getMidTermPartInt();             // 중도상환거치이자
        rmbrPlanVO.unrcvTims              = inMainSqlOUTDTO.getUnrcvTims();                  // 미수회차

        rmbrPlanVO.mainRmbrPamt           = inMainSqlOUTDTO.getMainRmbrPamt();               // 상환금
        rmbrPlanVO.preRcptFg              = getFg(inMainSqlOUTDTO.getPreRcptFg());           // 선납여부
        rmbrPlanVO.fcntTims               = inMainSqlOUTDTO.getFcntTims();                    // 초회
        rmbrPlanVO.fcntDueDt              = inMainSqlOUTDTO.getFcntDueDt();                   // 초회납입일자
        rmbrPlanVO.setlTrtFee             = inMainSqlOUTDTO.getSetlTrtFee();                  // 결제취급수수료

        return rmbrPlanVO;
	}

	/**
	 * <p>메소드명	: convertRmbrPlanVO2BndVO</p>
	 * <p>설　　명	: 상환계획 조회결과를 채권객체에 셋팅한다.</p>
	 * <p>메소드인수	: AskUnrcvVO, BndVO, RmbrPlanVO</p>
	 * <p>리　턴　값	: BndVO</p>
	 */
	private BndVO convertRmbrPlanVO2BndVO(AskUnrcvVO askUnrcvVO, BndVO bndVO, RmbrPlanVO rmbrPlanVO) {

		bndVO.curTims           = rmbrPlanVO.curTims;		// 현재_회차(조회결제일기준/영업일미보정)
		bndVO.thmmDueTims       = rmbrPlanVO.thmmDueTims; 	// 당월_납입_회차
		bndVO.bfmmDueTims       = rmbrPlanVO.bfmmDueTims; 	// 당월_납입_회차
		bndVO.midRmbrTims       = rmbrPlanVO.thmmDueTims; 	// 중도_상환_회차 = 당월납입회차
		bndVO.totTims           = rmbrPlanVO.totTims; 		// 총회차
		bndVO.rmbrFrmlCd        = rmbrPlanVO.rmbrFrmlCd; 	// 상환방식

		bndVO.stndDueDt         = rmbrPlanVO.dueDt; 		// 기준납입일자 = 납입_일자
		bndVO.stndRlDueDt       = rmbrPlanVO.rlDueDt; 		// 기준실납입일자 = 실_납입일자
		bndVO.stndThmmDueTims   = rmbrPlanVO.thmmDueTims; 	// 기준당월납입회차 = 당월_납입_회차
		bndVO.thmmDueDt         = rmbrPlanVO.dueDt; 		// 당월납입일자 = 납입일자
		bndVO.thmmRlDueDt       = rmbrPlanVO.rlDueDt; 		// 당월실납입일자 = 실납입일자
		bndVO.lastSetlDt        = rmbrPlanVO.lastSetlDt; 	// 최종결제일자
		bndVO.lastSetlTims      = rmbrPlanVO.lastSetlTims; 	// 최종결제회차
		bndVO.loanEprtDt        = rmbrPlanVO.loanEprtDt; 	// 대출만기일자
		bndVO.loanRlEprtDt      = rmbrPlanVO.loanRlEprtDt; 	// 대출실만기일자

		bndVO.loanEprtTims      = rmbrPlanVO.loanEprtTims; 	// 대출만기회차
		bndVO.unrcvTims         = rmbrPlanVO.unrcvTims; 	// 미수회차
		bndVO.mainRmbrPamt      = rmbrPlanVO.mainRmbrPamt; 	// 주상환원금

		bndVO.pamtRamt          = rmbrPlanVO.pamt; 			// 원금잔액
		bndVO.intRamt           = rmbrPlanVO.intt; 			// 이자잔액
		bndVO.trtFeeRamt        = rmbrPlanVO.trtFee; 		// 취급수수료잔액

		bndVO.preOccrDfee       = rmbrPlanVO.preOccrDfee; 		// 기발생연체료
		bndVO.dlyFg             = rmbrPlanVO.dlyFg; 			// 연체여부

		bndVO.termPartFg        = rmbrPlanVO.termPartFg; 		// 거치분할여부
		bndVO.termPartIntEndDt  = rmbrPlanVO.termPartIntEndDt; 	// 거치이자종료일자
		bndVO.termPartInt       = rmbrPlanVO.termPartInt; 		// 거치분할이자
		bndVO.midTermPartInt    = rmbrPlanVO.midTermPartInt; 	// 중도상환거치분할이자
		bndVO.loseFg            = rmbrPlanVO.loseFg;  			// 상실_여부
		bndVO.loseDueDt         = rmbrPlanVO.loseDueDt;  		// 상실_납입_일자
		bndVO.preRcptFg         = rmbrPlanVO.preRcptFg; 		// 선수납여부
		bndVO.fcntTims          = rmbrPlanVO.fcntTims; 			// 초회차
		bndVO.fcntDueDt         = rmbrPlanVO.fcntDueDt; 		// 초회납일일

		bndVO.midRmbrFg         = Constants.YES; 			// 중도_상환_여부
		bndVO.partRmbrFg        = Constants.YES; 			// 부분_상환_여부
		bndVO.midRmbrCalcFg     = Constants.YES; 			// 중도상환계산여부
		bndVO.midRmbrHidFg      = Constants.NO; 			// 중도상환금액숨김여부

		// 중도상환회차
		bndVO.midRmbrTims       = bndVO.stndThmmDueTims; //기준당월납입회차
		if (bndVO.stndDueDt.compareTo(bndVO.setlDt) <= 0 && bndVO.stndRlDueDt.compareTo(bndVO.setlDt) >= 0) {
			// 중도상환회차가 납입일자당일(실납입일자이전)이면 다음회차가 중도상환회차임.
			bndVO.midRmbrTims     = (bndVO.stndThmmDueTims+1>bndVO.loanEprtTims)?bndVO.loanEprtTims:(bndVO.stndThmmDueTims+1);
			bndVO.dueDtMidRmbrFg  = Constants.YES; //납입일_중도상환_여부 (납입일자에 중도상환을 하는경우 '1', 아니면 '0')
		}

        //기준실납입일자<결제일자 && 중도_상환_회차 >=대출_만기_회차
        if (bndVO.stndRlDueDt.compareTo(bndVO.setlDt) < 0 && bndVO.midRmbrTims >= bndVO.loanEprtTims) {
            bndVO.midRmbrHidFg  = Constants.YES; 	//중도상환금액숨김여부
            bndVO.midRmbrFg     = Constants.NO; 	//중도_상환_여부
            bndVO.partRmbrFg    = Constants.NO;   	//부분_상환_여부
            // 만기회차가 지났어도 중도상환 금액 계산은 하도록 수정
            bndVO.midRmbrTims   = -1; //중도_상환_회차
        }

		AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(bndVO.loanNo, bndVO.loanSeq);

		//대출확정, 기한상실 아닐때 가능
		if (!"22".equals(bndVO.loanStatCd) || "15".equals(askUnrcvObjVO.bndStatCd)) {
			bndVO.midRmbrHidFg  = Constants.YES;
			bndVO.midRmbrCalcFg = Constants.NO;
			bndVO.midRmbrFg     = Constants.NO;
			bndVO.partRmbrFg    = Constants.NO;
		}

		// 선결제가 있으면 중도상환할수 없다 / 중도상환 금액계산은 한다.
		if (bndVO.preRcptFg.equals(Constants.YES)) {
			bndVO.midRmbrFg     = Constants.NO;
			bndVO.partRmbrFg    = Constants.NO;
		}

		return bndVO;
	}


	/**
	 * <p>메소드명	: setAskUnrcvWithTims</p>
	 * <p>설　　명	: 채권정보에 회차정보를 누적한다.</p>
	 * <p>메소드인수	: AskUnrcvVO, Connection</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	private AskUnrcvVO setAskUnrcvWithTims(AskUnrcvVO askUnrcvVO) throws Exception {
		//log.info("■ AskUnrcvProcCC.setAskUnrcvWithTims");
		BndVO bndVO 		  = askUnrcvVO.getBndVO(askUnrcvVO.askUnrcvObjIdx); // 채권
		RmbrPlanVO rmbrPlanVO = askUnrcvVO.getRmbrPlan(askUnrcvVO.rmbrPlanIdx); // 상환계획

		// 조건에 따라 채권,회차미수 객체를 SET한다.
		TimsUnrcvVO timsUnrcvVO = createTimsUnrcvVO(askUnrcvVO, bndVO, rmbrPlanVO);

		if (timsUnrcvVO.tims == bndVO.midRmbrTims) { //회차 == 중도_상환_회차
			bndVO.setMidRmbrTims(timsUnrcvVO);
		}

		if (bndVO.midRmbrTims > 0) { // 중도상환 가능

			if (bndVO.midRmbrTims <= timsUnrcvVO.tims && bndVO.setlDt.compareTo(timsUnrcvVO.dueDt) < 0) {//채권.중도_상환_회차 <= 회차 && 채권.결제일자 < 납입_일자

				bndVO.midPreDueAmt  	+= timsUnrcvVO.setlAmt;		// 중도선납금액 		+= 결제_금액
				bndVO.midPreDuePamt 	+= timsUnrcvVO.setlPamt;	// 중도선납경과원금 	+= 결제_원금
				bndVO.midPreDueInt  	+= timsUnrcvVO.setlInt;		// 중도선납이자 		+= 결제_이자
				bndVO.midPreDueTrtFee 	+= timsUnrcvVO.setlTrtFee;	// 중도선납취급수수료	+= 결제취급수수료
				bndVO.midPreDueTint 	+= timsUnrcvVO.setlTint;	// 중도선납_총이자 	+= 결제총이자

				// 원금잔액(중도상환대상원금)
				bndVO.calcPamtRamt 			+= timsUnrcvVO.mmPamt;//계산원금잔액 += 월_원금
				bndVO.calcDivsTrtFeeRamt 	+= timsUnrcvVO.trtFee;//계산분할취급수수료잔액 += 취급수수료
			}

			// 중도상환전 받아야할 연체,정상금
			if (bndVO.midRmbrTims >= timsUnrcvVO.tims && bndVO.setlDt.compareTo(timsUnrcvVO.dueDt) >= 0) {	//채권.중도_상환_회차 >= 회차 && 채권.결제일자 >= 납입_일자
				// 중도상환전 받아야할(연체,정상금) 원금, 취급수수료
				bndVO.totPamt 		+= timsUnrcvVO.askPamt;		//누적원금 		+= 청구_원금
				bndVO.totDivsTrtFee += timsUnrcvVO.askTrtFee;	//누적취급수수료 	+= 청구취급수수료
			}
		}

		// 중도상환을 납입일자 당일에 할경우 경과일수, 정상원금, 이자를 계산하기 위한 회차정보를 셋팅한다.
		if (timsUnrcvVO.dueDt.equals(bndVO.setlDt)) {
			bndVO.setBfMidRmbrTims(timsUnrcvVO);
		}

		// 납입일자 <= 결제일자 <= 실납입일자 : 납입일자 구간에 중도상환 하는 경우
		if (timsUnrcvVO.dueDt.compareTo(bndVO.setlDt) <= 0 && bndVO.setlDt.compareTo(timsUnrcvVO.rlDueDt) <= 0) {
			bndVO.setDueDtMidRmbrTims(timsUnrcvVO);
		}

		// 받아야할 금액이 없으면 추가하지 않는다.
		if (  timsUnrcvVO.askPamt 		  == 0 && timsUnrcvVO.askInt        == 0
			&& timsUnrcvVO.askTrtFee 	  == 0 && timsUnrcvVO.preOccrDfee   == 0) {

			askUnrcvVO.setBndVOList(askUnrcvVO.askUnrcvObjIdx, bndVO);
			return askUnrcvVO;
		}

		askUnrcvVO.addTimsUnrcv(timsUnrcvVO); //회차미수객체 리스트에 추가한다.
		bndVO.timsUnrcvCnt++;	//회차_미수_건수 ++

		if (bndVO.timsUnrcvCnt == 1) {	//회차_미수_건수 == 1

			/*******************************************************************************************
			 * 미회수 첫회차에 대해 채권,회차미수 객체를 SET한다
			 * ASIS 메소드 밖으로 꺼내와서 처리 - addFirstTimsToBnd(askUnrcvVO, bndVO, timsUnrcvVO, rmbrPlanVO, con)
			 ******************************************************************************************/
			// 최초 당월납입회차는 기준회차값을 가짐.
			// 선납, 원금,이자등 청구금이 없는 회차는 SKIP하고 다음 청구할 회차를 당월납입회차로 수정한다.
			if (timsUnrcvVO.tims > bndVO.thmmDueTims) {
				// 선납등에 의해 기준회차 > (상환계획)당월회차 일때
				bndVO.thmmDueTims = rmbrPlanVO.tims;		//채권.당월납입회차	= 상환계획.회차
				bndVO.thmmRlDueDt = rmbrPlanVO.rlDueDt;		//채권.당월실납입일자	= 상환계획.실납입일자
				bndVO.thmmDueDt   = rmbrPlanVO.dueDt;		//채권.당월납입일자	= 상환계획.납입일자
			}

			/* 대출채권별 회차미수 시작 인텍스 SET */
			bndVO.timsUnrcvStrtIdx = askUnrcvVO.timsUnrcvIdx;	// 회차미수_시작인덱스 = 회차미수_인덱스(내부용)

			/* 미회수 첫회차에 법적조치비용을 SET한다 */
			timsUnrcvVO.leglActnCost = bndVO.leglActnCostRamt;	// 법적조치비용 = 법적조치비용잔액
			timsUnrcvVO.stmpFee = bndVO.stmpFeeRamt;

			timsUnrcvVO.askAmt 	+= timsUnrcvVO.leglActnCost;	// 청구금액		+= 법적조치비용
			timsUnrcvVO.askAmt 	+= timsUnrcvVO.stmpFee;			// 청구금액		+= 인지세(잔액)

			bndVO.unrcvAmt 		+= bndVO.leglActnCostRamt;		// 채권.미수금액	+= 법적조치비용잔액
			bndVO.unrcvAmt 		+= bndVO.stmpFeeRamt;		// 채권.미수금액	+= 인지세

			// 연체일때
			if (Constants.YES.equals(bndVO.dlyFg)) {
				bndVO.dlyDt 		= rmbrPlanVO.dlyDt;		//연체일자
				bndVO.dlyCalcDt 	= rmbrPlanVO.dlyCalcDt;	//연체계산일자
				bndVO.dlyStrtTims 	= rmbrPlanVO.tims;		//연체시작회차
			}

			/*****************************************************************************************
			 * 상실여부 확인
			 * ASIS 메소드 밖으로 꺼내와서 처리 - chkLose(askUnrcvVO, bndVO, timsUnrcvVO, rmbrPlanVO)
			 *****************************************************************************************/
			if (Constants.YES.equals(bndVO.loseCalcFg)) {

				AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(askUnrcvVO.askUnrcvObjIdx);

				if (askUnrcvObjVO.ddayPrftLoseStrtTims > 0) {
					// 기존에 상실인 경우. 상실납입일자이후 수납이 된 경우 시작 회차를 모를수 있어 채권마감에서 항목으로 관리
					DlyCalcVO dlyCalcVO = askUnrcvService.searchLoseDueDt(askUnrcvObjVO.loanNo, askUnrcvObjVO.loanSeq, askUnrcvObjVO.ddayPrftLoseStrtTims);

					if (dlyCalcVO == null) {
						throw new Exception("기한상실 회차가 존재하지 않습니다.");
					}

					bndVO.ddayPrftLoseStrtTims = askUnrcvObjVO.ddayPrftLoseStrtTims;
					bndVO.loseFg = Constants.YES;	// 상실여부
					bndVO.loseDt = dlyCalcVO.dueDt;
					bndVO.loseDueDt = dlyCalcVO.rlDueDt;
				} else {

					// 새로 기한상실 여부를 체크한다.
					long ddCnt = StringUtil.dateDiff(bndVO.dlyDt, bndVO.setlDt)+1;
					int dlyCnt = bndVO.thmmDueTims - rmbrPlanVO.tims;	//당월납입회차 - 회차

					if (dlyCnt > 0) {
						String  loseCalcCd  = bndVO.loseCalcCd; 	// 상실계산구분(1:회차, 2:일수)

						int loseCalcVal = bndVO.loseCalcVal;	// 상실계산기준값
						int dlyVal = (int) ("1".equals(loseCalcCd)?dlyCnt:ddCnt);	// 연체값 (LOSE_CD에 따라 회차수/일수)

						if (dlyVal > loseCalcVal) {

							if ("1".equals(loseCalcCd)) {	//연체회차

								DlyCalcVO dlyCalcVO = askUnrcvService.searchLoseDueDtAddTims(askUnrcvObjVO.loanNo, askUnrcvObjVO.loanSeq, rmbrPlanVO.tims + loseCalcVal);

								if (dlyCalcVO != null) {
									bndVO.loseFg = Constants.YES;	// 상실여부
									bndVO.loseDt = dlyCalcVO.dueDt;
									bndVO.loseDueDt = dlyCalcVO.rlDueDt;
									bndVO.ddayPrftLoseStrtTims = dlyCalcVO.tims;
								}

							} else {	//연체일수
								String loseRlDueDt = DateUtil.addDay(rmbrPlanVO.rlDueDt, loseCalcVal);	// 상실기준일

								DlyCalcVO dlyCalcVO = askUnrcvService.searchLoseDueDt(askUnrcvObjVO.loanNo, askUnrcvObjVO.loanSeq, loseRlDueDt);

								if (dlyCalcVO != null) {
									bndVO.loseFg = Constants.YES;	// 상실여부
									bndVO.loseDt = dlyCalcVO.dueDt;
									bndVO.loseDueDt = dlyCalcVO.rlDueDt;
									bndVO.ddayPrftLoseStrtTims = dlyCalcVO.tims;
								}
							}
						}
					}
				}
			}
		}

		// 실제청구금액 확인 (원 스케줄상 받아야 할금액. 선납등을 고려하여 실제남 받아야할 남은금액.
		// ex) 받아야 할 회차가 선납된경우 실제청구금액은 0원 이다.
		if (timsUnrcvVO.dueDt.compareTo(bndVO.setlDt) <= 0) { //납입_일자 <= 결제일자
			bndVO.stndAskAmt += timsUnrcvVO.askAmt; // 기준청구금액 += 청구_금액
			bndVO.addRealAskTims(timsUnrcvVO);		// 실청구회차
		}

		if (bndVO.stndThmmDueTims == rmbrPlanVO.tims) { // 기준회차 인덱스 (기준당월납입회차 == 회차)
			// 한회차 이상 선납된경우 -1 셋팅됨, 청구금액이 (무이자 등) 없는 경우도 -1 입력됨.
			bndVO.stndTimsIdx = askUnrcvVO.timsUnrcvIdx; //기준회차인덱스 = 회차_미수_인덱스(내부용)
		}

		// 회차별 처리건수 셋팅
		if (timsUnrcvVO.rlDueDt.compareTo(bndVO.setlDt) <= 0) { //실_납입_일자 <= 결제일자
			bndVO.procCnt++;//처리건수++
		}

		// 연체 - 정상 - 미도래 회차내역 계산
		if (Constants.ASK_DIV_UNCOMG.equals(rmbrPlanVO.askDivCd) && (bndVO.thmmDueTims == rmbrPlanVO.tims)) {// 미도래 == 청구구분코드 && 당월_납입_회차 == 회차
			// 미도래 회차지만 한회차 완납선납 등의 이유로 당월 회차로 인식해야할때
			rmbrPlanVO.askDivCd = Constants.ASK_DIV_NORM;
		}

		timsUnrcvVO.askDivCd = rmbrPlanVO.askDivCd;//청구구분코드
		timsUnrcvVO.askDivNm = StringUtil.decode(timsUnrcvVO.askDivCd, new String[]{"1","연체","2","정상","3","미도래"});	//청구구분명

		if (Constants.ASK_DIV_DLY.equals(rmbrPlanVO.askDivCd)) { // 연체계산 셋팅

			if (bndVO.isLose()) {//상실_여부 -- addFirstTimsToBnd 여기서 세팅한다.
				timsUnrcvVO.loseDueDt 	= rmbrPlanVO.loseCalcDueDt; //상실_납입_일자 = 차회차 납입일자
				timsUnrcvVO.loseFg 		= bndVO.loseFg;//상실_여부
			}

			/*******************************************************************************************
			 * 연체계산 - 시작
			 * ASIS 메소드 밖으로 꺼내와서 처리 - calcDfee(askUnrcvVO, bndVO, timsUnrcvVO)
			 ******************************************************************************************/
			// 연체료 계산을 위한 객체 생성
			DlyCalcVO dlyCalcVO = new DlyCalcVO();
			dlyCalcVO.loanNo 		= timsUnrcvVO.loanNo;	//대출번호
			dlyCalcVO.loanSeq 		= timsUnrcvVO.loanSeq;	//대출순번
			dlyCalcVO.tims 			= timsUnrcvVO.tims;		//회차
			dlyCalcVO.dueDt 		= timsUnrcvVO.dueDt;	//납입_일자
			dlyCalcVO.rlDueDt 		= timsUnrcvVO.rlDueDt;	//실_납입_일자
			dlyCalcVO.dlyCalcDt 	= timsUnrcvVO.dlyCalcDt;//연체_계산_일자(실납입일자 + 1day or 최종결제일자 + 1day)
			dlyCalcVO.setlDt 		= timsUnrcvVO.setlDt;	//결제_예정일자 -> 결제일자
			dlyCalcVO.thmmDueTims 	= bndVO.thmmDueTims;	//당월_납입_회차
			dlyCalcVO.thmmRlDueDt 	= bndVO.thmmRlDueDt;	//당월_실_납입_일자
			dlyCalcVO.thmmDueDt 	= bndVO.thmmDueDt;		//당월납입일자
			dlyCalcVO.lastSetlDt 	= timsUnrcvVO.lastSetlDt;//최종_결제일자
			dlyCalcVO.timsBfAskPamt = timsUnrcvVO.askPamt;	//연체_원금액 = 청구_원금
			dlyCalcVO.stndRt 		= bndVO.loanIntRt;		//정상이자율 = 대출_이자율
			dlyCalcVO.askInt 		= timsUnrcvVO.askInt;	//회차청구이자
			dlyCalcVO.rmbrFrmlCd    = timsUnrcvVO.rmbrFrmlCd;	//상환방식
			dlyCalcVO.tooltipFg     = askUnrcvVO.tooltipFg;	//툴팁표시여부

			if (StringUtil.isNull(timsUnrcvVO.rlDueDt)) {
				throw new BizException("RL_DUE_DT is Null... 상환계획을 확인하십시오.");
			}

			String rlDueDtAddOneDay = DateUtil.addDay(timsUnrcvVO.rlDueDt, 1);	//실_납입_일자 + 1day

			//2022-07-12 주석해제
			// 기한상실후 원금에 대해서만 연체료 계산을 원리금으로 처리하도록 수정
			if (Constants.YES.equals(bndVO.loseFg) && timsUnrcvVO.tims  >= bndVO.ddayPrftLoseStrtTims) {
				// 기한상실후 연체료계산
				dlyCalcVO.dlyAmt = timsUnrcvVO.askPamt;    //연체_금액 = 청구_원금
				dlyCalcVO.dfeeCalcDt = StringUtil.max(timsUnrcvVO.lastSetlDt, dlyCalcVO.dueDt); 	//연체료_계산_일자 = getMax(최종결제일자,납입_일자)
			}

			// 청구금액들의 sum -> askAmt로 수정
			dlyCalcVO.dlyAmt = timsUnrcvVO.askAmt - timsUnrcvVO.leglActnCost - timsUnrcvVO.stmpFee;	//연체_금액 = 청구원금 - 법적조치비용 - 인지세

			// 연체회차가 1이상이면 결제일이 연체계산시작일자 입니다
			if (bndVO.dlyCnt + 1 == 1) {
				if (StringUtils.equals(timsUnrcvVO.dueDt, timsUnrcvVO.rlDueDt)) {
					dlyCalcVO.dfeeCalcDt = StringUtil.max(timsUnrcvVO.lastSetlDt, timsUnrcvVO.rlDueDt);
				} else {
					dlyCalcVO.dfeeCalcDt = StringUtil.max(timsUnrcvVO.lastSetlDt, rlDueDtAddOneDay);
				}
			} else {
				dlyCalcVO.dfeeCalcDt = StringUtil.max(timsUnrcvVO.lastSetlDt, timsUnrcvVO.dueDt);
			}

			//연체시작일자에 결제를 할경우. 최종결제일자는 한번 결제한 경우이므로 제함.
			if (StringUtils.equals(rlDueDtAddOneDay, bndVO.setlDt) && !StringUtils.equals(rlDueDtAddOneDay, timsUnrcvVO.lastSetlDt)) {
				dlyCalcVO.isAddOneDayDfee = true;
			}

			dlyCalcVO.loseDueDt = bndVO.loseDueDt; //상실납입일자

			if (bndVO.isLose()) {	//상실

				dlyCalcVO.loseDt = bndVO.loseDt;	//상실일자
				dlyCalcVO.loseFg = bndVO.loseFg;	//상실여부

				if (timsUnrcvVO.tims == bndVO.dlyStrtTims) {
					bndVO.loseStndPramt = bndVO.pamtRamt - timsUnrcvVO.timsBfAskPamt + timsUnrcvVO.askPamt;
				}

				// 상실시작 회차인지 여부
				if (bndVO.ddayPrftLoseStrtTims ==  timsUnrcvVO.tims) {	//기한_이익_상실_시작_회차 == 미수회차

					//dlyCalcVO.loseCalcEndDt = getMin(bndVO.setlDt, StringUtil.addMonth(timsUnrcvVO.intEndDt,+1));
					dlyCalcVO.loseCalcEndDt = StringUtil.min(bndVO.setlDt, DateUtil.addMonth(timsUnrcvVO.intEndDt,+1));
					dlyCalcVO.isLoseTims1 = "1";	// 상실1회차
				}

				// 현재 회차가 상실인지 여부
				if (dlyCalcVO.isLoseTims1.equals("1") || StringUtil.dateDiff(bndVO.loseDueDt, timsUnrcvVO.dueDt) >= 0) {
					dlyCalcVO.isLoseTims = "1";
					timsUnrcvVO.askDivNm = "상실";
				}

				// 상실기준원금잔액 (상실시작회차의 원금잔액)
				if (dlyCalcVO.isLoseTims1.equals("1")) {
					// 상실 이후 회차부터는 이금액을 고정으로하여 계속 상실이자를 구한다.
					// 회차전 원금(원금_잔액 - 회차_전_청구_원금 + 당회차원금) => 당회차원금을 더해야 회차전 원금이 된다
					bndVO.loseStndPramt = bndVO.pamtRamt - timsUnrcvVO.timsBfAskPamt + timsUnrcvVO.askPamt;
				}
			}

			//상실이자 계산여부
			if (bndVO.isLose() && dlyCalcVO.isLoseTims.equals("1")) {

				// 상실기준일 당시 회차의 원금잔액
				dlyCalcVO.loseBalPamt = bndVO.loseStndPramt;

				// 기한상실 연체료 구간
				if (bndVO.loseDueDt.compareTo(timsUnrcvVO.dueDt) < 0) {	//채권.상실납입일자  < 회차미수.납입일자
					dlyCalcVO.loseCalcStrtDt = StringUtil.max(timsUnrcvVO.lastSetlDt, timsUnrcvVO.loseIntStrtDt); //상실계산시작일 = getMax(회차미수.최종결제일자, 회차미수.상실이자시작일자)

				} else {
					dlyCalcVO.loseCalcStrtDt = StringUtil.max(timsUnrcvVO.lastSetlDt, bndVO.loseDt);	//상실계산시작일 = getMax(회차미수.최종결제일자, 채권.상실납입일자)
				}

				dlyCalcVO.loseCalcEndDt 	= StringUtil.min(bndVO.setlDt, timsUnrcvVO.loseIntEndDt);	//상실계산종료일 = getMin(채권.결제일자, 회차미수.상실이자종료일자);

				// 경과이자 일할계산(회차경과일수구간-분자)
				dlyCalcVO.loseIntPsgStrtDt = StringUtil.max(dlyCalcVO.dueDt, bndVO.loseDt);	//상실경과이자시작일 = 스케쥴수납일(상실경과이자는 정상이자분이므로)
				dlyCalcVO.loseIntPsgStrtDt = StringUtil.max(dlyCalcVO.loseIntPsgStrtDt, timsUnrcvVO.lastSetlDt);	//기수납일있으면 수납일부터 경과이자계산
				dlyCalcVO.loseIntPsgEndDt  = dlyCalcVO.loseCalcEndDt;	//상실경과이자종료일 = 상실계산종료일
				dlyCalcVO.loseObjPsgInt    = timsUnrcvVO.loseObjPsgInt;	//납입일자 이후 회차의 정상이자=>연체료계산 쿼리에서 상실경과일수만큼 일할하여 빼주게된다)

				// 경과이자 일할계산(회차총일수구간-분모)
				dlyCalcVO.loseIntCalcStrtDt = timsUnrcvVO.loseIntStrtDt;	//상실이자시작일 = 회차미수.상실이자시작일
				dlyCalcVO.loseIntCalcEndDt 	= timsUnrcvVO.loseIntEndDt;		//상실이자종료일 = 회차미수.상실이자종료일
				dlyCalcVO.isAddOneDayLoseDfee = dlyCalcVO.isAddOneDayDfee;
			}

			// 연체료계산(연체1회차 휴일정상이자계산을 위해 bndVO.dlyCnt가 필요하여 bndVO 파라미터 추가)
			dlyCalcVO = askUnrcvService.calcDfee(dlyCalcVO);

			//대출만기일자 < 결제일자 && 당월실납입일자 < 결제일자
			if ((bndVO.loanEprtDt.compareTo(bndVO.setlDt) < 0) && (bndVO.thmmRlDueDt.compareTo(bndVO.setlDt) < 0)) {
				dlyCalcVO.dlyTcnt = dlyCalcVO.dlyTcnt + 1;	// 연체_횟수 = 연체_횟수 + 1
			}

			if (timsUnrcvVO.lastSetlDt.compareTo(bndVO.setlDt) > 0) {
				timsUnrcvVO.setlDfee = 0;
			}

			// 청구연체료 = 연체료 + 수납발생연체료 + 상실이자 -경과이자
			timsUnrcvVO.askDfee = (dlyCalcVO.dfee + timsUnrcvVO.preOccrDfee + dlyCalcVO.loseRamtDfee) - dlyCalcVO.losePsgInt;

			// 상실수정사항
			timsUnrcvVO.occrDfee = dlyCalcVO.dfee; //발생연체료 = 연체료

			/* 선납할인후 청구금액을 SET한다. !!!!현재 쓰지 않는 기능!!!!*/
			if (bndVO.pdueDiscDfeeRamt > 0) {
				// 선납할인연체료가 있을때 그 할인금액만큼 연체료에서 제한다.
				if (bndVO.pdueDiscDfeeRamt >= timsUnrcvVO.askDfee) {
					timsUnrcvVO.pdueDiscDfee = timsUnrcvVO.askDfee;
					timsUnrcvVO.askDfee = 0;
					bndVO.pdueDiscDfeeRamt -= timsUnrcvVO.pdueDiscDfee;
				} else {
					timsUnrcvVO.pdueDiscDfee = bndVO.pdueDiscDfeeRamt;
					timsUnrcvVO.askDfee -= timsUnrcvVO.pdueDiscDfee;
					bndVO.pdueDiscDfeeRamt = 0;
				}
				bndVO.pdueDiscDfee = bndVO.pdueDiscDfee + timsUnrcvVO.pdueDiscDfee;
			}

			// [강제해지]연체료조정금액이 있을경우 그 금액만큼 연체료에서 제한다.
			if (bndVO.dfeeAdjuAmt > 0) { //연체료조정금
				if (bndVO.dfeeAdjuAmt >= timsUnrcvVO.askDfee) { //연체료조정금 >= 청구_연체료
					bndVO.dfeeAdjuAmt -= timsUnrcvVO.askDfee;	//연체료조정금 -= 청구_연체료
					timsUnrcvVO.askDfee = 0;					//청구_연체료 = 0
					timsUnrcvVO.dlyFg = "0";					//회차미수.연체여부 = 0
				} else {
					timsUnrcvVO.askDfee -= bndVO.dfeeAdjuAmt;	//청구_연체료 -= 연체료조정금
					bndVO.dfeeAdjuAmt = 0;						//연체료조정금 = 0
				}
			}

			timsUnrcvVO.dfeeCalcDt 	 = dlyCalcVO.dfeeCalcDt;	//연체료_계산_일자
			timsUnrcvVO.dlyDdcnt 	 = dlyCalcVO.dlyDdcnt;		//연체_일수
			if (timsUnrcvVO.lastSetlDt.compareTo(bndVO.setlDt)>0) {
				timsUnrcvVO.dlyDdcnt = 0;	// 결제일을 기수납일 이전으로 조회 할 시 (연체일수는 0)
			}
			timsUnrcvVO.occrDlyDdcnt = (int) StringUtil.parseNature(dlyCalcVO.occrDlyDdcnt);	//발생연체일수
			timsUnrcvVO.dlyMmCnt 	 = dlyCalcVO.dlyMmCnt;		//연체_개월수
			timsUnrcvVO.dlyTcnt 	 = dlyCalcVO.dlyTcnt;		//연체_횟수
			timsUnrcvVO.dfeeRt 		 = dlyCalcVO.dfeeRt;		//연체료율
			timsUnrcvVO.addDfeeRt 	 = dlyCalcVO.addDfeeRt;		//가산연체료율
			timsUnrcvVO.loseDfeeRt 	 = dlyCalcVO.loseDfeeRt;	//상실연체료율
			timsUnrcvVO.askAmt      += timsUnrcvVO.askDfee;		//청구_금액 += 청구_연체료

			timsUnrcvVO.holyDfee     = dlyCalcVO.holyDfee;		//휴일_연체료
			timsUnrcvVO.dlyCalcSdt   = dlyCalcVO.dlyCalcSdt;	//연체계산_시작일
			timsUnrcvVO.dlyCalcEdt   = dlyCalcVO.dlyCalcEdt;	//연체계산_종료일
	        timsUnrcvVO.dlyToolTip   = dlyCalcVO.dlyToolTip;    //연체툴팁

			if (bndVO.isLose()) {
				timsUnrcvVO.loseFg 			= bndVO.loseFg;		//상실_여부
				timsUnrcvVO.loseDueDt 		= bndVO.loseDueDt;	//상실_납입_일자
				timsUnrcvVO.loseDt 			= bndVO.loseDt; 	//상실일자, 상실실납입일자 + 1day
				timsUnrcvVO.isLoseTims      = dlyCalcVO.isLoseTims;		//당회차가 상실회차인지

				timsUnrcvVO.losePamtRamt 	= dlyCalcVO.loseBalPamt; 	//상실원금잔액 = 당회차후 원금잔액 (잔액연체료 계산대상)
				timsUnrcvVO.losePsgInt 		= dlyCalcVO.losePsgInt; 	//당회차 경과이자(일할 계산된 이자)
				timsUnrcvVO.loseRamtDfee 	= dlyCalcVO.loseRamtDfee /*- dlyCalcVO.losePsgInt*/; // 잔액연체료 <=> 기한이익상실연체료 (2018-08-01 : 당회차경과이자를 빼지않음
				timsUnrcvVO.losePiamtDfee 	= dlyCalcVO.dfee; 			// 당회차발생연체료
				timsUnrcvVO.loseIntDfee 	= dlyCalcVO.losePsgInt; 	// 당회차 경과이자

				timsUnrcvVO.losePsgDdcnt 	= dlyCalcVO.losePsgDdcnt;
				timsUnrcvVO.loseIntPsgDdcnt = dlyCalcVO.loseIntPsgDdcnt;//상실경과이자일수
				timsUnrcvVO.loseTimsDdcnt 	= dlyCalcVO.loseTimsDdcnt;

				timsUnrcvVO.loseDlyStrtDt 	= dlyCalcVO.loseCalcStrtDt;	//상실_연체_시작일자
				timsUnrcvVO.loseDlyEndDt 	= dlyCalcVO.loseCalcEndDt;	//상실_연체_종료일자

				// 기한상실일자 이전이면 경과대상이자 0
				if (dlyCalcVO.loseIntPsgStrtDt.compareTo(bndVO.loseDt) < 0) {	//경과이자시작일 < 채권.상실납입일자
					timsUnrcvVO.loseObjPsgInt = 0;	//상실대상경과이자 = 0
				}

				bndVO.losePiamtDfee += timsUnrcvVO.losePiamtDfee;	//채권.상실_원리금_연체료 += 회차미수.상실_원리금_연체료
				bndVO.losePamtRamt 	+= timsUnrcvVO.losePamtRamt;	//채권.상실_원금_잔액 	+= 회차미수.상실_원금_잔액
				bndVO.loseRamtDfee 	+= timsUnrcvVO.loseRamtDfee;	//채권.상실_잔액_연체료	+= 회차미수.상실_잔액_연체료
				bndVO.loseIntDfee 	+= timsUnrcvVO.loseIntDfee;		//채권.상실_이자_연체료 	+= 회차미수.상실_이자_연체료

				bndVO.rvvlTims = timsUnrcvVO.tims;	//부활_회차 = 회차미수.회차
				bndVO.rvvlNeedAmt += timsUnrcvVO.askAmt;		//채권.부활_필요_금액       += 회차미수.청구_금액
			}

			// 연체일수 구간별 / 정상금리+가산금리 표기 등으로 인한 수정 (bndVO.dfeeRt => 가산이자율로 쓰임)
			if (bndVO.timsUnrcvCnt==1) {
				bndVO.dfeeRt    = dlyCalcVO.dfeeRt;			//채권.연체료율 = 연체계산객체.연체료율
				bndVO.addDfeeRt = dlyCalcVO.addDfeeRt;		//채권.가산연체료율 = 연체계산객체.가산연체료율
				bndVO.dfeeRtNm  = dlyCalcVO.stndRt+"+"+bndVO.addDfeeRt;
			}

			bndVO.dlyEndDueDt = timsUnrcvVO.dueDt;			//채권.연체_종료_납입_일자 = 회차미수.납입_일자
			bndVO.dlyEndTims  = timsUnrcvVO.tims;			//채권.연체_종료_회차 = 회차미수.회차

			bndVO.dlyAmt 	 += timsUnrcvVO.askAmt;			//채권.연체_금액 			+= 회차미수.청구_금액
			bndVO.dlyPamt 	 += timsUnrcvVO.askPamt;		//채권.연체_원금 			+= 회차미수.청구_원금
			bndVO.dlyInt 	 += timsUnrcvVO.askInt;			//채권.연체_이자 			+= 회차미수.청구_이자
			bndVO.dlyTrtFee  += timsUnrcvVO.askTrtFee;		//채권.연체_취급수수료 	+= 회차미수.청구취급수수료
			bndVO.dfee 		 += timsUnrcvVO.askDfee;		//채권.연체료				+= 회차미수.청구_연체료
			bndVO.dlyTint 	 += timsUnrcvVO.askTint;		//채권.연체_총이자		+= 회차미수.청구총이자
			bndVO.askAmt 	 += timsUnrcvVO.askAmt;			//채권.청구_금액			+= 회차미수.청구_금액
			bndVO.askPamt 	 += timsUnrcvVO.askPamt;		//채권.청구_원금			+= 회차미수.청구_원금
			bndVO.askInt 	 += timsUnrcvVO.askInt;			//채권.청구_이자			+= 회차미수.청구_원금
			bndVO.askTrtFee  += timsUnrcvVO.askTrtFee;		//채권.청구취급수수료		+= 회차미수.청구취급수수료
			bndVO.askDfee 	 += timsUnrcvVO.askDfee;		//채권.청구_연체료		+= 회차미수.청구_연체료
			bndVO.askTint 	 += timsUnrcvVO.askTint;		//채권.청구_총이자		+= 회차미수.청구_총이자

			/*******************************************************************************************
			 * 연체계산 - 끝
			 ******************************************************************************************/



			bndVO.dlyCnt += 1;	//채권.연체_건수 += 1
			timsUnrcvVO.dlyCnt = bndVO.dlyCnt; //회차미수.연체_건수 = 채권.연체_건수

			if (bndVO.dlyCnt == 1) { // 연체건수가 처음일때
				bndVO.dlyDdcnt 		= timsUnrcvVO.dlyDdcnt;		//채권.연체_일수 		= 회차미수.연체_일수
				bndVO.occrDlyDdcnt 	= timsUnrcvVO.occrDlyDdcnt;	//채권.발생_연체_일수= 회차미수.발생_연체_일수
				bndVO.dlyMmCnt 		= timsUnrcvVO.dlyMmCnt;		//채권.연체_개월수	= 회차미수.연체_개월수
				bndVO.dlyTcnt 		= timsUnrcvVO.dlyTcnt;		//채권.연체_횟수		= 회차미수.연체_횟수

				bndVO.dlyStrtDueDt 	= timsUnrcvVO.dueDt;		//채권.연체_시작_납입_일자 = 회차미수.납입_일자
				bndVO.dlyStrtIdx 	= askUnrcvVO.timsUnrcvIdx;	//채권.연체_시작_인덱스	 = 회차미수.회차_미수_인덱스

				//2022-07-12 주석해제
				// 상실수정사항
				if (Constants.YES.equals(bndVO.loseFg)) {//채권.상실여부
					bndVO.loseDt = timsUnrcvVO.loseDt;	//채권.상실_일자 = 회차미수.상실_일자
				}
			}

			// 누적연체일수 누적
			bndVO.totDlyDdcnt = bndVO.totDlyDdcnt + timsUnrcvVO.dlyDdcnt;

		}
		else if (Constants.ASK_DIV_NORM.equals(rmbrPlanVO.askDivCd)) {
			// 정상분이면
			bndVO.normCnt += 1;	//정상_건수 ++

			if (bndVO.normCnt == 1) {
				// 대출별 정상시작 회차미수 인덱스 SET
				bndVO.normStrtIdx = askUnrcvVO.timsUnrcvIdx;//채권.정상_시작_인덱스 = 청구미수객체.회차_미수_인덱스
			}

			bndVO.normAmt 		+= timsUnrcvVO.askAmt;		//채권.정상_금액 += 회차미수.청구_금액
			bndVO.normPamt 		+= timsUnrcvVO.askPamt;		//채권.정상_원금 += 회차미수.청구_원금
			bndVO.normInt 		+= timsUnrcvVO.askInt;		//채권.정상_이자 += 회차미수.청구_이자
			bndVO.normTrtFee 	+= timsUnrcvVO.askTrtFee;	//채권.정상_취급수수료 += 회차미수.청구_취급수수료

			bndVO.askAmt 		+= timsUnrcvVO.askAmt;		//채권.청구_금액 += 회차미수.청구_금액
			bndVO.askPamt 		+= timsUnrcvVO.askPamt;		//채권.청구_원금 += 회차미수.청구_원금
			bndVO.askInt 		+= timsUnrcvVO.askInt;		//채권.청구_이자 += 회차미수.청구_이자
			bndVO.askTrtFee 	+= timsUnrcvVO.askTrtFee;	//채권.청구_취급수수료 += 회차미수.청구_취급수수료

			bndVO.normTint 	+= timsUnrcvVO.askTint;	//채권.정상_총이자 += 회차미수.청구총이자
			bndVO.askTint 	+= timsUnrcvVO.askTint;	//채권.청구_총이자 += 회차미수.청구총이자

		}
		else { // 미도래
			bndVO.unComgCnt += 1; //채권.미_도래_건수 ++

			if (bndVO.unComgCnt == 1) {
				// 대출별 미도래시작 회차미수 인덱스 SET
				bndVO.unComgStrtIdx = askUnrcvVO.timsUnrcvIdx;	// 채권.미_도래_시작_인덱스 = 회차미수.회차_미수_인덱스
			}

			bndVO.unComgAmt 	+= timsUnrcvVO.askAmt;		//채권.미_도래금액 		= 회차미수.청구_금액
			bndVO.unComgPamt 	+= timsUnrcvVO.askPamt;		//채권.미_도래_원금		= 회차미수.청구_원금
			bndVO.unComgInt 	+= timsUnrcvVO.askInt;		//채권.미_도래_이자		= 회차미수.청구_이자
			bndVO.unComgTrtFee 	+= timsUnrcvVO.askTrtFee;	//채권.미_도래_취급수수료	= 회차미수.청구취급수수료

			bndVO.unComgTint += timsUnrcvVO.askTint;//채권.미도래_총이자 += 회차미수.청구_총이자
		}

		bndVO.tempRcptObjAmt += timsUnrcvVO.askAmt;	//채권.임시_수납_대상_금액 += 회차미수.청구금액

		// 수납대상금액추가
		timsUnrcvVO.rcptObjAmt = bndVO.tempRcptObjAmt;	//회차미수.수납_대상_금액 = 채권.임시_수납_대상_금액

		// 조회시점에 실제 납입할 대상금액 (연체 + 납입일자도래한 정상금액)
        if (timsUnrcvVO.rlDueDt.compareTo(bndVO.setlDt) <= 0) { //납입_일자 <= 결제일자
			bndVO.currentAskAmt += timsUnrcvVO.askAmt;
		}

		// 결제일 납입월에 해당하는 금액
		if (StringUtils.left(timsUnrcvVO.dueDt, 7).equals(StringUtils.left(bndVO.setlDt, 7))) {
			bndVO.thmmMmAskAmt = timsUnrcvVO.askAmt;
			bndVO.thmmMmAskTims = timsUnrcvVO.tims;
		}

        // 결제일 다음납입월 청구금액
		String bfDueDt = DateUtil.addMonth(timsUnrcvVO.dueDt, -1);
        if (StringUtils.left(bfDueDt, 7).equals(StringUtils.left(bndVO.setlDt, 7))) {
            bndVO.nextAskTims = timsUnrcvVO.tims;
            bndVO.nextAskAmt = timsUnrcvVO.askAmt;
        }

        askUnrcvVO.setBndVOList(askUnrcvVO.askUnrcvObjIdx, bndVO);
        return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: createTimsUnrcvVO</p>
	 * <p>설　　명	: 회차미수계획 셋팅(상환계획->회차미수)</p>
	 * <p>메소드인수	: AskUnrcvVO, BndVO, RmbrPlanVO</p>
	 * <p>리　턴　값	: TimsUnrcvVO</p>
	 */
	private TimsUnrcvVO createTimsUnrcvVO(AskUnrcvVO askUnrcvVO, BndVO bndVO, RmbrPlanVO rmbrPlanVO) {

	    TimsUnrcvVO timsUnrcvVO = new TimsUnrcvVO();
	    timsUnrcvVO.loanNo          = rmbrPlanVO.loanNo;		//대출_번호
	    timsUnrcvVO.loanSeq         = rmbrPlanVO.loanSeq;		//대출순번
	    timsUnrcvVO.tims            = rmbrPlanVO.tims;			//회차
	    timsUnrcvVO.endDivCd        = rmbrPlanVO.endDivCd;		//종료구분코드
	    timsUnrcvVO.rmbrFrmlCd      = rmbrPlanVO.rmbrFrmlCd;	//상환방식코드
	    timsUnrcvVO.dueDt           = rmbrPlanVO.dueDt;			//납입일자
	    timsUnrcvVO.rlDueDt         = rmbrPlanVO.rlDueDt;		//실납입일자
	    timsUnrcvVO.lastSetlDt      = rmbrPlanVO.lastSetlDt;	//최종결제일자
	    timsUnrcvVO.setlDt          = rmbrPlanVO.setlDt;		//결제일자
	    timsUnrcvVO.timsBfPamtRamt  = rmbrPlanVO.timsBfPamtRamt;//회차전원금잔액
	    timsUnrcvVO.timsAfPamtRamt  = rmbrPlanVO.timsAfPamtRamt;//회차후원금잔액
	    timsUnrcvVO.mmPamt          = rmbrPlanVO.pamt;			//원금
	    timsUnrcvVO.mmInt           = rmbrPlanVO.intt;			//이자
	    timsUnrcvVO.trtFee          = rmbrPlanVO.trtFee;		//취급수수료
	    timsUnrcvVO.setlPamt        = rmbrPlanVO.setlPamt;		//결제원금
	    timsUnrcvVO.setlInt         = rmbrPlanVO.setlInt;		//결제이자
	    timsUnrcvVO.setlDfee        = rmbrPlanVO.setlDfee;		//결제_연체료
	    timsUnrcvVO.setlTrtFee      = rmbrPlanVO.setlTrtFee;	//결제취급수수료

		timsUnrcvVO.tint 		= timsUnrcvVO.mmInt   ;								//총이자 	 월_이자
		timsUnrcvVO.setlTint 	= timsUnrcvVO.setlInt ;								//결제총이자 = 결제_이자
		timsUnrcvVO.setlAmt  	= timsUnrcvVO.setlPamt + timsUnrcvVO.setlInt		//결제_금액  = 결제_원금 + 결제_이자
		                        + timsUnrcvVO.setlTrtFee + timsUnrcvVO.setlDfee;	//			+ 결제취급수수료 + 결제_연체료

		timsUnrcvVO.preObjDfee  = rmbrPlanVO.occrDfee; 		// 기대상연체료 = 발생연체료
		timsUnrcvVO.preAdjDfee  = rmbrPlanVO.occrDfee - rmbrPlanVO.preOccrDfee; // 기정산연체료 = 발생연체료 - 기발생연체료
		timsUnrcvVO.preOccrDfee = rmbrPlanVO.preOccrDfee; 	//기_발생_연체료
		timsUnrcvVO.pdueDfee  	= rmbrPlanVO.pdueDfee;		//선납_연체료
		timsUnrcvVO.exmpDfee  	= rmbrPlanVO.exmpDfee;		//면제_연체료
		timsUnrcvVO.intStrtDt 	= rmbrPlanVO.intStrtDt;		//이자_시작일자
		timsUnrcvVO.intEndDt  	= rmbrPlanVO.intEndDt;		//이자_종료일자
		timsUnrcvVO.dlyFg 		= rmbrPlanVO.dlyFg;			//연체_여부
		timsUnrcvVO.dlyCalcDt 	= rmbrPlanVO.dlyCalcDt;		//연체_계산_일자

		// 상실수정사항
		timsUnrcvVO.timsBfAskPamt  = rmbrPlanVO.timsBfAskPamt;	//회차_전_청구_원금
		timsUnrcvVO.loseIntStrtDt  = rmbrPlanVO.loseIntStrtDt;	//상실_이자_시작일자
		timsUnrcvVO.loseIntEndDt   = rmbrPlanVO.loseIntEndDt;	//상실_이자_종료일자
		timsUnrcvVO.loseObjPsgInt  = rmbrPlanVO.loseObjPsgInt;	//2회차이후 월이자(스케줄 월이자)
		timsUnrcvVO.termPartInt    = rmbrPlanVO.termPartInt;	//거치이자
		timsUnrcvVO.midTermPartInt = rmbrPlanVO.midTermPartInt;	//중도상환거치이자

		if (timsUnrcvVO.setlAmt != 0) {	//결제_금액
			timsUnrcvVO.preSetlFg = Constants.YES;//선결제여부
		}

		// 스케줄상 미도래 일자 카운트
		if (timsUnrcvVO.dueDt.compareTo(askUnrcvVO.isrtDt) > 0) { //납입_일자 > 입력시스템일자
			bndVO.pdueTimsCnt 		= bndVO.pdueTimsCnt + 1; //선결제회차건수
			timsUnrcvVO.pdueTotCnt 	= bndVO.pdueTimsCnt;	 //선납누적건수
		}

		timsUnrcvVO.askPamt 	= timsUnrcvVO.mmPamt 	- timsUnrcvVO.setlPamt;		//청구_원금 		= 월_원금 - 결제_원금
		timsUnrcvVO.askInt  	= timsUnrcvVO.mmInt 	- timsUnrcvVO.setlInt;		//청구_이자 		= 월_이자 - 결제_이자
		timsUnrcvVO.askTrtFee 	= timsUnrcvVO.trtFee 	- timsUnrcvVO.setlTrtFee; 	//청구취급수수료 	= 취급수수료 - 결제취급수수료
		timsUnrcvVO.mmPiamt 	= timsUnrcvVO.askPamt 	+ timsUnrcvVO.askInt;		//월_원리금 		= 청구_원금 - 청구_이자

		timsUnrcvVO.askTint = timsUnrcvVO.tint - timsUnrcvVO.setlTint;	//청구총이자 = 총이자 - 결제총이자
		timsUnrcvVO.askAmt  = timsUnrcvVO.askPamt + timsUnrcvVO.askInt 	+ timsUnrcvVO.askTrtFee;	//청구_금액    = 청구_원금 + 청구_이자 + 청구취급수수료

		return timsUnrcvVO;
	}


	/**
	 * <p>메소드명	: calcMidRmbr</p>
	 * <p>설　　명	: 중도상환계산</p>
	 * <p>메소드인수	: AskUnrcvVO, Connection</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	@Override
	public AskUnrcvVO calcMidRmbr(AskUnrcvVO askUnrcvVO) throws Exception {
		// 모든 채권을 loopping돌면서 중도상환계산
		for (int i = 0, n = askUnrcvVO.sizeBndVOList(); i < n; i++) {
			BndVO bndVO = askUnrcvVO.getBndVO(i);	//채권객체

			// 면책금액 셋팅
			// 면책상황은 대출정상등록상태에서 선납이 없는 경우일때만 가능하므로 잔액등을 사용하고 면책등록시 선납등을 체크한다.
			bndVO.exemRcptObjPamt 		= bndVO.pamtRamt;	//채권.파산면책금액 = 채권.원금_잔액
			bndVO.exemRcptObjDivsTrtFee = bndVO.trtFeeRamt;	//채권.파산면책금액 = 채권.취급수수료잔액
			bndVO.exemRcptObjInt 		= bndVO.intRamt;	//채권.파산면책금액 = 채권.이자_잔액

			// 중도상환 계산여부추가
			if (Constants.YES.equals(bndVO.midRmbrCalcFg)) {	//채권.중도상환계산여부 = 1
				TimsUnrcvVO timsUnrcvVO = bndVO.getMidRmbrTims();	//회차미수객체
				if (timsUnrcvVO == null) { // 리스는 리스만기일자 또는 상환만기일이후도 계산해야한다.
					timsUnrcvVO = new TimsUnrcvVO();
					timsUnrcvVO.loanNo 		= bndVO.loanNo;			//대출번호
					timsUnrcvVO.loanSeq 	= bndVO.loanSeq;		//대출순번
					timsUnrcvVO.tims 		= bndVO.loanEprtTims;	//회차미수.회차 			= 채권.대출_만기_회차
					timsUnrcvVO.intStrtDt 	= bndVO.stndDueDt;		//회차미수.이자_시작일자 	= 채권.기준납입일자
					timsUnrcvVO.intEndDt 	= bndVO.stndDueDt;		//회차미수.이자_종료일자 	= 채권.기준납입일자
					timsUnrcvVO.setlDt 		= bndVO.setlDt;			//회차미수.결제일자		= 채권.결제일자
					timsUnrcvVO.rlDueDt 	= bndVO.stndRlDueDt;	//회차미수.실_납입_일자	= 채권.기준실납입일자
				}

				bndVO = setBndVOForMidRmbr(askUnrcvVO, bndVO, timsUnrcvVO);	//중도상환 계산

				bndVO = calcMidRmbrLoan(askUnrcvVO, bndVO);  //할부건 중도상환 계산

				// 전액/부분 중도상환대상금액 - 선납금액 추가
				bndVO.tamtRmbrObjAmtWithoutPdueAmt = bndVO.tamtRmbrObjAmt - bndVO.midPreDueAmt;
				bndVO.partRmbrObjAmtWithoutPdueAmt = bndVO.partRmbrObjAmt - bndVO.midPreDueAmt;

				// 중도상환 가능시 중도상환이자셋팅
				bndVO.exemRcptObjInt = bndVO.totMidRmbrInt;
			}

			askUnrcvVO.setBndVOList(i, bndVO);
		}

		return askUnrcvVO;
	}

	/**
	 * <p>메소드명	: setBndVOForMidRmbr</p>
	 * <p>설　　명	: 중도상환 계산</p>
	 * <p>메소드인수	: AskUnrcvVO, BndVO, TimsUnrcvVO</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	private BndVO setBndVOForMidRmbr(AskUnrcvVO askUnrcvVO, BndVO bndVO, TimsUnrcvVO timsUnrcvVO) {

		AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(bndVO.loanNo, bndVO.loanSeq);
		bndVO.midRmbrTimsFg 		= Constants.YES;			//채권.중도상환회차여부 			= "1"
		bndVO.rmbrPlanCrteTims 		= timsUnrcvVO.tims;				//채권.상환계획생성회차			= 회차미수.회차
		bndVO.midIntStrtDt 			= timsUnrcvVO.intStrtDt;		//채권.중도_상환_이자계산시작일자 	= 회차미수.이자_시작일자
		bndVO.midIntEndDt 			= timsUnrcvVO.intEndDt;			//채권.중도_상환_이자계산종료일자	= 회차미수.이자_종료일자
		bndVO.midTermPartTimsInt 	= timsUnrcvVO.midTermPartInt;	//채권.중도상환거치분할회차이자	= 회차미수.중도상환거치분할이자
		bndVO.midRmbrDueDt 			= timsUnrcvVO.dueDt;			//채권.중도_상환_납입일자 		= 회차미수.납입_일자

		if (isAutoLease(bndVO)) {//상품코드 "4"
			bndVO.rlPartRmbrPamt = 0;	//실부분상환원금
			bndVO.partRmbrPamt   = 0;	//부분상환원금
		} else {
			// bndVO.totPamt ==> 중도상환 회차전의 총 누적원금 [연체원금 + (결제일당일일경우)정상청구원금]
			long totPamt = bndVO.totPamt + 1;	//누적원금+1 (1원이라도 중도상환원금이 존재해야 중도상환수납처리가 될것이므로)
			long tmpPartRmbrPamt = askUnrcvObjVO.partRmbrPamt; 	//부분_상환_원금

			// 결제일 이후일때 보정
			if (StringUtil.dateDiff(bndVO.loanRlEprtDt,bndVO.setlDt)>0) {
				totPamt = bndVO.dlyPamt;	// 만기일 이후 미수금액은 전부 연체상태이므로 dlyPamt로 세팅
			}

			// 금융리스
			if (isFinanceLease(bndVO)) {
				// 연체원금보다 작거나, (주상환원금 + 연체원금)을 넘으면 안된다.
				if ((askUnrcvObjVO.partRmbrPamt < totPamt) || (askUnrcvObjVO.partRmbrPamt > bndVO.mainRmbrPamt + bndVO.totPamt)) { // 부분_상환_원금 < 누적원금+1 || 부분_상환_원금 > 채권.주상환원금 + 누적원금
					tmpPartRmbrPamt = totPamt;	//부분상환원금 = 누적원금 + 1
				}
				bndVO.partRmbrObjAddAmt = bndVO.totAddAskAmt; //금융리스일때 추가로 납부해야하는 금액(가산,대지급,정비료등) = 누적추가청구금
			}
			// 할부, 론
			else {
				// 연체원금(결제일 당일은 당월원금 포함)보다 작을경우
				if ((askUnrcvObjVO.partRmbrPamt < totPamt)) {	// 부분_상환_원금 < 누적원금 + 1
					tmpPartRmbrPamt = totPamt;	//부분상환원금 = 누적원금 + 1
				}
				// 총잔여원금보다 중도상환원금이 클 경우 잔여원금으로 보정
				else if (askUnrcvObjVO.partRmbrPamt > bndVO.pamtRamt) {	// 부분_상환_원금 > 원금_잔액
					tmpPartRmbrPamt = bndVO.pamtRamt;	//부분상환원금 = 원금잔액
				}
			}

			bndVO.rlPartRmbrPamt = tmpPartRmbrPamt - bndVO.totPamt;	//채권.실부분상환원금 = 부분상환원금 - 채권.누적원금
			bndVO.partRmbrPamt 	 = tmpPartRmbrPamt;					//채권.부분_상환_원금 = 부분상환원금
		}

		bndVO.rlTamtRmbrPamt 	= bndVO.calcPamtRamt;		//채권.실전액상환원금 		= 채권.계산원금잔액
		bndVO.tamtRmbrPamt 		= bndVO.pamtRamt;			//채권.전액_상환_원금 		= 채권.원금_잔액
		bndVO.rlTamtRmbrTrtFee 	= bndVO.calcDivsTrtFeeRamt;	//채권.실전액상환취급수수료 	= 채권.계산분할취급수수료잔액

		// 거치분할이자 추가
		if (bndVO.termPartFg.equals(Constants.YES)) { // 거치분할이면
			bndVO.midRmbrObjInt = timsUnrcvVO.mmInt - timsUnrcvVO.termPartInt;	//채권.중도상환대상이자 = 회차미수.월_이자 - 회차미수.거치분할이자
		} else { // 거치분할이 아니면
			bndVO.midRmbrObjInt = timsUnrcvVO.mmInt;	//채권.중도상환대상이자 = 회차미수.월_이자
		}

		// NOTE 중도상환 회차를 바꾸면 여기는 꼭 고려해줘야함.
		bndVO.tamtTimsAmt = timsUnrcvVO.askAmt;		// 전액상환회차금액
		bndVO.tamtTimsPamt = timsUnrcvVO.mmPamt;	// 전액상환회차경과원금
		bndVO.tamtTimsInt = timsUnrcvVO.mmInt;		// 전액상환회차이자
		bndVO.tamtTimsTint 	= timsUnrcvVO.mmInt + timsUnrcvVO.ppayInt;	//전액상환회차_총이자
		bndVO.preSetFg 		= timsUnrcvVO.preSetlFg;					//선결제여부

		return bndVO;
	}

	/**
	 * <p>메소드명	: calcMidRmbrLoan</p>
	 * <p>설　　명	: 할부건 중도상환 계산</p>
	 * <p>메소드인수	: AskUnrcvVO, BndVO, Connection</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	private BndVO calcMidRmbrLoan(AskUnrcvVO askUnrcvVO, BndVO bndVO) throws Exception {
		//log.info("■ calcMidRmbrLoan");

		long addNormAmt = 0;

		// 중도상환을 납입일자에 할경우 해당 납입일자까지의 원금,이자, 취급수수료를 다 받은후 한다.
		boolean isDueDtRmbr = Constants.YES.equals(bndVO.dueDtMidRmbrFg) && bndVO.stndThmmDueTims == bndVO.thmmDueTims;
		if (isDueDtRmbr) { //납입일_중도상환_여부 (납입일자에 중도상환을 하는경우 '1', 아니면 '0') && 기준당월납입회차 == 당월_납입_회차
			addNormAmt = bndVO.normPamt + bndVO.normInt + bndVO.normTrtFee;	//정상_원금 + 정상_이자 + 정상_취급수수료
		}

		AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(bndVO.loanNo, bndVO.loanSeq);

		// 중도상환수수료 면제아닌 미계산으로 구할때
		if (askUnrcvObjVO.midRmbrFeeUnCalcFg.equals(Constants.YES)) {	//중도상환미계산여부(1-미계산, 0-계산)
			log.info("■ 중도상환수수료 미계산여부=> " + askUnrcvObjVO.midRmbrFeeUnCalcFg);
			bndVO.tamtRmbrFee = 0;
			bndVO.partRmbrFee = 0;
		}

		// 중도상환 계산
		// OUT : 중도상환이자, 전액상환수수료, 부분상환수수료, 취급수수료할인, 취급수수료율, 중도상환잔여개월수, 대출총일수, 중도상환수수료율, 대출이자율, 연체료율
		// 단건은 관계없으나 멀티건 처리 시 askUnrcvVO.askUnrcvObjIdx 최종만읽음. 중도상환수수료 오계산 됨..
		bndVO = rcptService.calcMidRmbr(askUnrcvVO, askUnrcvObjVO, bndVO);

		/* 중도상환수수료율을 법정최고이자율 적용한 최대 금액이자 내에서 경과이자 중도상환수수료 수취 가능
		★ 계약기간  12개월 이상 (대출만기일-대출시작일 계산하여 년 환산시 1년 이상 또는 개월 환산시 12개월 이상)
			1. 수수료율 1% 미만
				: 수수료 = 중도원금 * 중도수수료율%
			2. 수수료율 1% 이상
				: 수수료 = 부대비용 + 중도원금 *(중도수수료율%-1%) * 잔존일수/(대출총일수-30)
				: 부대비용 = (중도원금)*1%
		★ 계약기간  12개월 미만 (대출만기일-대출시작일 계산하여 년 환산시 1년 미만 또는 개월 환산시 12개월 미만)
			수수료 = 중도원금 * 수수료율% * 잔존일수 / (대출총일수-30일)
			부대비용 = ZERO
		*/
		//int yrDdCnt = StringUtil.yrDdCnt(askUnrcvObjVO.loanDt);
		int yrDdCnt = StringUtil.yrDdCnt(askUnrcvObjVO.setlDt);
		bndVO.oneYearDdCnt = yrDdCnt;

		/**
		 * 잔존기간 (대출사용기간이 30일이 안되면 -30을 한다.)
		 */
		double midRmbrBalDdcnt = bndVO.midRmbrBalDdcnt;

		//대출사용기간이 30일 미만인 경우
		boolean isLoanDtBf30 = false;
		if (bndVO.loanTotDdcnt - bndVO.midRmbrBalDdcnt < 30) {
			isLoanDtBf30 = true;
			midRmbrBalDdcnt = bndVO.loanTotDdcnt - 30;
		}

		boolean isOneYearAfter = false;
		double incdCostRt      = bndVO.incdCostRt * 1.0D;	// 부대비용율
		long tamtIncdCost      = 0;   //전액상환 부대 비용
		long tamtRgdInt        = 0;   //전액상환 간주 이자
		long partIncdCost      = 0;   //부분상환 부대 비용
		long partRgdInt        = 0;   //부분상환 간주 이자
		long tamtMidRmbrAmt    = 0;   //전액상환 중도상환수수료
		long partMidRmbrAmt    = 0;   //부분상환 중도상환수수료

		//계약기간  12개월 이상
		if (bndVO.loanTotDdcnt >= yrDdCnt) {
			isOneYearAfter = true;
			if (bndVO.midRmbrFeeRt<1.0D) {
				//log.info("1년이상 - 수수료 1% 미만");
				tamtRgdInt   = (long)Math.floor(bndVO.rlTamtRmbrPamt * (bndVO.midRmbrFeeRt / 100.0D));
				partRgdInt   = (long)Math.floor(bndVO.rlPartRmbrPamt * (bndVO.midRmbrFeeRt / 100.0D));
			} else {
				//log.info("1년이상 - 수수료 1% 이상");
				tamtIncdCost = (long)Math.floor(bndVO.rlTamtRmbrPamt * incdCostRt / 100);
				partIncdCost = (long)Math.floor(bndVO.rlPartRmbrPamt * incdCostRt / 100);
				tamtRgdInt   = (long)Math.floor(bndVO.rlTamtRmbrPamt * ((bndVO.midRmbrFeeRt - incdCostRt) / 100.0D) * midRmbrBalDdcnt / (bndVO.loanTotDdcnt - 30));
				partRgdInt   = (long)Math.floor(bndVO.rlPartRmbrPamt * ((bndVO.midRmbrFeeRt - incdCostRt) / 100.0D) * midRmbrBalDdcnt / (bndVO.loanTotDdcnt - 30));
			}
		}
		//계약기간  12개월 미만
		else {
			log.info("1년미만");
			tamtRgdInt = (long)Math.floor(bndVO.rlTamtRmbrPamt * (bndVO.midRmbrFeeRt / 100.0D) * midRmbrBalDdcnt / (bndVO.loanTotDdcnt - 30));
			partRgdInt = (long)Math.floor(bndVO.rlPartRmbrPamt * (bndVO.midRmbrFeeRt / 100.0D) * midRmbrBalDdcnt / (bndVO.loanTotDdcnt - 30));
		}

		tamtIncdCost = StringUtil.parseNature(tamtIncdCost);
		tamtRgdInt   = StringUtil.parseNature(tamtRgdInt);
		partIncdCost = StringUtil.parseNature(partIncdCost);
		partRgdInt   = StringUtil.parseNature(partRgdInt);

		//전액_중도상환수수료 = 부대비용 + 간주이자
		tamtMidRmbrAmt    = tamtIncdCost + tamtRgdInt;
		//부분_중도상환수수료 = 부대비용 + 간주이자
		partMidRmbrAmt    = partIncdCost + partRgdInt;

		bndVO.tamtRmbrFee = tamtMidRmbrAmt;
		bndVO.partRmbrFee = partMidRmbrAmt;

		//중도상환 경과이자
		long midRmbrPsgInt = (long)Math.floor(bndVO.rlTamtRmbrPamt * ((bndVO.loanIntRt/100.0D) * bndVO.psgDdcnt / yrDdCnt));

		bndVO.midRmbrInt = midRmbrPsgInt;	// 윤년적용

		//최대수령 가능금액(법정이자율 적용 최고 금액)
		long maxMidRmbrFee = (long)Math.floor(bndVO.rlTamtRmbrPamt * ((bndVO.intUplmitRt/100.0D) * bndVO.psgDdcnt / yrDdCnt));
		if (maxMidRmbrFee>0 && midRmbrPsgInt>maxMidRmbrFee) {
			log.info("■ "+midRmbrPsgInt+"] vs 최대수령 가능금액(법정이자율 적용 최고 금액) = "+maxMidRmbrFee);
		}

		// 전액상환
		long dueDtRmbrMmInt = 0;
		long dueDtRmbrSetlMmInt = 0;
		TimsUnrcvVO dueDtMidRmbrTims = bndVO.getDueDtMidRmbrTims();
		if (dueDtMidRmbrTims != null) {
			dueDtRmbrMmInt = dueDtMidRmbrTims.mmInt;
			dueDtRmbrSetlMmInt = dueDtMidRmbrTims.setlInt;
		}

		//중도상환 경과이자
		long midPartRmbrPsgInt = midRmbrPsgInt;

		bndVO.calcPartMidRmbrInt = midPartRmbrPsgInt;

		// 결제 정보 저장용 값
		bndVO.cortMaxAmt = maxMidRmbrFee;     //법정_최고_금액
		bndVO.calcPsgInt = midRmbrPsgInt;     //전액_계산_경과이자
		bndVO.tamtCalcMidRmbrFee = tamtMidRmbrAmt;    //전액_계산_중도상환수수료
		bndVO.partCalcMidRmbrFee = partMidRmbrAmt;    //부분_계산_중도상환수수료

		// 기한상실, 개인면책시 (전액)중도상환수수료 0, 취급수수료할인 없음.
		if (bndVO.isLose() || askUnrcvVO.bkrpExemCalcFg.equals(Constants.YES)) {
			log.info("■ 기한상실 OR 개인면책 => 중도수수료 = 0, 취급수수료할인 없음");
			bndVO.tamtRmbrFee = 0;
			bndVO.partRmbrFee = 0;
			bndVO.trtFeeDisc  = 0;
			bndVO.custTrtFeeDisc = 0;
			bndVO.mmTrtFeeDisc   = 0;
		}

		// 거치분할중도상환 (거치기간중일때, 거치배분이자구간 전)
		if (bndVO.termPartFg.equals(Constants.YES)) {
			if (bndVO.setlDt.compareTo(bndVO.termPartIntEndDt) <= 0) {
				bndVO = rcptService.calcTermMidRmbr_Term(bndVO);
			}
		} else {
			bndVO.termPartPamtRmbrInt = bndVO.addTermInt;
			bndVO.termPartTamtRmbrInt = bndVO.addTermInt;
		}

		// 분할취급수수료는 중도완납시 받아야할 취급수수료에서 분할수납된 취급수수료를 뺀금액을 환입/환출한다.
		bndVO.trtFeeDisc = bndVO.mmTrtFeeDisc;

		// 임시 거치분할 수작업 투입. 렌터카공제조합 중도상환수수료 계산 방식 변경 2018-08-01 cyh
		// bndVO.totMidRmbrInt += bndVO.dlyInt + addNormInt + bndVO.termPartTamtRmbrInt;
		bndVO.totMidRmbrInt = bndVO.midRmbrInt +  bndVO.dlyInt + dueDtRmbrMmInt - dueDtRmbrSetlMmInt + bndVO.termPartTamtRmbrInt;
		bndVO.totMidRmbrTrtFee = bndVO.trtFeeRamt;
		bndVO.tamtRmbrFee += bndVO.dfee;

		bndVO.tamtRmbrAmt = bndVO.rlTamtRmbrPamt // 잔여원금 + 선납원금 - 정상원금 - 연체원금
				+ bndVO.midRmbrInt + bndVO.termPartTamtRmbrInt
				+ bndVO.rlTamtRmbrTrtFee // 잔여취급수수료 + 선납취급수수료 - 정상취급수수료 - 연체취급수수료
				+ bndVO.tamtRmbrFee - bndVO.dfee - bndVO.trtFeeDisc;

		// 중도전액상환시 취급수수료 잔액을 모두 받는다.
		bndVO.tamtRmbrObjAmt = bndVO.tamtRmbrAmt
				+ bndVO.dlyPamt + bndVO.dlyInt + bndVO.dlyTrtFee + bndVO.dfee
				+ bndVO.leglActnCostRamt + bndVO.stmpFeeRamt + addNormAmt; // 중도상환이 당월에 해당하면 당월청구금을 다 받는다.

		// 부분상환금액 계산
		bndVO.partMidRmbrInt = bndVO.calcPartMidRmbrInt + bndVO.dlyInt + dueDtRmbrMmInt - dueDtRmbrSetlMmInt + bndVO.termPartPamtRmbrInt;
		bndVO.totPartMidRmbrInt = bndVO.partMidRmbrInt;
		bndVO.partRmbrFee += bndVO.dfee;

		// 부분상환금액 (취급수수료 추가)
		bndVO.partRmbrAmt = bndVO.rlPartRmbrPamt
				+ bndVO.calcPartMidRmbrInt+ bndVO.termPartPamtRmbrInt - bndVO.midPreDueInt
				+ bndVO.partRmbrFee - bndVO.dfee - bndVO.trtFeeDisc;

		bndVO.partRmbrObjAmt = bndVO.partRmbrAmt
				+ bndVO.dlyPamt + bndVO.dlyInt + bndVO.dlyTrtFee + bndVO.dfee
				+ bndVO.leglActnCostRamt + bndVO.stmpFeeRamt + addNormAmt; // 중도상환이 당월에 해당하면 당월청구금을 다 받는다.

		// 중도부분상환거치배분이자잔액(부분상환 계산시)
		if (bndVO.setlDt.compareTo(bndVO.termPartIntEndDt) <= 0) {
			bndVO.calcTermPartPamtRmbrIntRamt = 0;
		} else {
			bndVO.calcTermPartPamtRmbrIntRamt = bndVO.midTermPartInt - bndVO.termPartPamtRmbrInt;
		}

		// 만기일 이후일때 보정
		if (StringUtil.dateDiff(bndVO.loanRlEprtDt,bndVO.setlDt)>0) {
			bndVO.rlPartRmbrPamt = 0;	// 만기일이 지났으므로 실중도상환원금은 0이다.
		}

		if (askUnrcvVO.isTooltipShow()) {

			NumberFormat numFmt = NumberFormat.getInstance();
			StringBuilder tamtRmbrIntTooTip = new StringBuilder(1024);
			tamtRmbrIntTooTip.append(String.format("■ 중도상환이자(+) : %s", numFmt.format(bndVO.midRmbrInt)));
			tamtRmbrIntTooTip.append("^");
			tamtRmbrIntTooTip.append(String.format("※ 경과이자 :  %s", numFmt.format(midRmbrPsgInt)));
			tamtRmbrIntTooTip.append(String.format(" (원금 * 대출이자율 / 100 * 경과일수 / %s)", numFmt.format(yrDdCnt)));
			tamtRmbrIntTooTip.append("^");
			tamtRmbrIntTooTip.append(String.format("※ 원금 : %s, 이자율 : %s, 경과일수 : %s", numFmt.format(bndVO.rlTamtRmbrPamt), bndVO.loanIntRt, numFmt.format(bndVO.psgDdcnt)));
			tamtRmbrIntTooTip.append("^");
			tamtRmbrIntTooTip.append(String.format("※ 이자시작일자 : %s, 이자종료일자 : %s (%s), 중도상환회차 : %s",bndVO.midIntStrtDt, bndVO.midIntEndDt, bndVO.calcMidIntEndDt, bndVO.midRmbrTims));
			if (dueDtRmbrMmInt>0) {
				tamtRmbrIntTooTip.append("^");
				tamtRmbrIntTooTip.append(String.format("■ 당월이자(+) : %s (회차이자 : %s - 결제이자 : %s)"
						, numFmt.format(dueDtRmbrMmInt - dueDtRmbrSetlMmInt), numFmt.format(dueDtRmbrMmInt), numFmt.format(dueDtRmbrSetlMmInt)));
			}
			if (bndVO.isDly() && bndVO.dlyInt>0) {
				tamtRmbrIntTooTip.append("^");
				tamtRmbrIntTooTip.append(String.format("■ 연체이자(+) : %s", numFmt.format(bndVO.dlyInt)));
			}

			StringBuilder partRmbrIntTooTip = new StringBuilder(1024);
			partRmbrIntTooTip.append(String.format("■ 중도상환이자(+) : %s", numFmt.format(bndVO.calcPartMidRmbrInt)));
			partRmbrIntTooTip.append("^");
			partRmbrIntTooTip.append(String.format("※ 경과이자 :  %s", numFmt.format(midPartRmbrPsgInt)));
			partRmbrIntTooTip.append(String.format(" (원금 * 대출이자율 / 100 * 경과일수 / %s)", numFmt.format(yrDdCnt)));
			partRmbrIntTooTip.append("^");
			partRmbrIntTooTip.append(String.format("※ 원금 : %s, 이자율 : %s, 경과일수 : %s", numFmt.format(bndVO.rlTamtRmbrPamt), bndVO.loanIntRt, numFmt.format(bndVO.psgDdcnt)));
			partRmbrIntTooTip.append("^");
			partRmbrIntTooTip.append(String.format("※ 이자시작일자 : %s, 이자종료일자 : %s (%s), 중도상환회차 : %s",bndVO.midIntStrtDt, bndVO.midIntEndDt, bndVO.calcMidIntEndDt, bndVO.midRmbrTims));
			if (dueDtRmbrMmInt>0) {
				partRmbrIntTooTip.append("^");
				partRmbrIntTooTip.append(String.format("■ 당월이자(+) : %s (회차이자 : %s - 결제이자 : %s)"
						, numFmt.format(dueDtRmbrMmInt - dueDtRmbrSetlMmInt), numFmt.format(dueDtRmbrMmInt), numFmt.format(dueDtRmbrSetlMmInt)));
			}
			if (bndVO.isDly() && bndVO.dlyInt > 0) {
				partRmbrIntTooTip.append("^");
				partRmbrIntTooTip.append(String.format("■ 연체이자(+) : %s", numFmt.format(bndVO.dlyInt)));
			}

			// 중도상환수수료(전액)
			StringBuilder tamtRmbrFeeTooTip = new StringBuilder(1024);
			tamtRmbrFeeTooTip.append(String.format("■ 중도상환수수료(+) : %s (부대비용 + 간주이자)", numFmt.format(bndVO.tamtCalcMidRmbrFee)));
			// 부대비용
			if (isOneYearAfter) {
				tamtRmbrFeeTooTip.append(String.format("^☞ 부대비용 : %s", numFmt.format(tamtIncdCost)));
				tamtRmbrFeeTooTip.append(String.format("^※ 원금 : %s, 부대비용율 : %s", numFmt.format(bndVO.rlTamtRmbrPamt), incdCostRt));
			} else {
				tamtRmbrFeeTooTip.append("^☞ 부대비용 : 0 (대출 12개월미만시 부대비용 계산안함)");
			}
			// 간주이자
			if (isOneYearAfter) {
				tamtRmbrFeeTooTip.append(String.format("^☞ 간주이자 : %s (원금 * (중도상환수수료율 - 부대비용율) / 100 * 잔존기간 / (실총대출일 - 30))", numFmt.format(tamtRgdInt)));
			} else {
				tamtRmbrFeeTooTip.append(String.format("^☞ 간주이자 : %s (원금 * 중도상환수수료율 / 100 * 잔존기간 / (실총대출일 - 30))", numFmt.format(tamtRgdInt)));
			}
			tamtRmbrFeeTooTip.append(String.format("^※ 중도상환수수료율 : %s , 잔존기간 : %s",bndVO.midRmbrFeeRt,numFmt.format((int) midRmbrBalDdcnt)));
			if (isLoanDtBf30) {
				tamtRmbrFeeTooTip.append(String.format("(%s " + "- 30(인정경과일수)", numFmt.format(bndVO.midRmbrBalDdcnt)));
			}
			tamtRmbrFeeTooTip.append(String.format(", 총대출일 : %s (실총대출일 : %s)", numFmt.format(bndVO.loanTotDdcnt - 30), numFmt.format(bndVO.loanTotDdcnt)));
			if (bndVO.isDly() && bndVO.dfee>0) {
				tamtRmbrFeeTooTip.append(String.format("^■ 연체료(+) : %s", numFmt.format(bndVO.dfee)));
			}

			// 중도상환수수료(부분상환)
			StringBuilder partRmbrFeeTooTip = new StringBuilder(1024);
			partRmbrFeeTooTip.append(String.format("■ 중도상환수수료(+) : %s (부대비용 + 간주이자)", numFmt.format(bndVO.partCalcMidRmbrFee)));
            // 부대비용
            if (isOneYearAfter) {
                partRmbrFeeTooTip.append(String.format("^☞ 부대비용 : %s", numFmt.format(partIncdCost)));
                partRmbrFeeTooTip.append(String.format("^※ 원금 : %s, 부대비용율 : %s", numFmt.format(bndVO.rlPartRmbrPamt), incdCostRt));
            } else {
                partRmbrFeeTooTip.append("^☞ 부대비용 : 0 (대출 12개월미만시 부대비용 계산안함)");
            }
            // 간주이자
            if (isOneYearAfter) {
                partRmbrFeeTooTip.append(String.format("^☞ 간주이자 : %s (원금 * (중도상환수수료율 - 부대비용율) / 100 * 잔존기간 / (실총대출일 - 30))",numFmt.format(partRgdInt)));
            } else {
                partRmbrFeeTooTip.append(String.format("^☞ 간주이자 : %s (원금 * 중도상환수수료율 / 100 * 잔존기간 / (실총대출일 - 30))",numFmt.format(partRgdInt)));
            }
            partRmbrFeeTooTip.append(String.format("^※ 중도상환수수료율 : %s , 잔존기간 : %s",bndVO.midRmbrFeeRt,numFmt.format((int) midRmbrBalDdcnt)));
            if (isLoanDtBf30) {
            	partRmbrFeeTooTip.append(String.format("(%s " + "- 30(인정경과일수))",numFmt.format(bndVO.loanTotDdcnt)));
            }
            partRmbrFeeTooTip.append(String.format(", 총대출일 : %s (실총대출일 : %s)", numFmt.format(bndVO.loanTotDdcnt - 30),numFmt.format(bndVO.loanTotDdcnt)));
            if (bndVO.isDly() && bndVO.dfee>0) {
                partRmbrFeeTooTip.append(String.format("^■ 연체료(+) : %s",numFmt.format(bndVO.dfee)));
            }

			bndVO.tmatRmbrIntTooltip=tamtRmbrIntTooTip.toString();
			bndVO.tmatRmbrFeeTooltip=tamtRmbrFeeTooTip.toString();
			bndVO.partRmbrIntTooltip=partRmbrIntTooTip.toString();
			bndVO.partRmbrFeeTooltip=partRmbrFeeTooTip.toString();
		}
		return bndVO;
	}

	/**
	 * <p>메소드명	: getFg</p>
	 * <p>설　　명	: 여부 상수값을 리턴</p>
	 * <p>메소드인수	: String inVal</p>
	 * <p>리　턴　값	: String</p>
	 */
	private static String getFg(String inVal) {
		if (StringUtils.isEmpty(inVal)) {
			return Constants.NO;
		} else {
			return inVal;
		}
	}

	// 리스 여부
	@Override
	public boolean isLease(String prdtLcd) {
		return StringUtil.in(prdtLcd, "3,4,6");
	}
	// 금융리스 여부
	private static boolean isFinanceLease(BndVO bndVO) {
		return bndVO.prdtLrgeClasCd.equals("3");
	}
	// 운용리스 여부
	private static boolean isAutoLease(BndVO bndVO) {
		return StringUtil.in(bndVO.prdtLrgeClasCd, "4,6");
	}

	// 청구미수 계산 대상 준비
	private AskUnrcvVO initAskUnrcvForBatch(AskUnrcvVO askUnrcvVO) {

		// ■ 대상정보에 대한 Temp Table에 등록
		askUnrcvService.createAskUnrcvObjForBatch(askUnrcvVO.getAskUnrcvObjList());

		// ■ 대상정보에 대한 대출정보 Set
		askUnrcvVO = askUnrcvService.searchLoanBaseForBatch(askUnrcvVO);

		return askUnrcvVO;
    }

}
