package hanalife.r.co.as.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.r.co.as.mapper.HmAskUnrcvMapper;
import hanalife.r.co.as.mapper.dto.SearchLoanObjINDTO;
import hanalife.r.co.as.mapper.dto.SearchLoanObjOUTDTO;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.service.HmAskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.as.vo.HmAskUnrcvProcVO;
import hanalife.r.co.as.vo.HmLoanTimsVO;
import hanalife.r.co.as.vo.HmLoanVO;
import hanalife.r.co.as.vo.TimsUnrcvVO;


/**
 * <pre>
 * 클래스　명 : HmAskUnrcvProcServiceImpl
 * 클래스설명 : 통합청구미수처리Impl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 16.
 *  * 작성자명    : 70279 / jung
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 16.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("HmAskUnrcvProcService")
public class HmAskUnrcvProcServiceImpl implements HmAskUnrcvProcService {

	/* 오류코드 상수*/
	private final static String ERR_SYSTEM = "8888";
	private final static String SUCCESS_CD = "0000";
	private final static String ERR_CD = "0001";
	private final static String NOT_FOUND = "0002";

	private static final Logger log = LoggerFactory.getLogger(HmAskUnrcvProcServiceImpl.class);

	static Map errMap;

	static {
		errMap = new HashMap();
		errMap.put(NOT_FOUND, "접수번호의 상담 정보가 존재하지 않습니다.");
	}

	@Autowired
	private HmAskUnrcvMapper hmAskUnrcvMapper;
	@Autowired
	private AskUnrcvProcService askUnrcvProcService;

	/**
	 * <p>메소드명		: proc</p>
	 * <p>설명			: 고객통합청구미수처리</p>
	 * <p>메소드인수1 	: HmAskUnrcvProcVO</p>
	 * <p>메소드인수2 	: ITransaction</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public List proc(HmAskUnrcvProcVO inVO) {
		List result = null;

		if (inVO == null) {
			return makeResult(ERR_SYSTEM, "요청정보가 입력되지 않았습니다.");
		}

		try {
			String rsCd = searchUnrcvObj(inVO);
			result = makeResult(rsCd, inVO.getRsltCntn());

		} catch(Exception e) {
			result = makeResult(ERR_SYSTEM, e.getMessage());
		}
		return result;
	}

	/**
	 * <p>메소드명		: CustProc</p>
	 * <p>설명			: 고객통합청구미수처리</p>
	 * <p>메소드인수1 	: HmAskUnrcvProcVO</p>
	 * <p>메소드인수2 	: ITransaction</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public List CustProc(HmAskUnrcvProcVO inVO) {
		List result = null;

		if (inVO == null) {
			return makeResult(ERR_SYSTEM, "요청정보가 입력되지 않았습니다.");
		}

		try {
			String rsCd = searchCustObj(inVO);
			result = makeResult(rsCd, inVO.getRsltCntn());
		} catch(Exception e) {
			result = makeResult(ERR_SYSTEM, e.getMessage());
		}
		return result;
	}

	/**
	 * <p>메소드명		: searchUnrcvObj</p>
	 * <p>설명			: 고객통합청구미수처리-청구미수태움</p>
	 * <p>메소드인수1 	: HmAskUnrcvProcVO</p>
	 * <p>메소드인수2 	: ITransaction</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String searchUnrcvObj(HmAskUnrcvProcVO inVO) throws Exception {

		try {
			//조회구분에 따른 입력 확인	(조회구분: 'L'-대출,'C'-고객)
			if (inVO.getSetlDt().length()!= 10) {
				log.error("결제일자 입력값이 유효하지 않습니다.["+inVO.getSetlDt()+"]");
				inVO.setRsltCntn("결제일자 입력값이 유효하지 않습니다.["+inVO.getSetlDt()+"]");
			}

			if (inVO.getSearchDivCd().equals("L")) {
				//대출건별
				if (inVO.getSearchLoanNo().equals("")) {
					log.error("대출건조회시 대출번호 필수입력["+inVO.getSearchLoanNo()+"]");
					inVO.setRsltCntn("대출건조회시 대출번호 필수입력["+inVO.getSearchLoanNo()+"]");

					return ERR_CD;
				}
			} else if (inVO.getSearchDivCd().equals("C")) {
				//고객번호
				if (inVO.getSearchCustNo().equals("")) {
					log.error("대출건조회시 대출번호 필수입력["+inVO.getSearchCustNo()+"]");
					inVO.setRsltCntn("대출건조회시 대출번호 필수입력["+inVO.getSearchCustNo()+"]");

					return ERR_CD;
				}
			} else {
				log.error("정의된 조회구분 값이 아닙니다.["+inVO.getSearchDivCd()+"]");
				inVO.setRsltCntn("정의된 조회구분 값이 아닙니다.["+inVO.getSearchDivCd()+"]");
				return ERR_CD;
			}

			//대출정보조회
			if (searchLoanInfo(inVO) < 1) {
				log.error("조건에 해당하는 대출정보가 존재하지 않습니다.");
				inVO.setRsltCntn("조건에 해당하는 대출정보가 존재하지 않습니다.");
				return ERR_CD;
			}

			if (inVO.getLeglChkFg().equals("1") && inVO.getLeglActsObjFg().equals("1") && !inVO.getSearchLoanNo().equals("")) {
				log.error("해당 관리부서로 문의해 주십시오.(법적조치 대상)");
				inVO.setRsltCntn("해당 관리부서로 문의해 주십시오.(법적조치 대상)");
				return ERR_CD;
			}

			//청구미수처리 호출
			AskUnrcvVO askUnrcvVO = new AskUnrcvVO();
			int idx=0;
			for (int n = inVO.getLoanVOList().size(); idx < n;idx++) {
				askUnrcvVO.addAskUnrcvObj(getAskUnrcvObjVO(inVO.getLoanVOList(idx)));	//청구미수 대상정보 set
			}

			if (idx>0) {
				askUnrcvVO = calcAskUnrcv(askUnrcvVO);

				/*******************************************************************************************
				 * HmAskUnrcvProcVO => AskUnrcvVO 변환
				 * ASIS 메소드 밖으로 꺼내와서 처리 - searchCustObj(HmAskUnrcvProcVO inVO)
				 ******************************************************************************************/
				int idx1 = 0;

				List loanVO = inVO.getLoanVOList();

				for (idx1 = 0; idx1 < loanVO.size(); idx1++) {

					HmLoanVO objVO = (HmLoanVO) loanVO.get(idx1);

					BndVO bndVO = askUnrcvVO.getBndVO(objVO.getLoanNo(), objVO.getLoanSeq());
					if (bndVO == null){
						if (!inVO.getDlyFg().equals("1") && objVO.getDlyMmcnt() >= 3) {
							inVO.setDlyFg("1");
						}
						continue;
					}

					objVO.setComgDueDt(bndVO.thmmDueDt);
					objVO.setComgTims(bndVO.thmmDueTims);
					objVO.setTotTims(bndVO.totTims);
					objVO.setLastSetlDt(bndVO.lastSetlDt);
					objVO.setDlyStrtDt(bndVO.dlyDt);
					objVO.setDlyCnt(bndVO.dlyCnt);
					objVO.setDlyDdcnt(bndVO.dlyDdcnt);
					objVO.setDlyMmcnt(bndVO.dlyMmCnt);
					objVO.setObjAmt(bndVO.askAmt);
					objVO.setNormAmt(bndVO.normAmt);
					objVO.setNormPamt(bndVO.normPamt);
					objVO.setNormInt(bndVO.normInt);
					objVO.setSpayAmt(bndVO.leglActnCostRamt);
					objVO.setDlyAmt(bndVO.dlyAmt);
					objVO.setDlyPamt(bndVO.dlyPamt);
					objVO.setDlyInt(bndVO.dlyInt);
					objVO.setDfee(bndVO.dfee);
					objVO.setPdueDiscDfee(bndVO.pdueDiscDfee);

					if (!objVO.getPrdtLrgeClasCd().equals("3") && !objVO.getPrdtLrgeClasCd().equals("4")) {

						objVO.setTamtRmbrAmt(bndVO.tamtRmbrObjAmt);
						objVO.setTamtRmbrPamt(bndVO.tamtRmbrPamt);
						objVO.setTamtRmbrInt(bndVO.totMidRmbrInt);
						objVO.setTamtRmbrFee(bndVO.tamtRmbrFee);
						objVO.setTrtFeeDisc(bndVO.trtFeeDisc);
						objVO.setPamtRmbrAmt(bndVO.partRmbrObjAmt);
						objVO.setPamtRmbrPamt(bndVO.partRmbrPamt);
						objVO.setPamtRmbrInt(bndVO.partMidRmbrInt);
						objVO.setPamtRmbrFee(bndVO.partRmbrFee);
						objVO.setMidPreDueAmt(bndVO.midPreDueAmt);
						objVO.setMidPreDuePamt(bndVO.midPreDuePamt);
						objVO.setMidPdueInt(bndVO.midPreDueInt);
						objVO.setMidPreDueTrtFee(bndVO.midPreDueTrtFee);

						objVO.setMidRmbrFg(bndVO.midRmbrFg);
						objVO.setMidRmbrTims(bndVO.midRmbrTims);
						//취급수수료 항목추가
						objVO.setTamtRmbrTrtFee(bndVO.rlTamtRmbrTrtFee);
						if (Constants.YES.equals(bndVO.dueDtMidRmbrFg)) {
							objVO.setPamtRmbrTrtFee(bndVO.normTrtFee);
						}
					}

					objVO.setBalPamt(objVO.getLoanPamtRamt() - objVO.getPamtRmbrPamt());
					objVO.setBalPamtWithPduePamt(objVO.getLoanPamtRamt() - objVO.getPamtRmbrPamt() + objVO.getMidPreDuePamt());
					objVO.setDsrcRamt(bndVO.dsrcRamt);
					objVO.setLtrmBrcvAmtRamt(bndVO.ltrmBrcvAmtRamt);

					//취급수수료 항목추가
					objVO.setNormTrtFee(bndVO.normTrtFee);
					objVO.setDlyTrtFee(bndVO.dlyTrtFee);
					if (!inVO.getDlyFg().equals("1") && objVO.getDlyMmcnt() >= 3) {
						inVO.setDlyFg("1");
					}

					objVO.setLoanIntRamt(bndVO.intRamt);
					objVO.setLeglActsCost(bndVO.occrLeglActnCost);
					objVO.setLeglActsCostRamt(bndVO.leglActnCostRamt);
					objVO.setBndRamt(objVO.getLoanPamtRamt() + objVO.getLoanIntRamt());
				}


				if (inVO.getSearchPrdtDivCd().equals("L")) {

					/*******************************************************************************************
					 * 회차정보
					 * ASIS 메소드 밖으로 꺼내와서 처리 - convertUnrcvTims(inVO, askUnrcvVO)
					 ******************************************************************************************/
					HmLoanVO hmLoanVO = inVO.getLoanVOList(0);

					for (int i=0, n=askUnrcvVO.getTimsUnrcvList().size(); i<n; i++) {
						TimsUnrcvVO timsUnrcvVO = askUnrcvVO.getTimsUnrcv(i);

						if (timsUnrcvVO.dueDt.compareTo(hmLoanVO.getComgDueDt())>0) {
							break;
						}

						HmLoanTimsVO objVO = new HmLoanTimsVO();
							objVO.setTims(timsUnrcvVO.tims);
							objVO.setDueDt(timsUnrcvVO.dueDt);
							objVO.setRlDueDt(timsUnrcvVO.rlDueDt);
							objVO.setRcptObjAmt(timsUnrcvVO.rcptObjAmt);
							objVO.setAskAmt(timsUnrcvVO.askAmt);
							objVO.setAskIpayInsuFee(timsUnrcvVO.askIpayInsuFee);
							objVO.setAskIpayCarTax(timsUnrcvVO.askIpayCartax);
							objVO.setAskIpayEnvImprBrdnamt(timsUnrcvVO.askAddEnvImprBrdnamt);
							objVO.setLeglActnCost(timsUnrcvVO.leglActnCost);
							objVO.setAskDfee(timsUnrcvVO.askDfee);
							objVO.setDlyDdcnt(timsUnrcvVO.dlyDdcnt);
						inVO.addLoanTimsVO(objVO);
					}
				}
			}

			if (inVO.getDlyChkFg().equals("1") && inVO.getDlyFg().equals("1") && !inVO.getSearchLoanNo().equals("")) {
				log.error("해당 관리부서로 문의해 주십시오.(3개월 이상 연체)");
				inVO.setRsltCntn("해당 관리부서로 문의해 주십시오.(3개월 이상 연체)");
				return ERR_CD;
			}

		} catch (Throwable e) {
			log.error("searchUnrcvObj 중 오류 [" + e.getMessage() + "]", e);
			throw new Exception("searchUnrcvObj 중 오류 [" + e.getMessage() + "]");
		}
		return SUCCESS_CD;
	}

	/**
	 * <p>메소드명		: searchCustObj</p>
	 * <p>설명			: 고객통합청구미수처리-청구미수안탐</p>
	 * <p>메소드인수1 	: HmAskUnrcvProcVO</p>
	 * <p>메소드인수2 	: ITransaction</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String searchCustObj(HmAskUnrcvProcVO inVO) throws Exception {

		try {
			//조회구분: 'L'-대출,'C'-고객
			//조회구분에 따른 입력 확인
			if (inVO.getSetlDt().length()!= 10) {
				log.error("결제일자 입력값이 유효하지 않습니다.["+inVO.getSetlDt()+"]");
				inVO.setRsltCntn("결제일자 입력값이 유효하지 않습니다.["+inVO.getSetlDt()+"]");
			}

			if (inVO.getLoanContFg().equals("0") && inVO.getLoanRlDueFg().equals("0") && inVO.getLoanEtcFg().equals("0")) {
				log.error("고객의 대출관계를 입력하세요.");
				inVO.setRsltCntn("고객의 대출관계를 입력하세요.");
				return ERR_CD;
			}

			if (inVO.getLoanStatRegFg().equals("0") && inVO.getLoanStatCnfmFg().equals("0") && inVO.getLoanStatEndFg().equals("0")) {
				log.error("대출상태를 입력하세요.");
				inVO.setRsltCntn("대출상태를 입력하세요.");
				return ERR_CD;
			}

			//대출정보조회
			int cnt = searchCustLoanInfo(inVO);
			if (cnt<1) {
				log.error("조건에 해당하는 대출정보가 존재하지 않습니다.");
				inVO.setRsltCntn("조건에 해당하는 대출정보가 존재하지 않습니다.");
				return ERR_CD;
			}

		} catch (Throwable e) {
			e.printStackTrace();
			log.error("searchCustObj 중 오류 [" + e.getMessage() + "]");
			throw new Exception("searchCustObj 중 오류 [" + e.getMessage() + "]");
		}
		return SUCCESS_CD;
	}

	/**
	 * <p>메소드명		: searchLoanInfo</p>
	 * <p>설명			: 대출정보조회</p>
	 * <p>메소드인수1 	: HmAskUnrcvProcVO</p>
	 * <p>메소드인수2 	: ITransaction</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int searchLoanInfo(HmAskUnrcvProcVO inVO) throws Exception {


		int sqlCnt=0;

		try {

			SearchLoanObjINDTO inDTO = new SearchLoanObjINDTO();
			inDTO.setSchCustNo(inVO.getSearchCustNo());
			inDTO.setSchLoanNo(inVO.getSearchLoanNo());
			inDTO.setSchLoanSeq(inVO.getSearchLoanSeq());
//			inDTO.setSchLoanStatCd(inVO.getSearchLoanStatCd());
			inDTO.setSchPrdtDivCd(inVO.getSearchPrdtDivCd());
			inDTO.setLoanContFg(inVO.getLoanContFg());
			inDTO.setLoanEtcFg(inVO.getLoanEtcFg());
			inDTO.setLoanRlDueFg(inVO.getLoanRlDueFg());
			inDTO.setLoanStatRegFg(inVO.getLoanStatRegFg());
			inDTO.setLoanStatCnfmFg(inVO.getLoanStatCnfmFg());
			inDTO.setLoanStatEndFg(inVO.getLoanStatEndFg());
			inDTO.setLoanLastFg(inVO.getLoanLastFg());
			inDTO.setDepsFg(inVO.getDepsFg());
			inDTO.setMloanCond(inVO.getMloanLmitFg());
			log.debug("ddddddddddddd");
			List<SearchLoanObjOUTDTO> outDTO = hmAskUnrcvMapper.selectLoanObj(inDTO);
			log.debug("ccccccccccccccc");
			for (SearchLoanObjOUTDTO sourceIO : outDTO) {
				sqlCnt++;

				HmLoanVO loanVO = new HmLoanVO();

				loanVO.setLoanNo(sourceIO.getLoanNo());                          /*대출번호*/
				loanVO.setLoanSeq(sourceIO.getLoanSeq());                        /*대출순번*/
				loanVO.setPrdtNm(sourceIO.getPrdtNm());                          /*상품명*/
				loanVO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());          /*상품대분류*/
				loanVO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd());            /*상품중분류*/
				loanVO.setPrdtMidClasNm(sourceIO.getPrdtMidClasNm());
				loanVO.setPrdtSmClasCd(sourceIO.getPrdtSmClasCd());              /*상품소분류*/
				loanVO.setLoanDt(sourceIO.getLoanDt());                          /*대출일자*/
				loanVO.setLoanPamt(sourceIO.getLoanPamt());                      /*대출원액*/
				loanVO.setLoanInt(sourceIO.getLoanInt());                        /*대출이자*/
				loanVO.setLoanPamtRamt(sourceIO.getLoanPamtRamt());              /*대출원금잔액*/
				loanVO.setMngDeptCd(sourceIO.getMngDeptCd());                    /*관리부서코드*/
				loanVO.setMngDeptNm(sourceIO.getMngDeptNm());                    /*관리부서명*/
				loanVO.setMngPlcDivCd(sourceIO.getMngPlcDivCd());                /*관리구분코드*/
				loanVO.setMngPlcDivNm(sourceIO.getMngPlcDivNm());                /*관리처구분명*/
				loanVO.setBndDivsEmpNo(sourceIO.getBndDivsEmpNo());              /*채권담당사원번호*/
				loanVO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm());              /*채권담당사원명*/
				loanVO.setLnDivsEmpNo(sourceIO.getLnDivsEmpNo());                /*여신담당사원번호*/
				loanVO.setLnDivsEmpNm(sourceIO.getLnDivsEmpNm());                /*여신담당사원명*/
				loanVO.setMngDeptTelNo(sourceIO.getMngDeptTelNo());              /*관리부서전화*/
				loanVO.setLoanIntRt(sourceIO.getLoanIntRt());                    /*대출이자율*/
				loanVO.setContManNo(sourceIO.getContManNo());
				loanVO.setContManNm(sourceIO.getContManNm());
				loanVO.setRlDueManNo(sourceIO.getRlDueManNo());                  /*실납입자번호*/
				loanVO.setRlDueManNm(sourceIO.getRlDueManNm());                  /*실납입자명*/
				loanVO.setLoanRelNm(sourceIO.getLoanRelNm());                    /*대출관계명*/
				loanVO.setDueMethCd(sourceIO.getDueMethCd());                    /*납입방법명*/
				loanVO.setBankNm(sourceIO.getBankNm());                          /*은행*/
				loanVO.setAcntNo(sourceIO.getAcntNo());                          /*계좌번호*/
				loanVO.setImgAcntBankNm(sourceIO.getImgAcntBankNm());            /*가상계좌은행명*/
				loanVO.setImgAcntNo(sourceIO.getImgAcntNo());                    /*가상계좌번호*/
				loanVO.setLoanStatCd(sourceIO.getLoanStatCd());
				loanVO.setLoanStatNm(sourceIO.getLoanStatNm());
				loanVO.setBndStatCd(sourceIO.getBndStatCd());
				loanVO.setBndStatNm(sourceIO.getBndStatNm());
				loanVO.setLeglActsObjFg(sourceIO.getLeglActsObjFg());            /*법적조치대상여부*/
				loanVO.setSetlDt(inVO.getSetlDt());                              /*결제일자*/
				loanVO.setPamtRmbrPamt(inVO.getPamtRmbrRamt());                  /*결제일자*/
				loanVO.setEprtDt(sourceIO.getEprtDt());                          /*만기일자*/
				loanVO.setLoanTerm(sourceIO.getLoanTerm());
				//loanVO.setGodsNm(rs.getString("GODS_NM")); /* 차종 */
				loanVO.setGodsPrce(sourceIO.getGodsPrce());
				loanVO.setTrtFee(sourceIO.getTrtFee());                          //취급수수료
				loanVO.setTrtFeeRamt(sourceIO.getTrtFeeRamt());                  //취급수수료잔액
				loanVO.setDepsAmt(sourceIO.getDepsAmt());                        //공탁금
				loanVO.setDepsRamt(sourceIO.getDepsRamt());                      //공탁금잔액
				loanVO.setLeglActsCost(sourceIO.getLeglActsCost());              //공탁금
				loanVO.setLeglActsCostRamt(sourceIO.getLeglActsCostRamt());      //공탁금잔액
				loanVO.setBndRamt(loanVO.getLoanPamtRamt());
				loanVO.setCrimRegFg(sourceIO.getCrimRegFg());

				inVO.addLoanVO(loanVO);

				if (loanVO.getLeglActsObjFg().equals("1") && !inVO.getLeglActsObjFg().equals("1")) {
					inVO.setLeglActsObjFg("1");
				}
			}

		} catch (Exception e) {
			throw new Exception( "tm상담정보조회중 오류 [" + e.getMessage() + "]" );
		}
		return sqlCnt;
	}

	/**
	 * <p>메소드명		: searchCustLoanInfo</p>
	 * <p>설명			: 고객대출정보조회</p>
	 * <p>메소드 인수1	: HmAskUnrcvProcVO</p>
	 * <p>메소드 인수2	: ITransaction</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int searchCustLoanInfo(HmAskUnrcvProcVO inVO) throws Exception {

		int sqlCnt=0;

		try {
			SearchLoanObjINDTO inDTO = new SearchLoanObjINDTO();

			inDTO.setSchCustNo(inVO.getSearchCustNo());
			inDTO.setLoanContFg(inVO.getLoanContFg());
			inDTO.setLoanEtcFg(inVO.getLoanEtcFg());
			inDTO.setLoanRlDueFg(inVO.getLoanRlDueFg());
			inDTO.setLoanStatRegFg(inVO.getLoanStatRegFg());
			inDTO.setLoanStatCnfmFg(inVO.getLoanStatCnfmFg());
			inDTO.setLoanStatEndFg(inVO.getLoanStatEndFg());
			inDTO.setLoanLastFg(inVO.getLoanLastFg());
			inDTO.setDepsFg(inVO.getDepsFg());
			inDTO.setMloanCond(inVO.getMloanLmitFg());

			List<SearchLoanObjOUTDTO> outDTO = hmAskUnrcvMapper.selectLoanByCust(inDTO);

			for (SearchLoanObjOUTDTO sourceIO : outDTO) {
				sqlCnt++;

				HmLoanVO loanVO = new HmLoanVO();

				loanVO.setLoanNo(sourceIO.getLoanNo());
				loanVO.setLoanSeq(sourceIO.getLoanSeq());
				loanVO.setPrdtNm(sourceIO.getPrdtNm());
				loanVO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());
				loanVO.setPrdtLrgeClasNm(sourceIO.getPrdtLrgeClasNm());
				loanVO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd());
				loanVO.setPrdtMidClasNm(sourceIO.getPrdtMidClasNm());
				loanVO.setPrdtSmClasCd(sourceIO.getPrdtSmClasCd());
				loanVO.setPrdtSmClasNm(sourceIO.getPrdtSmClasNm());
				loanVO.setGodsSpecCd(sourceIO.getGodsSpecCd());
				loanVO.setGodsSpecNm(sourceIO.getGodsSpecNm());
				loanVO.setGodsQty(sourceIO.getGodsQty());
				loanVO.setLoanDt(sourceIO.getLoanDt());
				loanVO.setLeasEprtDt(sourceIO.getLeasEprtDt());
				loanVO.setEprtDt(sourceIO.getEprtDt());
				loanVO.setEndDt(sourceIO.getEndDt());
				loanVO.setLoanTerm(sourceIO.getLoanTerm());
				loanVO.setLoanPamt(sourceIO.getLoanPamt());
				loanVO.setLoanInt(sourceIO.getLoanInt());
				loanVO.setGuarAmt(sourceIO.getGuarAmt());
				loanVO.setNoguarRamtAmt(sourceIO.getNoguarRamtAmt());
				loanVO.setLoanPamtRamt(sourceIO.getLoanPamtRamt());
				loanVO.setMngDeptCd(sourceIO.getMngDeptCd());
				loanVO.setMngDeptNm(sourceIO.getMngDeptNm());
				loanVO.setMngPlcDivCd(sourceIO.getMngPlcDivCd());
				loanVO.setMngPlcDivNm(sourceIO.getMngPlcDivNm());
				loanVO.setBndDivsEmpNo(sourceIO.getBndDivsEmpNo());
				loanVO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm());
				loanVO.setLnDivsEmpNo(sourceIO.getLnDivsEmpNo());
				loanVO.setLnDivsEmpNm(sourceIO.getLnDivsEmpNm());
				loanVO.setMngDeptTelNo(sourceIO.getMngDeptTelNo());
				loanVO.setLoanIntRt(sourceIO.getLoanIntRt());
				loanVO.setContManNo(sourceIO.getContManNo());
				loanVO.setContManNm(sourceIO.getContManNm());
				loanVO.setRlDueManNo(sourceIO.getRlDueManNo());
				loanVO.setRlDueManNm(sourceIO.getRlDueManNm());
				loanVO.setRecvManNo(sourceIO.getRecvManNo());
				loanVO.setRecvManNm(sourceIO.getRecvManNm());
				loanVO.setLoanRelNm(sourceIO.getLoanRelNm());
				loanVO.setLoanRelManNm(sourceIO.getLoanRelManNm());
				loanVO.setLoanRelManNo(sourceIO.getLoanRelManNo());
				loanVO.setDueMethCd(sourceIO.getDueMethCd());
				loanVO.setBankNm(sourceIO.getBankNm());
				loanVO.setAcntNo(sourceIO.getAcntNo());
				loanVO.setImgAcntBankNm(sourceIO.getImgAcntBankNm());
				loanVO.setImgAcntNo(sourceIO.getImgAcntNo());
				loanVO.setLoanStatCd(sourceIO.getLoanStatCd());
				loanVO.setLoanStatNm(sourceIO.getLoanStatNm());
				loanVO.setBndStatCd(sourceIO.getBndStatCd());
				loanVO.setBndStatNm(sourceIO.getBndStatNm());
				loanVO.setLeasStatNm(sourceIO.getLeasStatNm());
				loanVO.setSetlDd(sourceIO.getSetlDd());
				loanVO.setSetlDt(sourceIO.getSetlDt());
				loanVO.setPamtRmbrPamt(sourceIO.getPamtRmbrPamt());
				loanVO.setTrtFee(sourceIO.getTrtFee());
				loanVO.setTrtFeeRamt(sourceIO.getTrtFeeRamt());
				loanVO.setDepsAmt(sourceIO.getDepsAmt());
				loanVO.setDepsRamt(sourceIO.getDepsRamt());
				loanVO.setLeglActsCost(sourceIO.getLeglActsCost());
				loanVO.setLeglActsCostRamt(sourceIO.getLeglActsCostRamt());
				loanVO.setBndRamt(sourceIO.getBndRamt());
				loanVO.setCrimRegFg(sourceIO.getCrimRegFg());

				loanVO.setPamtRamt(sourceIO.getPamtRamt());
				loanVO.setIntRamt(sourceIO.getIntRamt());
				loanVO.setDlyPamt(sourceIO.getDlyPamt());
				loanVO.setDlyInt(sourceIO.getDlyInt());
				loanVO.setDlyTcnt(sourceIO.getDlyTcnt());
				loanVO.setDlyDdCnt(sourceIO.getDlyDdCnt());
				loanVO.setThmmComgTims(sourceIO.getThmmComgTims());
				loanVO.setCustResiNo(sourceIO.getCustResiNo());

				inVO.addLoanVO(loanVO);

			}
		} catch (Exception e) {
			throw new Exception( "고객대출정보조회 중 오류 [" + e.getMessage() + "]" );
		}
		return sqlCnt;
	}

	/**
	 * <p>메소드명		: getAskUnrcvObjVO</p>
	 * <p>설명			: 청구미수 대상객체를 얻는다</p>
	 * <p>메소드인수1 	: HmLoanVO</p>
	 * <p>메소드리턴값	: AskUnrcvObjVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	private AskUnrcvObjVO getAskUnrcvObjVO(HmLoanVO inVO) {
		AskUnrcvObjVO askUnrcvObjVO = new AskUnrcvObjVO();
			askUnrcvObjVO.loanNo = inVO.getLoanNo();
			askUnrcvObjVO.loanSeq = inVO.getLoanSeq();
			askUnrcvObjVO.setlDt = inVO.getSetlDt();
			askUnrcvObjVO.partRmbrPamt = inVO.getPamtRmbrPamt();
		return askUnrcvObjVO;
	}

	/**
	 * <p>메소드명		: calcAskUnrcv</p>
	 * <p>설명			: 청구미수계산</p>
	 * <p>메소드인수1 	: AskUnrcvVO</p>
	 * <p>메소드인수2 	: Connection</p>
	 * <p>메소드리턴값	: AskUnrcvVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	private AskUnrcvVO calcAskUnrcv(AskUnrcvVO askUnrcvVO) throws Exception {
		askUnrcvProcService.calcAskUnrcv(askUnrcvVO);
		if (!askUnrcvVO.isSuccess()) {
			throw new Exception("청구미수 계산중 에러발생[" + askUnrcvVO.rsltCntn + "]");
		}
		return askUnrcvVO;
	}


	/**
	 * <p>메소드명		: makeResult</p>
	 * <p>설명			: 요청결과를 에러코드 - 에러메시지로 생성</p>
	 * <p>메소드인수1 	: String errCd(4자리)</p>
	 * <p>메소드인수2 	: String addMsg</p>
	 * <p>메소드리턴값	: List</p>
	 * <p>예외처리		: N/A</p>
	 */
	private List makeResult(String errCd, String addMsg) {
		List result = new ArrayList();
		result.add(errCd);
		result.add(getMsg(errCd) + " " + addMsg);
		return result;
	}

	/**
	 * <p>메소드명		: getMsg</p>
	 * <p>설명			: 에러코드에 해당하는 에러메시지 얻기</p>
	 * <p>메소드인수1 	: String errCd(4자리)</p>
	 * <p>메소드리턴값	: String msg</p>
	 * <p>예외처리		: N/A</p>
	 */
	private String getMsg(String errCd) {
		String errMsg = (String) errMap.get(errCd);
		if (errMsg == null) {
			errMsg = "";
		}
		return errMsg;
	}

}
