package hanalife.r.co.as.vo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

import hanalife.b.cl.dl.vo.tmp.AskUnrcvConst;

@SuppressWarnings({"serial", "unchecked", "rawtypes"})
/**
 * <pre>
 * 클래스명    : BndVO
 * 클래스설명 : 채권정보 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class BndVO extends ValueObj implements Serializable, Comparable {

	/**
	 * 중도상환회차
	 */
	private TimsUnrcvVO midRmbrTimsVO = null;
	/**
	 * 중도상환전회차(납입일기준 중도상환회차)
	 */
	private TimsUnrcvVO bfMidRmbrTims = null;

	/**
	 * 납입일자에 중도상환하는 경우( 납입일자 <= 결제일자 <= 실납입일자 => 중도상환시 다 받고 넘어가야하는 금액 )
	 */
	private TimsUnrcvVO dueDtMidRmbrTims = null;

	public String loanNo;			//대출_번호
	public String loanSeq;			//대출_순번

	public String prdtClas;			//상품대중분류코드
	public String prdtLcd;			//상품대분류코드
	public String prdtMcd;			//상품중분류코드
	public String prdtScd;			//상품소분류코드
	public String prdtCd;			//상품코드

	public String setlDt;			//결제일자
	public String loanDt;			//대출일자
	public String eprtDt;			//만기일자

	public int thmmDueTims;			//당월_납입_회차
	public int bfmmDueTims;			//전월_납입_회차
	public int totTims;				//총_회차
	public String loanStatCd;		//대출상태코드
	public String asymmAcctFg;		//비대칭회계여부
	public String rmbrFrmlCd;		//상환_방식_코드
	public String thmmDueDt;		//당월_납입_일자
	public String thmmRlDueDt;		//당월_실_납입_일자
	public String lastSetlDt;		//최종_결제일자
	public int lastSetlTims;		//최종_결제_회차

	public String loanEprtDt;		//대출_만기_일자
	public String loanRlEprtDt;		//대출_실_만기_일자(영업일)
	public String leasEprtDt;		//리스_만기_일자
	public String leasRlEprtDt;		//리스_실_만기_일자
	public String leasEprtDlyDt;	//리스_만기_연체_일자
	public int loanEprtTims;		//대출_만기_회차
	public int procCnt;				//처리건수

	//리스승계여부를 확인하기위해 추가함.
	public String loanOccrCd;		//대출발생코드
	public String execDt;			//실행일자
	public String sixPreDt; 		//6개월전일자
	public double loanIntRt;		//대출_이자율
	public String clsFg;			//마감여부
	/**
	 * <p>상품중분류로 상실계산여부 등록되어있슴.
	 * ST_PRDT_CLAS.DDAY_PRFT_LOSE_FG
	 */
	public String loseCalcFg;		//상실_계산여부

	/**
	 * ST_PRDT_CLAS.DDAY_PRFT_LOSE_FG
	 * @return "1" == ST_PRDT_CLAS.DDAY_PRFT_LOSE_FG
	 */
	public boolean isLoseCalc(){
		return AskUnrcvConst.YES.equals(loseCalcFg);
	}
	public String loseCalcCd;		//상실_계산_구분(회차,일수)
	public int    loseCalcVal;		//상실_계산_구분값(회차,일수)
	public long   loanAmt;			//대출금액
	public long   loanAmt10;		//대출금액10%
	public String unrcvProcDt;		//미수처리일자(납입일자) 리스

	//회차별 정보
	public int timsUnrcvStrtIdx;	//회차_미수_시작_인덱스
	public int timsUnrcvCnt;		//회차_미수_건수

	//잔액정보
	public long pamtRamt;				//원금_잔액
	public long intRamt;				//이자_잔액
	public long trtFeeRamt;				//취급수수료잔액
	public long leasFeeRamt;			//리스료잔액
	public long baseLeasFeeRamt;		//기본리스료잔액
	public long addLeasFeeRamt;			//가산리스료잔액
	public long ppayIntRamt;			//선급이자잔액
	public long addCartaxRamt;			//가산자동차세잔액
	public long addEnvImprBrdnamtRamt;	//가산환개금잔액
	public long addInsuFeeRamt;			//가산보험료잔액
	public long addAsfeeRamt;			//가산정비료잔액
	public long vtaxRamt;				//부가세잔액
	public long ipayCartaxRamt;			//대지급자동차세잔엑
	public long ipayEnvImprBrdnamtRamt;	//대지급환개금잔액
	public long ipayInsuFeeRamt;		//대지급보험료잔액
	public long ipayPnltAmtRamt;		//대지급범칙금잔액
	public long ipayEtcRamt;			//대지급기타잔액
	public long cartaxRamt;				//자동차세잔액
	public long envImprBrdnamtRamt;		//환개금잔액
	public long insuFeeRamt;			//보험료잔액
	public long ltrmBrcvAmtRamt;		//장기선수금잔액
	public long brcvAmtLeasfeeRamt;		//선수금리스료잔액
	public long guarAmt;				//보증금액
	public long ramtAmt;				//잔가금액
	public String endAfAskStatCd;		//종료후청구상태코 (종료후청구상태,대지급청구발생)
	public String eprtAskMethCd;		//만기청구방법코드(원리금,잔가포함)
	public String guarAmtAdjFg;			//보증금대체여부(마지막회차 대체여부)

	public long currentAskAmt;			//현재시점 청구금액
	public long thmmMmAskAmt;			//당월청구금액
	public long thmmMmAskTims;			//당월청구회차
	public long nextAskAmt;				//실미도래회차청구금액
	public long nextAskTims;			//실미도래회차청

	public long stndAskAmt;				//기준청구금액
	public long askAmt;					//청구_금액
	public long askLeasFee;				//청구리스료
	public long askBaseLeasFee;			//청구기본리스료
	public long askAddLeasFee;			//청구가산리스료
	public long askPamt;				//청구_원금
	public long askInt;					//청구_이자
	public long askTrtFee;				//청구_취급수수료
	public long askPpayInt;				//청구선급이자
	public long askTint;				//청구_총이자
	public long askAddCartax;			//청구가산자동차세
	public long askAddEnvImprBrdnamt;	//청구가산환개금
	public long askAddInsuFee;			//청구가산보험료
	public long askAddAsfee;			//청구가산정비료
	public long askVtax;				//청구부가세
	public long askIpayCartax;			//청구대지급자동차세
	public long askIpayEnvImprBrdnamt;	//청구대지급환개금
	public long askIpayInsuFee;			//청구대지급보험료
	public long askIpayPnltAmt;			//청구대지급범칙금
	public long askIpayEtc;				//청구대지급기타
	public long askIpayTax;				//청구대지급조세
	public long askCartax;				//청구자동차세
	public long askEnvImprBrdnamt;		//청구환개금
	public long askInsuFee;				//청구보험료
	public long askLtrmBrcvAmt;			//청구장기선수금
	public long askDfee;				//청구_연체료
	public long askGuarAmt;				//청구보증금액
	public long askRamtAmt;				//청구잔가금액

	//연체 정보
	public int dlyStrtIdx;				//연체_시작_인덱스
	public int dlyCnt;					//연체_건수
	public double addDfeeRt;			//가산_연체료_율 (연체일때 가산금리)
	public double dfeeRt;				//연체료_율    (약정이자율+가산금리)
	public String dfeeRtNm;				//연체료_율_명 (약정이자율+가산금리)
	public long dlyAmt;					//연체_금액
	public long dlyLeasFee;				//연체리스료
	public long dlyBaseLeasFee;			//연체기본리스료
	public long dlyAddLeasFee;			//연체가산리스료
	public long dlyPamt;				//연체_원금
	public long dlyInt;					//연체이자
	public long dlyTrtFee;				//연체_취급수수료
	public long dlyPpayInt;				//연체선급이자
	public long dlyTint;				//연체_총이자
	public long dlyAddCartax;			//연체가산자동차세
	public long dlyAddEnvImprBrdnamt;	//연체가산환개금
	public long dlyAddInsuFee;			//연체가산보험료
	public long dlyAddAsfee;			//연체가산정비료
	public long dlyVtax;				//연체부가세
	public long dlyIpayCartax;			//연체대지급자동차세
	public long dlyIpayEnvImprBrdnamt;	//연체대지급환개금
	public long dlyIpayInsuFee;			//연체대지급보험료
	public long dlyIpayPnltAmt;			//연체대지급범칙금
	public long dlyIpayEtc;				//연체대지급기타
	public long dlyIpayTax;				//연체대지급조세
	public long dlyCartax;				//연체자동차세
	public long dlyEnvImprBrdnamt;		//연체환개금
	public long dlyInsuFee;				//연체보험료
	public long dlyLtrmBrcvAmt;			//연체장기선수금
	public long dfee;					//연체료
	public long dfeeKifrs;				//연체료_KIFRS (2018-08-01 최종원부장님 요청:연체금리가 아닌 정상금리로 계산)
	public long dlyGuarAmt;				//연체보증금액
	public long dlyRamtAmt;				//연체잔가금액
	public long preOccrDfee;			//기_발생_연체료
	public boolean isDly(){
		return AskUnrcvConst.YES.equals(dlyFg);
	}
	public String dlyFg;				//연체_여부
	public String dlyDt;				//연체_일자
	public String dlyCalcDt;			//연체_계산_일자
	public int dlyStrtTims;				//연체_시작_회차
	public String dlyStrtDueDt;			//연체_시작_납입_일자
	public int dlyEndTims;				//연체_종료_회차
	public String dlyEndDueDt;			//연체_종료_납입_일자
	public int dlyDdcnt;				//연체_일수
	public int occrDlyDdcnt;			//발생_연체_일수
	public int dlyMmCnt;				//연체_개월수
	public int dlyTcnt;					//연체_횟수
	public int lngsDlyDdcnt;			//최장_연체_일수
	public int totDlyDdcnt;				//누적_연체_일수
	public long occrPdueDiscDfee;		//발생_선납_할인_연체료
	public long adjPdueDiscDfee;		//정산_선납_할인_연체료
	public long pdueDiscDfeeRamt;		//선납_할인_연체료_잔액
	public long pdueDiscDfeeRamtBfDisc;	//선납_할인_연체료_잔액_할인전
	public long pdueDiscDfee;			//선납_할인_연체료
	public long tempPdueDiscInt;		//임시_선납_할인_이자
	public String loseDlyStrtDt;		//상실_연체_시작일자
	/**
	 * <p>상실납입일자(최초 시작 상실납입일자), rmbrplanvo.loseCalcDueDt
	 */
	public String loseDueDt;		//상실_납입_일자
	public String loseDt;			//상실_일자
	public String preLoseDt;		//기존_상실_일자
	public long rvvlNeedAmt;		//부활_필요_금액
	public int rvvlTims;			//부활_회차
	public long loseMmPamt;			//상실_월_원금
	public long loseMmInt;			//상실_월_이자
	public long losePamtRamt;		//상실_원금_잔액
	public long losePiamtDfee;		//상실_원리금_연체료
	public long loseIntDfee;		//상실_이자_연체료
	public long loseRamtDfee;		//상실_잔액_연체료
	public long loseStndPramt;		//상실기준 원금잔액

	public boolean isLose(){
		return AskUnrcvConst.YES.equals(loseFg);
	}
	public String loseFg;			//상실_여부
	public String exptLoseFg;		//예상_상실_여부
	public int    exptLoseDcnt;		//예상_상실_기준일 (n영업일 후 상실일지 예상하는 계산)
	public String loseExptDt;		//상실_예정_일자
	public int    ddayPrftLoseStrtTims;

	//장기선수금정보
	public int setlObjLtrmBrcvIdx;		//정산장기선수_인덱스
	public long setlObjLtrmBrcvAmt;		//결제대상장기선수금
	public long setlAfLtrmBrcvAmtRamt;	//결제후장기선수금잔액

	//운용리스미수금리스료 회차정보
	public int unrcvStrtIdx;		//미수_시작_인덱스
	public int unrcvCnt;			//미수_건수
	public int unrcvTims;			//미수회차
	public long unrcvAmt;			//미수_금액
	public long unrcvLeasFee;		//미수리스료
	public long unrcvBaseLeasFee;	//미수기본리스료
	public long unrcvAddLeasFee;	//미수가산리스료
	public long unrcvPamt;			//미수_원금
	public long unrcvInt;			//미수_이자
	public long unrcvPsgInt;		//미수_경과이자
	public long unrcvPpayInt;		//미수선급이자
	public long unrcvTint;			//연체_총이자
	public long unrcvAddCartax;		//미수가산자동차세
	public long unrcvAddEnvImprBrdnamt; //미수가산
	public long unrcvAddInsuFee;	//미수가산보험료
	public long unrcvAddAsfee;		//미수가산정비료
	public long unrcvVtax;			//미수부가세
	public long unrcvIpayCartax;	//미수대지급자동차세
	public long unrcvIpayEnvImprBrdnamt;  //미수대지급환개금
	public long unrcvIpayInsuFee;	//미수대지급보험료
	public long unrcvIpayPnltAmt;	//미수대지급범칙금
	public long unrcvIpayEtc;		//미수대지급기타
	public long unrcvCartax;		//미수자동차세
	public long unrcvEnvImprBrdnamt;//미수환개금
	public long unrcvInsuFee;		//미수보험료
	public long unrcvLtrmBrcvAmt;	//미수장기선수금
	public long unrcvGuarAmt;		//미수보증금액
	public long unrcvRamtAmt;		//미수잔가금액

	//중도상환대지급인덱스 회차정보
	public int ipayMaxIdx;			//대지급_최대_인덱스
	public int ipayMaxTims;			//대지급_최대_회차
	//정상상환계획정보
	public int normStrtIdx;			//정상_시작_인덱스
	public int normCnt;				//정상_건수
	public long normAmt;			//정상_금액
	public long normLeasFee;		//정상리스료
	public long normBaseLeasFee;	//정상기본리스료
	public long normAddLeasFee;		//정상가산리스료
	public long normPamt;			//정상_원금
	public long normInt;			//정상_이자
	public long normTrtFee;			//정상_취급수수료
	public long normPsgInt;			//정상_경과이자
	public long normPpayInt;		//정상선급이자
	public long normTint;			//정상_총이자
	public long normAddCartax;		//정상가산자동차세
	public long normAddEnvImprBrdnamt; //정산가산
	public long normAddInsuFee;		//정상가산보험료
	public long normAddAsfee;		//정상가산정비료
	public long normVtax;			//정상부가세
	public long normIpayCartax;		//정상대지급자동차세
	public long normIpayEnvImprBrdnamt; //정상대지급환개금
	public long normIpayInsuFee;	//정상대지급보험료
	public long normIpayPnltAmt;	//정상대지급범칙금
	public long normIpayEtc;		//정상대지급기타
	public long normIpayTax;		//정상대지급조세
	public long normCartax;			//정상자동차세
	public long normEnvImprBrdnamt;	//정상환개금
	public long normInsuFee;		//정상보험료
	public long normLtrmBrcvAmt;	//정산장기선수금
	public long normGuarAmt;		//정상보증금액
	public long normRamtAmt;		//정상잔가금액
	//미도래 정보
	public int unComgStrtIdx;		//미_도래_시작_인덱스
	public int unComgCnt;			//미_도래_건수
	public long unComgAmt;			//미_도래금액
	public long unComgLeasFee;		//미도래리스료
	public long unComgBaseLeasFee;	//미도래기본리스료
	public long unComgAddLeasFee;	//미도래가산리스료
	public long unComgPamt;			//미_도래_원금
	public long unComgInt;			//미_도래_이자
	public long unComgTrtFee;		//미_도래_취급수수료
	public long unComgPpayInt;		//미도래선급이자
	public long unComgTint;			//미도래_총이자
	public long unComgAddCartax;	//미도래가산자동차세
	public long unComgAddEnvImprBrdnamt;  //미도래가산환개금
	public long unComgAddInsuFee;	//미도래가산보험료
	public long unComgAddAsfee;		//미도래가산정비료
	public long unComgVtax;			//미도래부가세
	public long unComgIpayCartax;	//미도래대지급자동차세
	public long unComgIpayEnvImprBrdnamt;  //미도래대지급환개금
	public long unComgIpayInsuFee;	//미도래대지급보험료
	public long unComgIpayPnltAmt;	//미도래대지급범칙금
	public long unComgIpayEtc;		//미도래대지급기타
	public long unComgCartax;		//미도래자동차세
	public long unComgEnvImprBrdnamt;  //미도래환개금
	public long unComgInsuFee;		//미도래보험료
	public long unComgLtrmBrcvAmt;	//미도래장기선수금
	public long unComgGuarAmt;		//미도래보증금액
	public long unComgRamtAmt;		//미도래잔가금액

	//파산면책대상금액
	public long exemRcptObjInt;
	public long exemRcptObjPamt;
	public long exemRcptObjDivsTrtFee;

	//초회
	public int fcntTims;
	public String fcntDueDt;
	//기준회차정보
	public int stndTimsIdx; //기준회차인덱스
	public String stndDueDt; //기준납입일자
	public String stndRlDueDt; //기준실납입일자
	public int stndThmmDueTims; //기준당월납입회차
	public int curTims;          //현재회차 (setlDt 기준)
	public long stndLtrmBrcvAmt; //기준당월장기선수금
	//중도상환시입력값
	public String pnltStndCd; //범칙금기준코드
	public long pnltStndAmt;  //범칙금기준금액
	public String cartaxEnvAdjMethCd; //차세환개금정산방법코드
	public String cartaxIpayEndDt; //차세대지급종료일자
	public String envAmtIpayEndDt; //환개금대지급종료일자
	public String sellFg; //매각여부
	public String cmprCalcFrmlCd; //리스중도상환비교계산방식코드_입력
	public double cmprCalcRt; //리스중도상환비교계산율_입력
	public long pnltAdjuAmt; //패널티조정금액
	public long dfeeAdjuAmt; //연체료조정금
	public String ivltClosFg; //강제해지여부
	public String nmTranGuarAmtCalcFg;  //명의이전보증금계산여부

	//중도상환임시계산값
	public long balBaseLeasFee; //잔여기본리스료
	public long balAddLeasFee; //잔여가산리스료
	public long balLeasFee; //잔여리스료
	public long unWdrwPamt; //미회수원금 - 중도상환회차 부터 원금잔액
	public int cartaxPsgDdcnt; //차세경과일수
	public int envAmtPsgDdcnt; //환개금경과일수
	public long yyCartax; //년자동차세
	public long yyEnvAmt; //년환개금
	public long retnOdueAmt; //반납지연금액
	public long overDrvFee; //초과운행수수료
	public long orgupRcvrCost; //원상복구비용
	public long custCost; //고객비용
	public long deprDeprTamt; //감가상각누계액(참조용)
	public long dspLossApprAmt; //처분손실충당금(참조용)
	public long oprLeasAset; //운용리스자산(참조용)
	public long addClosGuarAmt; //추가해지보증금
	public long pnltAmtTot6; //6개월범칙금합계
	public String dueDtMidRmbrFg; //납입일_중도상환_여부 ( 납입일자에 중도상환을 하는경우 '1', 아니면 '0')
	public double midRmbrFeeRt; //중도_상환_수수료율
	public String midRmbrIntCalcDt; //중도_상환_이자_계산_일자
	/**
	 * 잔존기간 ( 중도_상환_잔여_일수 )
	 * 대출만기일자 - 결제일자
	 */
	public int midRmbrBalDdcnt; //중도_상환_잔여_일수
	public int origMidRmbrBalDdcnt;	//원 중도상환잔여일수(유예전 대출만기일으로 적용한)
	public double intUplmitRt;	//법정_최고_이자율(렌터카공제조합 이자상한제이율 계산용 2018-08-01)
	public long cortMaxAmt;       //법정_최고_금액. 렌터카공제조합 법정최고이자율 상한제 적용 2018-08-01
	public long calcPsgInt;       //계산_경과이자. 렌터카공제조합 법정최고이자율 상한제 적용 2018-08-01
	public long tamtCalcMidRmbrFee; //전액_계산_중도상환수수료. 렌터카공제조합 법정최고이자율 상한제 적용 2018-08-01
	public long partCalcMidRmbrFee; //부분_계산_중도상환수수료. 렌터카공제조합 법정최고이자율 상한제 적용 2018-08-01
	/**
	 * 부대비용율
	 */
	public double incdCostRt;

	//---- 중도상환 START-----------------------------------------
	public int midRmbrIdx; //중도_상환_인덱스
	public int midRmbrTims; //중도_상환_회차
	public String preSetFg; //선결제여부
	public int pdueTimsCnt;	//선결제회차건수
	public String preSetlCpayFg; //선결제완납여부
	public String midRmbrDueDt; //중도_상환_납입일자
	public String partRmbrRcptFg;	// 부분중도상환 결제여부
	/**
	 * 중도상환 회차의 이자시작일자
	 */
	public String midIntStrtDt; //중도_상환_이자계산시작일자
	public String midIntEndDt; //중도_상환_이자계산종료일자
	public String calcMidIntEndDt;	// 만기일 이후 이자계산 종료일자
	public long mainRmbrPamt; //주상환원금 (연체 및 결제당일원금 뺀 미도래 잔여원금으로 보면됨)
	public int mainEndTims; //mainEndTims

	public long totMidRmbrInt; //총_중도상환_이자
	public long totMidRmbrTrtFee; //총_중도상환_취급수수료

	public long tamtRmbrObjAmt; //전액_상환_대상_금액
	public long tamtRmbrObjAmtWithoutPdueAmt;	//전액상환대상금액_선납금액제외

	public long mmTrtFeeDisc; //월_취급_수수료_할인
	public long custTrtFeeDisc; //고객_취급_수수료_할인
	public long trtFee;

	public long tamtRmbrAmt; //전액_상환_금액
	/**
	 * 중도상환이자
	 * 중도상환원금 * 대출이자율(대출원장)  * 경과일수 / 365000
	 */
	public long midRmbrInt; //중도_상환_이자( 전액,부분 같이사용)
	public long trtFeeDisc; //취급_수수료_할인
	public long tamtRmbrCmprFee; //전액_상환_비교_수수료

	public long tamtRmbrPamt; //전액_상환_원금
	public long tamtRmbrExtsPamt; //전액상환유예원금
	public String tamtRmbrExtsFg; //전액상환유예여부

	public long tamtPsgLeasFee;  //전액상환경과리스료
	public long tamtPsgBaseLeasFee;  //전액상환경과기본리스료
	public long tamtPsgAddLeasFee;  //전액상환경과가산리스료
	public long tamtPsgPamt;  //전액상환경과원금
	public long tamtPsgInt;  //전액상환경과이자
	public long tamtPsgAddCartax;  //전액상환경과가산자동차세
	public long tamtPsgAddEnvImprBrdnamt;  //전액상환경과가산환개금
	public long tamtPsgAddInsuFee;  //전액상환경과가산보험료
	public long tamtPsgAddAsfee;  //전액상환경과정비료
	public long tamtPsgVtax;  //전액상환경과부가세
	public long tamtPpayInt;  //전액상환선급이자
	public long tamtIpayCartax;  //전액상환대지급자동차세
	public long tamtIpayEnvImprBrdnamt;  //전액상환대지급환개금
	public long tamtIpayInsuFee;  //전액상환대지급보험료
	public long tamtIpayPnltAmt;  //전액상환대지급범칙금
	public long tamtIpayEtc;  //전액상환대지급기타
	public long tamtIpayAmt;  //전액상환대지급금액
	public long tamtRmbrFee; //전액_상환_수수료

	public long carsSellAmt; //차량매각대금
	public double yycntRo;  //년차비율
	public double calcRt;	//계산율
	public long guarCartax;	//보증금자동차세
	public long guarEnvAmt; //보증금환개금
	public long guarPnltAmt; //보증금범칙금
	public long closGuarAmt; //해지보증금

	//만기이후 해지시 추가정산금액
	public String reSetlDt;			//지연결제일자
	public int oduePsgDdcnt;		//지연경과일수
	public long closOdueIndmAmt;	//해지지연배상금
	public long plusCartax;			//추가자동차세
	public long plusEnvImprBrdnamt;	//추가환개금
	public long plusPnltAmt;		//추가범칙금(NOTE 추가범칙금은 계산안함. 항목만만들어놓음)

	public long tamtTimsAmt; //전액상환회차금액
	public long tamtTimsLeasFee;  //전액상환회차리스료
	public long tamtTimsBaseLeasFee;  //전액상환회차기본리스료
	public long tamtTimsAddLeasFee; //전액상환회차가산리스료
	public long tamtTimsPamt;  //전액상환회차경과원금
	public long tamtTimsInt;  //전액상환회차이자
	public long tamtTimsPpayInt; //전액상환회차선급이자
	public long tamtTimsTint; //전액상환회차_총이자
	public long tamtTimsAddCartax;  //전액상환회차가산자동차세
	public long tamtTimsAddEnvImprBrdnamt;  //전액상환회차가산환개금
	public long tamtTimsAddInsuFee;  //전액상환회차가산보험료
	public long tamtTimsAddAsfee;  //전액상환회차가산정비료
	public long tamtTimsVtax;  //전액상환회차부가세
	public long tamtTimsIpayCartax;  //전액상환회차대지급자동차세
	public long tamtTimsIpayEnvImprBrdnamt;  //전액상환회차대지급환개금
	public long tamtTimsIpayInsuFee;  //전액상환회차대지급보험료
	public long tamtTimsIpayPnltAmt;  //전액상환회차대지급범칙금
	public long tamtTimsIpayEtc;  //전액상환회차대지급기타
	public long tamtTimsCartax;  //전액상환회차자동차세
	public long tamtTimsEnvImprBrdnamt;  //전액상환회차환개금
	public long tamtTimsInsuFee;  //전액상환회차보험료

	public long tamtTimsLtrmBrcvAmt;  //전액상환회차장기선수금
	public long tamtTimsGuarAmt;  //전액상환회차보증금액
	public long tamtTimsRamtAmt;  //전액상환회차잔가금액

	//부분상환 입력값
	public int partRmbrTims;
	public double partRmbrFeeRt;
	public long partRmbrPamt; //부분_상환_원금
	public long eprtLdgrAmt; //만기장부가_입력
	public String mmCalcFg; //월할계산여부_입력
	//부분상환 start
	public long partRmbrAmt; //부분_상환_금액
	public long partMidRmbrInt; //부분_중도_상환_이자
	public long calcPartMidRmbrInt;	//계산 부분중도상환이자
	public long totPartMidRmbrInt;	//총_부분중도상환이자

	//TODO 삭제예정 START
	public long partPpayInt; //부분상환선급이자
	public long partAddCartax;  //부분상환가산자동차세
	public long partAddEnvImprBrdnamt;  //부분상환가산환개금
	public long partAddInsuFee;  //부분상환가산보험료
	public long partAddAsfee;  //부분상환가산정비료
	public long partVtax;  //부분상환부가세
	public long partIpayCartax;  //부분상환대지급자동차세
	public long partIpayEnvImprBrdnamt;  //부분상환대지급환개금
	public long partIpayInsuFee;  //부분상환대지급보험료
	public long partIpayPnltAmt;  //부분상환대지급범칙금
	public long partIpayEtc;  //부분상환대지급기타
	public long partCartax;  //부분상환자동차세
	public long partEnvImprBrdnamt;  //부분상환환개금
	public long partInsuFee;  //부분상환보험료
	public long partLtrmBrcvAmt;  //부분상환장기선수금
	public long partRmbrFee; //부분_상환_수수료
	public long partRmbrAfPamtRamt; //부분_상환_후_원금_잔액
	public long partTimsPamtRamt; //부분상환회차원금잔액
	//TODO 삭제예정 END

	public long addTermInt;		//추가거치이자(중도상환)_사용안함
	public String partRmbrFg;	//부분_상환_여부
	public String midRmbrFg;	//중도_상환_여부

	/**
	 * 중도상환계산여부
	 * 0 : 계산불가
	 * 1 : 계산가능, 화면표현불가
	 * 2 : 계산가능, 화면표현가능
	 */
	public String midRmbrCalcFg;	//중도상환계산여부
	public String midRmbrHidFg;		//중도상환금액숨김여부
	public String midRmbrTimsFg;	//중도상환회차여부
	public String preRcptFg;		//선수납여부

	public long partRmbrObjAmt;					//부분_상환_대상_금액
	public long partRmbrObjAmtWithoutPdueAmt;	//부분_상환_대상_금액(선납금액포함)
	public long partRmbrObjAddAmt;				//금융리스일때 추가로 납부해야하는 금액(가산,대지급,정비료등)

	/**
	 * 대출총일수 ( 대출종료일자 - 대출일자 )
	 */
	public int oneYearDdCnt;
	public int loanTotDdcnt;		//대출_총_일수
	public int origLoanTotDdcnt;	//원대출총일수(유예하기전 대출총일수)
	public int loanPsgDdcnt;		//대출_경과_일수
	public int loanpsgMmCnt;		//대출_경과_월수
	public double trtFeeRt;			//취급_수수료율
	public long custTrtFee;			//고객_취급_수수료
	public int trtFeeDiscExclFg;	//취급수수료할인제외여부
	public long midRmbrObjInt;		//중도상환대상이자

	public long calcPamtRamt;		//계산원금잔액
	public long calcDivsTrtFeeRamt;	//계산분할취급수수료잔액

	public long rlTamtRmbrPamt;		//실전액상환원금
	public long rlTamtRmbrTrtFee;	//실전액상환취급수수료
	public long rlPartRmbrPamt;		//실부분상환원금
	public long rlPartRmbrTrtFee;	//실부분상환취급수수료
	public String midRmbrThddFg;	//중도상환당일여부
	public int rmbrPlanCrteTims;	//상환계획생성회차

	public long tempRcptObjAmt;		//임시_수납_대상_금액
	public long totPamt;			//누적원금
	public long totDivsTrtFee;		//누적취급수수료
	public long totAddAskAmt;		//누적추가청구금, 실중도부분상환원금 구할시 대지급,부가세등을 빼기위해서.

	public String termPartFg;			//거치분할여부
	public String termPartIntStrtDt;	//거치이자시작일자
	public String termPartIntEndDt;		//거치이자종료일자
	public long termPartInt;			//거치분할이자
	public double termPartIntRt;		//거치분할이자율
	public long midTermPartInt;			//중도상환거치분할이자
	public long midTermPartTimsInt;		//중도상환거치분할회차이자
	public int termPartDdcnt;			//거치분할일수
	public long termPartPamtRmbrInt;	//거치분할부분상환이자
	public long calcTermPartPamtRmbrIntRamt;	//거치분할부분상환이자잔액
	public long termPartTamtRmbrInt;			//거치분할전액상환이자

	/**
	 * 경과일수
	 * 결제일자(만기일이후면 만기일자) - 중도상환회차의 이자시작일자
	 */
	public int psgDdcnt; //경과일수
	public int psgMmcnt; //경과일수
	public int orgIntDdcnt; //원이자일수
	public int loanTotMmCnt; //대출총개월수
	public int midRmbrBalMmCnt; //중도상환잔여개월수
	public String balTermCalcFg; //잔여기간계산여부

	public long midPreDueAmt; //중도선납금액
	public long midPreDueLeasFee;  //중도선납리스료
	public long midPreDueBaseLeasFee;  //중도선납기본리스료
	public long midPreDueAddLeasFee; //중도선납가산리스료
	public long midPreDuePamt;  //중도선납경과원금
	public long midPreDueInt;  //중도선납이자
	public long midPreDueTrtFee;  //중도선납취급수수료
	public long midPreDuePpayInt; //중도선납선급이자
	public long midPreDueTint; //중도선납_총이자
	public long midPreDueAddCartax;  //중도선납가산자동차세
	public long midPreDueAddEnvImprBrdnamt;  //중도선납가산환개금
	public long midPreDueAddInsuFee;  //중도선납가산보험료
	public long midPreDueAddAsfee;  //중도선납가산정비료
	public long midPreDueVtax;  //중도선납부가세
	public long midPreDueIpayCartax;  //중도선납대지급자동차세
	public long midPreDueIpayEnvImprBrdnamt;  //중도선납대지급환개금
	public long midPreDueIpayInsuFee;  //중도선납대지급보험료
	public long midPreDueIpayPnltAmt;  //중도선납대지급범칙금
	public long midPreDueIpayEtc;  //중도선납대지급기타
	public long midPreDueCartax;  //중도선납자동차세
	public long midPreDueEnvImprBrdnamt;  //중도선납환개금
	public long midPreDueInsuFee;  //중도선납보험료
	public long midPreDueLtrmBrcvAmt;  //중도선납장기선수금
	public long midPreDueGuarAmt;  //중도선납보증금액
	public long midPreDueRamtAmt;  //중도선납잔가금액


	//---- 중도상환  END-----------------------------------------
	public int thmmTims; //당월_회차
	public String thmmDlyFg; //당월_연체_여부
	public long thmmAmt; //당월_금액
	public long thmmPamt; //당월_원금
	public long thmmInt; //당월_이자
	public long thmmTrtFee; //당월_취급수수료
	public long thmmDfee; //당월_연체료
	public long bfmmAmt; //전월_금액
	public long bfmmPamt; //전월_원금
	public long bfmmInt; //전월_이자
	public long bfmmTrtFee; //전월_취급수수료
	public long bfmmDfee; //전월_연체료

	//---- 예가수 START  -----------------------------------------
	public int dsrcStrtIdx; 	//예가수_시작_인덱스
	public int dsrcCnt;			//예가수_건수
	public String dsrcNo;		//예가수_번호
	public String dsrcOccrCd;	//예가수_발생_코드
	public String dsrcSetlDt;	//예가수_결제_일자
	public int dsrcSnum;		//예가수_일련번호
	public int rfndSnum;		//환불_일련번호  2018-08-01 추가
	public String rfndStatCd;	//환불상태코드
	public String dsrcOccrDt;	//예가수_발생_일자
	public long dsrcOccrAmt;	//예가수_발생_금액
	public long dsrcAdjAmt;		//예가수_정산_금액
	public long dsrcRamt;		//예가수_잔액
	public long srcpRamt;		//가수_잔액
	public String dsrcAdjDeptCd; //예가수_정산_부서_코드
	public String dsrcOccrAcctDt;	//2018-08-01 두비스 추가, 예가수발생회계일자
	public String bfLoanNo;		//이전대출번호(대출번호변경시 사용)
	public String bfLoanSeq;	//이전대출순번(대출번호변경시 사용)
	//---- 예가수 END  -----------------------------------------

	public long crdtRcvrUnrcvAmt; //신용회복미수금
	public long rmbrCrdtRcvrUnrcvAmt; //상환_신용회복미수금
	public long crdtRcvrUnrcvAmtRamt; //신용회복미수금_잔액
	//법적조치 정보
	public long occrLeglActnCost; //발생_법적_조치_비용
	public long adjLeglActnCost; //정산_법적_조치_비용
	public long leglActnCostRamt; //법적_조치_비용_잔액
	public long unOccrLeglActnCost; //발생_법적_조치_비용(미계산)
	public long unAdjLeglActnCost; //정산_법적_조치_비용(미계산)
	public long unLeglActnCostRamt; //법적_조치_비용_잔액(미계산)
	public long depsRamt;	// 공탁금잔액

	//선결제정보
	public long preSetlPamtSum;	//선결제원금합
	public long preSetlIntSum;	//선결제이자합

	// 미수(인지세) 관련 항목
	public String stmpFeeUnrcvNo;
	public long stmpFeeOccrAmt;
	public long stmpFeeAdjAmt;
	public long stmpFeeRamt;

	public String tmatRmbrIntTooltip;
	public String tmatRmbrFeeTooltip;
	public String partRmbrIntTooltip;
	public String partRmbrFeeTooltip;

	public String prdtLrgeClasCd;	//상품대분류코드
	public String prdtMidClasCd;	//상품중분류코드
	public String prdtSmClasCd;		//상품소분류코드

	private List realAskList = null;

	public BndVO() {
		init();
	}

	public void addRealAskTims(TimsUnrcvVO tims){
		realAskList.add(tims);
	}

	public TimsUnrcvVO getRealAskTims(int idx){
		if( sizeRealAskTims() <= idx){
			return null;
		}
		return (TimsUnrcvVO)realAskList.get(idx);
	}

	public int sizeRealAskTims(){
		if( realAskList != null){
			return realAskList.size();
		}
		return 0;
	}

	public TimsUnrcvVO getMidRmbrTims(){
		return midRmbrTimsVO;
	}

	public void setMidRmbrTims(TimsUnrcvVO inVO){
		midRmbrTimsVO = inVO;
	}

	public TimsUnrcvVO getBfMidRmbrTims() {
		return bfMidRmbrTims;
	}

	public void setBfMidRmbrTims(TimsUnrcvVO bfMidRmbrTims) {
		this.bfMidRmbrTims = bfMidRmbrTims;
	}

	public TimsUnrcvVO getDueDtMidRmbrTims() {
		return dueDtMidRmbrTims;
	}

	public void setDueDtMidRmbrTims(TimsUnrcvVO dueDtMidRmbrTims) {
		this.dueDtMidRmbrTims = dueDtMidRmbrTims;
	}

	public void init() {
		loanNo   = StringUtils.EMPTY;		//대출_번호
		loanSeq  = StringUtils.EMPTY;		//대출_순번
		prdtClas = StringUtils.EMPTY;		//상품대중분류코드
		prdtLcd  = StringUtils.EMPTY;		//상품대분류코드
		prdtMcd  = StringUtils.EMPTY;		//상품중분류코드
		prdtScd  = StringUtils.EMPTY;		//상품소분류코드
		prdtCd = StringUtils.EMPTY;			//상품_코드
		loanStatCd = StringUtils.EMPTY;		//대출상태코드 2018-08-01 두비스
		thmmDueTims = 0;					//당월_납입_회차
		bfmmDueTims = 0;					//전월_납입_회차
		totTims = 0;						//총_회차
		prdtLrgeClasCd = StringUtils.EMPTY; //상품_대분류_코드
		prdtMidClasCd  = StringUtils.EMPTY; //상품_중분류_코드
		prdtSmClasCd   = StringUtils.EMPTY; //상품_소분류_코드
		asymmAcctFg    = StringUtils.EMPTY; //비대칭회계여부
		rmbrFrmlCd = StringUtils.EMPTY;		//상환_방식_코드
		thmmDueDt = StringUtils.EMPTY;		//당월_납입_일자
		thmmRlDueDt = StringUtils.EMPTY;	//당월_실_납입_일자
		lastSetlDt = StringUtils.EMPTY;		//최종_결제일자
		lastSetlTims = 0;					//최종_결제_회차
		loanEprtDt = StringUtils.EMPTY;		//대출_만기_일자
		loanRlEprtDt = StringUtils.EMPTY;	//대출_실_만기_일자(영업일)
		leasEprtDt = StringUtils.EMPTY;		//리스_만기_일자
		leasRlEprtDt = StringUtils.EMPTY;	//리스_실_만기일자
		leasEprtDlyDt = StringUtils.EMPTY;	//리스만기연체일자
		loanEprtTims = 0;					//대출_만기_회차
		setlDt = StringUtils.EMPTY;			//결제일자
		procCnt = 0;
		loanDt = StringUtils.EMPTY;			//대출일자
		loanAmt   = 0;						//대출금액
		loanAmt10 = 0;						//대출금액10% (할부전용 : 상실여부 판단 기준)
		execDt = StringUtils.EMPTY;			//승계일자
		loanOccrCd = StringUtils.EMPTY;		//대출발생코드
		sixPreDt = StringUtils.EMPTY;		//6개월전일자
		loanIntRt = 0;						//대출_이자율
		totPamt = 0;
		totDivsTrtFee=0;
		clsFg = "0";
		unrcvProcDt = StringUtils.EMPTY;	//미수처리일자(납입일자)
		calcPamtRamt = 0;

		timsUnrcvStrtIdx= -1;				//회차_미수_시작_인덱스
		timsUnrcvCnt=0;						//회차_미수_건수

		pamtRamt = 0;				//원금_잔액
		intRamt = 0;				//이자_잔액
		leasFeeRamt = 0;			//리스료잔액
		baseLeasFeeRamt = 0;		//기본리스료잔액
		addLeasFeeRamt = 0;			//가산리스료잔액
		ppayIntRamt = 0;			//선급이자잔액
		addCartaxRamt = 0;			//가산자동차세잔액
		addEnvImprBrdnamtRamt = 0;	//가산환개금잔액
		addInsuFeeRamt = 0;			//가산보험료잔액
		addAsfeeRamt = 0;  //가산정비료잔액
		vtaxRamt = 0;  //부가세잔액
		ipayCartaxRamt = 0;  //대지급자동차세잔액
		ipayEnvImprBrdnamtRamt = 0;  //대지급환개금잔액
		ipayInsuFeeRamt = 0;  //대지급보험료잔액
		ipayPnltAmtRamt = 0; //대지급범칙금잔액
		ipayEtcRamt = 0;  //대지급기타잔액
		cartaxRamt = 0;  //자동차세잔액
		envImprBrdnamtRamt = 0;  //환개금잔액
		insuFeeRamt = 0;  //보험료
		ltrmBrcvAmtRamt = 0;  //장기선수금잔액
		guarAmt = 0;  //보증금액
		ramtAmt = 0;  //잔가금액
		endAfAskStatCd = "0";  //종료후청구상태코 (종료후청구상태,대지급청구발생)
		eprtAskMethCd = "0";  //만기청구방법코드(원리금,잔가포함)
		guarAmtAdjFg = "0";  //보증금대체여부(마지막회차 대체여부)

		stndAskAmt = 0;	//기준청구금액
		askAmt = 0; //청구_금액
		askLeasFee = 0; //청구리스료잔액
		askBaseLeasFee = 0; //청구기본리스료
		askAddLeasFee = 0; //청구가산리스료
		askPamt = 0; //청구_원금
		askInt = 0; //청구_이자
		askPpayInt = 0;  //청구선급이자
		askTint = 0;  //청구총이자
		askAddCartax = 0;  //청구가산자동차세
		askAddEnvImprBrdnamt = 0;  //청구가산환개금
		askAddInsuFee = 0;  //청구가산보험료
		askAddAsfee = 0;  //청구가산정비료
		askVtax = 0;  //청구부가세
		askIpayCartax = 0;  //청구대지급자동차세
		askIpayEnvImprBrdnamt = 0;  //청구대지급환개금
		askIpayInsuFee = 0;  //청구대지급보험료
		askIpayPnltAmt = 0;  //청구대지급범칙금
		askIpayEtc = 0;  //청구대지급기타
		askIpayTax = 0;  //청구대지급조세
		askCartax  = 0;  //청구자동차세
		askEnvImprBrdnamt = 0;  //청구환개금
		askInsuFee = 0;		//청구보험료
		askLtrmBrcvAmt = 0;	//청구장기선수금
		askDfee    = 0;		//청구_연체료
		askGuarAmt = 0;		//청구보증금액
		askRamtAmt = 0;		//청구잔가금액

		dlyStrtIdx = -1;	//연체_시작_인덱스
		dlyCnt     = 0;		//연체_건수 (회차)
		addDfeeRt  = 0;		//가산_연체료_율
		dfeeRt     = 0;		//연체료_율
		dfeeRtNm   = "";	//연체료_율_명

		dlyAmt    = 0;		//연체_금액
		dlyPamt   = 0;		//연체_원금
		dlyInt    = 0;		//연체이자
		dfee      = 0;		//연체료
		dfeeKifrs = 0;		//연체료(KIFRS)
		dlyLeasFee = 0;		//연체리스료잔액
		dlyBaseLeasFee = 0;	//연체기본리스료
		dlyAddLeasFee = 0;	//연체가산리스료
		dlyPpayInt = 0;		//연체선급이자
		dlyTint = 0;		//연체총이자
		dlyAddCartax = 0;	//연체가산자동차세
		dlyAddEnvImprBrdnamt = 0;  //연체가산환개금
		dlyAddInsuFee = 0;  //연체가산보험료
		dlyAddAsfee = 0;	//연체가산정비료
		dlyVtax = 0;		//연체부가세
		dlyIpayCartax = 0;	//연체대지급자동차세
		dlyIpayEnvImprBrdnamt = 0;  //연체대지급환개금
		dlyIpayInsuFee = 0;  //연체대지급보험료
		dlyIpayPnltAmt = 0;  //연체대지급범칙금
		dlyIpayEtc = 0;  //연체대지급기타
		dlyIpayTax = 0;  //연체대지급조세
		dlyCartax = 0;  //연체자동차세
		dlyEnvImprBrdnamt = 0;  //연체환개금
		dlyInsuFee = 0;  //연체보험료
		dlyLtrmBrcvAmt = 0;  //연체장기선수금
		dlyGuarAmt = 0;  //연체보증금액
		dlyRamtAmt = 0;  //연체잔가금액
		preOccrDfee = 0; //기_발생_연체료
		dlyFg = "0"; //연체_여부
		dlyDt = StringUtils.EMPTY; //연체_일자
		dlyCalcDt = StringUtils.EMPTY; //연체_계산_일자
		dlyStrtTims = 0; //연체_시작_회차
		dlyStrtDueDt = StringUtils.EMPTY; //연체_시작_납입_일자
		dlyEndTims = 0; //연체_종료_회차
		dlyEndDueDt = StringUtils.EMPTY; //연체_종료_납입_일자
		dlyDdcnt = 0; //연체_일수
		occrDlyDdcnt = 0; //발생_연체_일수
		dlyMmCnt = 0; //연체_개월수
		dlyTcnt = 0; //연체_횟수
		lngsDlyDdcnt = 0; //최장_연체_일수
		totDlyDdcnt = 0; //누적_연체_일수
		occrPdueDiscDfee = 0; //발생_선납_할인_연체료
		adjPdueDiscDfee = 0; //정산_선납_할인_연체료
		pdueDiscDfeeRamt = 0; //선납_할인_연체료
		pdueDiscDfee = 0; //선납_할인_연체료
		tempPdueDiscInt = 0; //임시_선납_할인_이자
		loseDlyStrtDt = StringUtils.EMPTY; //상실_연체_시작일자
		loseDueDt = StringUtils.EMPTY;	//상실_납입_일자
		loseDt    = StringUtils.EMPTY;	//상실_일자
		preLoseDt = StringUtils.EMPTY;	//기존_상실_일자
		rvvlNeedAmt = 0;	//부활_필요_금액
		rvvlTims=0;
		loseMmPamt = 0;		//상실_월_원금
		loseMmInt  = 0;		//상실_월_이자
		losePamtRamt  = 0;	//상실_원금_잔액
		losePiamtDfee = 0;	//상실_원리금_연체료
		loseIntDfee  = 0;	//상실_이자_연체료
		loseRamtDfee = 0;	//상실_잔액_연체료
		loseStndPramt = 0;	//상실기준원금잔액
		loseFg = "0";		//상실_여부
		exptLoseFg   = "0";					//예상_상실_여부
		exptLoseDcnt = 10;					//상실_예정_일수
		loseExptDt   = StringUtils.EMPTY;	//상실_예정_일자
		ddayPrftLoseStrtTims = 0;	// 기한_이익_상실_시작_회차

		setlObjLtrmBrcvIdx = -1;		//정산장기선수_인덱스
		setlObjLtrmBrcvAmt = 0;			//결제대상장기선수금
		setlAfLtrmBrcvAmtRamt = 0;		//결제후장기선수금잔액

		unrcvStrtIdx = -1;				//미수_시작_인덱스
		unrcvCnt = 0;					//미수_건수
		unrcvTims = 0;					//미수회차
		unrcvAmt = 0;					//미수_금액
		unrcvLeasFee = 0;				//미수리스료
		unrcvBaseLeasFee = 0;			//미수기본리스료
		unrcvAddLeasFee = 0;			//미수가산리스료
		unrcvPamt = 0;					//미수_원금
		unrcvInt = 0;					//미수_이자
		unrcvPsgInt = 0;				//미수_경과이자
		unrcvPpayInt = 0;				//미수선급이자
		unrcvTint = 0;					//미수총이자
		unrcvAddCartax = 0;				//미수가산자동차세
		unrcvAddEnvImprBrdnamt = 0;		//미수가산
		unrcvAddInsuFee = 0;			//미수가산보험료
		unrcvAddAsfee = 0;				//미수가산정비료
		unrcvVtax = 0;					//미수부가세
		unrcvIpayCartax = 0;			//미수대지급자동차세
		unrcvIpayEnvImprBrdnamt = 0;	//미수대지급환개금
		unrcvIpayInsuFee = 0;			//미수대지급보험료
		unrcvIpayPnltAmt = 0;			//미수대지급범칙금
		unrcvIpayEtc = 0;				//미수대지급기타
		unrcvCartax = 0;				//미수자동차세
		unrcvEnvImprBrdnamt = 0;		//미수환개금
		unrcvInsuFee = 0;				//미수보험료
		unrcvLtrmBrcvAmt = 0;			//미수장기선수금
		unrcvGuarAmt = 0;				//미수보증금액
		unrcvRamtAmt = 0;				//미수잔가금액

		ipayMaxIdx = -1; //대지급max idx
		ipayMaxTims = 0; //대지급 최대 회차

		normStrtIdx = -1;			//정상_시작_인덱스
		normCnt = 0;				//정상_건수
		normAmt = 0;				//정상_금액
		normLeasFee = 0;			//정상리스료잔액
		normBaseLeasFee = 0;		//정상기본리스료
		normAddLeasFee = 0;			//정상가산리스료
		normPamt = 0;				//정상_원금
		normInt = 0;				//정상_이자
		normPsgInt = 0;				//정상_경과이자
		normPpayInt = 0;			//정상선급이자
		normTint = 0;				//정상총이자
		normAddCartax = 0;			//정상가산자동차세
		normAddEnvImprBrdnamt = 0;	//정상가산자동차세
		normAddInsuFee = 0;			//정상가산보험료
		normAddAsfee = 0;			//정상가산정비료
		normVtax = 0;				//정상부가세
		normIpayCartax = 0;			//정상대지급자동차세
		normIpayEnvImprBrdnamt = 0;	//정상대지급환개금
		normIpayInsuFee = 0;		//정상대지급보험료
		normIpayPnltAmt = 0;		//정상대지급범칙금
		normIpayEtc = 0;			//정상대지급기타
		normIpayTax = 0;			//정상대지급조세
		normCartax = 0;				//정상자동차세
		normEnvImprBrdnamt = 0;		//정상환개금
		normInsuFee = 0;			//정상보험료
		normLtrmBrcvAmt = 0;		//정상장기선수금
		normGuarAmt = 0;			//정상보증금액
		normRamtAmt = 0;			//정상잔가금액

		unComgStrtIdx = -1;				//미_도래_시작_인덱스
		unComgCnt = 0;					//미_도래_건수
		unComgAmt = 0;					//미_도래금액
		unComgLeasFee = 0;				//미도래리스료잔액
		unComgBaseLeasFee = 0;			//미도래기본리스료
		unComgAddLeasFee = 0;			//미도래가산리스료
		unComgPamt = 0;					//미_도래_원금
		unComgInt = 0;					//미_도래_이자
		unComgPpayInt = 0;				//미도래선급이자
		unComgTint = 0;					//미도래총이자
		unComgAddCartax = 0;			//미도래가산자동차세
		unComgAddEnvImprBrdnamt = 0;	//미도래가산환개금
		unComgAddInsuFee = 0;			//미도래가산보험료
		unComgAddAsfee = 0;				//미도래가산정비료
		unComgVtax = 0;					//미도래부가세
		unComgIpayCartax = 0;			//미도래대지급자동차세
		unComgIpayEnvImprBrdnamt = 0;	//미도래대지급환개금
		unComgIpayInsuFee = 0;			//미도래대지급보험료
		unComgIpayPnltAmt = 0;			//미도래대지급범칙금
		unComgIpayEtc = 0;				//미도래대지급기타
		unComgCartax  = 0;				//미도래자동차세
		unComgEnvImprBrdnamt = 0;  		//미도래환개금
		unComgInsuFee = 0;				//미도래보험료
		unComgLtrmBrcvAmt = 0;			//미도래장기선수금
		unComgGuarAmt = 0;				//미도래보증금액
		unComgRamtAmt = 0;				//미도래잔가금액

		//면책금액
		exemRcptObjInt =0;
		exemRcptObjPamt=0;
		exemRcptObjDivsTrtFee=0;

		stndTimsIdx = -1;
		stndDueDt   = StringUtils.EMPTY;	//기준납입일자
		stndRlDueDt = StringUtils.EMPTY;	//기준실납입일자
		stndThmmDueTims = 0;	//기준당월납입회차
		stndLtrmBrcvAmt = 0;	//기준당월장기선수금

		pnltStndCd = "1";	//범칙금기준코드
		pnltStndAmt = 0;	//범칙금기준금액
		cartaxEnvAdjMethCd = StringUtils.EMPTY; //차세환개금정산방법코드
		cartaxIpayEndDt = StringUtils.EMPTY;	//차세대지급종료일자
		envAmtIpayEndDt = StringUtils.EMPTY;	//환개금대지급종료일자
		sellFg = "0";				//매각여부
		cmprCalcFrmlCd = StringUtils.EMPTY;		//중도상환비교계산방법코드
		cmprCalcRt  = 0;		//중도상환비교계산율
		pnltAdjuAmt = 0;		//패널티조정금액
		dfeeAdjuAmt = 0;		//연체료조정금액
		ivltClosFg  = "0";		//강제해지여부

		balBaseLeasFee = 0;		//잔여기본리스료
		balAddLeasFee = 0;		//잔여가산리스료
		balLeasFee = 0;			//잔여리스료
		unWdrwPamt = 0;			//미회수원금 - 중도상환회차 부터 원금잔액
		cartaxPsgDdcnt = 0;
		envAmtPsgDdcnt = 0;
		yyCartax = 0;			//년자동차세
		yyEnvAmt = 0;			//년환개금
		retnOdueAmt = 0;		//반납지연금액
		overDrvFee = 0;			//초과운행수수료
		orgupRcvrCost = 0;		//원상복구비용
		custCost = 0;			//고객비용
		deprDeprTamt = 0;		//감가상각누계액(참조용)
		dspLossApprAmt = 0;		//처분손실충당금(참조용)
		oprLeasAset = 0;		//운용리스자산(참조용)
		addClosGuarAmt = 0;		//추가해지보증금
		pnltAmtTot6 = 0;		//6개월범칙금합계
		dueDtMidRmbrFg = "0";	//납입일_중도상환_여부
		midRmbrFeeRt = 0;		//중도_상환_수수료율
		midRmbrIntCalcDt = StringUtils.EMPTY; //중도_상환_이자_계산_일자
		midRmbrBalDdcnt = 0; //중도_상환_잔여_일수
		origMidRmbrBalDdcnt = 0;	//원 중도상환잔여일수

		intUplmitRt = 0;
		cortMaxAmt = 0;
		calcPsgInt = 0;
		tamtCalcMidRmbrFee=0;
		partCalcMidRmbrFee=0;
		incdCostRt=0;

		midRmbrIdx = -1; //중도_상환_인덱스
		midRmbrTims = 0; //중도_상환_회차
		preSetFg = "0"; //중도상환회차선결제여부
		pdueTimsCnt=0;
		preSetlCpayFg = StringUtils.EMPTY;	//선결제완납여부
		midRmbrDueDt = StringUtils.EMPTY;	//중도_상환_납입일자
		partRmbrRcptFg = AskUnrcvConst.NO;
		midIntStrtDt = StringUtils.EMPTY;	//중도_상환_이자계산시작일자
		midIntEndDt = StringUtils.EMPTY;	//중도_상환_이자계산종료일자
		calcMidIntEndDt = StringUtils.EMPTY;	//중도_상환_이자계산종료일자(만기일처리)
		mainRmbrPamt = 0;		//주상환원금
		mainEndTims = 0;		//주상환종료회차
		tamtRmbrObjAmt = 0;		//전액_상환_대상_금액
		tamtRmbrObjAmtWithoutPdueAmt = 0;	//전액상환대상금액(선납금액제외)
		totMidRmbrInt = 0;
		tamtRmbrAmt = 0;		//전액_상환_금액
		tamtRmbrPamt = 0;		//전액_상환_원금
		tamtRmbrExtsPamt = 0;	//전액상환유예원금
		tamtRmbrExtsFg = "0";	//전액상환유예여부
		midRmbrInt = 0;			//중도_상환_이자
		trtFeeDisc = 0;			//취급_수수료_할인
		mmTrtFeeDisc=0;			//월_취급수수료_할인
		tamtPsgLeasFee = 0;		//전액상환경과원금
		tamtPsgBaseLeasFee = 0;	//전액상환경과원금
		tamtPsgAddLeasFee = 0;	//전액상환경과원금
		tamtPsgPamt = 0;		//전액상환경과원금
		tamtPsgInt = 0;			//전액상환경과원금
		tamtPsgAddCartax = 0;	//전액상환경과가산자동차세
		tamtPsgAddEnvImprBrdnamt = 0;  //전액상환가산경과상환환개금
		tamtPsgAddInsuFee = 0;		//전액상환경과가산보험료
		tamtPsgAddAsfee = 0; 		//전액상환경과가산정비료
		tamtPsgVtax = 0;			//전액상환경과부가세
		tamtIpayCartax = 0;			//전액상환대지급자동차세
		tamtIpayEnvImprBrdnamt = 0;	//전액상환대지급환개금
		tamtIpayInsuFee = 0;		//전액상환대지급보험료
		tamtIpayPnltAmt = 0;		//전액상환대지급범칙금
		tamtIpayEtc = 0;			//전액상환대지급기타
		tamtIpayAmt = 0;			//전액상환대지급금액
		tamtRmbrFee = 0;			//전액_상환_수수료
		tamtRmbrCmprFee = 0;		//전액_상환_비교_수수료

		carsSellAmt=0; //차량매각대금
		yycntRo = 0;
		calcRt = 0;
		guarCartax = 0;
		guarEnvAmt = 0;
		guarPnltAmt = 0;
		closGuarAmt = 0;
		//만기이후 해지시 추가정산금액
		reSetlDt = StringUtils.EMPTY;	//지연결제일자
		oduePsgDdcnt=0;		//지연경과일수
		closOdueIndmAmt=0;	//해지지연배상금
		plusCartax=0;			//추가자동차세
		plusEnvImprBrdnamt=0;	//추가환개금
		plusPnltAmt=0;		//추가범칙금

		tamtTimsAmt = 0; //전액상환회차금액
		tamtTimsLeasFee = 0;  //전액상환회차리스료
		tamtTimsBaseLeasFee = 0;  //전액상환회차기본리스료
		tamtTimsAddLeasFee = 0; //전액상환회차가산리스료
		tamtTimsPamt = 0; //전액_상환_원금
		tamtTimsInt = 0; //중도_상환_이자
		tamtTimsPpayInt = 0;  //전액상환선급이자
		tamtTimsTint = 0;  //전액상환총이자
		tamtTimsAddCartax = 0;  //전액상환회차자동차세
		tamtTimsAddEnvImprBrdnamt = 0; //전액상환회차환개금
		tamtTimsAddInsuFee = 0;  //전액상환가산보험료
		tamtTimsAddAsfee = 0;  //전액상환회차가산정비료
		tamtTimsVtax = 0; //전액상환회차부가세
		tamtTimsIpayCartax = 0; //전액상환대지급자동차세
		tamtTimsIpayEnvImprBrdnamt = 0;  //전액상환대지급환개금
		tamtTimsIpayInsuFee = 0;  //전액상환대지급보험료
		tamtTimsIpayPnltAmt = 0;  //전액상환대지급범칙금
		tamtTimsIpayEtc = 0;  //전액상환대지급기타
		tamtTimsCartax = 0;  //전액상환자동차세
		tamtTimsEnvImprBrdnamt = 0;  //전액상환환개금
		tamtTimsInsuFee = 0;  //전액상환보험료
		tamtTimsLtrmBrcvAmt = 0;  //전액상환장기선수금
		tamtTimsGuarAmt = 0;  //전액상환회차보증금액
		tamtTimsRamtAmt = 0;  //전액상환회차잔가금액

		partRmbrTims=0;
		partRmbrFeeRt = 0;
		partRmbrPamt=0; 	//부분_상환_원금
		eprtLdgrAmt = 0;	//만기장부가
		mmCalcFg = "0"; 	//월할계산여부

		partRmbrAmt = 0; //부분_상환_금액
		partMidRmbrInt = 0; //부분_중도_상환_이자
		totPartMidRmbrInt = 0;	// 총부분중도상환이자
		calcPartMidRmbrInt = 0;	// 계산부분중도상환이자
		partPpayInt = 0; //부분상환선급이자
		partAddCartax = 0;  //부분상환가산자동차세
		partAddEnvImprBrdnamt = 0;  //부분상환가산환개금
		partAddInsuFee = 0;  //부분상환가산보험료
		partAddAsfee = 0;  //부분상환가산정비료
		partVtax = 0;  //부분상환부가세
		partIpayCartax = 0;  //부분상환대지급자동차세
		partIpayEnvImprBrdnamt = 0;  //부분상환대지급환개금
		partIpayInsuFee = 0;  //부분상환대지급보험료
		partIpayPnltAmt = 0;  //부분상환대지급범칙금
		partIpayEtc = 0;  //부분상환대지급기타
		partCartax = 0;  //부분상환자동차세
		partEnvImprBrdnamt = 0;  //부분상환환개금
		partInsuFee = 0;  //부분상환보험료
		partLtrmBrcvAmt = 0;  //부분상환장기선수금
		partRmbrFee = 0; //부분_상환_수수료
		partRmbrAfPamtRamt = 0; //부분_상환_후_원금_잔액
		partTimsPamtRamt = 0; //부분상환회차원금잔액
		addTermInt = 0; //추가거치이자(중도상환)
		partRmbrFg = "0"; //부분_상환_여부
		midRmbrFg = "0"; //중도_상환_여부
		midRmbrCalcFg = "0";	//중도상환계산여부
		midRmbrHidFg = "0";	//중도상환금액숨김여부
		midRmbrTimsFg = "0"; //중도상환회차여부
		preRcptFg = "0";	//선납여부

		partRmbrObjAmt = 0; //부분_상환_대상_금액
		partRmbrObjAmtWithoutPdueAmt = 0;
		oneYearDdCnt=365;	// 일년 일수
		loanTotDdcnt = 0; //대출총일수
		origLoanTotDdcnt = 0;	//원대출총일수(유예하기전 대출총일수)
		loanPsgDdcnt = 0; //대출경과일수
		loanpsgMmCnt = 0; //대출경과월수
		trtFeeRt = 0; //취급_수수료율
		custTrtFee = 0;
		trtFeeDiscExclFg = 0; //취급수수료할인제외여부 정수형
		midRmbrObjInt = 0; //중도상환대상이자

		rlTamtRmbrPamt = 0; //실전액상환원금
		rlTamtRmbrTrtFee=0;	//실전액상환취급수수료
		rlPartRmbrPamt = 0; //실부분상환원금
		rlPartRmbrTrtFee=0;
		midRmbrThddFg = "0";
		rmbrPlanCrteTims = 0; //상환계획생성회차

		tempRcptObjAmt = 0; //임시_수납_대상_금액
		loseCalcFg  = "0";	//상실계산여부
		loseCalcCd  = "";	//상실계산구분(회차,일수)
		loseCalcVal = 0;	//상실계산구분값(회차,일수)
		termPartFg = "0";
		termPartIntStrtDt = StringUtils.EMPTY;
		termPartIntEndDt = StringUtils.EMPTY;
		termPartInt = 0;
		termPartIntRt = 0;
		midTermPartInt = 0;
		midTermPartTimsInt = 0;
		termPartDdcnt = 0;
		termPartPamtRmbrInt = 0;
		termPartTamtRmbrInt = 0;

		psgDdcnt = 0;	//경과일수
		psgMmcnt = 0;	//경과월수
		orgIntDdcnt = 0; //원이자일수
		loanTotMmCnt = 0; //대출총개월수
		midRmbrBalMmCnt = 0; //중도상환잔여개월수
		balTermCalcFg = "0"; //잔여기간계산여부

		midPreDueAmt = 0; //중도선납금액
		midPreDueLeasFee = 0;  //중도선납리스료
		midPreDueBaseLeasFee = 0;  //중도선납기본리스료
		midPreDueAddLeasFee = 0; //중도선납가산리스료
		midPreDuePamt = 0;  //중도선납경과원금
		midPreDueInt = 0;  //중도선납이자
		midPreDueTrtFee = 0;	//중도선납_거치이자
		midPreDuePpayInt = 0; //중도선납선급이자
		midPreDueTint = 0;  //중도선납총이자
		midPreDueAddCartax = 0;  //중도선납가산자동차세
		midPreDueAddEnvImprBrdnamt = 0;  //중도선납가산환개금
		midPreDueAddInsuFee = 0;  //중도선납가산보험료
		midPreDueAddAsfee = 0;  //중도선납가산정비료
		midPreDueVtax = 0;  //중도선납부가세
		midPreDueIpayCartax = 0;  //중도선납대지급자동차세
		midPreDueIpayEnvImprBrdnamt = 0;  //중도선납대지급환개금
		midPreDueIpayInsuFee = 0;  //중도선납대지급보험료
		midPreDueIpayPnltAmt = 0;  //중도선납대지급범칙금
		midPreDueIpayEtc = 0;  //중도선납대지급기타
		midPreDueCartax = 0;  //중도선납자동차세
		midPreDueEnvImprBrdnamt = 0;  //중도선납환개금
		midPreDueInsuFee = 0;  //중도선납보험료
		midPreDueLtrmBrcvAmt = 0;  //중도선납장기선수금
		midPreDueGuarAmt = 0;  //중도선납보증금액
		midPreDueRamtAmt = 0;  //중도선납잔가금액

		thmmTims = 0; //당월_회차
		thmmDlyFg = "0"; //당월_연체_여부
		thmmAmt = 0; //당월_금액
		thmmPamt = 0; //당월_원금
		thmmInt = 0; //당월_이자
		thmmDfee = 0; //당월_연체료
		bfmmAmt = 0; //전월_금액
		bfmmPamt = 0; //전월_원금
		bfmmInt = 0; //전월_이자
		bfmmDfee = 0; //전월_연체료

		dsrcStrtIdx = -1; //예가수_시작_인덱스
		dsrcCnt = 0; //예가수_건수
		dsrcNo = StringUtils.EMPTY; //예가수_번호
		dsrcOccrCd = StringUtils.EMPTY; //예가수발생코드
		dsrcSetlDt = StringUtils.EMPTY; //예가수결제일자
		dsrcSnum = 0; //예가수_일련번호
		rfndSnum = 0; //환불_일련번호
		rfndStatCd = StringUtils.EMPTY;//환불상태코드
		dsrcOccrDt = StringUtils.EMPTY; //예가수_발생_일자
		dsrcOccrAmt = 0;	//예가수_발생_금액
		dsrcAdjAmt = 0;		//예가수_정산_금액
		dsrcRamt = 0;		//예가수_잔액
		srcpRamt = 0;		//가수잔액
		dsrcAdjDeptCd = StringUtils.EMPTY;//예가수_정산_부서_코드
		dsrcOccrAcctDt = StringUtils.EMPTY;	//예가수발생회계일자

		crdtRcvrUnrcvAmt=0; //신용_회복_미수금
		rmbrCrdtRcvrUnrcvAmt=0; //상환_신용_회복_미수금
		crdtRcvrUnrcvAmtRamt=0; //신용_회복_미수금_잔액

		occrLeglActnCost=0; //발생_법적_조치_비용
		adjLeglActnCost=0; //정산_법적_조치_비용
		leglActnCostRamt=0; //법적_조치_비용_잔액
		unOccrLeglActnCost=0; //발생_법적_조치_비용(미계산)
		unAdjLeglActnCost=0; //정산_법적_조치_비용(미계산)
		unLeglActnCostRamt=0; //법적_조치_비용_잔액(미계산)
		//초회추가
		fcntTims=0;
		fcntDueDt="";
		//선결제합 추가
		preSetlPamtSum=0;
		preSetlIntSum=0;

		totAddAskAmt=0;
		partRmbrObjAddAmt=0;

		if( realAskList != null){
			realAskList.clear();
		}
		realAskList = new ArrayList();

		trtFeeRamt = 0;	//취급수수료잔액
		askTrtFee = 0;	//청구_취급수수료
		dlyTrtFee = 0;	//연체_취급수수료
		normTrtFee = 0; //정상_취급수수료
		unComgTrtFee = 0; //미_도래_취급수수료
		thmmTrtFee = 0; //당월_취급수수료
		bfmmTrtFee = 0; //전월_취급수수료

		// 미수(인지세) 관련 항목
		stmpFeeUnrcvNo = "";
		stmpFeeOccrAmt = 0;
		stmpFeeAdjAmt = 0;
		stmpFeeRamt = 0;

		tmatRmbrIntTooltip="";
		tmatRmbrFeeTooltip="";
		partRmbrIntTooltip="";
		partRmbrFeeTooltip="";

		bfMidRmbrTims = null;
		midRmbrTimsVO = null;
		dueDtMidRmbrTims = null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	@Override
	public int compareTo(Object o) {
		BndVO inVO = (BndVO)o;
		if(inVO==null) {
			throw new IllegalArgumentException("입력된 채권객체를 확인하세요");
		}

		int compare = loanNo.compareTo(inVO.loanNo);
		if(compare >0){
			return 1;
		} else if( compare < 0) {
			return -1;
		}

		compare = loanSeq.compareTo(inVO.loanSeq);
		return compare > 0 ? 1 : (compare < 0 ? -1 : 0);
	}
}
