package hanalife.r.co.as.vo;

import org.apache.commons.lang.StringUtils;


/**
 * <pre>
 * 클래스명    : RmbrPlanVO
 * 클래스설명 : 상환계획정보 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class RmbrPlanVO extends ValueObj {
	public String loanNo;			//대출번호
	public String loanSeq;			//대출순번
	/**
	 * LT_LEAS_RMBR_SCHD.END_DIV_CD
	 */
	public String endDivCd;			//종료구분코드
	public int tims;				//회차
	/**
	 * <p>현재회차(조회결제일기준/영업일 미보정)</p>
	 * DUE_DT >= SETL_DT THEN TIMS
	 */
	public int curTims;
	/**
	 * <p>당월납입회차</p>
	 * RL_DUE_DT >= SETL_DT THEN TIMS
	 */
	public int thmmDueTims;
	/**
	 * <p>전월납입회차</p>
	 * MAX(RL_DUE_DT < SETL_DT THEN TIMS)
	 */
	public int bfmmDueTims;
	/**
	 * <p>상환스케쥴의 최대회차</p>
	 * MAX(TIMS)
	 */
	public int totTims;				//총회차
	public String prdtCd;			//상품코드
	/**
	 * 상환방식코드
	 * MAX(ST_RMBR_PLAN_DESC.RMBR_FRML_CD) BY TIMS
	 */
	public String rmbrFrmlCd;
	/**
	 * 납입일자
	 * MAX(ST_RMBR_PLAN_DESC.DUE_DT) BY TIMS
	 */
	public String dueDt;
	/**
	 * 실납입일자
	 * MAX(DBSRQST.RF_RL_DUE_DT(ST_RMBR_PLAN_DESC.DUE_DT)) BY TIMS
	 */
	public String rlDueDt;
	/**
	 * 최종결제일자
	 * MAX(RT_RCPT_DESC.SETL_DT)
	 */
	public String lastSetlDt;
	/**
	 * 최종결제회차
	 * MAX(RT_RCPT_DESC.TIMS)
	 */
	public int lastSetlTims;
	/**
	 * 대출만기일자
	 * MAX(DUE_DT)
	 */
	public String loanEprtDt;
	/**
	 * 대출만기일자
	 * MAX(DBSRQST.RF_RL_DUE_DT(DUE_DT))
	 */
	public String loanRlEprtDt;
	/**
	 * 대출만기회차
	 * MAX(RT_RCPT_DESC.TIMS)
	 */
	public int loanEprtTims;		//대출만기회차
	public String setlDt;			//결제일자
	public String askDivCd;			//청구구분코드
	/**
	 * 회차전원금잔액
	 * ST_RMBR_PLAN_DESC.TIMS_BF_PAMT_RAMT
	 */
	public long timsBfPamtRamt;
	/**
	 * 회차전이자잔액
	 * ST_RMBR_PLAN_DESC.TIMS_BF_INT_RAMT
	 */
	public long timsBfIntRamt;
	/**
	 * 회차후원금잔액
	 * ST_RMBR_PLAN_DESC.TIMS_AF_PAMT_RAMT
	 */
	public long timsAfPamtRamt;
	/**
	 * 회차후이자잔액
	 * ST_RMBR_PLAN_DESC.TIMS_AF_INT_RAMT
	 */
	public long timsAfIntRamt;
	/**
	 * <p>
	 * 원금
	 * 채권일때 : PAMT - SETL_PAMT
	 * 스케쥴일때 : PAMT
	 * </p>
	 */
	public long pamt;
	/**
	 * <p>
	 * 이자
	 * 채권일때 : INT - SETL_INT
	 * 스케쥴일때 : INT
	 * </p>
	 */
	public long intt;
	/**
	 * <p>
	 * 취급수수료
	 * 채권일때 : TRT_FEE - SETL_TRT_FEE
	 * 스케쥴일때 : TRT_FEE
	 * </p>
	 */
	public long trtFee;
	public long ppayInt; //선급이자
	public long addInsuFee;  //가산보험료
	public long addCartax;  //가산자동차세
	public long addEnvImprBrdnamt;  //가산환개금
	public long addAsfee;  //가산정비료
	public long vtax; //부가세
	public long ipayCartax;  //대지급자동차세
	public long ipayEnvImprBrdnamt;  //대지급환개금
	public long ipayInsuFee;  //대지급보험료
	public long ipayPnltAmt;  //대지급범칙금
	public long ipayEtc;  //대지급기타
	public long ltrmBrcvAmt;  //장기선수금

	public long setlPamt; //결제원금
	public long setlInt; //결제이자
	public long setlTrtFee;	//결제취급수수료
	public long setlPpayInt;
	public long setlAddInsuFee;
	public long setlAddCartax;
	public long setlAddEnvImprBrdnamt;
	public long setlAddAsfee;
	public long setlVtax;
	public long setlIpayCartax;
	public long setlIpayEnvImprBrdnamt;
	public long setlIpayInsuFee;
	public long setlIpayPnltAmt;
	public long setlIpayEtc;
	public long setlLtrmBrcvAmt;
	public long setlRamtAmt;  //잔가금액
	public long setlGuarAmt;  //보증금액
	/**
	 * 결제연체료<br>
	 * RT_RCPT_DESC.DFEE<br>
	 * RT_RCPT_DLY_DESC.SETL_NO = MAX(RT_RCPT_DLY_DESC.SETL_NO) BY TIMS<br>
	 */
	public long setlDfee;
	/**
	 * 발생연체료<br>
	 * RT_RCPT_DLY_DESC.OCCR_DFEE<br>
	 * RT_RCPT_DLY_DESC.SETL_NO = MAX(RT_RCPT_DLY_DESC.SETL_NO) BY TIMS<br>
	 */
	public long occrDfee;
	/**
	 * 기발생연체료<br>
	 * RT_RCPT_DLY_DESC.OCCR_DFEE - RT_RCPT_DLY_DESC.ADJ_DFEE<br>
	 * RT_RCPT_DLY_DESC.SETL_NO = MAX(RT_RCPT_DLY_DESC.SETL_NO) BY TIMS<br>
	 */
	public long preOccrDfee;
	/**
	 * 선납연체료<br>
	 * RT_RCPT_DLY_DESC.PDUE_DISC_DFEE<br>
	 * RT_RCPT_DLY_DESC.SETL_NO = MAX(RT_RCPT_DLY_DESC.SETL_NO) BY TIMS<br>
	 */
	public long pdueDfee;
	/**
	 * 면제연체료<br>
	 * RT_RCPT_DLY_DESC.EXMP_DFEE<br>
	 * RT_RCPT_DLY_DESC.SETL_NO = MAX(RT_RCPT_DLY_DESC.SETL_NO) BY TIMS<br>
	 */
	public long exmpDfee;
	/**
	 * 이자시작일자
	 * ST_RMBR_PLAN_DESC.INT_STRT_DT
	 */
	public String intStrtDt;
	/**
	 * 이자종료일자
	 * ST_RMBR_PLAN_DESC.INT_END_DT
	 */
	public String intEndDt;
	public String dlyFg; //연체여부
	/**
	 * 연체일자<br>
	 * 연체일때 실납입일자 + 1<br>
	 * RL_DUE_DT < SETL_DT THEN DBSRQST.RF_ADD_DAYS(RL_DUE_DT,1)<br>
	 */
	public String dlyDt; //연체일자
	/**
	 * 연체계산일자<br>
	 * 연체일때 기존에 결제한 일자가 있으면 그이후부터 아니면 실납입일자 + 1<br>
	 * - RL_DUE_DT < LAST_SETL_DT THEN DBSRQST.RF_ADD_DAYS(LAST_SETL_DT,1)<br>
	 * - DBSRQST.RF_ADD_DAYS(RL_DUE_DT,1)<br>
	 */
	public String dlyCalcDt; //연체계산일자
	/**
	 * 연체시작회차
	 * MIN(RL_DUE_DT < SETL_DT) THEN TIMS
	 */
	public int dlyStrtTims;
	public String loanStatCd; //대출상태코드

	/**
	 * <p>차회차 납입일자
	 */
	public String loseCalcDueDt;
	/**
	 * <p>차회차 실납입일자
	 */
	public String loseCalcRlDueDt;
	public long timsBfAskPamt  ;
	/**
	 * <p>초기세팅 0
	 */
	public long losePsgInt     ;
	/**
	 * <p>2회차이후 월이자 (다음회차의 이자, 2회차이후 월이자는 다음회차원금에 대한 이자임 )
	 */
	public long loseObjPsgInt;
	/**
	 * <p>차회차의 이자시작일자
	 */
	public String loseIntStrtDt;
	/**
	 * <p>차회차의 이자종료일자
	 */
	public String loseIntEndDt ;
	/**
	 * 초기세팅 ''
	 */
	public String loseDueDt;
	/**
	 * 초기세팅 '0'
	 */
	public String loseFg;

	public String termPartFg; //거치분할여부
	public String termPartIntEndDt; //거치분할이자종료일자
	public long termPartInt; //거치이자
	public long midTermPartInt; //중도상환거치이자
	public int unrcvTims; //미수회차
	public long pnltAmtTot6; //범칙금6개월합
	public long mainRmbrPamt; //범칙금6개월합

	//2018-08-01 두비스 선납여부
	public String preRcptFg;
	//2018-08-01 두비스 초회추가
	public int fcntTims;
	public String fcntDueDt;

	public RmbrPlanVO() {
		init();
	}

	public void init() {
		loanNo = StringUtils.EMPTY; //대출번호
		loanSeq = StringUtils.EMPTY; //대출순번
		endDivCd = StringUtils.EMPTY; //종료구분코드
		tims = 0; //회차
		curTims = 0; //현재회차
		thmmDueTims = 0; //당월납입회차
		totTims = 0; //총회차
		prdtCd = StringUtils.EMPTY; //상품코드
		rmbrFrmlCd = StringUtils.EMPTY; //상환방식코드
		dueDt = StringUtils.EMPTY; //납입일자
		rlDueDt = StringUtils.EMPTY; //실납입일자
		lastSetlDt = StringUtils.EMPTY; //최종결제일자
		lastSetlTims = 0; //최종결제회차
		loanEprtDt = StringUtils.EMPTY; //대출만기일자
		loanRlEprtDt = StringUtils.EMPTY; //대출실만기일자
		loanEprtTims = 0; //대출만기회차
		setlDt = StringUtils.EMPTY; //결제일자
		askDivCd = StringUtils.EMPTY; //청구구분코드
		timsBfPamtRamt = 0; //회차전원금잔액
		timsBfIntRamt = 0; //회차전이자잔액
		timsAfPamtRamt = 0; //회차후원금잔액
		timsAfIntRamt = 0; //회차후이자잔액
		pamt = 0; //원금
		intt = 0; //이자
		trtFee=0;
		ppayInt = 0; //선급이자
		addInsuFee = 0;  //가산보험료
		addCartax = 0;  //가산자동차세
		addEnvImprBrdnamt = 0;  //가산환개금
		addAsfee = 0;  //가산정비료
		vtax = 0;  //부가세
		ipayCartax = 0;  //대지급자동차세
		ipayEnvImprBrdnamt = 0;  //대지급환개금
		ipayInsuFee = 0;  //대지급보험료
		ipayPnltAmt = 0;  //대지급범칙금
		ipayEtc = 0;  //대지급기타
		ltrmBrcvAmt = 0;  //장기선수금
		setlPamt = 0; //결제원금
		setlInt = 0; //결제이자
		setlTrtFee=0;	//결제취급수수료
		setlPpayInt = 0;  //결제선급이자
		setlAddInsuFee = 0;  //결제가산보험료
		setlAddCartax = 0;  //결제가산자동차세
		setlAddEnvImprBrdnamt = 0;  //결제가산환개금
		setlAddAsfee = 0;  //결제가산정비료
		setlVtax = 0;  //결제부가세
		setlIpayCartax = 0;  //결제대지급자동차세
		setlIpayEnvImprBrdnamt = 0;  //결제대지급환개금
		setlIpayInsuFee = 0;  //결제대지급보험료
		setlIpayPnltAmt = 0;  //결제대지급보험료
		setlIpayEtc = 0;  //결제재지급기타
		setlLtrmBrcvAmt = 0;  //결제장기선수금
		setlRamtAmt = 0; //잔가금액
		setlGuarAmt = 0; //보증금액
		setlDfee = 0; //결제연체료
		occrDfee = 0; //발생연체료
		preOccrDfee = 0; //기발생연체료
		pdueDfee = 0; //선납연체료
		exmpDfee = 0; //면제연체료
		intStrtDt = StringUtils.EMPTY; //이자시작일자
		intEndDt = StringUtils.EMPTY; //이자종료일자
		dlyFg = "0"; //연체여부
		dlyDt = StringUtils.EMPTY; //연체일자
		dlyCalcDt = StringUtils.EMPTY; //연체계산일자
		dlyStrtTims = 0; //연체시작회차
		loanStatCd = StringUtils.EMPTY;

		loseCalcDueDt = StringUtils.EMPTY;
		loseCalcRlDueDt = StringUtils.EMPTY;
		timsBfAskPamt = 0  ;
		losePsgInt = 0  ;
		loseObjPsgInt = 0;
		loseIntStrtDt = StringUtils.EMPTY;
		loseIntEndDt  = StringUtils.EMPTY;
		loseDueDt = StringUtils.EMPTY;
		loseFg = "0";

		termPartFg = "0";
		termPartIntEndDt = StringUtils.EMPTY;
		termPartInt = 0;
		midTermPartInt = 0;
		unrcvTims = 0;
		pnltAmtTot6 = 0;
		mainRmbrPamt = 0; //
		preRcptFg = "0";
		fcntDueDt="";
		fcntTims=0;
	}
}
