package hanalife.r.co.at.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.co.at.mapper.AcntChkGramMapper;
import hanalife.r.co.at.service.AcntChkGramService;
import hanalife.r.co.at.vo.AcntChkGramInVO;
import hanalife.r.co.at.vo.AcntChkGramOutVO;
import hanalife.r.co.at.vo.AcntChkGramVO;
import hanalife.util.BizException;
import hanalife.util.format.ServerSysDate;

@Service("AcntChkGramService")
public class AcntChkGramServiceImpl implements AcntChkGramService{

	private static final Logger log = LoggerFactory.getLogger(AcntChkGramServiceImpl.class);

	@Autowired
	private AcntChkGramMapper acntChkGramMapper;

	@Override
	public AcntChkGramVO procSend(AcntChkGramVO acntChkGramVO) throws Exception {

		try {
			//입력값을 체크한다.
			chkInptData(acntChkGramVO);

			//거래기관 조회
			AcntChkGramOutVO trOrgBase = getAcntCnfmTrOrg();
			if (trOrgBase==null) {
				throw new BizException("계좌확인 기관으로 등록된 은행을 찾을수 없습니다. 시스템관리자에 문의요.");
			}
			String vndrCd = trOrgBase.getVndrCd();
			String firmBankCd = trOrgBase.getBankCd();

			// 처리일시, 요청전문번호 채번

			return null;

		} catch (Throwable tr) {
			log.error(tr.getMessage(), tr);
			if (tr instanceof BizException) {
				throw (BizException) tr;
			}
			throw new BizException("계좌확인 오류(" + tr.getMessage() + ")", tr);
		}

	}

	/**
	 * <p>입력데이터의 유효성을 체크한다.
	 * @param acntChkGramVO
	 * @throws Exception
	 */
	private void chkInptData(AcntChkGramVO acntChkGramVO) {

		if (acntChkGramVO==null) {
			throw new BizException("계좌확인 요청데이터가 없습니다.");
		}

		if (!TR_DIV_ACNT_CNFM.equals(acntChkGramVO.getTrDivCd()) ) {
			throw new BizException("거래구분이 잘못 입력되었습니다.");
		}

		String acntNo = acntChkGramVO.getAcntNo();
		String depoOwnNm = acntChkGramVO.getDepoOwnNm();
		String bankCd = acntChkGramVO.getBankCd();

		if (StringUtils.isBlank(bankCd)) {
			throw new BizException("은행코드를 입력하세요.");
		}
		if (StringUtils.isBlank(acntNo)) {
			throw new BizException("계좌번호를 입력하세요.");
		} else {
			if (!StringUtils.isNumeric(acntNo)) {
				throw new BizException("계좌번호는 숫자값만 입력하세요.[입력값 : " + acntNo + "]");
			}
		}
		if (StringUtils.isBlank(depoOwnNm)) {
			throw new BizException("예금주명을 입력하세요.");
		}
	}

	/**
	 * 계좌확인 거래기관 조회
	 * @return
	 */
	private AcntChkGramOutVO getAcntCnfmTrOrg() {

		try {

			// VO 세팅
			AcntChkGramInVO inVO = new AcntChkGramInVO();
			AcntChkGramOutVO outVO = new AcntChkGramOutVO();
			List<AcntChkGramOutVO> list = new ArrayList<AcntChkGramOutVO>();
			String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
			//yyyymmdd = DateFormatUtil.format(yyyymmdd);

			inVO.setRcptTpCd(RCPT_TP_ACNT_CNFM);
			inVO.setDueDt(yyyymmdd);

			list = acntChkGramMapper.getAcntCnfmTrOrg(inVO);

			if(list.size() > 0 ) {
				outVO = list.get(0);
			}else {
				throw new BizException("대외기관(VAN)사 정보를 찾을 수 없습니다.");
			}

			log.info("outVO" + outVO.getBankCd());
			return outVO;
		} catch (Exception e) {
			throw new BizException("대외기관(VAN)사 정보 조회 실패",e );
		}
	}

}
