package hanalife.r.co.im.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.im.mapper.ImgAcntProcMapper;
import hanalife.r.co.im.mapper.dto.ImgAcntProcDTO;
import hanalife.r.co.im.service.ImgAcntProcService;
import hanalife.r.co.im.vo.ImgAcntProcInVO;
import hanalife.r.co.im.vo.ImgAcntProcOutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : ImgAcntProcServiceImpl.java Class
 * 클래스설명   : 가상계좌변경관리 Service Implements
 * 작성일자     : 2023. 3. 9.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :    proc         : 가상계좌처리
 *              imgAcntReg   : 가상계좌등록
 *              imgAcntClos  : 가상계좌해지
 *              makeResult   : 결과코드생성
 *              getMsg       : 에러메세지생성
 * </pre>
 */
@Service("imgAcntProcService")
public class ImgAcntProcServiceImpl implements ImgAcntProcService {

    private static final Logger LOGGER = LoggerFactory.getLogger(ImgAcntProcServiceImpl.class);

    /** 오류 메시지 전역 변수 선언 */
    private MsgEnum msgEnum;

    @Autowired
    private ImgAcntProcMapper imgAcntProcMapper;

    /**
     * <pre>
     * 메소드명      : imgAcntReg
     * 작성일자      : 2023. 3. 29.
     * 작성자(author): 70317 younghwe.Kim
     * 설명          : 가상계좌등록을(를) 조회 한다.
     * 메소드인수1   : 가상계좌등록 입력 - ImgAcntProcInVO
     * 메소드리턴값  : 가상계좌등록 출력 - ImgAcntProcOutVO
     * 예외처리      : Exception
     * </pre>
     */
    @Override
	public ImgAcntProcOutVO imgAcntReg(ImgAcntProcInVO inVO) throws Exception {

    	/*************************************************
		 * ■ 서비스 호출 수행 처리 결과값 초기값 설정
		 *************************************************/
        ImgAcntProcOutVO resultVo = new ImgAcntProcOutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try{

        	/*************************************************
    		 * ■ 대출번호의 가상계좌를 해지
    		 *************************************************/
            LOGGER.info("■ 대출번호의 가상계좌를 해지");
            resultVo = this.imgAcntClos(inVO);

            if ( msgEnum.SUCCESS.getErrorCd().equals(resultVo.getRsltCd()) == false ) {
                LOGGER.info("가상계좌해지시 오류");
                return resultVo;
            }


            /*************************************************
    		 * ■ 가상계좌은행에 해당하는 신규 가상계좌번호 조회
    		 *************************************************/
            LOGGER.info("■ 가상계좌은행에 해당하는 신규 가상계좌번호 조회");
            ImgAcntProcDTO inDto = new ImgAcntProcDTO();

            inDto.setApplDivCd(inVO.getApplDivCd());                 /** 신청구분코드 */
            inDto.setDisuDt("");                                     /** 폐기일자 */
            inDto.setUseFg("0");                                     /** 사용여부 */
            inDto.setLoanNo(inVO.getLoanNo());                       /** 대출번호 */
            inDto.setLoanSeq(inVO.getLoanSeq());                     /** 대출순번 */
            inDto.setRegEmpNo(inVO.getRegEmpNo());                   /** 등록사원번호 */
            inDto.setBfImgAcntNo(inVO.getBfImgAcntNo());             /** 변경전가상계좌번호 */
            inDto.setBfImgAcntBankCd(inVO.getBfImgAcntBankCd());     /** 변경전가상계좌은행코드 */
            inDto.setAfImgAcntNo(inVO.getAfImgAcntNo());             /** 변경후가상계좌번호 */
            inDto.setAfImgAcntBankCd(inVO.getAfImgAcntBankCd());     /** 변경후가상계좌은행코드 */

            List<ImgAcntProcDTO> imgAcntInfo = imgAcntProcMapper.searchImgAcntBaseReg(inDto);


            /*************************************************
    		 * ■ 해당은행의 가상계좌번호 체크
    		 *************************************************/
            if ( imgAcntInfo == null ) {
            	// □ Error Message : [ 0007 ] 해당은행의 가상계좌번호가 없습니다.
                LOGGER.error("■ 은행코드["+inVO.getAfImgAcntBankCd()+"]의 미사용 가상계좌번호가 없습니다.");
                resultVo.setRsltCd(msgEnum.IMGACNT_BANK_ACNT_ZERO.getErrorCd());
                resultVo.setRsltCntn(msgEnum.IMGACNT_BANK_ACNT_ZERO.getErrorCn());
                return resultVo;
            }


            /*************************************************
    		 * ■ 가상계좌내역 수정
    		 *************************************************/
            // □ 가상계좌 해지 후 신규 등록 시 사용여부 값 변경 : 0 -> 1
            inDto.setUseFg("1");
            // □ 가상계좌번호SET
            inDto.setAfImgAcntNo(imgAcntInfo.get(0).getImgAcntNo());

            LOGGER.info("■ 가상계좌내역 수정");
            if( imgAcntProcMapper.updateImgAcntDesc(inDto) != 1 ) {
            	// □ Error Message : [ 0004 ] 가상계좌내역 대상이 없습니다.
                resultVo.setRsltCd(msgEnum.IMGACNT_DESC_ZERO.getErrorCd());
                resultVo.setRsltCntn(msgEnum.IMGACNT_DESC_ZERO.getErrorCn());
                return resultVo;
            }


            /*************************************************
    		 * ■ 가상계좌이력 등록
    		 *************************************************/
            LOGGER.info("■ 가상계좌이력 등록");
            if ( imgAcntProcMapper.insertImgAcntHistReg(inDto) != 1 ) {
            	// □ Error Message : [ 0005 ] 가상계좌이력 대상이 없습니다.
                LOGGER.info("[가상계좌이력내역 오류]가상계좌 사용이력 등록중 오류");
                resultVo.setRsltCd(msgEnum.IMGACNT_HIST_ZERO.getErrorCd());
                resultVo.setRsltCntn(msgEnum.IMGACNT_DESC_ZERO.getErrorCn());
                return resultVo;
            }


            /*************************************************
    		 * ■ [ST_LOAN_BASE] 신규 가상계좌로 UPDATE
    		 *************************************************/
            LOGGER.info("■ [ST_LOAN_BASE] 신규 가상계좌로 UPDATE");

            if ( imgAcntProcMapper.updateLoanBase(inDto) != 1 ) {
            	// □ Error Message : [ 0006 ] 대출기본 건수가 없습니다.
                LOGGER.info("대출기본 수정건수가 없습니다.");
                resultVo.setRsltCd(msgEnum.IMGACNT_LOAN_BASE_ZERO.getErrorCd());
                resultVo.setRsltCntn(msgEnum.IMGACNT_LOAN_BASE_ZERO.getErrorCn());
                return resultVo;
            }

        } catch(Exception e) {
            LOGGER.error("error: " + e.getMessage());
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
        }

        return resultVo;

    }


    /**
     * <pre>
     * 메소드명      : imgAcntClos
     * 작성일자      : 2023. 3. 29.
     * 작성자(author): 70317 younghwe.Kim
     * 설명          : 가상계좌해지을(를) 조회 한다.
     * 메소드인수1   : 가상계좌해지 입력 - ImgAcntProcInVO
     * 메소드리턴값  : 가상계좌해지 출력 - ImgAcntProcOutVO
     * 예외처리      : Exception
     * </pre>
     */
    @Override
	public ImgAcntProcOutVO imgAcntClos(ImgAcntProcInVO inVO) throws Exception {

    	/*************************************************
		 * ■ 서비스 호출 수행 처리 결과값 초기값 설정
		 *************************************************/
        ImgAcntProcOutVO resultVo = new ImgAcntProcOutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());


        /*************************************************
		 * ■ 해지할 가상계좌정보를 조회
		 *************************************************/
        LOGGER.info("■ 해지할 가상계좌정보를 조회");
        ImgAcntProcDTO inDto = new ImgAcntProcDTO();

//        inDto.setApplDivCd(inVO.getApplDivCd());               /** 신청구분코드 */
        inDto.setLoanNo(inVO.getLoanNo());                     /** 대출번호 */
        inDto.setLoanSeq(inVO.getLoanSeq());                   /** 대출순번 */
        inDto.setRegEmpNo(inVO.getRegEmpNo());                 /** 등록사원번호 */
        inDto.setBfImgAcntNo(inVO.getBfImgAcntNo());           /** 변경전가상계좌번호 */
        inDto.setBfImgAcntBankCd(inVO.getBfImgAcntBankCd());   /** 변경전가상계좌은행코드 */

        // □ 해지 시에는 변경 후 계좌 정보 null로 세팅
        inDto.setAfImgAcntNo("");                              /** 변경후가상계좌번호 */
        inDto.setAfImgAcntBankCd("");                          /** 변경후가상계좌은행코드 */

        List<ImgAcntProcDTO> imgAcntInfo = imgAcntProcMapper.searchImgAcntBase(inDto);


        /*************************************************
		 * ■ 조회된 결과가 없으면 해지 처리하지 않음
		 *************************************************/
        if ( imgAcntInfo.isEmpty() == true ) {
        	// □ Error Message : [ 0002 ] 대출번호에 등록된 가상계좌가 없음, 정보가 존재하지 않습니다.
            resultVo.setRsltCd(msgEnum.NOT_FOUND.getErrorCd());
            resultVo.setRsltCntn(msgEnum.NOT_FOUND.getErrorCn());
            return resultVo;
        }


        /*************************************************
		 * ■ 사용여부/폐기일자 Setting
		 *************************************************/
        String useFg  = "";      // 사용여부
        String disuDt = "";      // 폐기일자

        for (ImgAcntProcDTO sourceIO : imgAcntInfo) {
            useFg  = sourceIO.getUseFg();
            disuDt = sourceIO.getDisuDt();
        }


        /*************************************************
		 * ■ 가상계좌 사용여부 확인
		 *************************************************/
        if ( useFg.equals("0") ) {
        	// □ Error Message : [ 0011 ] 대출번호에 등록된 가상계좌가 없음, 미사용 계좌입니다.
            resultVo.setRsltCd(msgEnum.IMGACNT_UNUSE_CD.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IMGACNT_UNUSE_CD.getErrorCn());
            return resultVo;
        }


        /*************************************************
		 * ■ 가상계좌 폐기여부 확인
		 *************************************************/
        if ( !StringUtil.isNull(disuDt) ) {
        	// □ Error Message : [ 0012 ] 대출번호에 등록된 가상계좌가 없음, 폐기된 계좌입니다.
            resultVo.setRsltCd(msgEnum.IMGACNT_DISU_CD.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IMGACNT_DISU_CD.getErrorCn());
            return resultVo;
        }


        /*************************************************
		 * ■ [ST_LOAN_IMG_ACNT_DESC] USE_FG = '0', USE_CMPL_DT 수정
		 *************************************************/
        // □ 가상계좌 해지 시 사용여부 값 세팅 : 0
        inDto.setUseFg("0");

        LOGGER.info("■ [ST_LOAN_IMG_ACNT_DESC] USE_FG = '0', USE_CMPL_DT 수정");
        if ( imgAcntProcMapper.updateImgAcntDesc(inDto) != 1 ) {
        	// □ Error Message : [ 0004 ] 가상계좌내역 대상이 없습니다.
            LOGGER.info("　☞ 가상계좌내역 수정건수가 없습니다.");
            resultVo.setRsltCd(msgEnum.IMGACNT_DESC_ZERO.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IMGACNT_DESC_ZERO.getErrorCn());
            return resultVo;
        }


        /*************************************************
		 * ■ [ST_LOAN_IMG_ACNT_HIST] UPDATE
		 *************************************************/
        LOGGER.info("■ [ST_LOAN_IMG_ACNT_HIST] UPDATE");
        if ( imgAcntProcMapper.updateImgAcntHistClos(inDto) != 1 ) {
        	// □ Error Message : [ 0005 ] 가상계좌이력 대상이 없습니다.
            LOGGER.info("　☞ 가상계좌이력 수정건수가 없습니다.");
            resultVo.setRsltCd(msgEnum.IMGACNT_HIST_ZERO.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IMGACNT_DESC_ZERO.getErrorCn());
            return resultVo;
        }


        /*************************************************
		 * ■ [ST_LOAN_BASE] 가상계좌 초기화
		 *************************************************/
        LOGGER.info("■ [ST_LOAN_BASE] 가상계좌 초기화");
        if ( imgAcntProcMapper.updateLoanBase(inDto) != 1 ) {
        	// □ Error Message : [ 0006 ] 대출기본 건수가 없습니다.
            LOGGER.info("　☞ 대출기본 수정건수가 없습니다.");
            resultVo.setRsltCd(msgEnum.IMGACNT_LOAN_BASE_ZERO.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IMGACNT_LOAN_BASE_ZERO.getErrorCn());
            return resultVo;
        }

        return resultVo;

    }

}
