package hanalife.r.co.rc.service;

import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.as.vo.TimsUnrcvVO;
import hanalife.r.co.rc.vo.AmtAdjVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;

/**
 * <pre>
 * 클래스명    : AdjCalcService
 * 클래스설명  : 금액정산 Service
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 28.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface AdjCalcService {

	/**
	 * <p>회차정산
	 * @param iamtUnrcvObjVO
	 */
	public void procTimsAdj(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>연체료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcDfee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>취급수수료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcTrtFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>이자정산
	 * @param IamtUnrcvObjVO
	 * @param TimsUnrcvVO
	 */
	public void calcInt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>원금 정산
	 * @param IamtUnrcvObjVO
	 * @param TimsUnrcvVO
	 */
	public void calcPamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>선급이자 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcPpayInt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산환개금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddEnvImprBrdnamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddCartax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산보험료정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddInsuFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산정비료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddAsfee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>대지급기타 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIpayEtc(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>대지급범칙금 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIpayPnltAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>대지급환개금 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIpayEnvImprBrdnamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>대지급자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIpayCartax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>대지급보험료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIpayInsuFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>부가세 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcVtax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	//------------------------------------------------------------------------------------------------
	// 장기선수금대체 계산
	//------------------------------------------------------------------------------------------------
	/**
	 * <p>부가체 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcVtaxWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>이자정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcIntWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>원금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcPamtWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>선급이자 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcPpayIntWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산환개금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddEnvImprBrdnamtWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddCartaxWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산보험료정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddInsuFeeWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>가산정비료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	public void calcAddAsfeeWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO);

	/**
	 * <p>중도상환원금 계산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	public void calcMidRmbrPamt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>중도상환이자 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	public void calcMidRmbrInt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>중도상환취급수수료(분할) 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	public void calcMidRmbrTrtFee(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>중도상환수수료 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	public void calcMidRmbrFee(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>중도해지시 명의_변경_보증금 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	public void calcNmChngGuarAmt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>메소드명 : calcAdjAmt </p>
	 * <p>설　　명 : (3.2.6.        금액정산처리)
	 * 수납금액에 대해 회차별 원리금, 이자, 연체료 등을 금액정산한다.
	 * 계산방법 : 결제금액(우선정산금액 + 할인금액 + 면제금액 + 결제금액) - 청구금액
	 * 정산순서 : 우선정산금액 -> 할인금액 -> 면제금액 -> 결제금액
	 * </p>
	 * <p>메소드인수1 : amtAdjVO AmtAdjVO </p>
	 * <p>메소드리턴값 : amtAdjVO AmtAdjVO </p>
	 */
	public AmtAdjVO calcAdjAmt(AmtAdjVO amtAdjVO);

}
