package hanalife.r.co.rc.service;

import java.sql.SQLException;

import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.RcptBaseVO;

/**
 * <pre>
 * 클래스명    : LoanService
 * 클래스설명  : 입금미수관련 대출정보 Service
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 22.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface LoanService {

	/**
	 * 메소드명		: updateLoanBase
	 * 설명			: 수납결과를 [ST_LOAN_BASE]에 반영
	 * 메소드인수1 	: String cnclFg
	 * 메소드인수2 	: IamtUnrcvObjVO
	 * 메소드인수3 	: RcptBaseVO
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	public int updateLoanBase(String cnclFg, IamtUnrcvObjVO iamtUnrcvObjVO, RcptBaseVO rcptBaseVO);

	/**
	 * TODO 리스 미사용
	 * 메소드명		: updateLoanBase
	 * 설명			: 수납결과를 [ST_LEAS_BASE]에 반영
	 * 메소드인수1 	: String cnclFg
	 * 메소드인수2 	: IamtUnrcvObjVO
	 * 메소드인수3 	: RcptBaseVO
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	//public int updateLeaseBase(String cnclFg, IamtUnrcvObjVO iamtUnrcvObjVO, RcptBaseVO rcptBaseVO);

	/**
	 * 메소드명		: updateLoanBaseSetlNo
	 * 설명			: [ST_LOAN_BASE] 결제번호 증가
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	public int updateLoanBaseSetlNo(String loanNo, String loanSeq);

	/**
	 * 메소드명		: searchOrg
	 * 설명			: 제휴정보 얻기
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	public IamtUnrcvObjVO searchOrg(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * TODO 미사용
	 * 메소드명		: updateLeasBaseForUnrcvProcDt
	 * 설명			: 미수처리일자 변경
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드인수3 	: String unrcvProcDt
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	//void updateLeasBaseForUnrcvProcDt(String loanNo, String loanSeq, String unrcvProcDt);

	/**
	 * 메소드명		: getLeglActsCostRamt
	 * 설명			: 입력된 채권에 대한 법적조치비용 잔액구하기
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드리턴값	: long
	 * 예외처리		: N/A
	 */
	public long getLeglActsCostRamt( String loanNo, String loanSeq);

	/**
	 * TODO 미사용
	 * 메소드명		: isBsnCls
	 * 설명			: 입력 회계일자, 부서에 대해 업무마감 여부
	 * 메소드인수1 	: String acctDt
	 * 메소드인수2 	: String deptCd
	 * 메소드리턴값	: boolean
	 * 예외처리		: N/A
	 */
	//boolean isBsnCls(String acctDt, String deptCd);

	/**
	 * TODO 미사용
	 * 메소드명		: searchUnwinding
	 * 설명			: 충당금처리대상금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 * IamtUnrcvObjVO
	 * IamtUnrcvObjVO
	 */
	//long[] searchUnwinding(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * TODO 미사용
	 * 메소드명		: searchUnwindingCncl
	 * 설명			: 충당금처리대상취소금액 조회 (수납취소 시 전표 역분개를 위해 충당금 조회)
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	//long[] searchUnwindingCncl(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * TODO 미사용
	 * 메소드명		: searchHairCut
	 * 설명			: WO 이전 HairCut수납처리 금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	//long[] searchHairCut(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * TODO 미사용
	 * 메소드명		: searchHairCut
	 * 설명			: WO 이전 HairCut수납취소처리 금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	//long[] searchHairCutCncl(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * 메소드명		: getRetnRt
	 * 설명			: 입력된 채권에 대한 환입율 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: String
	 * 예외처리		: N/A
	 */
	public String getRetnRt(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>지급수수료환입율 신규등록
	 * @param clawbkBaseVOList
	 * @return int
	 * @throws SQLException
	 */
	public int createClawbkBase(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>지급수수료환입율 삭제
	 * @param clawbkBaseVOList
	 * @return int
	 * @throws SQLException
	 */
	public int deleteClawbkBase(IamtUnrcvObjVO iamtUnrcvObjVO);
}
