package hanalife.r.co.rc.service;

import java.util.List;

import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.RcptBaseVO;
import hanalife.s.ln.ch.vo.MidPartRmbrObj;

/**
 * <pre>
 * 클래스명    : RcptService
 * 클래스설명  : 입금미수 수납관련 쿼리를 수행하는 Service
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 22.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface RcptRCService {

	/**
	 * <p>메소드명	: searchIamtUnrcvObj</p>
	 * <p>설　　명	: 입금대상(요청)에 추가로 DB에서 얻은 정보 셋팅</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: N/A</p>
	 */
	public IamtUnrcvObjVO searchIamtUnrcvObj(IamtUnrcvObjVO inObj);

	/**
	 * <p>메소드명	: setCnclObj</p>
	 * <p>설　　명	: 취소대상구성</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: N/A</p>
	 */
	public IamtUnrcvObjVO setCnclObj(IamtUnrcvObjVO inObj);

	/**
	 * <p>메소드명	: searchCnclCond</p>
	 * <p>설    명	: 취소조건조회</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: RcptBaseVO</p>
	 */
	public RcptBaseVO searchCnclCond(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: cnfmRcptDesc</p>
	 * <p>설　　명	: 취소대상 수납확인</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: boolean - 취소대상 존재여부</p>
	 */
	public boolean cnfmRcptDesc(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * TODO 미사용
	 * <p>메소드명	: hasDueDtBfExstDt</p>
	 * <p>설　　명	: 유예일자이전 납입일자 존재여부 체크</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: boolean - 유예일자이전 납입일자 존재여부</p>
	 */
	//boolean hasDueDtBfExstDt(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: createRcptBase</p>
	 * <p>설　　명	: [수납_기본]등록 (단건)</p>
	 * <p>메소드인수	: trDescNo, RcptBaseVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int createRcptBase(int trDescNo, RcptBaseVO rcptBaseVO);

	/**
	 * <p>메소드명	: createRcptBase</p>
	 * <p>설　　명	: [수납_기본]등록 (여러건)</p>
	 * <p>메소드인수	: trDescNo, List rcptBaseVOList - 등록할 RcptBaseVO의 리스트, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int createRcptBase(int trDescNo, List rcptBaseVOList);

	/**
	 * <p>메소드명	: createRcptDescForCncl</p>
	 * <p>설　　명	: [수납_기본] 리스트 등록(취소), 기존정보를 조회하고 생성함.</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int createRcptDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: createRcptDescForCnclPiamt</p>
	 * <p>설　　명	: 원리금수납을 취소한다.</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int createRcptDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: searchRcptBaseByPK</p>
	 * <p>설　　명	: [수납_기본] 조회<</p>
	 * <p>메소드인수	: RcptBaseVO, Connection</p>
	 * <p>리 턴 값	: RcptBaseVO</p>
	 */
	public RcptBaseVO searchRcptBaseByPK(RcptBaseVO rcptBaseVO);

	/**
	 * <p>메소드명	: createRcptDesc</p>
	 * <p>설　　명	: [수납_내역] 리스트등록<</p>
	 * <p>메소드인수	: List rcptDescVOList, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int createRcptDesc(List rcptDescVOList);

	/**
	 * <p>메소드명	: updateRcptDescForCncl</p>
	 * <p>설　　명	: [수납_내역] 취소 반영<</p>
	 * <p>메소드인수	: List rcptDescVOList, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateRcptDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: updateRcptDescForCnclPiamt</p>
	 * <p>설　　명	: 원리금수납취소<</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateRcptDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: updateRcptBaseForCncl</p>
	 * <p>설　　명	: 수납_기본을 취소처리<</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateRcptBaseForCncl(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: updateRcptBaseForMidRmbrCncl</p>
	 * <p>설　　명	: 중도일부상환 취소시 수납기본에 상환스케쥴 TR_SNUM 반영<</p>
	 * <p>메소드인수	: MidPartRmbrObj, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateRcptBaseForMidRmbrCncl(MidPartRmbrObj mRmbrObj, int setlNo);

	/**
	 * <p>메소드명	: updateRcptBaseForCnclPiamt</p>
	 * <p>설　　명	: 부분취소시 처리</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateRcptBaseForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO);

	/**
	 * <p>메소드명	: updateDdayPrftLoseStrtTims</p>
	 * <p>설　　명	: 기한상실 시작회차 수정(부활/상실)</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, int ddayPrftLoseStrtTims, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	public int updateDdayPrftLoseStrtTims(IamtUnrcvObjVO iamtUnrcvObjVO, int ddayPrftLoseStrtTims);

	/**
	 * <p>메소드명	: getNextNum</p>
	 * <p>설　　명	: 미확인번호 채번</p>
	 * <p>메소드인수	: Connection</p>
	 * <p>리 턴 값	: String</p>
	 */
	public String getNextNum();
}
