package hanalife.r.co.rc.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.as.vo.TimsUnrcvVO;
import hanalife.r.co.rc.service.AdjCalcService;
import hanalife.r.co.rc.vo.AmtAdjVO;
import hanalife.r.co.rc.vo.AmtCalcVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;
import hanalife.util.IamtUtil;


/**
 * <pre>
 * 클래스　명 : adjCalcServiceImpl
 * 클래스설명 : 금액정산ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 28.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 28.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("adjCalcService")
public class AdjCalcServiceImpl implements AdjCalcService {

	private static final Logger log = LoggerFactory.getLogger(AdjCalcServiceImpl.class);
	private static boolean isDebugEnabled = log.isDebugEnabled();

	@Autowired
	private static AdjCalcService adjCalcService;
	/**
	 * <p>회차정산
	 * @param iamtUnrcvObjVO
	 */
	@Override
	public void procTimsAdj(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//정산금액 초기화
		iamtUnrcvObjVO.adjAmt          = 0; //정산금액
		iamtUnrcvObjVO.adjPamt         = 0; //정산원금
		iamtUnrcvObjVO.adjInt          = 0; //정산이자
		iamtUnrcvObjVO.adjTrtFee       = 0; //정산취급수수료
		iamtUnrcvObjVO.adjDfee         = 0; //정산연체료
		iamtUnrcvObjVO.adjPdueDiscDfee = 0;	//정산선납할인연체료
		iamtUnrcvObjVO.adjExmpPamt     = 0;	//면제원금
		iamtUnrcvObjVO.adjExmpInt      = 0;	//면제이자
		iamtUnrcvObjVO.adjExmpTrtFee   = 0;	//면제취급수수료
		iamtUnrcvObjVO.adjExmpDfee     = 0;	//면제연체료
		iamtUnrcvObjVO.dlyCpayFg = Constants.YES;
		iamtUnrcvObjVO.intCpayFg = Constants.YES;
		if (IamtUtil.isLease(iamtUnrcvObjVO)) {
			iamtUnrcvObjVO.adjVtax               = 0;   //부가세
			iamtUnrcvObjVO.adjIpayInsuFee        = 0;   //대지급_보험료
			iamtUnrcvObjVO.adjIpayCartax         = 0;   //대지급_자동차세
			iamtUnrcvObjVO.adjIpayEnvImprBrdnamt = 0;   //대지급_환경_개선_부담금
			iamtUnrcvObjVO.adjIpayPnltAmt        = 0;   //대지급_범칙금
			iamtUnrcvObjVO.adjIpayEtc            = 0;   //대지급_기타
			iamtUnrcvObjVO.adjAddAsfee           = 0;   //가산_정비료
			iamtUnrcvObjVO.adjAddInsuFee         = 0;   //보험료
			iamtUnrcvObjVO.adjAddCartax          = 0;   //차세
			iamtUnrcvObjVO.adjAddEnvImprBrdnamt  = 0;   //환개금
			iamtUnrcvObjVO.adjPpayInt			 = 0;	//선급_이자(초회산입이자일때)

			iamtUnrcvObjVO.vtaxCpayFg				 = Constants.YES;   //부가세
			iamtUnrcvObjVO.ppayIntCpayFg             = Constants.YES;	//선급_이자
			iamtUnrcvObjVO.addInsuFeeCpayFg          = Constants.YES;   //보험료
			iamtUnrcvObjVO.addCartaxCpayFg           = Constants.YES;   //차세
			iamtUnrcvObjVO.addEnvImprBrdnamtCpayFg   = Constants.YES;   //환개금
			iamtUnrcvObjVO.addAsfeeCpayFg            = Constants.YES;   //가산_정비료
			iamtUnrcvObjVO.ipayInsuFeeCpayFg         = Constants.YES;   //대지급_보험료
			iamtUnrcvObjVO.ipayCartaxCpayFg          = Constants.YES;   //대지급_자동차세
			iamtUnrcvObjVO.ipayEnvImprBrdnamtCpayFg  = Constants.YES;   //대지급_환경_개선_부담금
			iamtUnrcvObjVO.ipayPnltAmtCpayFg         = Constants.YES;   //대지급_범칙금
			iamtUnrcvObjVO.ipayEtcCpayFg             = Constants.YES;   //대지급_기타
		}

		AmtCalcVO calcVO = null;
		if (isDebugEnabled) {
			calcVO = new AmtCalcVO(iamtUnrcvObjVO, timsUrcvVO);
		}

		/* 회차별 금액항목별로 정산처리 */
		if (IamtUtil.isLease(iamtUnrcvObjVO)) {
			//부가세
			adjCalcService.calcVtax(iamtUnrcvObjVO, timsUrcvVO);

			//연체금액 정산
			adjCalcService.calcDfee(iamtUnrcvObjVO, timsUrcvVO);

			//대지급보험료
			adjCalcService.calcIpayInsuFee(iamtUnrcvObjVO, timsUrcvVO);

			//대지급차세
			adjCalcService.calcIpayCartax(iamtUnrcvObjVO, timsUrcvVO);

			//대지급환개금
			adjCalcService.calcIpayEnvImprBrdnamt(iamtUnrcvObjVO, timsUrcvVO);

			//대지급범칙금
			adjCalcService.calcIpayPnltAmt(iamtUnrcvObjVO, timsUrcvVO);

			//대지급기타
			adjCalcService.calcIpayEtc(iamtUnrcvObjVO, timsUrcvVO);

			//가산정비료
			adjCalcService.calcAddAsfee(iamtUnrcvObjVO, timsUrcvVO);

			//가산보험료
			adjCalcService.calcAddInsuFee(iamtUnrcvObjVO, timsUrcvVO);

			//가산차세
			adjCalcService.calcAddCartax(iamtUnrcvObjVO, timsUrcvVO);

			//가산환개금
			adjCalcService.calcAddEnvImprBrdnamt(iamtUnrcvObjVO, timsUrcvVO);

			//선급기간이자(초회)
			adjCalcService.calcPpayInt(iamtUnrcvObjVO, timsUrcvVO);

			//이자  정산
			adjCalcService.calcInt(iamtUnrcvObjVO, timsUrcvVO);

			//원리금 정산
			adjCalcService.calcPamt(iamtUnrcvObjVO, timsUrcvVO);
		}
		else {
			//취급수수료정산
			adjCalcService.calcTrtFee(iamtUnrcvObjVO, timsUrcvVO);

			//연체금액 정산
			adjCalcService.calcDfee(iamtUnrcvObjVO, timsUrcvVO);

			//이자  정산
			adjCalcService.calcInt(iamtUnrcvObjVO, timsUrcvVO);

			//원리금 정산
			adjCalcService.calcPamt(iamtUnrcvObjVO, timsUrcvVO);
		}

		if (isDebugEnabled) {
			calcVO.calc(iamtUnrcvObjVO);
			calcVO= null;
		}
	}


	/**
	 * <p>연체료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcDfee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구연체료
		//결제대상 : 결제금액, 면제연체료
		//정산(수납)금  : 연체료, 선납할인연체료, 면제연체료
		if ( ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpDfee + iamtUnrcvObjVO.tempFrstAdjDfee) > 0)
				|| (timsUrcvVO.askDfee != 0 || timsUrcvVO.pdueDiscDfee != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.vtaxCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]부가세 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();

			//청구미수 구할때 선납할인연체료를 청구연체료에서 미리 빼놓음.
			//따라서 실연체료는 연체료 + 선납할인연체료임.
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askDfee + timsUrcvVO.pdueDiscDfee;

			//결제금액
			amtAdjVO.frstDfee = iamtUnrcvObjVO.tempFrstAdjDfee;
			amtAdjVO.discAmt  = timsUrcvVO.pdueDiscDfee;
			amtAdjVO.exmpAmt  = iamtUnrcvObjVO.tempExmpDfee;
			amtAdjVO.setlAmt  = iamtUnrcvObjVO.tempSetlAmt;

			//결제순서 : 할인금액(선납할인연체료) -> 면제금액(면제연체료) ->우선정산 연체료 -> 결제금액
			amtAdjVO = calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempFrstAdjDfee = amtAdjVO.frstDfee;
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpDfee = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산(수납)금액
			iamtUnrcvObjVO.adjPdueDiscDfee = amtAdjVO.adjDiscAmt;
			iamtUnrcvObjVO.adjExmpDfee = amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjDfee = amtAdjVO.adjAmt + amtAdjVO.adjDiscAmt + amtAdjVO.adjFrstDfee + amtAdjVO.adjExmpAmt;

			//연체완납여부
			iamtUnrcvObjVO.dlyCpayFg = (amtAdjVO.askAmt == 0) ? Constants.YES : Constants.NO;
		}
	}


	/**
	 * <p>취급수수료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcTrtFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//청구대상 : 청구취급수수료
		//결제대상 : 결제금액, 면제취급수수료, 우선결제취급수수료
		//정산(수납)금  : 월취급수수료, 면제취급수수료
		if (((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpTrtFee + iamtUnrcvObjVO.tempFrstAdjTrtFee) > 0) &&
				(timsUrcvVO.askTrtFee != 0)) {

//			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
//				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ppayIntCpayFg)) {
//					IamtExceptionHandler.throwIamtException(iamtUnrcvObjVO, "[" + timsUrcvVO.tims + "]선급이자 정산이 먼저이루어져야합니다.");
//				}
//			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액(취급수수료)
			amtAdjVO.askAmt = timsUrcvVO.askTrtFee;

			//결제금액(결제순서 : 우선정산금 -> 면제금 -> 결제금)
			amtAdjVO.frstAmt = iamtUnrcvObjVO.tempFrstAdjTrtFee;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpTrtFee;
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;

			//결제순서 : 우선정산금 -> 면제취급수수료 -> 결제금액
			amtAdjVO = calcAdjAmt(amtAdjVO);

			//정산후 결제금액
			iamtUnrcvObjVO.tempFrstAdjTrtFee = amtAdjVO.frstAmt;
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpTrtFee = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjExmpTrtFee = amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjTrtFee = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt + amtAdjVO.adjFrstAmt;

			iamtUnrcvObjVO.trtFeeCpayFg = (amtAdjVO.askAmt == 0) ? Constants.YES : Constants.NO;
		}
	}

	//이자정산
	@Override
	public void calcInt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//청구대상 : 청구이자 (음수가 입력될수도 있다.)
		//결제대상 : 결제금액, 면제이자, 우선결제이자
		//정산(수납)금  : 월이자, 면제이자
		if (((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpInt + iamtUnrcvObjVO.tempFrstAdjIntAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt) > 0) &&
				(timsUrcvVO.askInt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ppayIntCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]선급이자 정산이 먼저이루어져야합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액(이자)
			amtAdjVO.askAmt = timsUrcvVO.askInt;

			//결제금액(결제순서 : 우선정산금 -> 면제금 -> 결제금)
			amtAdjVO.frstAmt = iamtUnrcvObjVO.tempFrstAdjIntAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpInt;
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmInt > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmInt) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmInt - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmInt;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제순서 : 면제이자 -> 결제금액
			amtAdjVO = calcAdjAmt(amtAdjVO);

			//정산후 결제금액
			iamtUnrcvObjVO.tempFrstAdjIntAmt = amtAdjVO.frstAmt;
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			iamtUnrcvObjVO.tempExmpInt = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjExmpInt = amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjInt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt + amtAdjVO.adjFrstAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			//이자완납여부
			if (amtAdjVO.askAmt < 0) {
				if (amtAdjVO.askAmt == iamtUnrcvObjVO.adjInt) {
					iamtUnrcvObjVO.intCpayFg = Constants.YES;
				} else {
					iamtUnrcvObjVO.intCpayFg = Constants.NO;
				}
			} else {
				//이자는 minus 이자가 입력될수 있으므로 청구금-정산금으로 정산(완납)여부를 확인한다.
				iamtUnrcvObjVO.intCpayFg = (amtAdjVO.askAmt == 0) ? Constants.YES : Constants.NO;
			}
		}
	}

	//원금 정산
	@Override
	public void calcPamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//청구대상 : 청구원금
		//결제대상 : 결제금액, 면제원금, 우선결제원금
		//정산(수납)금  : 월원금, 면제원금
		if (((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpPamt + iamtUnrcvObjVO.tempFrstAdjAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt) > 0) &&
				(timsUrcvVO.askPamt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.intCpayFg)) {
					throw new BizException("이자 정산이 먼저이루어져야 합니다.");
				}
			}

			//결제금액 : 면제원금 + 결제금액
			//청구금액 : (회차)청구원금
			AmtAdjVO amtAdjVO = new AmtAdjVO();

			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askPamt;

			//결제금액
			amtAdjVO.frstAmt = iamtUnrcvObjVO.tempFrstAdjAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpPamt;
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmPamt > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmPamt) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmPamt - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmPamt;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제순서 : 우선정산금액 -> 면제금액 -> 결제금액
			amtAdjVO = calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempFrstAdjAmt = amtAdjVO.frstAmt;
			iamtUnrcvObjVO.tempExmpPamt = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjExmpPamt = amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjPamt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt + amtAdjVO.adjFrstAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.pamtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;

		} else {
			//원금정산시 완료여부를 여기서 체크하는 이유는
			//정산순서에 따라 원금이 항상 마지막으로 되기때문임.
			//설사 원금우선순위라도 원금우선결제금으로 미리 계산이 되므로 원금이 항상 마지막에 계산되는 구조임
			if (timsUrcvVO.askPamt == 0) {	//회차전체 정산이 이루어졌다는 뜻!
				iamtUnrcvObjVO.pamtCpayFg = Constants.YES;
			}
		}
	}

	/**
	 * <p>선급이자 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcPpayInt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구선급이자
		//결제대상 : 결제금액
		//정산(수납)금  : 선급이자
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askPpayInt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.addEnvImprBrdnamtCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]환경부담금 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askPpayInt;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmPpayInt > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmPpayInt) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmPpayInt - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmPpayInt;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;

			//정산(수납)금액
			iamtUnrcvObjVO.adjPpayInt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.ppayIntCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산환개금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddEnvImprBrdnamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산환개금
		//결제대상 : 결제금액
		//정산(수납)금  : 환개금
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddEnvImprBrdnamt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.addCartaxCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]자동차세 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddEnvImprBrdnamt;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmAddEnvImprBrdnamt > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmAddEnvImprBrdnamt) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmAddEnvImprBrdnamt - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmAddEnvImprBrdnamt;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddEnvImprBrdnamt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addEnvImprBrdnamtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddCartax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산자동차세
		//결제대상 : 결제금액
		//정산(수납)금  : 차세
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddCartax != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.addInsuFeeCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]보험료 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddCartax;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmAddCartax > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmAddCartax) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmAddCartax - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmAddCartax;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddCartax = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addCartaxCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산보험료정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddInsuFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산보험료
		//결제대상 : 결제금액
		//정산(수납)금  : 보험료
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddInsuFee != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.addAsfeeCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]정비료 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddInsuFee;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmAddInsuFee > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmAddInsuFee) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmAddInsuFee - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmAddInsuFee;
			}
			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddInsuFee = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addInsuFeeCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산정비료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddAsfee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산정비료
		//결제대상 : 결제금액
		//정산(수납)금  : 가산정비료
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddAsfee != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ipayEtcCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]대지급기타 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddAsfee;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmAddAsfee > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmAddAsfee) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmAddAsfee - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmAddAsfee;
			}

			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.ltrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddAsfee = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addAsfeeCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>대지급기타 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIpayEtc(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구대지급기타
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급기타
		if ((iamtUnrcvObjVO.tempSetlAmt > 0) && (timsUrcvVO.askIpayEtc != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ipayPnltAmtCpayFg)) {
					throw new BizException("대지급범칙금 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askIpayEtc;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjIpayEtc = amtAdjVO.adjAmt ;

			iamtUnrcvObjVO.ipayEtcCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>대지급범칙금 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIpayPnltAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구대지급범칙금
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급범칙금
		if ((iamtUnrcvObjVO.tempSetlAmt > 0) && (timsUrcvVO.askIpayPnltAmt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ipayEnvImprBrdnamtCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]대지급 환경개선부담금 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askIpayPnltAmt;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjIpayPnltAmt = amtAdjVO.adjAmt;

			iamtUnrcvObjVO.ipayPnltAmtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>대지급환개금 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIpayEnvImprBrdnamt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구대지급환개금
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급환개금
		if ((iamtUnrcvObjVO.tempSetlAmt > 0) && (timsUrcvVO.askIpayEnvImprBrdnamt != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ipayCartaxCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]대지급자동차세 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askIpayEnvImprBrdnamt;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjIpayEnvImprBrdnamt = amtAdjVO.adjAmt;

			iamtUnrcvObjVO.ipayEnvImprBrdnamtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>대지급자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIpayCartax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구대지급자동차세
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급자동차세
		if ((iamtUnrcvObjVO.tempSetlAmt  > 0) && (timsUrcvVO.askIpayCartax != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.ipayInsuFeeCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]대지급보험료 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askIpayCartax;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjIpayCartax = amtAdjVO.adjAmt;


			iamtUnrcvObjVO.ipayCartaxCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>대지급보험료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIpayInsuFee(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구대지급보험료
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급보험료
		if ((iamtUnrcvObjVO.tempSetlAmt > 0) && (timsUrcvVO.askIpayInsuFee != 0)) {

			if (IamtUtil.equals(iamtUnrcvObjVO.setlFrstRank, Constants.SETL_FRST_RANK_TIMS)) { //회차우선순위
				if (IamtUtil.equals(Constants.NO, iamtUnrcvObjVO.dlyCpayFg)) {
					throw new BizException("[" + timsUrcvVO.tims + "]연체료 정산이 먼저이루어져야 합니다.");
				}
			}

			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askIpayInsuFee;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjIpayInsuFee = amtAdjVO.adjAmt;

			iamtUnrcvObjVO.ipayInsuFeeCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>부가세 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcVtax(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//청구대상 : 청구대지급보험료
		//결제대상 : 결제금액
		//정산(수납)금  : 대지급보험료
		if ((iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askVtax != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askVtax;
			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;	//결제금
			//제외금
			if (iamtUnrcvObjVO.tempLtrmBrcvAmt > 0 && timsUrcvVO.ltrmVtax > 0) {
				if (iamtUnrcvObjVO.tempLtrmBrcvAmt <= timsUrcvVO.ltrmVtax) {
					amtAdjVO.exclAmt = timsUrcvVO.ltrmVtax - iamtUnrcvObjVO.tempLtrmBrcvAmt;
				}
			} else {
				amtAdjVO.exclAmt = timsUrcvVO.ltrmVtax;
			}

			//장기선수금
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;

			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;

			//정산(수납)금액
			iamtUnrcvObjVO.adjVtax = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;
			iamtUnrcvObjVO.adjLtrmBrcvAmt += amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.vtaxCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	//------------------------------------------------------------------------------------------------
	// 장기선수금대체 계산
	//------------------------------------------------------------------------------------------------
	/**
	 * <p>부가체 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcVtaxWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구부가세
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산부가세
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askVtax != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askVtax;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjVtax = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.vtaxCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>이자정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcIntWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {

		//TODO 이자가 음수 일땐 어떻게 해야하나...
		//청구대상 : 청구이자
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산이자
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askInt != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askInt;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjInt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.intCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>원금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcPamtWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO,
			TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구원금
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산원금
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askPamt != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askPamt;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjPamt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.pamtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>선급이자 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcPpayIntWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구선급이자
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산선급이자
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askPpayInt != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askPpayInt;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjPpayInt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.ppayIntCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산환개금정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddEnvImprBrdnamtWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산환개금
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산가산환개금
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddEnvImprBrdnamt != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddEnvImprBrdnamt;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddEnvImprBrdnamt = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addEnvImprBrdnamtCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산자동차세
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddCartaxWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산자동차세
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산가산자동차세
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddCartax != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddCartax;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddCartax = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addCartaxCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산보험료정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddInsuFeeWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산보험료
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산가산보험료
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddInsuFee != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddInsuFee;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddInsuFee = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addInsuFeeCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	/**
	 * <p>가산정비료 정산
	 * @param iamtUnrcvObjVO
	 * @param timsUrcvVO
	 */
	@Override
	public void calcAddAsfeeWithBrcvAmt(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO) {
		//청구대상 : 청구가산보험료
		//결제대상 : 장기선수금대체
		//정산(수납)금  : 정산가산보험료
		if ((iamtUnrcvObjVO.tempLtrmBrcvAmt > 0) && (timsUrcvVO.askAddAsfee != 0)) {
			AmtAdjVO amtAdjVO = new AmtAdjVO();
			//청구금액
			amtAdjVO.askAmt = timsUrcvVO.askAddAsfee;
			//결제금액
			amtAdjVO.ltrmBrcvAmt = iamtUnrcvObjVO.tempLtrmBrcvAmt;
			//결제
			amtAdjVO = calcAdjAmt(amtAdjVO);
			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
			//정산(수납)금액
			iamtUnrcvObjVO.adjAddAsfee = amtAdjVO.adjAmt + amtAdjVO.adjLtrmBrcvAmt;

			iamtUnrcvObjVO.addAsfeeCpayFg = (amtAdjVO.askAmt == 0)? Constants.YES : Constants.NO;
		}
	}

	//------------------------------------------------------------------------------------------------
	// 중도상환원금 정산처리
	//------------------------------------------------------------------------------------------------

	/**
	 * <p>중도상환원금 계산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	@Override
	public void calcMidRmbrPamt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO) {

		AmtAdjVO amtAdjVO = new AmtAdjVO();
		if (iamtUnrcvObjVO.procSetlDivCd.equals(Constants.SETL_DIV_MIDRMBR_T)) {
			//청구금액
			amtAdjVO.askAmt = bndVO.rlTamtRmbrPamt;

			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpPamt;

			//결제순서 : 면제원금 -> 결제금액
			amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpPamt = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			iamtUnrcvObjVO.adjMidRmbrPamt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjExmpPamt = amtAdjVO.adjExmpAmt;
		} else {
			//청구금액
			amtAdjVO.askAmt = bndVO.rlPartRmbrPamt;

			//결제금액 (2018-08-01 중도상환수수료 면제금액 추가)
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpPamt;

			//결제순서 : 면제원금 -> 결제금액
			amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpPamt = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjMidRmbrPamt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjExmpPamt = amtAdjVO.adjExmpAmt;
		}
	}

	/**
	 * <p>중도상환이자 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	@Override
	public void calcMidRmbrInt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO) {

		AmtAdjVO amtAdjVO = new AmtAdjVO();
		//청구금액
		if (iamtUnrcvObjVO.procSetlDivCd.equals(Constants.SETL_DIV_MIDRMBR_T)) {
			amtAdjVO.askAmt = bndVO.midRmbrInt + bndVO.termPartTamtRmbrInt;	//전액상환
		} else {
			amtAdjVO.askAmt = bndVO.calcPartMidRmbrInt + bndVO.termPartPamtRmbrInt;	//부분상환
		}

		//결제금액
		amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
		amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpInt;

		//결제순서 : 면제금액(면제연체료) -> 결제금액
		amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

		//정산후 남은 결제금액
		iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
		iamtUnrcvObjVO.tempExmpInt = amtAdjVO.exmpAmt;
		iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

		//정산금액
		iamtUnrcvObjVO.adjMidRmbrInt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
		iamtUnrcvObjVO.adjExmpInt = amtAdjVO.adjExmpAmt;
	}


	/**
	 * <p>중도상환취급수수료(분할) 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	@Override
	public void calcMidRmbrTrtFee(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO) {

		AmtAdjVO amtAdjVO = new AmtAdjVO();

		//중도상환 수수료 정산, 중도상환취급수수료 할인
		if (iamtUnrcvObjVO.procSetlDivCd.equals(Constants.SETL_DIV_MIDRMBR_T)) {
			//청구금액
			amtAdjVO.askAmt = bndVO.rlTamtRmbrTrtFee;

			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpTrtFee;

			//결제순서 : 할인금액() -> 면제금액() -> 결제금액
			amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpTrtFee = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjMidRmbrTrtFee = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjExmpTrtFee = amtAdjVO.adjExmpAmt;
		}
	}

	/**
	 * <p>중도상환수수료 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	@Override
	public void calcMidRmbrFee(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO) {

		AmtAdjVO amtAdjVO = new AmtAdjVO();
		//중도상환 수수료 정산, 중도상환취급수수료 할인
		if (iamtUnrcvObjVO.procSetlDivCd.equals(Constants.SETL_DIV_MIDRMBR_T)) {
			//청구금액(중도상환수수료. 연체료가 포함되어있어서 연체료를 제한다.)
			amtAdjVO.askAmt = bndVO.tamtRmbrFee - bndVO.dfee;

			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpMidRmbrFee;

			//결제순서 : 할인금액(선납할인연체료) -> 면제금액(면제연체료) -> 결제금액
			amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpMidRmbrFee = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjMidRmbrFee = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjExmpMidRmbrFee = amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjTrtFeeDisc = bndVO.trtFeeDisc;
		} else {
			//청구금액(중도상환수수료. 연체료가 포함되어있어서 연체료를 제한다.)
			amtAdjVO.askAmt = bndVO.partRmbrFee - bndVO.dfee;

			//결제금액
			amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
			amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempExmpMidRmbrFee;

			//결제순서 : 할인금액(선납할인연체료) -> 면제금액(면제연체료) -> 결제금액
			amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

			//정산후 남은 결제금액
			iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
			iamtUnrcvObjVO.tempExmpMidRmbrFee = amtAdjVO.exmpAmt;
			iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

			//정산금액
			iamtUnrcvObjVO.adjMidRmbrFee = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
			iamtUnrcvObjVO.adjExmpMidRmbrFee = amtAdjVO.adjExmpAmt;
		}
	}


	/**
	 * <p>중도해지시 명의_변경_보증금 정산
	 * @param iamtUnrcvObjVO
	 * @param bndVO
	 */
	@Override
	public void calcNmChngGuarAmt(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO) {

		AmtAdjVO amtAdjVO = new AmtAdjVO();
		//명의이전보증금
		//청구금액
		amtAdjVO.askAmt = bndVO.closGuarAmt;

		//결제금액
		amtAdjVO.setlAmt = iamtUnrcvObjVO.tempSetlAmt;
		amtAdjVO.exmpAmt = iamtUnrcvObjVO.tempNmChngExmpGuarAmt;

		//결제순서 : 면제금액(명의변경면제보증금) -> 결제금액
		amtAdjVO = adjCalcService.calcAdjAmt(amtAdjVO);

		//정산후 남은 결제금액
		iamtUnrcvObjVO.tempSetlAmt = amtAdjVO.setlAmt;
		iamtUnrcvObjVO.tempNmChngExmpGuarAmt = amtAdjVO.exmpAmt;
		iamtUnrcvObjVO.tempExmpAmt -= amtAdjVO.adjExmpAmt;

		//정산금액
		iamtUnrcvObjVO.adjNmChngGuarAmt = amtAdjVO.adjAmt + amtAdjVO.adjExmpAmt;
		iamtUnrcvObjVO.adjNmChngExmpGuarAmt = amtAdjVO.adjExmpAmt;
	}

	/**
	 * <p>메소드명 : calcAdjAmt </p>
	 * <p>설　　명 : (3.2.6.        금액정산처리)
	 * 수납금액에 대해 회차별 원리금, 이자, 연체료 등을 금액정산한다.
	 * 계산방법 : 결제금액(우선정산금액 + 할인금액 + 면제금액 + 결제금액) - 청구금액
	 * 정산순서 : 우선정산금액 -> 할인금액 -> 면제금액 -> 결제금액
	 * </p>
	 * <p>메소드인수1 : amtAdjVO AmtAdjVO </p>
	 * <p>메소드리턴값 : amtAdjVO AmtAdjVO </p>
	 */
	@Override
	public AmtAdjVO calcAdjAmt(AmtAdjVO amtAdjVO) {

		//청구금액 체크
		if (amtAdjVO.askAmt < 0) {
			amtAdjVO.adjAmt = amtAdjVO.askAmt;
			amtAdjVO.setlAmt -= amtAdjVO.askAmt;
			return amtAdjVO;
		}

		//결제금액 체크
		if ((amtAdjVO.setlAmt + amtAdjVO.exmpAmt + amtAdjVO.discAmt + amtAdjVO.frstAmt + amtAdjVO.frstDfee + amtAdjVO.ltrmBrcvAmt) == 0) {
			return amtAdjVO;
		}

		//결제순서 : 제외금 -> 우선정산금액 -> 할인금액 -> 면제금액 -> 결제금액
		//원리금 우선순위에 의해  총원리금  - 잔여원금의 결제금액 정산을 위한 금액필드
		if (amtAdjVO.exclAmt >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.exclAmt) {
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.exclAmt;
			} else {
				amtAdjVO.askAmt = 0;
				return amtAdjVO;
			}
		}

		//원리금 우선순위에 의해  총원리금  - 잔여원금의 결제금액 정산을 위한 금액필드
		if (amtAdjVO.frstAmt >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.frstAmt) {
				amtAdjVO.adjFrstAmt = amtAdjVO.frstAmt;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.frstAmt;
				amtAdjVO.frstAmt = 0;
			} else {
				amtAdjVO.adjFrstAmt = amtAdjVO.askAmt;
				amtAdjVO.frstAmt -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;

				return amtAdjVO;
			}
		}

		//원리금 우선순위에 의해  총원리금  - 잔여원금의 결제금액 정산을 위한 금액필드
		if (amtAdjVO.frstDfee >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.frstDfee) {
				amtAdjVO.adjFrstDfee = amtAdjVO.frstDfee;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.frstDfee;
				amtAdjVO.frstDfee = 0;
			} else {
				amtAdjVO.adjFrstDfee = amtAdjVO.askAmt;
				amtAdjVO.frstDfee -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;

				return amtAdjVO;
			}
		}
		if (amtAdjVO.discAmt >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.discAmt) {
				amtAdjVO.adjDiscAmt = amtAdjVO.discAmt;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.discAmt;
				amtAdjVO.discAmt = 0;
			} else {
				amtAdjVO.adjDiscAmt = amtAdjVO.askAmt;
				amtAdjVO.discAmt -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;

				return amtAdjVO;
			}
		}

		if (amtAdjVO.exmpAmt >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.exmpAmt) {
				amtAdjVO.adjExmpAmt = amtAdjVO.exmpAmt;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.exmpAmt;
				amtAdjVO.exmpAmt = 0;
			} else {
				amtAdjVO.adjExmpAmt = amtAdjVO.askAmt;
				amtAdjVO.exmpAmt -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;

				return amtAdjVO;
			}
		}

		if (amtAdjVO.ltrmBrcvAmt >= 0) {
			if (amtAdjVO.askAmt > amtAdjVO.ltrmBrcvAmt) {
				amtAdjVO.adjLtrmBrcvAmt = amtAdjVO.ltrmBrcvAmt;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.ltrmBrcvAmt;
				amtAdjVO.ltrmBrcvAmt = 0;
			} else {
				amtAdjVO.adjLtrmBrcvAmt = amtAdjVO.askAmt;
				amtAdjVO.ltrmBrcvAmt -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;
				return amtAdjVO;
			}
		}

		if (amtAdjVO.setlAmt > 0) {
			if (amtAdjVO.askAmt >= amtAdjVO.setlAmt) {
				amtAdjVO.adjAmt = amtAdjVO.setlAmt;
				amtAdjVO.askAmt = amtAdjVO.askAmt - amtAdjVO.setlAmt;
				amtAdjVO.setlAmt = 0;
			} else {
				amtAdjVO.adjAmt = amtAdjVO.askAmt;
				amtAdjVO.setlAmt -= amtAdjVO.askAmt;
				amtAdjVO.askAmt = 0;

				return amtAdjVO;
			}
		}
		return amtAdjVO;
	}
}
