package hanalife.r.co.rc.service.impl;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.RtRcptChkDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.service.RcptChkService;
import hanalife.r.co.rc.vo.ChkDescVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : RcptChkServiceImpl
 * 클래스설명 : 수표내역 ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptChkService")
public class RcptChkServiceImpl implements RcptChkService {

	private static final Logger log = LoggerFactory.getLogger(RcptChkServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>수표내역등록
	 * @param iamtUnrcvVOList
	 * @return
	 * @throws Exception
	 */
	@Override
	public int createRcptChkDescList(List iamtUnrcvVOList) {

		int exeCnt = 0;

		try {

			String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
			String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

			RtRcptChkDescDTO inDTO = new RtRcptChkDescDTO();

			ChkDescVO chkDescVO = null;

			for (int j = 0; j < iamtUnrcvVOList.size(); j++) {

				IamtUnrcvObjVO iamtUnrcvObj = (IamtUnrcvObjVO)iamtUnrcvVOList.get(j);

				for(int i=0; i < iamtUnrcvObj.sizeChkDescVO(); i++ ) {

					chkDescVO = iamtUnrcvObj.getChkDescVO(i);

					inDTO.setLoanNo(chkDescVO.loanNo);         				// 대출번호
					inDTO.setLoanSeq(chkDescVO.loanSeq);        			// 대출순번
					inDTO.setSetlNo(iamtUnrcvObj.setlNo);         			// 결제번호
					inDTO.setChkNo(chkDescVO.chkNo);          				// 수표번호
					inDTO.setSetlAmt(new BigDecimal(chkDescVO.setlAmt));    // 결제금액
					inDTO.setChkAmt(new BigDecimal(chkDescVO.chkAmt));      // 수표금액
					inDTO.setIssuBankCd(chkDescVO.issuBankCd);     			// 발행은행코드
					inDTO.setIssuBrnchCd(chkDescVO.issuBrnchCd);    		// 발행지점코드
					inDTO.setIssuDt(chkDescVO.issuDt);         				// 발행일자
					inDTO.setChkCnfmNo(chkDescVO.chkCnfmNo);        		// 수표확인번호
					inDTO.setCnclFg(chkDescVO.cnclFg);           			// 취소여부
					inDTO.setCnclDt(chkDescVO.cnclDt);         				// 취소일자
					inDTO.setChkReadman(chkDescVO.chkReadman);     			// 수표조회자
					inDTO.setIvltRegFg(chkDescVO.ivltRegFg);      			// 강제등록여부
					inDTO.setRmrk(chkDescVO.rmrk);           				// 비고
					inDTO.setFrstRegDt(procDt);      						// 최초등록일자
					inDTO.setFrstRegTm(procTm);      						// 최초등록시각
					inDTO.setFrstRegEmpNo(iamtUnrcvObj.frstRegEmpNo);   	// 최초등록사원번호
					inDTO.setLastProcDt(procDt);     						// 최종처리일자
					inDTO.setLastProcTm(procTm);     						// 최종처리시각
					inDTO.setLastProcEmpNo(iamtUnrcvObj.frstRegEmpNo);  	// 최종처리사원번호

					exeCnt += iamtUnrcvMapper.insertRcptChkDesc(inDTO);

				}
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수표내역 생성실패", se);
			throw new BizException("수표내역 생성실패", se);
		}

		return exeCnt;
	}

	/**
	 * TODO 미사용
	 * <p>기 납부한 수표리스트를 조회한다.
	 * @param loanNo
	 * @param loanSeq
	 * @param orgSetlNo
	 * @param setlNo
	 * @return
	 * @throws Exception
	 */
	/*
	@Override
	public List searchRcptChkDescList(String loanNo, String loanSeq, int orgSetlNo, int setlNo) {

		RtRcptChkDescDTO inDTO = new RtRcptChkDescDTO();
		List<ChkDescVO> result = new ArrayList<ChkDescVO>();

		inDTO.setLoanNo(loanNo);				//대출_번호
		inDTO.setLoanSeq(loanSeq);			//대출_순번
		inDTO.setSetlNo(orgSetlNo);			//결제_번호

		try {
			 List<RtRcptChkDescDTO> outListDTO = iamtUnrcvMapper.selectChkDesc(inDTO);

			 for(RtRcptChkDescDTO sourceIO : outListDTO) {
				 ChkDescVO chkDescVO = new ChkDescVO();
				 chkDescVO.loanNo        = sourceIO.getLoanNo();        //대출_번호
				 chkDescVO.loanSeq       = sourceIO.getLoanSeq();       //대출_순번
				 chkDescVO.setlNo        = Long.valueOf(sourceIO.getSetlNo()).intValue(); //결제_번호
				 chkDescVO.chkNo         = sourceIO.getChkNo();         //수표_번호
				 chkDescVO.setlAmt       = sourceIO.getSetlAmt().longValue();       //수표_금액
				 chkDescVO.chkAmt        = sourceIO.getChkAmt().longValue();        //수표_금액
				 chkDescVO.issuBankCd    = sourceIO.getIssuBankCd();    //발행_은행_코드
				 chkDescVO.issuBrnchCd   = sourceIO.getIssuBrnchCd();   //발행_지점_코드
				 chkDescVO.issuDt        = sourceIO.getIssuDt();        //발행_일자
				 chkDescVO.chkCnfmNo     = sourceIO.getChkCnfmNo();     //수표_확인_번호
				 chkDescVO.cnclFg        = sourceIO.getCnclFg();        //취소_여부
				 chkDescVO.cnclDt        = sourceIO.getCnclDt();        //취소_일자
				 chkDescVO.regDt         = sourceIO.getFrstRegDt();     //최초_등록_일자
				 chkDescVO.regEmpNo      = sourceIO.getFrstRegEmpNo();  //최초_등록_사원번호

				 chkDescVO.chkReadman    = sourceIO.getChkReadman();    //수표조회자
				 chkDescVO.ivltRegFg     = sourceIO.getIvltRegFg();     //강제등록여부
				 chkDescVO.rmrk          = sourceIO.getRmrk();          //비고

				 result.add(chkDescVO);
			 }
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수표내역 조회실패", se);
			throw new BizException("수표내역 조회실패", se);
		}

		return result;
	}
	*/
}
