package hanalife.r.co.rc.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.RtRcptDsrcBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptDsrcDescDTO;
import hanalife.c.co.mapper.dto.RtRcptRfndDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.SelectOccrDsrcINDTO;
import hanalife.r.co.rc.mapper.dto.SelectOccrDsrcOUTDTO;
import hanalife.r.co.rc.mapper.dto.SelectRcptDsrcBasePkINDTO;
import hanalife.r.co.rc.mapper.dto.SelectRcptDsrcBasePkOUTDTO;
import hanalife.r.co.rc.service.RcptDsrcService;
import hanalife.r.co.rc.vo.DsrcBaseVO;
import hanalife.r.co.rc.vo.DsrcDescVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : RcptDsrcServiceImpl
 * 클래스설명 : RcptDsrcServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptDsrcService")
public class RcptDsrcServiceImpl implements RcptDsrcService {

	private static final Logger log = LoggerFactory.getLogger(RcptDsrcServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>메소드명 : searchOccrDsrc</p>
	 * <p>설명 : 발생 예가수정보를 조회한다. </p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드인수2 : IamtUnrcvObjVO</p>
	 * <p>메소드리턴값 : List </p>
	 */
	@Override
	public List searchOccrDsrc(String dsrcNo, IamtUnrcvObjVO iamtUnrcvObjVO) {

		List result = null;

		SelectOccrDsrcINDTO inDTO = new SelectOccrDsrcINDTO();

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);			//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq); 		//대출_순번
		inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo); 	//원_결제_번호

		try {
			SelectOccrDsrcOUTDTO outDTO = iamtUnrcvMapper.selectOccrDsrc(inDTO);

			if(outDTO != null) {
				result = new ArrayList(2);

				DsrcBaseVO dsrcBaseVO = new DsrcBaseVO();
				DsrcDescVO dsrcDescVO = new DsrcDescVO();

				int i = 1;
				dsrcBaseVO.dsrcOccrAmt = outDTO.getDsrcOccrAmt();	// 임시_예가수_발생_금액
				dsrcBaseVO.dsrcRamt = outDTO.getDsrcRamt(); 		// 임시_예가수_잔액
				dsrcDescVO.dsrcAdjAmt = outDTO.getDsrcAdjAmt(); 	// 임시_예가수_정산_금액
				dsrcBaseVO.dsrcSnum = outDTO.getDsrcSnum(); 		// 임시_예가수_일련번호
				dsrcBaseVO.rfndSnum = outDTO.getRfndSnum(); 		// 임시_환불_일련번호
				dsrcBaseVO.rfndStatCd = outDTO.getRfndStatCd(); 	// 임시_환불_상태_코드
				dsrcBaseVO.dsrcOccrCd = outDTO.getDsrcOccrCd(); 	// 예가수발생코드

				result.add(dsrcBaseVO);
				result.add(dsrcDescVO);
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("발생 예가수조회실패", se);
			throw new BizException("발생 예가수조회실패", se);
		}

		return result;
	}

	/**
	 * <p>메소드명 : createRcptDsrcDesc</p>
	 * <p>설명 : [수납_예가수_내역]등록 </p>
	 * <p>메소드인수1 : List dsrcDescVOList</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int createRcptDsrcDesc(List dsrcDescVOList) {

		int exeCnt = 0;

		String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

		int cnt = 0;
		DsrcDescVO dsrcDescVO = null;

		for (int i = 0; i < dsrcDescVOList.size(); i++) {

			RtRcptDsrcDescDTO inDTO = new RtRcptDsrcDescDTO();
			dsrcDescVO = (DsrcDescVO) dsrcDescVOList.get(i);

			inDTO.setDsrcNo(dsrcDescVO.dsrcNo);            //예가수_번호
			inDTO.setDsrcSnum(dsrcDescVO.dsrcSnum);        //예가수_일련번호
			inDTO.setLoanNo(dsrcDescVO.loanNo);            //대출_번호
			inDTO.setLoanSeq(dsrcDescVO.loanSeq);          //대출_순번
			inDTO.setSetlNo(dsrcDescVO.setlNo);            //결제_번호
			inDTO.setRcptTpCd(dsrcDescVO.rcptTpCd);        //수납_유형_코드
			inDTO.setAcctDt(dsrcDescVO.acctDt);            //회계_일자
			inDTO.setDsrcOccrCd(dsrcDescVO.dsrcOccrCd);    //예가수_발생_코드
			inDTO.setDsrcAdjCd(dsrcDescVO.dsrcAdjCd);      //예가수_정산_코드
			inDTO.setSetlDt(dsrcDescVO.setlDt);            //결제일자
			inDTO.setDsrcOccrAmt(new BigDecimal(dsrcDescVO.dsrcOccrAmt));  //예가수_발생_금액
			inDTO.setDsrcRamt(new BigDecimal(dsrcDescVO.dsrcRamt));        //예가수_잔액
			inDTO.setDsrcAdjAmt(new BigDecimal(dsrcDescVO.dsrcAdjAmt));    //예가수_정산_금액
			inDTO.setIsrtDeptCd(dsrcDescVO.isrtDeptCd);    //입력_부서_코드
			inDTO.setAdjDeptCd(dsrcDescVO.adjDeptCd);      //정산_부서_코드
			inDTO.setRmk(dsrcDescVO.rmk);                  //적요
			inDTO.setCnclFg(dsrcDescVO.cnclFg);            //취소_여부
			inDTO.setCnclDt(dsrcDescVO.cnclDt);            //취소_일자
			inDTO.setCustNo(dsrcDescVO.custNo);            //고객_번호
			inDTO.setFrstRegDt(procDt);                    //최초등록일자
			inDTO.setFrstRegTm(procTm);                    //최초등록시각
			inDTO.setFrstRegEmpNo(dsrcDescVO.procEmpNo);   //최초등록자사번
			inDTO.setLastProcDt(procDt);                   //최종처리일자
			inDTO.setLastProcTm(procTm);                   //최종처리일
			inDTO.setLastProcEmpNo(dsrcDescVO.procEmpNo);  //최종처리자

			try {
				exeCnt += iamtUnrcvMapper.insertDsrcDesc(inDTO);
			} catch (Exception se) {
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납연체내역 수정실패(부분취소)", se);
				throw new BizException("수납연체내역 수정실패(부분취소)", se);
			}
		}
		return exeCnt;
	}

	/**
	 * <p>메소드명 : createRcptDsrcDescForCncl</p>
	 * <p>설명 : 입금미수.대상 객체에 예가수_내역을 등록한다.</p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드인수1 : IamtUnrcvObjVO</p>
	 * <p>메소드인수1 : DsrcBaseVO</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int createRcptDsrcDescForCncl(String dsrcNo, IamtUnrcvObjVO iamtUnrcvObjVO, DsrcBaseVO dsrcBaseVO,
			DsrcDescVO dsrcDescVO) {
		int exeCnt = 0;

		RtRcptDsrcDescDTO inDTO = new RtRcptDsrcDescDTO();

		inDTO.setDsrcSnum(dsrcBaseVO.dsrcSnum);
		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setDsrcRamt(new BigDecimal(dsrcBaseVO.dsrcRamt));
		inDTO.setDsrcAdjAmt(new BigDecimal(dsrcDescVO.dsrcAdjAmt));
		inDTO.setIsrtDeptCd(iamtUnrcvObjVO.isrtDeptCd);
		inDTO.setAdjDeptCd(iamtUnrcvObjVO.adjDeptCd);
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);		// 대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	// 대출_순번
		inDTO.setDsrcNo(dsrcNo);					// 예가수_번호
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);	// 결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreateRcptDsrcDesc(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수내역 생성실패(취소)", se);
			throw new BizException("예가수내역 생성실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명 : createDsrcBase</p>
	 * <p>설명 : [수납_예가수_기본]등록</p>
	 * <p>메소드인수1 : List dsrcBaseVOList</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int createDsrcBase(List dsrcBaseVOList) {

		int exeCnt = 0;
		DsrcBaseVO dsrcBaseVO = null;

		String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

		for (int i = 0; i < dsrcBaseVOList.size(); i++) {

			RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();
			dsrcBaseVO = (DsrcBaseVO) dsrcBaseVOList.get(i);

			inDTO.setDsrcNo(dsrcBaseVO.dsrcNo);             //예가수_번호
			inDTO.setOccrLoanNo(dsrcBaseVO.occrLoanNo);     //발생_대출_번호
			inDTO.setOccrLoanSeq(dsrcBaseVO.occrLoanSeq);   //발생_대출_순번
			inDTO.setSetlNo(dsrcBaseVO.setlNo);             //결제_번호
			inDTO.setRcptTpCd(dsrcBaseVO.rcptTpCd);         //수납_유형_코드
			inDTO.setAcctDt(dsrcBaseVO.acctDt);             //회계_일자
			inDTO.setDsrcOccrCd(dsrcBaseVO.dsrcOccrCd);     //예가수_발생_코드
			inDTO.setSetlDt(dsrcBaseVO.setlDt);             //결제일자
			inDTO.setDsrcOccrAmt(new BigDecimal(dsrcBaseVO.dsrcOccrAmt));   //예가수_발생_금액
			inDTO.setDsrcRamt(new BigDecimal(dsrcBaseVO.dsrcRamt));         //예가수_잔액
			inDTO.setUnCnfmFg(dsrcBaseVO.unCnfmFg);         //미_확인_여부
			inDTO.setRfndSnum(dsrcBaseVO.rfndSnum);         //환불_일련번호
			inDTO.setDsrcSnum(dsrcBaseVO.dsrcSnum);         //예가수_일련번호
			inDTO.setRfndStatCd(dsrcBaseVO.rfndStatCd);     //환불_상태_코드
			inDTO.setAdjLoanNo(dsrcBaseVO.adjLoanNo);       //정산_대출_번호
			inDTO.setAdjLoanSeq(dsrcBaseVO.adjLoanSeq);     //정산_대출_순번
			inDTO.setRmk(dsrcBaseVO.rmk);                   //적요
			inDTO.setIsrtDeptCd(dsrcBaseVO.isrtDeptCd); 	//입력_부서_코드
			inDTO.setAdjDeptCd(dsrcBaseVO.adjDeptCd);   	//정산_부서_코드

			inDTO.setFrstRegDt(procDt);                    //최초등록일자
			inDTO.setFrstRegTm(procTm);                    //최초등록시각
			inDTO.setFrstRegEmpNo(dsrcBaseVO.procEmpNo);   //최초등록자사번
			inDTO.setLastProcDt(procDt);                   //최종처리일자
			inDTO.setLastProcTm(procTm);                   //최종처리일
			inDTO.setLastProcEmpNo(dsrcBaseVO.procEmpNo);  //최종처리자

			try {
				exeCnt += iamtUnrcvMapper.insertDsrcBase(inDTO);
			} catch (Exception se) {
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수기본 생성실패", se);
				throw new BizException("예가수기본 생성실패", se);
			}
		}
		return exeCnt;

	}

	/**
	 * <p>메소드명 : updateDsrcBase</p>
	 * <p>설명 : [수납_예가수_기본]수정</p>
	 * <p>메소드인수1 : List dsrcUpdtVOList</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int updateDsrcBase(List dsrcUpdtVOList) {

		int exeCnt = 0;
		DsrcBaseVO dsrcBaseVO = null;

		String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

		for (int i = 0; i < dsrcUpdtVOList.size(); i++) {

			RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();
			dsrcBaseVO = (DsrcBaseVO) dsrcUpdtVOList.get(i);

			inDTO.setDsrcRamt(new BigDecimal(dsrcBaseVO.dsrcRamt));	// 예가수_잔액
			inDTO.setAdjDeptCd(dsrcBaseVO.adjDeptCd);		// 정산_부서_코드
			inDTO.setAdjLoanNo(dsrcBaseVO.adjLoanNo);   	// 정산_대출_번호
			inDTO.setAdjLoanSeq(dsrcBaseVO.adjLoanSeq); 	// 정산_대출_순번
			inDTO.setDsrcSnum(dsrcBaseVO.dsrcSnum);     	// 예가수_일련번호
			inDTO.setLastProcDt(procDt);                   	// 최종처리일자
			inDTO.setLastProcTm(procTm);                   	// 최종처리일
			inDTO.setLastProcEmpNo(dsrcBaseVO.procEmpNo);  	// 최종처리자
			inDTO.setDsrcNo(dsrcBaseVO.dsrcNo);				// 정산_부서_코드

			try {
				exeCnt += iamtUnrcvMapper.updateRcptDsrcBase(inDTO);
			} catch (Exception se) {
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수기본 수정실패", se);
				throw new BizException("예가수기본 수정실패", se);
			}
		}
		return exeCnt;

	}

	/**
	 * <p>메소드명 : updateRcptDsrcBaseForCncl</p>
	 * <p>설명 : 입금미수.대상에 대해 예가수 잔액을 수정한다.</p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드인수2 : IamtUnrcvObjVO</p>
	 * <p>메소드인수3 : DsrcBaseVO</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int updateRcptDsrcBaseForCncl(String dsrcNo, IamtUnrcvObjVO iamtUnrcvObjVO, DsrcBaseVO dsrcBaseVO) {

		int exeCnt = 0;

		RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();

		inDTO.setDsrcRamt(new BigDecimal(dsrcBaseVO.dsrcRamt));	// 대출_번호
		inDTO.setDsrcSnum(dsrcBaseVO.dsrcSnum);					// 대출_순번
		inDTO.setAdjDeptCd(iamtUnrcvObjVO.adjDeptCd);			// 결제_번호
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);		// 결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDsrcBaseForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수기본 수정실패(취소)", se);
			throw new BizException("예가수기본 수정실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명 : updateRcptRfndDescForCncl</p>
	 * <p>설명 : 입금미수.대상에 대해 예가수 잔액을 수정한다.</p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드인수2 : IamtUnrcvObjVO</p>
	 * <p>메소드인수3 : DsrcBaseVO</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int updateRcptRfndDescForCncl(String dsrcNo, IamtUnrcvObjVO iamtUnrcvObjVO, DsrcBaseVO dsrcBaseVO) {

		int exeCnt = 0;

		RtRcptRfndDescDTO inDTO = new RtRcptRfndDescDTO();

		//set
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setDsrcSnum(dsrcBaseVO.dsrcSnum);
		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		//where
		inDTO.setRfndLoanNo(iamtUnrcvObjVO.loanNo);
		inDTO.setRfndLoanSeq(iamtUnrcvObjVO.loanSeq);
		inDTO.setDsrcNo(dsrcNo);
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);

		try {
			exeCnt = iamtUnrcvMapper.updateRcptRfndDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("환불내역 수정실패(취소)", se);
			throw new BizException("환불내역 수정실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명 : searchDsrcBase</p>
	 * <p>설명 : 예가수 발생금액 확인</p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public DsrcBaseVO searchDsrcBase(String dsrcNo) {

		DsrcBaseVO dsrcBaseVO = null;

		SelectRcptDsrcBasePkINDTO inDTO = new SelectRcptDsrcBasePkINDTO();

		inDTO.setDsrcNo(dsrcNo);

		try {
			SelectRcptDsrcBasePkOUTDTO outDTO = iamtUnrcvMapper.selectRcptDsrcBasePk(inDTO);

			if(outDTO != null) {

				dsrcBaseVO.dsrcOccrAmt = outDTO.getDsrcOccrAmt();
				dsrcBaseVO.dsrcRamt = outDTO.getDsrcRamt();
				dsrcBaseVO.adjDeptCd = outDTO.getAdjDeptCd();
				dsrcBaseVO.rfndStatCd = outDTO.getRfndStatCd();
				dsrcBaseVO.dsrcOccrCd = outDTO.getDsrcOccrCd();
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수기본 조회실패", se);
			throw new BizException("예가수기본 조회실패", se);
		}

		return dsrcBaseVO;
	}

	/**
	 * <p>메소드명 : updateRcptDsrcDescForCncl</p>
	 * <p>설명 : 예가수내역에 대해 취소처리한다.</p>
	 * <p>      입금미수.대상 객체에 대하여 수납_예가수_내역을 수정한다.</p>
	 * <p>메소드인수1 : String dsrcNo</p>
	 * <p>메소드인수2 : IamtUnrcvObjVO</p>
	 * <p>메소드리턴값 : int </p>
	 */
	@Override
	public int updateRcptDsrcDescForCncl(String dsrcNo, IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptDsrcDescDTO inDTO = new RtRcptDsrcDescDTO();

		//set
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);
		inDTO.setDsrcNo(dsrcNo);
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDsrcDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("예가수내역 수정실패(취소)", se);
			throw new BizException("예가수내역 수정실패(취소)", se);
		}

		return exeCnt;
	}

}
