package hanalife.r.co.rc.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.BtBndClsBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.SelectCnclObjCondINDTO;
import hanalife.r.co.rc.mapper.dto.SelectCnclObjCondOUTDTO;
import hanalife.r.co.rc.mapper.dto.SelectCnclObjINDTO;
import hanalife.r.co.rc.mapper.dto.SelectCnclObjOUTDTO;
import hanalife.r.co.rc.mapper.dto.SelectObjINDTO;
import hanalife.r.co.rc.mapper.dto.SelectObjOUTDTO;
import hanalife.r.co.rc.mapper.dto.SelectRcptDescExistINDTO;
import hanalife.r.co.rc.service.RcptRCService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.RcptBaseVO;
import hanalife.r.co.rc.vo.RcptDescVO;
import hanalife.s.ln.ch.vo.MidPartRmbrObj;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : RcptServiceImpl
 * 클래스설명 : 입금미수 수납관련 쿼리를 수행하는 ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptRCService")
public class RcptRCServiceImpl implements RcptRCService {

	private static final Logger log = LoggerFactory.getLogger(RcptRCServiceImpl.class);

	@Autowired
	private static IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>메소드명	: searchIamtUnrcvObj</p>
	 * <p>설　　명	: 입금대상(요청)에 추가로 DB에서 얻은 정보 셋팅</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: N/A</p>
	 */
	@Override
	public IamtUnrcvObjVO searchIamtUnrcvObj(IamtUnrcvObjVO inObj) {

		try {
			SelectObjINDTO inDTO = new SelectObjINDTO();

			inDTO.setSetlDt(inObj.setlDt);
			inDTO.setRcptTpCd(inObj.rcptTpCd);
			inDTO.setFrstRegEmpNo(inObj.frstRegEmpNo);
			inDTO.setIsrtDeptCd(inObj.isrtDeptCd);
			inDTO.setAcctDt(inObj.acctDt);
			inDTO.setCustNo(inObj.custNo);
			inDTO.setSetlDivCd(inObj.setlDivCd);
			inDTO.setRcptTpCd(inObj.rcptTpCd);
			inDTO.setLoanNo(inObj.loanNo);
			inDTO.setLoanSeq(inObj.loanSeq);

			SelectObjOUTDTO outDTO = iamtUnrcvMapper.selectObj(inDTO);

			if(outDTO != null) {
				//대출 -> [대출기본] 대출번호가 대출에 없을때 [미확인기본]의 디폴트값을 얻는다.
				inObj.setlNo = outDTO.getSetlNo(); //결제_번호(대출기본.결제번호 + 1)
				inObj.prdtCd = StringUtil.trim(outDTO.getPrdtCd()); //상품_코드
				inObj.loanDt = StringUtil.trim(outDTO.getLoanDt()); //대출_일자
				inObj.loanApplDt = StringUtil.trim(outDTO.getApplDt());  //신청일자
				inObj.prdtLrgeClasCd = StringUtil.trim(outDTO.getPrdtLrgeClasCd()); //상품_대분류_코드
				inObj.prdtMidClasCd  = StringUtil.trim(outDTO.getPrdtMidClasCd());  //상품_중분류_코드
				inObj.prdtSmClasCd   = StringUtil.trim(outDTO.getPrdtSmClasCd());   //상품_소분류_코드
				inObj.godsCd = StringUtil.trim(outDTO.getGodsCd()); //물품_코드( 대출물품내역.물품코드)
				inObj.trTpCd = StringUtil.trim(outDTO.getTrTpCd()); //거래_유형_코드( 공통코드-R00012,key:대상.수납유형코드)
				//2018-08-01 주성용 관리회계단위코드 얻기
				//inObj.acctUnitCd = StringUtil.trim(outDTO.getACCT_UNIT_CD"); //회계_단위_코드 (유동화_구분코드 + 유동화_차수)
				inObj.mngAcctUnitCd = StringUtil.trim(outDTO.getMngAcctUnitCd()); //관리_회계_단위_코드 (유동화_구분코드 + 유동화_차수)
				inObj.loanIntRt  = outDTO.getLoanIntRt(); //대출_이자율
				inObj.loanStatCd = StringUtil.trim(outDTO.getLoanStatCd()); //대출_상태_코드
				inObj.bndStatCd  = StringUtil.trim(outDTO.getBndStatCd()); //채권_상태_코드( 채권마감.채권상태코드)
				inObj.bndDivsEmpNo = StringUtil.trim(outDTO.getBndDivsEmpNo()); //채권_담당_사원번호
				inObj.mngDeptCd  = StringUtil.trim(outDTO.getMngDeptCd()); //관리_부서_코드 (or 대상.입력부서코드 )
				inObj.unCnfmFg   = StringUtil.trim(outDTO.getUnCnfmFg()); //미_확인_여부
				inObj.isrtDt     = StringUtil.trim(outDTO.getIsrtDt()); //입력_일자 (현재일자)
				inObj.rcntSetlDt = StringUtil.trim(outDTO.getRcntSetlDt()); //최근_결제_일자(수납기본에 최근결제건의 결제일자)
				inObj.rcntAcctDt = StringUtil.trim(outDTO.getRcntAcctDt()); //최근_회계_일자(수납기본에 최근결제건의 회계일자)
				inObj.endDt      = StringUtil.trim(outDTO.getEndDt());
				inObj.curCpayTims = outDTO.getCurCpayTims(); //대출.완납회차
				inObj.bfSaleDt   = StringUtil.trim(outDTO.getBfSaleDt()); //2018-08-01 두비스 직전영업일자
				inObj.rsltCnclDt = StringUtil.trim(outDTO.getRsltCnclDt()); //2018-08-01 두비스 추가
				inObj.custNo     = outDTO.getCustNo();	//입력.고객번호 or 대출.고객번호
				inObj.setlDivNm  = StringUtil.trim(outDTO.getSetlDivNm());	//결제구분명
				inObj.moBankCd   = StringUtil.nvl(inObj.moBankCd, StringUtil.trim(outDTO.getMoBankCd()));	//입력된 값 없을때 모계좌_은행_코드
			}
			else {
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException(inObj, "대출원장에 대출정보가 존재하지 않습니다.");
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("입금정보 조회실패", se);
			throw new BizException("입금정보 조회실패", se);
		}

		return inObj;
	}

	/**
	 * <p>메소드명	: setCnclObj</p>
	 * <p>설　　명	: 취소대상구성</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: N/A</p>
	 */
	@Override
	public IamtUnrcvObjVO setCnclObj(IamtUnrcvObjVO inObj) {
		try {
			SelectCnclObjINDTO inDTO = new SelectCnclObjINDTO();

			inDTO.setGodsCd("");
			inDTO.setIsrtDeptCd(inObj.isrtDeptCd);
			inDTO.setLoanNo(inObj.loanNo);
			inDTO.setLoanSeq(inObj.loanSeq);
			inDTO.setAcctDt(inObj.acctDt);
			inDTO.setOrgSetlNo(inObj.orgSetlNo);

			SelectCnclObjOUTDTO outDTO = iamtUnrcvMapper.selectCnclObj(inDTO);

			if(outDTO != null) {
				//입금미수.대상.각항목 = 검색.각항목
				inObj.setlNo = outDTO.getSetlNo() + 1; //결제_번호( 대출기본.결제번호 or 수납기본.max결제번호) + 1
				inObj.prdtCd = StringUtil.trim(outDTO.getPrdtCd()); //상품_코드
				inObj.loanDt = StringUtil.trim(outDTO.getLoanDt()); //대출_일자 (대출기본.대출_일자, 수납기본.결제_일자)
				inObj.prdtLrgeClasCd = StringUtil.trim(outDTO.getPrdtLrgeClasCd()); //상품_대분류_코드
				inObj.prdtMidClasCd  = StringUtil.trim(outDTO.getPrdtMidClasCd()); //상품_중분류_코드
				inObj.prdtSmClasCd   = StringUtil.trim(outDTO.getPrdtSmClasCd()); //상품_소분류_코드
				inObj.godsCd = StringUtil.trim(outDTO.getGodsCd()); //물품_코드
				inObj.trTpCd = StringUtil.trim(outDTO.getTrTpCd()); //거래_유형_코드( R00012 + 수납기본.수납유형코드 or 입력)
				inObj.trSnum = outDTO.getTrSnum(); //수납기본.거래순번
				inObj.mngAcctUnitCd = StringUtil.trim(outDTO.getMngAcctUnitCd()); //회계_단위_코드( 대출기본.유동화구분코드 +유동화차수 or 입력)

				inObj.loanStatCd = StringUtil.trim(outDTO.getLoanStatCd()); //대출_상태_코드 (대출기본.대출상태코드 or 수납기본.대출상태코드)
				inObj.bndStatCd = StringUtil.trim(outDTO.getBndStatCd()); //채권_상태_코드 (채권마감기본.채권상태코드 or 수납기본.채권상태코드)
				inObj.bndDivsEmpNo = StringUtil.trim(outDTO.getBndDivsEmpNo()); //채권_담당자 (대출기본.채권담당자 or 수납기본.채권담당자 )
				inObj.mngDeptCd = StringUtil.trim(outDTO.getMngDeptCd()); //관리_부서_코드 ( 대출기본.관리부서 or 입력 )
				inObj.orgIsrtDeptCd = StringUtil.trim(outDTO.getOrgIsrtDeptCd()); //원입력부서코드 ( 수납기본.입력부서 )
				inObj.rcptTpCd = StringUtil.trim(outDTO.getRcptTpCd()); //수납_유형_코드 (수납기본.수납유형코드)
				inObj.setlDt = StringUtil.trim(outDTO.getSetlDt()); //결제_일자 (수납기본.결제일자)
				inObj.setlDivCd = StringUtil.trim(outDTO.getSetlDivCd()); //결제_구분코드(수납기본.결제구분코드)
				inObj.dsrcNo = StringUtil.trim(outDTO.getDsrcNo()); //예가수_번호 (수납기본.예가수번호)
				inObj.nmChngDsrcNo = StringUtil.trim(outDTO.getNmChngDsrcNo()); //예가수_번호 (수납기본.명의이전예가수번호)

				inObj.carsSellDsrcNo = StringUtil.trim(outDTO.getCarsSellDsrcNo()); //예가수_번호 (수납기본.차량매각예가수번호)
				inObj.unCnfmFg = StringUtil.trim(outDTO.getUnCnfmFg()); //미_확인_여부 (수납기본.미확인여부)
				inObj.isrtDt   = StringUtil.trim(outDTO.getIsrtDt()); //입력일자 (현재일자)
				inObj.orgAcctDt = StringUtil.trim(outDTO.getAcctDt()); //수납기본.회계일자
				inObj.setlAmt = outDTO.getSetlAmt(); //수납기본.결제금액)
				inObj.cashAmt = outDTO.getCashAmt(); //수납기본.현금금액
				inObj.chkAmt  = outDTO.getChkAmt(); //수납기본.수표금액
				inObj.curLoanStatCd = StringUtil.trim(outDTO.getCurLoanStatCd()); //대출기본.대출상태코드
				inObj.endDt = StringUtil.trim(outDTO.getEndDt()); //대출기본.대출종료일자
				inObj.orgRcptStrtTims = outDTO.getRcptStrtTims(); //수납기본.수납시작회차

				inObj.curCpayTims = outDTO.getCurCpayTims(); //대출기본.완납회차
				inObj.exmpConsNo = StringUtil.trim(outDTO.getExmpConsNo());	//면제품의번호
				inObj.rsltCnclDt = StringUtil.trim(outDTO.getRsltCnclDt());	//결과취소일자
				inObj.cnclFg = Constants.YES;
				inObj.extsDt = StringUtil.trim(outDTO.getExtsDt());				//유예일자
				inObj.bfmmLastDt = StringUtil.trim(outDTO.getBfmmLastDt());	//전월말일
				inObj.bankCd = StringUtil.trim(outDTO.getBankCd());	//은행코드
				inObj.acntNo = StringUtil.trim(outDTO.getAcntNo());	//계좌번호

			}
			else {
				//이미 취소 되었거나 취소대상이 존재하지 않습니다.
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtExceptionByErrCd(inObj, "0005");
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("취소대상 조회실패", se);
			throw new BizException("취소대상 조회실패", se);
		}

		return inObj;
	}

	/**
	 * <p>메소드명	: searchCnclCond</p>
	 * <p>설    명	: 취소조건조회</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: RcptBaseVO</p>
	 */

	@Override
	public RcptBaseVO searchCnclCond(IamtUnrcvObjVO iamtUnrcvObjVO) {

		SelectCnclObjCondINDTO inDTO = new SelectCnclObjCondINDTO();
		RcptBaseVO rcptBaseVO = null;

		try {

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);			// 대출_번호
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);		// 대출_순번
			inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);	// 원_결제_번호

			SelectCnclObjCondOUTDTO outDTO = iamtUnrcvMapper.getSelectCnclObjCond(inDTO);

			if(outDTO != null) {
				rcptBaseVO = new RcptBaseVO();
				rcptBaseVO.loanNo                 = outDTO.getLoanNo();
				rcptBaseVO.loanSeq                = outDTO.getLoanSeq();
				rcptBaseVO.cnclFg                 = outDTO.getCnclFg();
				rcptBaseVO.isrtDeptCd             = outDTO.getIsrtDeptCd();
				rcptBaseVO.dsrcNo                 = outDTO.getDsrcNo();
				rcptBaseVO.dsrcOccrAmt            = outDTO.getDsrcOccrAmt();
				rcptBaseVO.dsrcAdjAmt             = outDTO.getDsrcAdjAmt();
				rcptBaseVO.setlDivCd              = outDTO.getSetlDivCd();
				rcptBaseVO.rcptTpCd               = outDTO.getRcptTpCd();
				rcptBaseVO.leglActnCost           = outDTO.getLeglActnCost();
				rcptBaseVO.setlFrstRank           = outDTO.getSetlFrstRank();
				rcptBaseVO.trSnum                 = outDTO.getTrSnum();
				rcptBaseVO.loanStatCd             = outDTO.getLoanStatCd();
				rcptBaseVO.dsrcAdjCd              = outDTO.getDsrcAdjCd();
				rcptBaseVO.dsrcOccrCd             = outDTO.getDsrcOccrCd();
				rcptBaseVO.dmscDeptCd             = outDTO.getDmscDeptCd();
				rcptBaseVO.mngDeptCd              = outDTO.getMngDeptCd();
				rcptBaseVO.rcptPamt               = outDTO.getRcptPamt();
				rcptBaseVO.rcptIpayCartax         = outDTO.getRcptIpayCartax();
				rcptBaseVO.rcptIpayEnvImprBrdnamt = outDTO.getRcptIpayEnvImprBrdnamt();
				rcptBaseVO.rcptIpayPnltAmt        = outDTO.getRcptIpayPnltAmt();
				rcptBaseVO.rcptIpayEtc            = outDTO.getRcptIpayEtc();
				rcptBaseVO.setlDt                 = outDTO.getSetlDt();
				rcptBaseVO.acctDt                 = outDTO.getAcctDt();
				rcptBaseVO.partCnclCd             = outDTO.getPartCnclCd();
				rcptBaseVO.setlNo                 = outDTO.getSetlNo();
				rcptBaseVO.guarAmt                = outDTO.getGuarAmt();
				rcptBaseVO.ltrmBrcvAmt            = outDTO.getLtrmBrcvAmt();
				rcptBaseVO.prdtMidClasCd          = outDTO.getPrdtMidClasCd();
				rcptBaseVO.stmpFee                = outDTO.getStmpFee();
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("취소정보 조회실패", se);
			throw new BizException("취소정보 조회실패", se);
		}

		return rcptBaseVO;
	}

	/**
	 * <p>메소드명	: cnfmRcptDesc</p>
	 * <p>설　　명	: 취소대상 수납확인</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: boolean - 취소대상 존재여부</p>
	 */
	@Override
	public boolean cnfmRcptDesc(IamtUnrcvObjVO iamtUnrcvObjVO) {

		SelectRcptDescExistINDTO inDTO = new SelectRcptDescExistINDTO();
		boolean bRtn = false;

		try {

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);
			inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);
			inDTO.setCnclFg("0"); // 취소여부

			String sExist = iamtUnrcvMapper.selectRcptDescExist(inDTO);

			if(Constants.YES.equals(sExist)) {
				bRtn = true;
			}


		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("취소대상 조회실패", se);
			throw new BizException("취소대상 조회실패", se);
		}

		return bRtn;
	}

	/**
	 * TODO 미사용
	 * <p>메소드명	: hasDueDtBfExstDt</p>
	 * <p>설　　명	: 유예일자이전 납입일자 존재여부 체크</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: boolean - 유예일자이전 납입일자 존재여부</p>
	 */
	/*
	@Override
	public boolean hasDueDtBfExstDt(IamtUnrcvObjVO iamtUnrcvObjVO) {

	}
	*/

	/**
	 * <p>메소드명	: createRcptBase</p>
	 * <p>설　　명	: [수납_기본]등록 (단건)</p>
	 * <p>메소드인수	: trDescNo, RcptBaseVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int createRcptBase(int trDescNo, RcptBaseVO rcptBaseVO) {
		List inVOList = new ArrayList(1);
		inVOList.add(rcptBaseVO);
		return createRcptBase(trDescNo,inVOList);
	}

	/**
	 * <p>메소드명	: createRcptBase</p>
	 * <p>설　　명	: [수납_기본]등록 (여러건)</p>
	 * <p>메소드인수	: trDescNo, List rcptBaseVOList - 등록할 RcptBaseVO의 리스트</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int createRcptBase(int trDescNo, List rcptBaseVOList) {
		int rcptSize = rcptBaseVOList.size();
		if (rcptSize<1) return 0;

		RcptBaseVO rcptBaseVO = null;
		int exeCnt = 0;
		RtRcptBaseDTO inDTO = new RtRcptBaseDTO();

		String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

		try {
			for (int i = 0; i < rcptSize; i++) {
				rcptBaseVO = (RcptBaseVO) rcptBaseVOList.get(i);

				inDTO.setLoanNo(rcptBaseVO.loanNo);                                        	//대출번호
				inDTO.setLoanSeq(rcptBaseVO.loanSeq);                                      	//상담/대출순번
				inDTO.setSetlNo(rcptBaseVO.setlNo);                                        	//결제_번호
				inDTO.setAcctDt(rcptBaseVO.acctDt);                                        	//회계_일자
				inDTO.setIsrtDt(rcptBaseVO.isrtDt);                                        	//입력_일자
				inDTO.setAcctUnitCd(rcptBaseVO.acctUnitCd);                                	//회계_단위_코드
				inDTO.setIsrtDeptCd(rcptBaseVO.isrtDeptCd);                                	//입력_부서_코드
				inDTO.setTrTpCd(rcptBaseVO.trTpCd);                                        	//거래_형태_코드
				inDTO.setTrSnum(trDescNo);                                               	//거래_일련번호(전표거래내역번호)
				inDTO.setPrdtCd(rcptBaseVO.prdtCd);                                        	//상품_코드
				inDTO.setPrdtLrgeClasCd(rcptBaseVO.prdtLrgeClasCd);                        	//상품_대분류_코드
				inDTO.setPrdtMidClasCd(rcptBaseVO.prdtMidClasCd);                          	//상품_중분류_코드
				inDTO.setPrdtSmClasCd(rcptBaseVO.prdtSmClasCd);                            	//상품_소분류_코드
				inDTO.setRcptTpCd(rcptBaseVO.rcptTpCd);                                    	//수납_유형_코드
				inDTO.setSetlDivCd(rcptBaseVO.setlDivCd);                                  	//결제_구분코드
				inDTO.setDsrcNo(rcptBaseVO.dsrcNo);                                        	//예가수_번호
				inDTO.setDsrcAdjCd(rcptBaseVO.dsrcAdjCd);                                  	//예가수_정산_코드
				inDTO.setDsrcOccrCd(rcptBaseVO.dsrcOccrCd);                                	//예가수_발생_코드
				inDTO.setSetlFrstRank(rcptBaseVO.setlFrstRank);                            	//결제_우선_순위
				inDTO.setSetlDt(rcptBaseVO.setlDt);                                        	//결제일자
				inDTO.setBankCd(rcptBaseVO.bankCd);                                        	//은행_코드
				inDTO.setAcntNo(rcptBaseVO.acntNo);                                        	//계좌_번호
				inDTO.setSetlAmt(new BigDecimal(rcptBaseVO.setlAmt));                   	//결제_금액
				inDTO.setDsrcAdjAmt(new BigDecimal(rcptBaseVO.dsrcAdjAmt));                 //예가수_정산_금액
				inDTO.setExmpConsNo(rcptBaseVO.exmpConsNo);                                	//면제_품의_번호
				inDTO.setExmpAmt(new BigDecimal(rcptBaseVO.exmpAmt));                       //면제_금액
				inDTO.setPdueDiscDfee(new BigDecimal(rcptBaseVO.pdueDiscDfee));             //선납_할인_연체료
				inDTO.setRcptAmt(new BigDecimal(rcptBaseVO.rcptAmt));                       //수납_금액
				inDTO.setCashAmt(new BigDecimal(rcptBaseVO.cashAmt));                       //현금_금액
				inDTO.setChkAmt(new BigDecimal(rcptBaseVO.chkAmt));                         //수표_금액
				inDTO.setRcptPamt(new BigDecimal(rcptBaseVO.rcptPamt));                     //수납_원금
				inDTO.setRcptInt(new BigDecimal(rcptBaseVO.rcptInt));                       //수납_이자
				inDTO.setRcptDfee(new BigDecimal(rcptBaseVO.rcptDfee));                     //수납_연체료
				inDTO.setLeglActnCost(new BigDecimal(rcptBaseVO.leglActnCost));             //법적조치_비용
				inDTO.setMidRmbrPamt(new BigDecimal(rcptBaseVO.midRmbrPamt));               //중도_상환_원금
				inDTO.setMidRmbrInt(new BigDecimal(rcptBaseVO.midRmbrInt));                 //중도_상환_이자
				inDTO.setMidRmbrFee(new BigDecimal(rcptBaseVO.midRmbrFee));                 //중도_상환_수수료
				inDTO.setTrtFeeDisc(rcptBaseVO.trtFeeDisc);                                	//취급_수수료_할인
				inDTO.setCrdtRcvrUnrcvAmt(new BigDecimal(rcptBaseVO.crdtRcvrUnrcvAmt));     //신용_회복_미수금
				inDTO.setExmpPamt(new BigDecimal(rcptBaseVO.exmpPamt));                     //면제_원금
				inDTO.setExmpInt(new BigDecimal(rcptBaseVO.exmpInt));                       //면제_이자
				inDTO.setExmpDfee(new BigDecimal(rcptBaseVO.exmpDfee));                     //면제_연체료
				inDTO.setExmpLeglActnCost(new BigDecimal(rcptBaseVO.exmpLeglActnCost));     //면제_법적_조치_비용
				inDTO.setExmpMidRmbrFee(new BigDecimal(rcptBaseVO.exmpMidRmbrFee));         //면제_중도_상환_수수료
				inDTO.setDsrcOccrAmt(new BigDecimal(rcptBaseVO.dsrcOccrAmt));               //예가수_발생_금액
				inDTO.setRcptAfPamtRamt(new BigDecimal(rcptBaseVO.rcptAfPamtRamt));			//수납_후_원금_잔액
				inDTO.setRcptStrtTims(rcptBaseVO.rcptStrtTims);                            	//수납_시작_회차
				inDTO.setRcptEndTims(rcptBaseVO.rcptEndTims);                              	//수납_종료_회차
				inDTO.setUnCnfmFg(rcptBaseVO.unCnfmFg);                                    	//미_확인_여부
				inDTO.setRfndFg(rcptBaseVO.rfndFg);                                        	//환불_여부
				inDTO.setExmpFg(rcptBaseVO.exmpFg);                                        	//면제_여부
				inDTO.setCnclFg(rcptBaseVO.cnclFg);                                        	//취소여부
				inDTO.setCnclDt(rcptBaseVO.cnclDt);                                        	//취소일자
				inDTO.setLoanStatCd(rcptBaseVO.loanStatCd);                                	//대출_상태_코드
				inDTO.setBndStatCd(rcptBaseVO.bndStatCd);                                  	//채권_상태_코드
				inDTO.setBndDivsEmpNo(rcptBaseVO.bndDivsEmpNo);                            	//채권_담당_사원번호
				inDTO.setDmscDeptCd(rcptBaseVO.dmscDeptCd);                                	//자판_부서_코드
				inDTO.setMngDeptCd(rcptBaseVO.mngDeptCd);                                  	//부서_코드
				inDTO.setTrTranNo(rcptBaseVO.trTranNo);                                    	//거래_이체_번호
				inDTO.setFrstRegDt(procDt);                    								//최초등록일자
				inDTO.setFrstRegTm(procTm);                    								//최초등록시각
				inDTO.setFrstRegEmpNo(rcptBaseVO.procEmpNo);   								//최초등록자사번
				inDTO.setLastProcDt(procDt);                   								//최종처리일자
				inDTO.setLastProcTm(procTm);                   								//최종처리일
				inDTO.setLastProcEmpNo(rcptBaseVO.procEmpNo);  								//최종처리자
				inDTO.setMngAcctUnitCd(rcptBaseVO.mngAcctUnitCd);                          	//관리_회계_단위_코드
				inDTO.setFlotIzeJobDt(rcptBaseVO.flotIzeJobDt);                            	//유동화_작업_일자
				inDTO.setFlotIzeAdjFg(rcptBaseVO.flotIzeAdjFg);                            	//유동화_정산_여부
				inDTO.setPartCnclCd(rcptBaseVO.partCnclCd);                                	//부분_취소_코드
				inDTO.setPlanTrSnum(rcptBaseVO.planTrSnum);                                	//계획_거래_일련번호
				inDTO.setPlanSubSnum(rcptBaseVO.planSubSnum);                              	//계획_보조_일련번호
				inDTO.setRcptPpayInt(new BigDecimal(rcptBaseVO.rcptPpayInt));               //수납_선급_이자
				inDTO.setRcptAddInsuFee(new BigDecimal(rcptBaseVO.rcptAddInsuFee));         //수납_가산_보험료
				inDTO.setRcptAddCartax(new BigDecimal(rcptBaseVO.rcptAddCartax));           //차세
				inDTO.setRcptAddEnvImprBrdnamt(new BigDecimal(rcptBaseVO.rcptAddEnvImprBrdnamt));	//환개금
				inDTO.setRcptAddAsfee(new BigDecimal(rcptBaseVO.rcptAddAsfee));                     //수납_가산_정비료
				inDTO.setRcptIpayInsuFee(new BigDecimal(rcptBaseVO.rcptIpayInsuFee));               //수납_대지급_보험료
				inDTO.setRcptIpayCartax(new BigDecimal(rcptBaseVO.rcptIpayCartax));                 //수납_대지급_자동차세
				inDTO.setRcptIpayEnvImprBrdnamt(new BigDecimal(rcptBaseVO.rcptIpayEnvImprBrdnamt)); //수납_대지급_환경_개선_부담금
				inDTO.setRcptIpayPnltAmt(new BigDecimal(rcptBaseVO.rcptIpayPnltAmt));               //수납_대지급_범칙금
				inDTO.setRcptIpayEtc(new BigDecimal(rcptBaseVO.rcptIpayEtc));                       //수납_대지급_기타
				inDTO.setRcptVtax(new BigDecimal(rcptBaseVO.rcptVtax));                             //수납_부가세
				inDTO.setLtrmBrcvAmt(new BigDecimal(rcptBaseVO.ltrmBrcvAmt));                       //장기_선수금
				inDTO.setRamtAmt(new BigDecimal(rcptBaseVO.ramtAmt));                               //잔가_금액
				inDTO.setGuarAmt(new BigDecimal(rcptBaseVO.guarAmt));                               //보증금
				inDTO.setNmChngDsrcNo(rcptBaseVO.nmChngDsrcNo);                            			//명의_변경_예가수_번호
				inDTO.setNmChngGuarAmt(new BigDecimal(rcptBaseVO.nmChngGuarAmt));                   //명의_변경_보증금
				inDTO.setRetnOdueAmt(new BigDecimal(rcptBaseVO.retnOdueAmt));                       //반납_지연_금액
				inDTO.setOverDrvFee(new BigDecimal(rcptBaseVO.overDrvFee));                         //초과_운행_수수료
				inDTO.setOrgupRcvrCost(new BigDecimal(rcptBaseVO.orgupRcvrCost));                   //원상_복구_비용
				inDTO.setCarsSellDsrcNo(rcptBaseVO.carsSellDsrcNo);                        			//차량_매각_예가수_번호
				inDTO.setCarsSellAmt(new BigDecimal(rcptBaseVO.carsSellAmt));                       //차량_매각_대금
				inDTO.setNmChngExmpGuarAmt(new BigDecimal(rcptBaseVO.nmChngExmpGuarAmt));           //명의이전면제보증금

				inDTO.setMidRmbrPpayInt(new BigDecimal(rcptBaseVO.midRmbrPpayInt));                       	//중도_상환_선급_이자
				inDTO.setMidRmbrAddInsuFee(new BigDecimal(rcptBaseVO.midRmbrAddInsuFee));                  	//중도_상환_가산_보험료
				inDTO.setMidRmbrAddCartax(new BigDecimal(rcptBaseVO.midRmbrAddCartax));                    	//중도_상환_자동차세
				inDTO.setMidRmbrAddEnvImprBrdnamt(new BigDecimal(rcptBaseVO.midRmbrAddEnvImprBrdnamt));    	//중도_상환_환경_개선_부담금
				inDTO.setMidRmbrAddAsfee(new BigDecimal(rcptBaseVO.midRmbrAddAsfee));                      	//중도_상환_가산_정비료
				inDTO.setMidRmbrVtax(new BigDecimal(rcptBaseVO.midRmbrVtax));                              	//중도_상환_부가세
				inDTO.setDeprDeprTamt(new BigDecimal(rcptBaseVO.deprDeprTamt));                            	//감가_상각_누계액
				inDTO.setDspLossApprAmt(new BigDecimal(rcptBaseVO.dspLossApprAmt));                        	//처분_손실_충당금
				inDTO.setOprLeasAset(new BigDecimal(rcptBaseVO.oprLeasAset));                              	//운용_리스_자산
				inDTO.setCustCost(new BigDecimal(rcptBaseVO.custCost));                                    	//고객_비용

				inDTO.setSysPathCd(rcptBaseVO.sysPathCd);                                  					//시스템_경로_코드
				inDTO.setRcptTrtFee(new BigDecimal(rcptBaseVO.rcptTrtFee));                                	//취급수수료
				inDTO.setExmpTrtFee(new BigDecimal(rcptBaseVO.exmpTrtFee));                                	//면제_취급수수료
				inDTO.setRcptAfTrtFeeRamt(new BigDecimal(rcptBaseVO.rcptAfTrtFeeRamt));                    	//수납후_취급수수료잔액
				inDTO.setMidRmbrTrtFee(new BigDecimal(rcptBaseVO.midRmbrTrtFee));                          	//중도상환취급수수료
				inDTO.setBfLoseStrtTims(new BigDecimal(rcptBaseVO.bfLoseStrtTims).longValue());             //수납전상실시작회차
				inDTO.setStmpFee(new BigDecimal(rcptBaseVO.stmpFee));                                      	//인지대
			}

			exeCnt += iamtUnrcvMapper.getCreateRcptBaseSql(inDTO);

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납기본 생성", se);
			throw new BizException("수납기본 생성", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: createcreateRcptDescForCnclRcptDescForCncl</p>
	 * <p>설　　명	: [수납_기본] 리스트 등록(취소), 기존정보를 조회하고 생성함.</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int createRcptDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {
		int exeCnt = 0;

		RtRcptDescDTO inDTO = new RtRcptDescDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);		// 대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	// 대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);	// 결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreateRcptDesc(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 갱신실패", se);
			throw new BizException("수납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: createRcptDescForCnclPiamt</p>
	 * <p>설　　명	: 원리금수납을 취소한다.</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int createRcptDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {
		int exeCnt = 0;

		RtRcptDescDTO inDTO = new RtRcptDescDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setCnclFg("1");
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);		// 대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	// 대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);	// 결제_번호

		try {
			//부분취소가 현재는 없지만 있다면 면제금은 0으로 처리할지 확인해야함. 현재는 기존금액 마이너스로 처리하고있음
			exeCnt = iamtUnrcvMapper.getCreateRcptDescPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 갱신실패", se);
			throw new BizException("수납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: searchRcptBaseByPK</p>
	 * <p>설　　명	: [수납_기본] 조회<</p>
	 * <p>메소드인수	: RcptBaseVO</p>
	 * <p>리 턴 값	: RcptBaseVO</p>
	 */
	@Override
	public RcptBaseVO searchRcptBaseByPK(RcptBaseVO rcptBaseVO) {

		RtRcptBaseDTO inDTO = new RtRcptBaseDTO();
		RcptBaseVO outRcptBaseVO = null;

		inDTO.setLoanNo(rcptBaseVO.loanNo);		// 대출_번호
		inDTO.setLoanSeq(rcptBaseVO.loanSeq);	// 대출_순번
		inDTO.setSetlNo(rcptBaseVO.setlNo);	// 결제_번호

		try {
			RtRcptBaseDTO outDTO = iamtUnrcvMapper.getSearchRcptBase(inDTO);

			if(outDTO != null) {
				outRcptBaseVO.loanNo = outDTO.getLoanNo();                                      //대출번호
				outRcptBaseVO.loanSeq = outDTO.getLoanSeq();                                    //상담/대출순번
				outRcptBaseVO.setlNo = Long.valueOf(outDTO.getSetlNo()).intValue();             //결제_번호
				outRcptBaseVO.acctDt = outDTO.getAcctDt();                                      //회계_일자
				outRcptBaseVO.isrtDt = outDTO.getIsrtDt();                                      //입력_일자
				outRcptBaseVO.acctUnitCd = outDTO.getAcctUnitCd();                              //회계_단위_코드
				outRcptBaseVO.isrtDeptCd = outDTO.getIsrtDeptCd();                              //입력_부서_코드
				outRcptBaseVO.trTpCd = outDTO.getTrTpCd();                                      //거래_형태_코드
				outRcptBaseVO.trSnum = Long.valueOf(outDTO.getTrSnum()).intValue();             //거래_일련번호
				outRcptBaseVO.prdtCd = outDTO.getPrdtCd();                                      //상품_코드
				outRcptBaseVO.prdtLrgeClasCd = outDTO.getPrdtLrgeClasCd();                      //상품_대분류_코드
				outRcptBaseVO.prdtMidClasCd = outDTO.getPrdtMidClasCd();                        //상품_중분류_코드
				outRcptBaseVO.prdtSmClasCd = outDTO.getPrdtSmClasCd();                          //상품_소분류_코드
				outRcptBaseVO.rcptTpCd = outDTO.getRcptTpCd();                                  //수납_유형_코드
				outRcptBaseVO.setlDivCd = outDTO.getSetlDivCd();                                //결제_구분코드
				outRcptBaseVO.dsrcNo = outDTO.getDsrcNo();                                      //예가수_번호
				outRcptBaseVO.dsrcAdjCd = outDTO.getDsrcAdjCd();                                //예가수_정산_코드
				outRcptBaseVO.dsrcOccrCd = outDTO.getDsrcOccrCd();                              //예가수_발생_코드
				outRcptBaseVO.setlFrstRank = outDTO.getSetlFrstRank();                          //결제_우선_순위
				outRcptBaseVO.setlDt = outDTO.getSetlDt();                                      //결제일자
				outRcptBaseVO.bankCd = outDTO.getBankCd();                                      //은행_코드
				outRcptBaseVO.acntNo = outDTO.getAcntNo();                                      //대출_번호
				outRcptBaseVO.setlAmt = outDTO.getSetlAmt().longValue();                                    //결제_금액
				outRcptBaseVO.dsrcAdjAmt = outDTO.getDsrcAdjAmt().longValue();                              //예가수_정산_금액
				outRcptBaseVO.exmpConsNo = outDTO.getExmpConsNo();                              //면제_품의_번호
				outRcptBaseVO.exmpAmt = outDTO.getExmpAmt().longValue();                                    //면제_금액
				outRcptBaseVO.pdueDiscDfee = outDTO.getPdueDiscDfee().longValue();                          //선납_할인_연체료
				outRcptBaseVO.rcptAmt = outDTO.getRcptAmt().longValue();                                    //수납_금액
				outRcptBaseVO.cashAmt = outDTO.getCashAmt().longValue();                                    //현금_금액
				outRcptBaseVO.chkAmt = outDTO.getChkAmt().longValue();                                      //수표_금액
				outRcptBaseVO.rcptPamt = outDTO.getRcptPamt().longValue();                                  //수납_원금
				outRcptBaseVO.rcptInt = outDTO.getRcptInt().longValue();                                    //수납_이자
				outRcptBaseVO.rcptDfee = outDTO.getRcptDfee().longValue();                                  //수납_연체료
				outRcptBaseVO.leglActnCost = outDTO.getLeglActnCost().longValue();                          //법적조치_비용
				outRcptBaseVO.midRmbrPamt = outDTO.getMidRmbrPamt().longValue();                            //중도_상환_원금
				outRcptBaseVO.midRmbrInt = outDTO.getMidRmbrInt().longValue();                              //중도_상환_이자
				outRcptBaseVO.midRmbrFee = outDTO.getMidRmbrFee().longValue();                              //중도_상환_수수료
				outRcptBaseVO.trtFeeDisc = outDTO.getTrtFeeDisc();                              //취급_수수료_할인
				outRcptBaseVO.crdtRcvrUnrcvAmt = outDTO.getCrdtRcvrUnrcvAmt().longValue();                  //신용_회복_미수금
				outRcptBaseVO.exmpPamt = outDTO.getExmpPamt().longValue();                                  //면제_원금
				outRcptBaseVO.exmpInt = outDTO.getExmpInt().longValue();                                    //면제_이자
				outRcptBaseVO.exmpDfee = outDTO.getExmpDfee().longValue();                                  //면제_연체료
				outRcptBaseVO.exmpLeglActnCost = outDTO.getExmpLeglActnCost().longValue();                  //면제_법적_조치_비용
				outRcptBaseVO.exmpMidRmbrFee = outDTO.getExmpMidRmbrFee().longValue();                      //면제_중도_상환_수수료
				outRcptBaseVO.dsrcOccrAmt = outDTO.getDsrcOccrAmt().longValue();                            //예가수_발생_금액
				outRcptBaseVO.rcptAfPamtRamt = outDTO.getRcptAfPamtRamt().longValue();                      //수납_후_원금_잔액
				outRcptBaseVO.rcptStrtTims = Long.valueOf(outDTO.getRcptStrtTims()).intValue();                          //수납_시작_회차
				outRcptBaseVO.rcptEndTims = Long.valueOf(outDTO.getRcptEndTims()).intValue();                            //수납_종료_회차
				outRcptBaseVO.unCnfmFg = outDTO.getUnCnfmFg();                                  //미_확인_여부
				outRcptBaseVO.rfndFg = outDTO.getRfndFg();                                      //환불_여부
				outRcptBaseVO.exmpFg = outDTO.getExmpFg();                                      //면제_여부
				outRcptBaseVO.cnclFg = outDTO.getCnclFg();                                      //취소여부
				outRcptBaseVO.cnclDt = outDTO.getCnclDt();                                      //취소일자
				outRcptBaseVO.loanStatCd = outDTO.getLoanStatCd();                              //대출_상태_코드
				outRcptBaseVO.bndStatCd = outDTO.getBndStatCd();                                //채권_상태_코드
				outRcptBaseVO.bndDivsEmpNo = outDTO.getBndDivsEmpNo();                          //채권_담당_사원번호
				outRcptBaseVO.dmscDeptCd = outDTO.getDmscDeptCd();                              //자판_부서_코드
				outRcptBaseVO.mngDeptCd = outDTO.getMngDeptCd();                                //부서_코드
				outRcptBaseVO.trTranNo = Long.valueOf(outDTO.getTrTranNo()).intValue();         //거래_이체_번호
				outRcptBaseVO.mngAcctUnitCd = outDTO.getMngAcctUnitCd();                        //관리_회계_단위_코드
				outRcptBaseVO.flotIzeJobDt = outDTO.getFlotIzeJobDt();                          //유동화_작업_일자
				outRcptBaseVO.flotIzeAdjFg = outDTO.getFlotIzeAdjFg();                          //유동화_정산_여부
				outRcptBaseVO.partCnclCd = outDTO.getPartCnclCd();                              //부분_취소_코드


				outRcptBaseVO.planTrSnum = Long.valueOf(outDTO.getPlanTrSnum()).intValue();     //계획_거래_일련번호
				outRcptBaseVO.planSubSnum = Long.valueOf(outDTO.getPlanSubSnum()).intValue();   //계획_보조_일련번호
				outRcptBaseVO.rcptPpayInt = outDTO.getRcptPpayInt().longValue();                            //수납_선급_이자
				outRcptBaseVO.rcptAddInsuFee = outDTO.getRcptAddInsuFee().longValue();                      //보험료
				outRcptBaseVO.rcptAddCartax = outDTO.getRcptAddCartax().longValue();                        //차세
				outRcptBaseVO.rcptAddEnvImprBrdnamt = outDTO.getRcptAddEnvImprBrdnamt().longValue();        //환개금
				outRcptBaseVO.rcptAddAsfee = outDTO.getRcptAddAsfee().longValue();                          //수납_가산_정비료
				outRcptBaseVO.rcptIpayInsuFee = outDTO.getRcptIpayInsuFee().longValue();                    //수납_대지급_보험료
				outRcptBaseVO.rcptIpayCartax = outDTO.getRcptIpayCartax().longValue();                      //수납_대지급_자동차세
				outRcptBaseVO.rcptIpayEnvImprBrdnamt = outDTO.getRcptIpayEnvImprBrdnamt().longValue();      //수납_대지급_환경_개선_부담금
				outRcptBaseVO.rcptIpayPnltAmt = outDTO.getRcptIpayPnltAmt().longValue();                    //수납_대지급_범칙금
				outRcptBaseVO.rcptIpayEtc = outDTO.getRcptIpayEtc().longValue();                            //수납_대지급_기타
				outRcptBaseVO.rcptVtax = outDTO.getRcptVtax().longValue();                                  //수납_부가세
				outRcptBaseVO.ltrmBrcvAmt = outDTO.getLtrmBrcvAmt().longValue();                            //장기_선수금
				outRcptBaseVO.ramtAmt = outDTO.getRamtAmt().longValue();                                    //잔가_금액
				outRcptBaseVO.guarAmt = outDTO.getGuarAmt().longValue();                                    //보증금


				outRcptBaseVO.nmChngDsrcNo = outDTO.getNmChngDsrcNo();                          //명의_변경_예가수_번호
				outRcptBaseVO.nmChngGuarAmt = outDTO.getNmChngGuarAmt().longValue();                        //명의_변경_보증금
				outRcptBaseVO.retnOdueAmt = outDTO.getRetnOdueAmt().longValue();                            //반납_지연_금액
				outRcptBaseVO.overDrvFee = outDTO.getOverDrvFee().longValue();                              //초과_운행_수수료
				outRcptBaseVO.orgupRcvrCost = outDTO.getOrgupRcvrCost().longValue();                        //원상_복구_비용
				outRcptBaseVO.carsSellDsrcNo = outDTO.getCarsSellDsrcNo();                      //차량_매각_예가수_번호
				outRcptBaseVO.carsSellAmt = outDTO.getCarsSellAmt().longValue();                            //차량_매각_대금
				outRcptBaseVO.nmChngExmpGuarAmt = outDTO.getNmChngExmpGuarAmt().longValue();                //


				outRcptBaseVO.midRmbrPpayInt = outDTO.getMidRmbrPpayInt().longValue();                      //중도_상환_선급_이자
				outRcptBaseVO.midRmbrAddInsuFee = outDTO.getMidRmbrAddInsuFee().longValue();                //중도_상환_가산_보험료
				outRcptBaseVO.midRmbrAddCartax = outDTO.getMidRmbrAddCartax().longValue();                  //중도_상환_자동차세
				outRcptBaseVO.midRmbrAddEnvImprBrdnamt = outDTO.getMidRmbrAddEnvImprBrdnamt().longValue();  //중도_상환_환경_개선_부담금
				outRcptBaseVO.midRmbrAddAsfee = outDTO.getMidRmbrAddAsfee().longValue();                    //중도_상환_가산_정비료
				outRcptBaseVO.midRmbrVtax = outDTO.getMidRmbrVtax().longValue();                            //중도_상환_부가세
				outRcptBaseVO.deprDeprTamt = outDTO.getDeprDeprTamt().longValue();                          //감가_상각_누계액
				outRcptBaseVO.dspLossApprAmt = outDTO.getDspLossApprAmt().longValue();                      //처분_손실_충당금
				outRcptBaseVO.oprLeasAset = outDTO.getOprLeasAset().longValue();                            //운용_리스_자산
				outRcptBaseVO.custCost = outDTO.getCustCost().longValue();                                  //고객_비용
				outRcptBaseVO.rcptTrtFee = outDTO.getRcptTrtFee().longValue();                              //취급수수료
				outRcptBaseVO.exmpTrtFee = outDTO.getExmpTrtFee().longValue();                              //면제_취급_수수료
				outRcptBaseVO.rcptAfTrtFeeRamt = outDTO.getRcptAfTrtFeeRamt().longValue();                  //수납후취급수수료잔액
				outRcptBaseVO.midRmbrTrtFee = outDTO.getMidRmbrTrtFee().longValue();                        //취급수수료잔액
				outRcptBaseVO.bfLoseStrtTims = Long.valueOf(outDTO.getBfLoseStrtTims()).intValue();         //수납전기한상실시작회차
				outRcptBaseVO.stmpFee = outDTO.getStmpFee().longValue();                                    //인지세
			}
			else {
				//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("원거래수납을 찾을수 없습니다.");
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("원거래수납 조회실패", se);
			throw new BizException("원거래수납 조회실패", se);
		}

		return outRcptBaseVO;
	}

	/**
	 * <p>메소드명	: createRcptDesc</p>
	 * <p>설　　명	: [수납_내역] 리스트등록<</p>
	 * <p>메소드인수	: List rcptDescVOList</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int createRcptDesc(List rcptDescVOList) {

		RcptDescVO rcptDescVO = null;
		int exeCnt = 0;
		RtRcptDescDTO inDTO = new RtRcptDescDTO();

		String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

		try {
			for (int i = 0; i < rcptDescVOList.size(); i++) {
				rcptDescVO = (RcptDescVO) rcptDescVOList.get(i);

				inDTO.setLoanNo(rcptDescVO.loanNo);                              //대출번호
				inDTO.setLoanSeq(rcptDescVO.loanSeq);                            //상담/대출순번
				inDTO.setSetlNo(rcptDescVO.setlNo);                              //결제_번호
				inDTO.setSetlSnum(rcptDescVO.setlSnum);                          //입금_번호
				inDTO.setTims(rcptDescVO.tims);                                  //회차
				inDTO.setDueDt(rcptDescVO.dueDt);                                //유효일
				inDTO.setAcctDt(rcptDescVO.acctDt);                              //회계_일자
				inDTO.setRcptTpCd(rcptDescVO.rcptTpCd);                          //수납_유형_코드
				inDTO.setSetlDivCd(rcptDescVO.setlDivCd);                        //결제_구분코드
				inDTO.setSetlDt(rcptDescVO.setlDt);                              //결제일자
				inDTO.setMmPamt(new BigDecimal(rcptDescVO.mmPamt));                              //월_원금
				inDTO.setMmInt(new BigDecimal(rcptDescVO.mmInt));                                //월_이자
				inDTO.setDfee(new BigDecimal(rcptDescVO.dfee));                                  //연체료
				inDTO.setPdueDiscDfee(new BigDecimal(rcptDescVO.pdueDiscDfee));                  //선납_할인_연체료
				inDTO.setMidRmbrPamt(new BigDecimal(rcptDescVO.midRmbrPamt));                    //중도_상환_원금
				inDTO.setMidRmbrInt(new BigDecimal(rcptDescVO.midRmbrInt));                      //중도_상환_이자
				inDTO.setMidRmbrFee(new BigDecimal(rcptDescVO.midRmbrFee));                      //중도_상환_수수료
				inDTO.setTrtFeeDisc(new BigDecimal(rcptDescVO.trtFeeDisc));                      //취급_수수료_할인
				inDTO.setExmpPamt(new BigDecimal(rcptDescVO.exmpPamt));                          //면제_원금
				inDTO.setExmpInt(new BigDecimal(rcptDescVO.exmpInt));                            //면제_이자
				inDTO.setExmpDfee(new BigDecimal(rcptDescVO.exmpDfee));                          //면제_연체료
				inDTO.setExmpMidRmbrFee(new BigDecimal(rcptDescVO.exmpMidRmbrFee));              //면제_중도_상환_수수료
				inDTO.setPdueFg(rcptDescVO.pdueFg);                              //선납_여부
				inDTO.setDlyFg(rcptDescVO.dlyFg);                                //연체_여부
				inDTO.setExmpFg(rcptDescVO.exmpFg);                              //면제_여부
				inDTO.setCnclFg(rcptDescVO.cnclFg);                              //취소여부
				inDTO.setCnclDt(rcptDescVO.cnclDt);                              //취소일자
				inDTO.setFrstRegDt(procDt);                           			//최초등록일자
				inDTO.setFrstRegTm(procTm);                           			//최초등록시각
				inDTO.setFrstRegEmpNo(rcptDescVO.procEmpNo);                     //최초등록자사번
				inDTO.setLastProcDt(procDt);                          			//최종처리일자
				inDTO.setLastProcTm(procTm);                           			//최종처리일
				inDTO.setLastProcEmpNo(rcptDescVO.procEmpNo);                 	//최종처리자
				inDTO.setPartCnclCd(rcptDescVO.partCnclCd);                      //부분_취소_코드
				inDTO.setPpayInt(new BigDecimal(rcptDescVO.ppayInt));                            //선급이자
				inDTO.setAddInsuFee(new BigDecimal(rcptDescVO.addInsuFee));                      //보험료
				inDTO.setAddCartax(new BigDecimal(rcptDescVO.addCartax));                        //차세
				inDTO.setAddEnvImprBrdnamt(new BigDecimal(rcptDescVO.addEnvImprBrdnamt));        //환개금
				inDTO.setAddAsfee(new BigDecimal(rcptDescVO.addAsfee));                          //가산_정비료
				inDTO.setIpayInsuFee(new BigDecimal(rcptDescVO.ipayInsuFee));                    //대지급_보험료
				inDTO.setIpayCartax(new BigDecimal(rcptDescVO.ipayCartax));                      //대지급_자동차세
				inDTO.setIpayEnvImprBrdnamt(new BigDecimal(rcptDescVO.ipayEnvImprBrdnamt));      //대지급_환경_개선_부담금
				inDTO.setIpayPnltAmt(new BigDecimal(rcptDescVO.ipayPnltAmt));                    //대지급_범칙금
				inDTO.setIpayEtc(new BigDecimal(rcptDescVO.ipayEtc));                            //대지급_기타
				inDTO.setVtax(new BigDecimal(rcptDescVO.vtax));                                  //부가세
				inDTO.setLtrmBrcvAmt(new BigDecimal(rcptDescVO.ltrmBrcvAmt));                    //장기_선수금
				inDTO.setRamtAmt(new BigDecimal(rcptDescVO.ramtAmt));                            //잔가_금액
				inDTO.setGuarAmt(new BigDecimal(rcptDescVO.guarAmt));                            //보증금
				inDTO.setEndDivCd(rcptDescVO.endDivCd);                       //종료_구분_코드
				inDTO.setTrtFee(new BigDecimal(rcptDescVO.trtFee));                              //취급수수료
				inDTO.setExmpTrtFee(new BigDecimal(rcptDescVO.exmpTrtFee));                      //취급수수료
				inDTO.setMidRmbrTrtFee(new BigDecimal(rcptDescVO.midRmbrTrtFee));                //중도상환취급수수료
				inDTO.setCortMaxAmt(new BigDecimal(rcptDescVO.cortMaxAmt));                      //법정_최고_금액
				inDTO.setCalcMidRmbrFee(new BigDecimal(rcptDescVO.calcMidRmbrFee));              //계산_경과_이자
				inDTO.setCalcPsgInt(new BigDecimal(rcptDescVO.calcPsgInt));                      //계산_중도상환수수료

			}

			exeCnt += iamtUnrcvMapper.insertRcptDesc(inDTO);

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 생성", se);
			throw new BizException("수납내역 생성", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateRcptDescForCncl</p>
	 * <p>설　　명	: [수납_내역] 취소 반영<</p>
	 * <p>메소드인수	: List rcptDescVOList</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateRcptDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptDescDTO inDTO = new RtRcptDescDTO();

		//set
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);					//취소여부
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt); 				//회계일자
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo); 	//처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 갱신실패", se);
			throw new BizException("수납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateRcptDescForCnclPiamt</p>
	 * <p>설　　명	: 원리금수납취소<</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateRcptDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptDescDTO inDTO = new RtRcptDescDTO();

		//set
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);			//취소여부
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt); 				//회계일자
		inDTO.setCnclFg(Constants.YES); 						//취소여부
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo); 	//처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDescForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 갱신실패", se);
			throw new BizException("수납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateRcptBaseForCncl</p>
	 * <p>설　　명	: 수납_기본을 취소처리<</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateRcptBaseForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptBaseDTO inDTO = new RtRcptBaseDTO();

		//set
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);					//취소여부
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt); 				//회계일자
		inDTO.setTrTranNo(iamtUnrcvObjVO.orgSetlNo); 			//원_결제_번호
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo); 	//처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptBaseForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납기본 갱신실패", se);
			throw new BizException("수납기본 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateRcptBaseForMidRmbrCncl</p>
	 * <p>설　　명	: 중도일부상환 취소시 수납기본에 상환스케쥴 TR_SNUM 반영<</p>
	 * <p>메소드인수	: MidPartRmbrObj</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateRcptBaseForMidRmbrCncl(MidPartRmbrObj mRmbrObj, int setlNo) {

		int exeCnt = 0;

		RtRcptBaseDTO inDTO = new RtRcptBaseDTO();

		//set
		inDTO.setPlanTrSnum(mRmbrObj.trSnum);	//취소여부

		//where
		inDTO.setLoanNo(mRmbrObj.loanNo);		//대출_번호
		inDTO.setLoanSeq(mRmbrObj.loanSeq);		//대출_순번
		inDTO.setSetlNo(setlNo);				//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updatePlanTrSnumForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납기본 스케쥴 일련번호 갱신실패", se);
			throw new BizException("수납기본 스케쥴 일련번호 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateRcptBaseForCnclPiamt</p>
	 * <p>설　　명	: 부분취소시 처리</p>
	 * <p>메소드인수	: IamtUnrcvObjVO</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateRcptBaseForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptBaseDTO inDTO = new RtRcptBaseDTO();

		//set
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);		//취소여부
		inDTO.setTrTranNo(iamtUnrcvObjVO.orgSetlNo); 		//회계일자
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);//처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptBaseForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납내역 갱신실패", se);
			throw new BizException("수납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: updateDdayPrftLoseStrtTims</p>
	 * <p>설　　명	: 기한상실 시작회차 수정(부활/상실)</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, int ddayPrftLoseStrtTims</p>
	 * <p>리 턴 값	: int</p>
	 */
	@Override
	public int updateDdayPrftLoseStrtTims(IamtUnrcvObjVO iamtUnrcvObjVO, int ddayPrftLoseStrtTims) {

		int exeCnt = 0;

		BtBndClsBaseDTO inDTO = new BtBndClsBaseDTO();

		//set
		inDTO.setDdayPrftLoseStrtTims(ddayPrftLoseStrtTims);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번

		try {
			exeCnt = iamtUnrcvMapper.updateDdayPrftLoseStrtTims(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("기한상실 회차수정 실패", se);
			throw new BizException("기한상실 회차수정 실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명	: getNextNum</p>
	 * <p>설　　명	: 미확인번호 채번</p>
	 * <p>리 턴 값	: String</p>
	 */
	@Override
	public String getNextNum() {
		String sRtn = "";
		try {
			sRtn = StringUtils.leftPad(String.valueOf(iamtUnrcvMapper.getRsDsrcUncnfmNo()), 6, '0');;
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("채번실패", se);
			throw new BizException("기한상실 회차수정 실패", se);
		}

		return sRtn;
	}

}
