package hanalife.r.co.rc.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.SearchRcptRfndDescINDTO;
import hanalife.r.co.rc.mapper.dto.SearchRcptRfndDescOUTDTO;
import hanalife.r.co.rc.service.RcptRfndService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.RfndDescVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : RcptRfndServiceImpl
 * 클래스설명 : RcptRfndServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptRfndService")
public class RcptRfndServiceImpl implements RcptRfndService {

	//private static final Logger log = LoggerFactory.getLogger(RcptRfndServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>취소대상의 환불내역 조회
	 * @param IamtUnrcvObjVO
	 * @return RfndDescVO
	 */
	@Override
	public RfndDescVO searchRfndDesc(IamtUnrcvObjVO inVO) {

		RfndDescVO rfndDescVO = null;

		try {
			SearchRcptRfndDescINDTO inDTO = new SearchRcptRfndDescINDTO();

			inDTO.setDsrcNo(inVO.dsrcNo);
			inDTO.setLoanNo(inVO.loanNo);
			inDTO.setLoanSeq(inVO.loanSeq);
			inDTO.setOrgSetlNo(inVO.orgSetlNo);

			SearchRcptRfndDescOUTDTO outDTO = iamtUnrcvMapper.getSearchRcptRfndDesc(inDTO);

			if(outDTO != null) {
				rfndDescVO = new RfndDescVO();

				rfndDescVO.dsrcNo          = outDTO.getDsrcNo();         //예가수_번호
				rfndDescVO.rfndSnum        = outDTO.getRfndSnum();       //환불_일련번호
				rfndDescVO.rfndLoanNo      = outDTO.getRfndLoanNo();     //환불_대출_번호
				rfndDescVO.rfndLoanSeq     = outDTO.getRfndLoanSeq();    //환불_대출_순번
				rfndDescVO.rfndDt          = outDTO.getRfndDt();         //환불_일자
				rfndDescVO.acctDt          = outDTO.getAcctDt();         //회계_일자
				rfndDescVO.rfndStatCd      = outDTO.getRfndStatCd();     //환불_상태_코드
				rfndDescVO.rcptTpCd        = outDTO.getRcptTpCd();       //수납_유형_코드
				rfndDescVO.rfndRsnCd       = outDTO.getRfndRsnCd();      //환불_사유_코드
				rfndDescVO.dsrcOccrAmt     = outDTO.getDsrcOccrAmt();    //예가수_발생_금액
				rfndDescVO.dsrcRamt        = outDTO.getDsrcRamt();       //예가수_잔액
				rfndDescVO.dsrcAdjAmt      = outDTO.getDsrcAdjAmt();     //예가수_정산_금액
				rfndDescVO.autoTranAplyFg  = outDTO.getAutoTranAplyFg(); //자동이체_적용_여부
				rfndDescVO.bankCd          = outDTO.getBankCd();         //은행_코드
				rfndDescVO.acntNo          = outDTO.getAcntNo();         //대출_번호
				rfndDescVO.depoOwnNo       = outDTO.getDepoOwnNo();      //예금주_번호
				rfndDescVO.depoOwnnm       = outDTO.getDepoOwnnm();      //예금주명
				rfndDescVO.depoOwnRelCd    = outDTO.getDepoOwnRelCd();   //예금주_관계_코드
				rfndDescVO.acntCnfmNo      = outDTO.getAcntCnfmNo();     //계좌_확인_번호
				rfndDescVO.acntCnfmDt      = outDTO.getAcntCnfmDt();     //계좌_확인_일자
				rfndDescVO.acntCnfmTm      = outDTO.getAcntCnfmTm();     //계좌_확인_시각
				rfndDescVO.acntRsltCd      = outDTO.getAcntRsltCd();     //계좌_결과_코드
				rfndDescVO.ivltRegFg       = outDTO.getIvltRegFg();      //강제_등록_여부
				rfndDescVO.cnfmDepoOwnnm   = outDTO.getCnfmDepoOwnnm();  //확인_예금주명
				rfndDescVO.payNo           = outDTO.getPayNo();          //지급_번호
				rfndDescVO.rfndRsltCd      = outDTO.getRfndRsltCd();     //환불_결과_코드
				rfndDescVO.isrtDeptCd      = outDTO.getIsrtDeptCd();     //입력_부서_코드
				rfndDescVO.adjDeptCd       = outDTO.getAdjDeptCd();      //정산_부서_코드
				rfndDescVO.dsrcSnum        = outDTO.getDsrcSnum();       //예가수_일련번호
				rfndDescVO.setlFg          = outDTO.getSetlFg();         //결제_여부
				rfndDescVO.setlNo          = outDTO.getSetlNo();         //예가수_번호
				rfndDescVO.cnclFg          = outDTO.getCnclFg();         //취소여부
				rfndDescVO.cnclDt          = outDTO.getCnclDt();         //취소일자
				rfndDescVO.cnclDsrcSnum    = outDTO.getCnclDsrcSnum();   //취소_예가수_일련번호
				rfndDescVO.cnclSetlFg      = outDTO.getCnclSetlFg();     //취소_결제_여부
				rfndDescVO.cnclSetlNo      = outDTO.getCnclSetlNo();     //취소_결제_번호
				rfndDescVO.trOrgCd         = outDTO.getTrOrgCd();        //거래_부서_코드
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("환불내역 수정실패", se);
			throw new BizException("환불내역 수정실패", se);
		}

		return rfndDescVO;
	}

}
