package hanalife.r.co.rc.vo;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;

import hanalife.r.co.as.vo.TimsUnrcvVO;


@SuppressWarnings({"unchecked","rawtypes"})
/**
 * <pre>
 * 클래스명    : AmtCalcVO
 * 클래스설명 : 입금미수 금액계산 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class AmtCalcVO {

	static final String BLANK = "";
	static final String DIV = "|";

	public AmtCalcVO(){
	}

	public AmtCalcVO(IamtUnrcvObjVO iamtUnrcvObjVO, TimsUnrcvVO timsUrcvVO){
		this.tims = timsUrcvVO.tims;

		//청구금 셋팅
		long tmpTotAskAmt = timsUrcvVO.askDfee
			+ timsUrcvVO.askInt
			+ timsUrcvVO.askTrtFee
			+ timsUrcvVO.askPamt
			+ timsUrcvVO.askPpayInt
			+ timsUrcvVO.askAddEnvImprBrdnamt
			+ timsUrcvVO.askAddCartax
			+ timsUrcvVO.askAddInsuFee
			+ timsUrcvVO.askAddAsfee
			+ timsUrcvVO.askIpayEtc
			+ timsUrcvVO.askIpayPnltAmt
			+ timsUrcvVO.askIpayEnvImprBrdnamt
			+ timsUrcvVO.askIpayCartax
			+ timsUrcvVO.askIpayInsuFee
			+ timsUrcvVO.askVtax;

		this.askTotAmt            = tmpTotAskAmt;
		this.askDfee              = timsUrcvVO.askDfee               ;
		this.askInt               = timsUrcvVO.askInt                ;
		this.askPamt              = timsUrcvVO.askPamt               ;
		this.askTrtFee            = timsUrcvVO.askTrtFee             ;
		this.askPpayInt           = timsUrcvVO.askPpayInt            ;
		this.askAddEnvImprBrdnamt = timsUrcvVO.askAddEnvImprBrdnamt  ;
		this.askAddCartax         = timsUrcvVO.askAddCartax          ;
		this.askAddInsuFee        = timsUrcvVO.askAddInsuFee         ;
		this.askAddAsfee          = timsUrcvVO.askAddAsfee           ;
		this.askIpayEtc           = timsUrcvVO.askIpayEtc            ;
		this.askIpayPnltAmt       = timsUrcvVO.askIpayPnltAmt        ;
		this.askIpayEnvImprBrdnamt= timsUrcvVO.askIpayEnvImprBrdnamt ;
		this.askIpayCartax        = timsUrcvVO.askIpayCartax         ;
		this.askIpayInsuFee       = timsUrcvVO.askIpayInsuFee        ;
		this.askVtax              = timsUrcvVO.askVtax               ;

		//결제금셋팅
		long totBfSetlAmt = iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt;
		this.setlTotSetlAmt			= totBfSetlAmt;
		this.setlSetlAmt			= iamtUnrcvObjVO.tempSetlAmt			;
		this.setlExmpAmt			= iamtUnrcvObjVO.tempExmpAmt            ;
		this.setlExmpPamt			= iamtUnrcvObjVO.tempExmpPamt           ;
		this.setlExmpInt			= iamtUnrcvObjVO.tempExmpInt            ;
		this.setlExmpTrtFee			= iamtUnrcvObjVO.tempExmpTrtFee         ;
		this.setlExmpDfee			= iamtUnrcvObjVO.tempExmpDfee           ;
		this.setlExmpLeglActnCost	= iamtUnrcvObjVO.tempExmpLeglActnCost   ;
		this.setlExmpMidRmbrFee	    = iamtUnrcvObjVO.tempExmpMidRmbrFee     ;
		this.setlPdueDiscDfee		= iamtUnrcvObjVO.tempPdueDiscDfee       ;
		this.setlLtrmBrcvAmt 		= iamtUnrcvObjVO.tempLtrmBrcvAmt        ;

		//제외금액
		this.ltrmPamt				= timsUrcvVO.ltrmPamt				    ; //장기선수대체_원금
		this.ltrmInt				= timsUrcvVO.ltrmInt				    ; //장기선수대체_이자
		this.ltrmPpayInt			= timsUrcvVO.ltrmPpayInt			    ;  //장기선수대체선급이자
		this.ltrmAddInsuFee			= timsUrcvVO.ltrmAddInsuFee			    ;  //장기선수대체가산보험료
		this.ltrmAddCartax			= timsUrcvVO.ltrmAddCartax			    ;  //장기선수대체가산자동차세
		this.ltrmAddEnvImprBrdnamt	= timsUrcvVO.ltrmAddEnvImprBrdnamt	    ;  //장기선수대체가산환개금
		this.ltrmAddAsfee			= timsUrcvVO.ltrmAddAsfee			    ;  //장기선수대체가산정비료
		this.askLtrmBrcvAmt         = timsUrcvVO.askLtrmBrcvAmt;
	}

	public void calc(IamtUnrcvObjVO iamtUnrcvObjVO){
		//정산내역
		long tmpTotAdjAmt = iamtUnrcvObjVO.adjPamt
			+ iamtUnrcvObjVO.adjInt
			+ iamtUnrcvObjVO.adjTrtFee
			+ iamtUnrcvObjVO.adjDfee //adjPdueDiscDfee포함됨.
			+ iamtUnrcvObjVO.adjVtax
			+ iamtUnrcvObjVO.adjPpayInt
			+ iamtUnrcvObjVO.adjAddInsuFee
			+ iamtUnrcvObjVO.adjAddCartax
			+ iamtUnrcvObjVO.adjAddEnvImprBrdnamt
			+ iamtUnrcvObjVO.adjAddAsfee
			+ iamtUnrcvObjVO.adjIpayInsuFee
			+ iamtUnrcvObjVO.adjIpayCartax
			+ iamtUnrcvObjVO.adjIpayEnvImprBrdnamt
			+ iamtUnrcvObjVO.adjIpayPnltAmt
			+ iamtUnrcvObjVO.adjIpayEtc;

		this.adjAmt               = tmpTotAdjAmt                          ;
		this.adjPamt              = iamtUnrcvObjVO.adjPamt                ;
		this.adjInt               = iamtUnrcvObjVO.adjInt                 ;
		this.adjTrtFee            = iamtUnrcvObjVO.adjTrtFee              ;
		this.adjDfee              = iamtUnrcvObjVO.adjDfee                ;
		this.adjVtax              = iamtUnrcvObjVO.adjVtax                ;
		this.adjPpayInt			  = iamtUnrcvObjVO.adjPpayInt			  ;
		this.adjAddInsuFee        = iamtUnrcvObjVO.adjAddInsuFee          ;
		this.adjAddCartax         = iamtUnrcvObjVO.adjAddCartax           ;
		this.adjAddEnvImprBrdnamt = iamtUnrcvObjVO.adjAddEnvImprBrdnamt   ;
		this.adjAddAsfee          = iamtUnrcvObjVO.adjAddAsfee            ;
		this.adjIpayInsuFee       = iamtUnrcvObjVO.adjIpayInsuFee         ;
		this.adjIpayCartax        = iamtUnrcvObjVO.adjIpayCartax          ;
		this.adjIpayEnvImprBrdnamt= iamtUnrcvObjVO.adjIpayEnvImprBrdnamt  ;
		this.adjIpayPnltAmt       = iamtUnrcvObjVO.adjIpayPnltAmt         ;
		this.adjIpayEtc           = iamtUnrcvObjVO.adjIpayEtc             ;
		this.adjLtrmBrcvAmt       = iamtUnrcvObjVO.adjLtrmBrcvAmt         ;


		this.adjExmpAmt = iamtUnrcvObjVO.adjExmpDfee
		 + iamtUnrcvObjVO.adjExmpInt
		 + iamtUnrcvObjVO.adjExmpPamt
		 + iamtUnrcvObjVO.adjExmpTrtFee
		 + iamtUnrcvObjVO.adjExmpMidRmbrFee;

		this.adjExmpInt = iamtUnrcvObjVO.adjExmpInt;
		this.adjExmpDfee = iamtUnrcvObjVO.adjExmpDfee;
		this.adjExmpPamt = iamtUnrcvObjVO.adjExmpPamt;
		this.adjExmpTrtFee = iamtUnrcvObjVO.adjExmpTrtFee;
		this.adjExmpMidRmbrFee = iamtUnrcvObjVO.adjExmpMidRmbrFee;

		//결제후남은 잔액
		long totAfterSetlAmt = iamtUnrcvObjVO.tempSetlAmt + iamtUnrcvObjVO.tempExmpAmt + iamtUnrcvObjVO.tempLtrmBrcvAmt;
		this.afterTotSetlAmt			= totAfterSetlAmt;
		this.afterSetlSetlAmt			= iamtUnrcvObjVO.tempSetlAmt			;
		this.afterSetlExmpAmt			= iamtUnrcvObjVO.tempExmpAmt            ;
		this.afterSetlExmpPamt			= iamtUnrcvObjVO.tempExmpPamt           ;
		this.afterSetlExmpInt			= iamtUnrcvObjVO.tempExmpInt            ;
		this.afterSetlExmpTrtFee		= iamtUnrcvObjVO.tempExmpTrtFee         ;
		this.afterSetlExmpDfee			= iamtUnrcvObjVO.tempExmpDfee           ;
		this.afterSetlExmpLeglActnCost	= iamtUnrcvObjVO.tempExmpLeglActnCost   ;
		this.afterSetlExmpMidRmbrFee	= iamtUnrcvObjVO.tempExmpMidRmbrFee     ;
		this.afterSetlPdueDiscDfee		= iamtUnrcvObjVO.tempPdueDiscDfee       ;
		this.afterSetlLtrmBrcvAmt 		= iamtUnrcvObjVO.tempLtrmBrcvAmt        ;
	}

	public int tims;

	//청구대상금액
	public long askTotAmt;
	public long askDfee;
	public long askInt;
	public long askTrtFee;
	public long askPamt;
	public long askPpayInt;
	public long askAddEnvImprBrdnamt;
	public long askAddCartax;
	public long askAddInsuFee;
	public long askAddAsfee;
	public long askIpayEtc;
	public long askIpayPnltAmt;
	public long askIpayEnvImprBrdnamt;
	public long askIpayCartax;
	public long askIpayInsuFee;
	public long askVtax;

	//결제금액
	public long setlTotSetlAmt; //결제_금액
	public long setlSetlAmt; //결제_금액
	public long setlFrstAdjAmt; //임시선정산금액(원금우선순위 결제일때 사용.)
	public long setlFrstAdjIntAmt; //임시선정산이자금액(원금우선순위 결제일때 사용.)
	public long setlExmpAmt; //면제_금액(면제원금+면제이자+면제연체료+면제법적조치비용+면제중도상환수수료)
	public long setlExmpPamt; //면제_원금
	public long setlExmpInt; //면제_이자
	public long setlExmpTrtFee; //면제_취급수수료
	public long setlExmpDfee; //면제_연체료
	public long setlExmpLeglActnCost; //면제_법적_조치_비용
	public long setlExmpMidRmbrFee; //면제_중도_상환_수수료
	public long setlPdueDiscDfee; //선납_할인_연체료
	public long setlLtrmBrcvAmt ;   //장기_선수_금액
	public long setlExecGuarAmtTrnsAmt;   //보증_금액

	//결제후 남은 결제금
	public long afterTotSetlAmt; //결제_금액
	public long afterSetlSetlAmt; //결제_금액
	public long afterSetlFrstAdjAmt; //선정산금액(원금우선순위 결제일때 사용.)
	public long afterSetlFrstAdjIntAmt; //선정산이자금액(원금우선순위 결제일때 사용.)
	public long afterSetlExmpAmt; //면제_금액(면제원금+면제이자+면제연체료+면제법적조치비용+면제중도상환수수료)
	public long afterSetlExmpPamt; //면제_원금
	public long afterSetlExmpInt; //면제_이자
	public long afterSetlExmpTrtFee; //면제_취급수수료
	public long afterSetlExmpDfee; //면제_연체료
	public long afterSetlExmpLeglActnCost; //면제_법적_조치_비용
	public long afterSetlExmpMidRmbrFee; //면제_중도_상환_수수료
	public long afterSetlPdueDiscDfee; //선납_할인_연체료
	public long afterSetlLtrmBrcvAmt ;   //장기_선수_금액
	public long afterSetlExecGuarAmtTrnsAmt;   //보증_금액

	//정산금액
	public long adjAmt; //정산_금액
	public long adjExmpAmt; //정산_면제_금액
	public long adjLeglActnCost; //정산_법적_조치_비용
	public long adjExmpLeglActnCost; //정산_면제_법적_조치_비용
	public long adjPamt; //정산_원금(정산_면제_원금 포함)
	public long adjExmpPamt; //정산_면제_원금
	public long adjInt; //정산_이자(정산_면제_이자 포함)
	public long adjExmpInt; //정산_면제_이자
	public long adjTrtFee; //정산_취급수수료(정산_면제_이자 포함)
	public long adjExmpTrtFee; //정산_취급수수료(정산_면제_이자 포함)
	public long adjDfee; //정산_연체료(정산_면제_연체료,정산_선납_할인_연체료포함)
	public long adjExmpDfee; //정산_면제_연체료
	public long adjPdueDiscDfee; //정산_선납_할인_연체료
	public long adjMidRmbrFee; //정산_중도_상환_수수료
	public long adjExmpMidRmbrFee; //정산_면제_중도_상환_수수료
	public long adjTrtFeeDisc; //정산_취급_수수료_할인
	public long adjMidRmbrPAmt; //정산중도상환원금
	public long adjMidRmbrInt; //정산중도상환이자
	public long adjVtax               ;   //부가세
	public long adjPpayInt			  ;	  //선급_이자
	public long adjAddInsuFee         ;   //보험료
	public long adjAddCartax          ;   //차세
	public long adjAddEnvImprBrdnamt  ;   //환개금
	public long adjAddAsfee           ;   //가산_정비료
	public long adjIpayInsuFee        ;   //대지급_보험료
	public long adjIpayCartax         ;   //대지급_자동차세
	public long adjIpayEnvImprBrdnamt ;   //대지급_환경_개선_부담금
	public long adjIpayPnltAmt        ;   //대지급_범칙금
	public long adjIpayEtc            ;   //대지급_기타
	public long adjLtrmBrcvAmt        ;   //장기_선수_금액
	public long adjExecGuarAmtTrnsAmt   ;   //보증_금액

	//제외금액
	public long askLtrmBrcvAmt;	//장기선수대체_원금
	public long ltrmPamt; 		//장기선수대체_원금
	public long ltrmInt; 		//장기선수대체_이자
	public long ltrmPpayInt;  	//장기선수대체선급이자
	public long ltrmAddInsuFee; //장기선수대체가산보험료
	public long ltrmAddCartax;  //장기선수대체가산자동차세
	public long ltrmAddEnvImprBrdnamt;  //장기선수대체가산환개금
	public long ltrmAddAsfee;  //장기선수대체가산정비료

	@Override
	public String toString(){
		StringBuffer buff = new StringBuffer(1024);
		buff.append("\n");
		buff.append( "[입금처리] 회차정산 (" + this.tims + ")-----------------------------------------------------------\n");

		List askList = new ArrayList();
		addVal(askList,"askTotAmt"             );
		addVal(askList,"askDfee"               );
		addVal(askList,"askInt"                );
		addVal(askList,"askPamt"               );
		addVal(askList,"askTrtFee"             );
		addVal(askList,"askPpayInt"            );
		addVal(askList,"askAddEnvImprBrdnamt"  );
		addVal(askList,"askAddCartax"          );
		addVal(askList,"askAddInsuFee"         );
		addVal(askList,"askAddAsfee"           );
		addVal(askList,"askIpayEtc"            );
		addVal(askList,"askIpayPnltAmt"        );
		addVal(askList,"askIpayEnvImprBrdnamt" );
		addVal(askList,"askIpayCartax"         );
		addVal(askList,"askIpayInsuFee"        );
		addVal(askList,"askVtax"               );
		addVal(askList,"ltrmPamt"              );
		addVal(askList,"ltrmInt"               );
		addVal(askList,"ltrmPpayInt"           );
		addVal(askList,"ltrmAddInsuFee"        );
		addVal(askList,"ltrmAddCartax"         );
		addVal(askList,"ltrmAddEnvImprBrdnamt" );
		addVal(askList,"ltrmAddAsfee"          );
		addVal(askList,"askLtrmBrcvAmt"        );


		List adjList = new ArrayList();
		addVal( adjList, "adjAmt"                );
		addVal( adjList, "adjDfee"               );
		addVal( adjList, "adjInt"                );
		addVal( adjList, "adjPamt"               );
		addVal( adjList, "adjTrtFee"             );
		addVal( adjList, "adjPpayInt"            );
		addVal( adjList, "adjAddEnvImprBrdnamt"  );
		addVal( adjList, "adjAddCartax"          );
		addVal( adjList, "adjAddInsuFee"         );
		addVal( adjList, "adjAddAsfee"           );
		addVal( adjList, "adjIpayEtc"            );
		addVal( adjList, "adjIpayPnltAmt"        );
		addVal( adjList, "adjIpayEnvImprBrdnamt" );
		addVal( adjList, "adjIpayCartax"         );
		addVal( adjList, "adjIpayInsuFee"        );
		addVal( adjList, "adjVtax"               );


		List adjExmpList = new ArrayList();
		addVal( adjExmpList, "adjExmpAmt"            );
		addVal( adjExmpList, "adjExmpDfee"           );
		addVal( adjExmpList, "adjExmpInt"            );
		addVal( adjExmpList, "adjExmpPamt"           );
		addVal( adjExmpList, "adjExmpTrtFee"         );
		addVal( adjExmpList, "adjPdueDiscDfee"       );

		List setlList = new ArrayList();
		addVal(setlList, "setlTotSetlAmt");
		addVal(setlList, "setlSetlAmt");
		addVal(setlList, "setlFrstAdjAmt");
		addVal(setlList, "setlFrstAdjIntAmt");
		addVal(setlList, "setlExmpAmt");
		addVal(setlList, "setlExmpPamt");
		addVal(setlList, "setlExmpInt");
		addVal(setlList, "setlExmpDfee");
		addVal(setlList, "setlExmpLeglActnCost");
		addVal(setlList, "setlExmpMidRmbrFee");
		addVal(setlList, "setlExmpTrtFee");
		addVal(setlList, "setlPdueDiscDfee");
		addVal(setlList, "setlLtrmBrcvAmt");
		addVal(setlList, "setlExecGuarAmtTrnsAmt");

		List aftSetlList = new ArrayList();
		addVal(aftSetlList, "afterTotSetlAmt");
		addVal(aftSetlList, "afterSetlSetlAmt");
		addVal(aftSetlList, "afterSetlFrstAdjAmt");
		addVal(aftSetlList, "afterSetlFrstAdjIntAmt");
		addVal(aftSetlList, "afterSetlExmpAmt");
		addVal(aftSetlList, "afterSetlExmpPamt");
		addVal(aftSetlList, "afterSetlExmpInt");
		addVal(aftSetlList, "afterSetlExmpTrtFee");
		addVal(aftSetlList, "afterSetlExmpDfee");
		addVal(aftSetlList, "afterSetlExmpLeglActnCost");
		addVal(aftSetlList, "afterSetlExmpMidRmbrFee");
		addVal(aftSetlList, "afterSetlPdueDiscDfee");
		addVal(aftSetlList, "afterSetlLtrmBrcvAmt");
		addVal(aftSetlList, "afterSetlExecGuarAmtTrnsAmt");

		int maxCnt = sizeOfList(askList);
		if( maxCnt < sizeOfList(setlList)){
			maxCnt = sizeOfList(setlList);
		}
		if( maxCnt < sizeOfList(adjList)){
			maxCnt = sizeOfList(adjList);
		}
		if( maxCnt < sizeOfList(adjExmpList)){
			maxCnt = sizeOfList(adjExmpList);
		}
		if( maxCnt < sizeOfList(aftSetlList)){
			maxCnt = sizeOfList(aftSetlList);
		}

		for(int i=0; i<maxCnt;i++){
			buff.append( getStrValFromList(setlList, i) );
			buff.append( DIV );
			buff.append( getStrValFromList(askList, i) );
			buff.append( DIV );
			buff.append( getStrValFromList(adjList, i) );
			buff.append( DIV );
			buff.append( getStrValFromList(adjExmpList, i) );
			buff.append( DIV );
			buff.append( getStrValFromList(aftSetlList, i) );
			buff.append("\n");
		}
		return buff.toString();
	}

	private void addVal( List list, String colname ){
		Class c = this.getClass();
		try {
			Field f =  c.getField(colname);
			Object val = f.get(this);

			double amt = NumberUtils.toDouble( String.valueOf(val));
			if( amt != 0){
				list.add(getStr(colname) + getStr((long)amt));
			}
		} catch (Exception e) {
			//e.printStackTrace();
		}
	}

	private int sizeOfList(List list){
		if(list == null ){
			return 0;
		}
		return list.size();
	}

	private String getStrValFromList(List list, int idx){
		if( sizeOfList(list) > idx ){
			return (String)list.get(idx);
		}
		return StringUtils.leftPad("", 38, ' ');
	}


	private String getStr(String title){
		return StringUtils.rightPad(title, 23);
	}

	private String getStr(long amt){
		return StringUtils.leftPad(String.valueOf(amt), 15);
	}
}
