package hanalife.r.co.sr.service.impl;

import java.sql.SQLException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.CtCommCdDescDTO;
import hanalife.c.co.mapper.dto.RtRcptDsrcBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptRfndDescDTO;
import hanalife.c.co.mapper.dto.StMoAcntBaseDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.rc.service.IamtUnrcvService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;
import hanalife.r.co.sr.mapper.RfndRsltMapper;
import hanalife.r.co.sr.mapper.dto.SearchRfndINDTO;
import hanalife.r.co.sr.mapper.dto.SearchRfndOUTDTO;
import hanalife.r.co.sr.service.RfndRsltService;
import hanalife.r.co.sr.vo.RfndDescVO;
import hanalife.r.co.sr.vo.RfndRsltVO;

/**
 * <pre>
 * 클래스명    : RfndRsltServiceImpl
 * 클래스설명  : 환불결과처리ServiceImpl
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 4. 13.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RfndRsltService")
public class RfndRsltServiceImpl implements RfndRsltService {
	@Autowired
	private IamtUnrcvService iamtUnrcvService;
	@Autowired
	private AskUnrcvProcService askUnrcvProcService;
	@Autowired
	private RfndRsltMapper rfndRsltMapper;

	public static final String KIB_RECV_ERR = "W98"; //KIB전문수신이 안왔을때
	public static final String KIB_RECV_FORMMAT_ERR = "W97"; //KIB수신전문 포맷 에러
	public static final String KIB_TIEM_OUT = "001"; //KIB전문수신이 기관무응답으로 왔을때

	//환불결과처리 CC 응답코드
	public static final String SUCCESS = "0000"; //성공결과코드
	public static final String ERR_DSRC_ADJ_ERR = "W001"; //예가수처리중 에러
	public static final String ERR_COMM_ERR = "9999"; //수행중 발생한 에러

	//환불상태코드
	public static final String RFND_STAT_RFND_PROC_MID = "50"; //환불처리중
	public static final String RFND_STAT_RFND_ERR = "60"; //환불오류
	public static final String RFND_STAT_RFND_SCS = "70"; //환불성공
	public static final String RFND_STAT_DSRC = "00"; //예가수

	//수납유형코드( 환불관련 )
	public final String RFND_DIV_IMMD = "F1"; //즉시환불
	public final String RFND_DIV_CASH = "F2"; //환불_창구현금
	public final String RFND_DIV_BANK = "F3"; //환불_창구예금

	private static final Logger log = LoggerFactory.getLogger(RfndRsltServiceImpl.class);

	//환불결과처리
	@Override
	public RfndRsltVO procRfnd(RfndRsltVO rfndRsltVO) throws Exception {

		//환불대상 조회
		RfndDescVO savedRfndDesc = searchRfndDesc(rfndRsltVO.getPayNo(), rfndRsltVO.getDsrcNo(), rfndRsltVO.getRfndSnum());

		if (savedRfndDesc == null) {
			throw new Exception("환불결과 요청정보가 원장에 존재하지 않습니다.");
		}

		//외부에서 입력된 환불일자로 처리
		savedRfndDesc.setAcctDt(rfndRsltVO.getAcctDt());

		// 처리사번
		rfndRsltVO.setProcEmpNo(StringUtil.nvl(rfndRsltVO.getProcEmpNo(), savedRfndDesc.getLastProcEmpNo()));

		//대외계 환불처리결과가 정상일때 예가수정산처리(환불)를 한다.
		if (SUCCESS.equals(rfndRsltVO.getRfndRsltCd())) {
			procDsrc(rfndRsltVO, savedRfndDesc);
		}

		String rcptTpCd = savedRfndDesc.getRcptTpCd();
		if (StringUtil.in(rcptTpCd, new String[]{RFND_DIV_CASH, RFND_DIV_BANK}) && !SUCCESS.equals(rfndRsltVO.getRsltCd())) {
			log.info("창구환불 결과 return"+rfndRsltVO.getRsltCd());
			return rfndRsltVO;
		}

		//결과 상태를 수정한다.
		updateRslt(savedRfndDesc.getRcptTpCd(), rfndRsltVO);

		return rfndRsltVO;
	}

	/**
	 * <p>메소드명		: searchRfndDesc</p>
	 * <p>설    명		: 환불내역조회</p>
	 * <p>메소드 인수1	: String payNo</p>
	 * <p>메소드 인수2	: String dsrcNo</p>
	 * <p>메소드 인수3	: int rfndSnum</p>
	 * <p>메소드 인수4	: Connection</p>
	 * <p>메소드 리턴값	: RfndRsltVO</p>
	 * <p>예외처리		: SQLException</p>
	 */
	private RfndDescVO searchRfndDesc(String payNo, String dsrcNo, int rfndSnum) throws Exception {

		RfndDescVO rfndDescVO = new RfndDescVO();
		RtRcptRfndDescDTO inDTO = new RtRcptRfndDescDTO();
		RtRcptRfndDescDTO outDTO = new RtRcptRfndDescDTO();

		inDTO.setPayNo(payNo);
		inDTO.setDsrcNo(dsrcNo);
		inDTO.setRfndSnum(rfndSnum);

		if(!StringUtil.isNull(dsrcNo)) {
			outDTO = rfndRsltMapper.selectRfndDescPk(inDTO);
		}
		else {
			outDTO = rfndRsltMapper.selectRfndDesc(inDTO);
		}

		if(outDTO != null) {
			rfndDescVO.setRfndDt(outDTO.getRfndDt()); // 환불_일자
			rfndDescVO.setDsrcNo(outDTO.getDsrcNo()); // 가수_번호
			rfndDescVO.setRfndLoanNo(outDTO.getRfndLoanNo()); // 환불_대출_번호
			rfndDescVO.setRfndLoanSeq(outDTO.getRfndLoanSeq()); // 환불_대출_순번
			rfndDescVO.setAcctDt(outDTO.getAcctDt()); // 회계_일자
			rfndDescVO.setRfndStatCd(outDTO.getRfndStatCd()); // 환불_상태_코드
			rfndDescVO.setRcptTpCd(outDTO.getRcptTpCd()); // 수납_유형_코드
			rfndDescVO.setDsrcAdjAmt(outDTO.getDsrcAdjAmt().longValue()); // 예가수_정산_금액
			rfndDescVO.setIsrtDeptCd(outDTO.getIsrtDeptCd()); // 입력_부서_코드
			rfndDescVO.setAdjDeptCd(outDTO.getAdjDeptCd()); // 정산_부서_코드
			rfndDescVO.setLastProcEmpNo(outDTO.getLastProcEmpNo()); // 최초_등록_사원_번호
			rfndDescVO.setTrOrgCd(outDTO.getTrOrgCd()); // 거래_기관_코드
		}

		return rfndDescVO;
	}

	/**
	 * <p>메소드명		: procDsrc</p>
	 * <p>설    명		: 환불 후 예가수처리</p>
	 * <p>메소드 인수1	: RfndRsltVO</p>
	 * <p>메소드 인수2	: RfndDescVO</p>
	 * <p>메소드 인수3	: Connection</p>
	 * <p>메소드 리턴값	: RfndRsltVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	private RfndRsltVO procDsrc(RfndRsltVO rfndRsltVO, RfndDescVO searchVO) throws Exception {
		try {
			//청구미수 요청정보 셋팅
			AskUnrcvVO reqObj = setAskUnrcvVO(searchVO);
			if (!reqObj.isSuccess()) {
				rfndRsltVO.setRsltCd(ERR_DSRC_ADJ_ERR);
				rfndRsltVO.setRsltCntn("[" + reqObj.rsltCd + "] " + reqObj.rsltCntn);
				return rfndRsltVO;
			}

			//입금미수 요청정보 셋팅
			IamtUnrcvVO reqIamt = setIamtUnrcvVO(reqObj.getBndVO(0), rfndRsltVO, searchVO);

			reqIamt = iamtUnrcvService.calcRcptDsrcAdj(reqIamt, reqObj);
			if (!reqIamt.isSuccess()) {
				rfndRsltVO.setRsltCd(ERR_DSRC_ADJ_ERR);
				rfndRsltVO.setRsltCntn("[" + reqIamt.rsltCd + "] " + reqIamt.rsltCntn);
			}

			IamtUnrcvObjVO iamtObj = reqIamt.getIamtUnrcvObjVO(0);

			//결제정보 셋팅
			rfndRsltVO.setSetlNo(iamtObj.setlNo);
			rfndRsltVO.setDsrcSnum(iamtObj.dsrcSnum);

		} catch (Exception e) {
			log.error("예가수정산처리중 에러발생", e);
			rfndRsltVO.setRsltCd(ERR_DSRC_ADJ_ERR);
			rfndRsltVO.setRsltCntn("[" + ERR_DSRC_ADJ_ERR + "] " + e.getMessage());
			throw new Exception("[" + ERR_DSRC_ADJ_ERR + "] " + e.getMessage());
		}
		return rfndRsltVO;
	}

	/**
	 * <p>환불결과처리
	 * @param rcptTpCd
	 * @param rfndRsltVO
	 * @param con
	 * @return
	 * @throws Exception
	 */
	private RfndRsltVO updateRslt(String rcptTpCd, RfndRsltVO rfndRsltVO) throws Exception {

		log.info("■ [RT_RCPT_RFND_DESC] 수정");
		updateRfndDesc(rcptTpCd, rfndRsltVO);

		log.info("■ [RT_RCPT_DSRC_BASE] 수정");
		updateDsrcBase(rcptTpCd, rfndRsltVO);

		return rfndRsltVO;
	}

	/**
	 * <p>메소드명		: updateRfndDesc</p>
	 * <p>설    명		: [환불내역] 업데이트</p>
	 * <p>메소드 인수1	: String rcptTpCd</p>
	 * <p>메소드 인수2	: RfndRsltVO</p>
	 * <p>메소드 인수3	: Connection</p>
	 * <p>메소드 리턴값	: RfndRsltVO</p>
	 * <p>예외처리		: SQLException</p>
	 */
	private RfndRsltVO updateRfndDesc(String rcptTpCd, RfndRsltVO rfndRsltVO) throws Exception {

		String rfndRsltCd = rfndRsltVO.getRfndRsltCd();
		String rfndStatCd = RFND_STAT_RFND_PROC_MID; //환불처리중...

		RfndDescVO updateVO = new RfndDescVO();
			updateVO.setSetlFg("0");	//default
			updateVO.setSetlNo(0);		//default
			updateVO.setDsrcSnum(0);	//default

		//즉시환불시
		if (rcptTpCd.equals(RFND_DIV_IMMD)) {
			if (!ERR_DSRC_ADJ_ERR.equals(rfndRsltVO.getRsltCd())) {
				if (SUCCESS.equals(rfndRsltCd)) {
					rfndStatCd = RFND_STAT_RFND_SCS; //환불성공
					updateVO.setSetlFg("1");
					updateVO.setSetlNo(rfndRsltVO.getSetlNo());
					updateVO.setDsrcSnum(rfndRsltVO.getDsrcSnum());
				} else if (StringUtil.in(rfndRsltCd, new String[]{KIB_RECV_ERR, KIB_TIEM_OUT, KIB_RECV_FORMMAT_ERR})) {
					rfndStatCd = RFND_STAT_RFND_PROC_MID; //환불처리중...
				} else {
					rfndStatCd = RFND_STAT_RFND_ERR; //환불실패
				}
			}
		}
		// 즉시환불 외
		else {
			if (!rfndRsltVO.getRsltCd().equals(SUCCESS)) {
				rfndStatCd = RFND_STAT_RFND_ERR;
				rfndRsltCd = ERR_DSRC_ADJ_ERR;	//예가수정산실패
			} else {
				rfndStatCd = RFND_STAT_RFND_SCS;
				rfndRsltCd = SUCCESS; //예가수정산성공
				updateVO.setSetlFg("1");
				updateVO.setSetlNo(rfndRsltVO.getSetlNo());
				updateVO.setDsrcSnum(rfndRsltVO.getDsrcSnum());
			}
			//결과코드 재수정
			rfndRsltVO.setRfndRsltCd(rfndRsltCd);
		}

		//set
		updateVO.setRfndStatCd(rfndStatCd);
		updateVO.setRfndRsltCd(rfndRsltCd);
		updateVO.setPayNo(rfndRsltVO.getPayNo());
		updateVO.setAcctDt(rfndRsltVO.getAcctDt());
		updateVO.setLastProcEmpNo(rfndRsltVO.getProcEmpNo());

		//where
		updateVO.setDsrcNo(rfndRsltVO.getDsrcNo());
		updateVO.setRfndSnum(rfndRsltVO.getRfndSnum());

		if (updateRfndDesc(updateVO)!=1) {
			rfndRsltVO.setRsltCd(ERR_COMM_ERR);
			rfndRsltVO.setRsltCntn("환불처리결과를 수정할수 없습니다.");
		}
		return rfndRsltVO;
	}

	private RfndRsltVO updateDsrcBase(String rcptTpCd, RfndRsltVO rfndRsltVO) throws Exception {

		String rfndStatCd = RFND_STAT_DSRC; //성공, 실패 등의 환불처리중일때 환불상태코드는 예가수상태로 수정.
		String rfndRsltCd = rfndRsltVO.getRfndRsltCd();

		//즉시환불 시
		if (rcptTpCd.equals(RFND_DIV_IMMD)) {
			if (ERR_DSRC_ADJ_ERR.equals(rfndRsltVO.getRsltCd()) || StringUtil.in(rfndRsltCd, new String[]{KIB_RECV_ERR, KIB_TIEM_OUT})) {
				//예가수정산시 에러, 환불결과코드가 수신에러, 은행무응답일때
				rfndStatCd = RFND_STAT_RFND_PROC_MID; //환불처리중
			}
		}
		//즉시환불 외
		else {
			if(!rfndRsltVO.getRsltCd().equals(SUCCESS)) {
				rfndStatCd = RFND_STAT_DSRC;
				rfndRsltCd = ERR_DSRC_ADJ_ERR; //예가수정산실패
			} else {
				rfndStatCd = RFND_STAT_DSRC;
				rfndRsltCd = "000";	//예가수정산성공
			}
			//결과코드 재수정.
			rfndRsltVO.setRfndRsltCd(rfndRsltCd);
		}

		RfndDescVO updateVO = new RfndDescVO();

		//set
		updateVO.setRfndStatCd(rfndStatCd);
		updateVO.setLastProcEmpNo(rfndRsltVO.getProcEmpNo());

		//where
		updateVO.setDsrcNo(rfndRsltVO.getDsrcNo());
		updateVO.setRfndSnum(rfndRsltVO.getRfndSnum());

		if (updateDsrcBase(updateVO) != 1) {
			rfndRsltVO.setRsltCd(ERR_COMM_ERR);
			rfndRsltVO.setRsltCntn("환불처리결과를 수정할수 없습니다.");
		}
		return rfndRsltVO;
	}

	/**
	 * <p>메소드명		: setAskUnrcvVO</p>
	 * <p>설명			: 청구미수관련 SET</p>
	 * <p>메소드인수1 	: RfndDescVO</p>
	 * <p>메소드인수2 	: Connection</p>
	 * <p>메소드리턴값	: AskUnrcvVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	private AskUnrcvVO setAskUnrcvVO(RfndDescVO searchVO) throws Exception {

		AskUnrcvObjVO askObj = new AskUnrcvObjVO();
			askObj.loanNo  = searchVO.getRfndLoanNo();
			askObj.loanSeq = searchVO.getRfndLoanSeq();
			askObj.dsrcNo  = searchVO.getDsrcNo();

		AskUnrcvVO reqObj = new AskUnrcvVO();
			reqObj.addAskUnrcvObj(askObj);

		//예가수 잔액조회
		return askUnrcvProcService.calcDsrcRamt(reqObj);
	}

	/**
	 * <p>메소드명		: setIamtUnrcvVO</p>
	 * <p>설명			: 입금미수관련 SET</p>
	 * <p>메소드인수1 	: BndVO</p>
	 * <p>메소드인수2 	: RfndRsltVO</p>
	 * <p>메소드인수3 	: RfndDescVO</p>
	 * <p>메소드인수4 	: Connection</p>
	 * <p>메소드리턴값	: IamtUnrcvVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	private IamtUnrcvVO setIamtUnrcvVO(BndVO bndVO, RfndRsltVO rfndRsltVO, RfndDescVO searchVO) throws Exception {

		String rcptTpCd = searchVO.getRcptTpCd();

		String rfndDeptCd = searchVO.getIsrtDeptCd();

		IamtUnrcvVO reqIamt = new IamtUnrcvVO();
		RfndDescVO acnts = new RfndDescVO();

		if (rcptTpCd.equals(RFND_DIV_IMMD)) {
			reqIamt.autoSetlFg = Constants.YES;

			//즉시환불,예금환불
			acnts = searchRfndMoAcnt(searchVO);
			if (acnts == null) {
				throw new Exception("환불모계좌정보가 등록되어 있지 않습니다. 시스템관리자에게 문의하세요.");
			}

			rfndDeptCd = searchRfndDept();
			if (rfndDeptCd == null) {
				throw new Exception("본부부서코드가 등록되어 있지 않습니다(R000038). 시스템관리자에게 문의하세요.");
			}
		}

		IamtUnrcvObjVO iamtObj = new IamtUnrcvObjVO();
			iamtObj.loanNo = searchVO.getRfndLoanNo();
			iamtObj.loanSeq = searchVO.getRfndLoanSeq();
			iamtObj.acctDt = searchVO.getAcctDt();
			iamtObj.setlDt = searchVO.getAcctDt();

			iamtObj.acctUnitCd = "W01";
			iamtObj.setlDivCd = Constants.SETL_DIV_DSRC;
			iamtObj.rcptTpCd = rcptTpCd;
			iamtObj.dsrcNo = searchVO.getDsrcNo();
			iamtObj.dsrcOccrCd = bndVO.dsrcOccrCd;
			if(Constants.RCPT_DIV_DSRC_INTG_ADJ.equals(rcptTpCd)){
				iamtObj.dsrcAdjCd = Constants.DSRC_DIV_INTG_ADJ;
                reqIamt.vochUnprocFg = Constants.YES;  // 예가수통합 정리는 전표를 발생시키지 않는다.
			} else {
				iamtObj.dsrcAdjCd = Constants.DSRC_DIV_RFND;
			}
			iamtObj.setlAmt = 0;
			iamtObj.rcptAmt = searchVO.getDsrcAdjAmt();
			iamtObj.dsrcAdjAmt = searchVO.getDsrcAdjAmt();

			iamtObj.isrtDeptCd = rfndDeptCd;
			iamtObj.adjDeptCd = bndVO.dsrcAdjDeptCd;
			iamtObj.frstRegEmpNo = searchVO.getLastProcEmpNo();
			iamtObj.sysPathCd = rfndRsltVO.getSysPathCd();

			//환불모계좌정보
			iamtObj.bankCd = acnts.getBankCd();
			iamtObj.acntNo = acnts.getAcntNo();

		reqIamt.addIamtUnrcvObjVO(iamtObj);
		return reqIamt;
	}

	/**
	 * <p>메소드명		: searchRfndResultObj</p>
	 * <p>설명			: 환불결과 반영 대상 조회 (지급 후 처리할 대상)</p>
	 * <p>메소드인수1 	: String payNo</p>
	 * <p>메소드인수2 	: Connection</p>
	 * <p>메소드리턴값	: RfndRsltVO</p>
	 * <p>예외처리		: SQLException</p>
	 */
	@Override
	public RfndRsltVO searchRfndResultObj(String payNo) throws Exception {

		RfndRsltVO rfndRsltVO = new RfndRsltVO();

		SearchRfndINDTO inDTO = new SearchRfndINDTO();
		inDTO.setPayNo(payNo);

		SearchRfndOUTDTO outDTO = rfndRsltMapper.searchRfnd(inDTO);

		if(outDTO != null) {
			rfndRsltVO.setDsrcNo(outDTO.getDsrcNo()); // 예가수번호
			rfndRsltVO.setRfndSnum(outDTO.getRfndSnum()); // 환불일련번호
			rfndRsltVO.setPayNo(outDTO.getPayNo()); // 지급번호
			rfndRsltVO.setLoanNo(outDTO.getRfndLoanNo()); // 대출번호
			rfndRsltVO.setLoanSeq(outDTO.getRfndLoanSeq()); // 대출순번
			rfndRsltVO.setCustNo(outDTO.getCustNo()); // 고객번호
			rfndRsltVO.setCustNm(outDTO.getCustNm()); // 고객명
			rfndRsltVO.setBankNm(outDTO.getBankNm()); // 은행명
			rfndRsltVO.setTranAmt(outDTO.getAmt()); // 이체금액
			rfndRsltVO.setSendSmsFg(outDTO.getSmsSendFg()); // SMS전송여부
			rfndRsltVO.setHp1(outDTO.getCntcPlcTel1()); // 고객핸드폰1
			rfndRsltVO.setHp2(outDTO.getCntcPlcTel2()); // 고객핸드폰2
			rfndRsltVO.setHp3(outDTO.getCntcPlcTel3()); // 고객핸드폰3
			rfndRsltVO.setRetnTel(outDTO.getRetnTel()); // 회신번호
			rfndRsltVO.setCmpmNm(outDTO.getCmpnNm()); // 회사명
			rfndRsltVO.setSendUserNo(outDTO.getLastProcEmpNo()); // 발송사번
			rfndRsltVO.setMngDeptCd(outDTO.getMngDeptCd()); // 관리부서
		}

		return rfndRsltVO;
	}

	/**
	 * TODO 미사용 - 향후 사용시 개발
	 * 예가수 환불처리 결재요청에 대한 쪽지 알림
	 * @param dsrcNo
	 * @param empNo
	 * @param clientIp
	 * @param con
	 */
	//public void sendOcTalkForJst(String dsrcNo, String empNo, String clientIp) {


	/**
	 * TODO 미사용 - 향후 사용시 개발
	 * 예가수 환불처리 결재완료시 본요청자에게 쪽지 알림
	 * @param dsrcNo
	 * @param empNo
	 * @param clientIp
	 * @param con
	 */
	//public void sendOcTalkForJstRslt(String dsrcNo, String empNo, String clientIp) {

	/**
	 * TODO 미사용 - 향후 사용시 개발
	 * 예가수 환불내역 조회
	 * @param dsrcNo
	 * @param rfndStatCd (R00032 - 30 결재대기, 40 환불대기)
	 * @param con
	 * @return
	 */
	//private Map searchDsrcRfndDescForJst(String dsrcNo, String rfndStatCd){


	/**
	 * sms전송 환불결과 업데이트
	 * @param rfndRsltVO
	 * @param sendSms
	 * @param smsTxt
	 * @param con
	 */
	@Override
	public int updateSmsRslt(RfndRsltVO rfndRsltVO, boolean sendSms, String smsTxt){

		int exeCnt = 0;

		RtRcptRfndDescDTO inDTO = new RtRcptRfndDescDTO();

		inDTO.setSmsSendStatCd(sendSms?"3":"4");
		inDTO.setSmsSendTxt(StringUtil.strCut(smsTxt,80));
		inDTO.setPayNo(rfndRsltVO.getPayNo());	//지급번호

		try {
			exeCnt = rfndRsltMapper.updateSmsRslt(inDTO);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: updateRfndDesc</p>
	 * <p>설명			: UPDATE [환불내역]</p>
	 * <p>메소드인수1 	: RfndDescVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateRfndDesc(RfndDescVO rfndDescVO) throws SQLException {

		int exeCnt = 0;

		String yyyymmdd = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		String hhmmss = DateUtil.getServerDate(DateUtil.HHMMSS);

		RtRcptRfndDescDTO inDTO = new RtRcptRfndDescDTO();

		inDTO.setRfndStatCd(rfndDescVO.getRfndStatCd());//환불상태코드
		inDTO.setRfndRsltCd(rfndDescVO.getRfndRsltCd());//환불_결과_코드
		inDTO.setPayNo(rfndDescVO.getPayNo());	//지급번호
		inDTO.setRfndDt(rfndDescVO.getAcctDt());//환불일자
		inDTO.setAcctDt(rfndDescVO.getAcctDt());//회계일자
		inDTO.setDsrcSnum(rfndDescVO.getDsrcSnum());//DSRC_SNUM
		inDTO.setSetlFg(rfndDescVO.getSetlFg());//SETL_FG
		inDTO.setSetlNo(rfndDescVO.getSetlNo());//SETL_NO
		inDTO.setDsrcNo(rfndDescVO.getDsrcNo());//예가수_번호
		inDTO.setRfndSnum(rfndDescVO.getRfndSnum());//환불순번
		inDTO.setLastProcDt(yyyymmdd); //최종처리일자
		inDTO.setLastProcTm(hhmmss); //최종처리시간
		inDTO.setLastProcEmpNo(rfndDescVO.getLastProcEmpNo()); //최종처리자사번

		try {
			exeCnt = rfndRsltMapper.updateRfndDescStat(inDTO);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: updateDsrcBase</p>
	 * <p>설명			: UPDATE [예가수기본]</p>
	 * <p>메소드인수1 	: RfndDescVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateDsrcBase(RfndDescVO rfndDescVO) throws SQLException {

		int exeCnt = 0;

		RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();

		inDTO.setRfndStatCd(rfndDescVO.getRfndStatCd());//환불상태코드
		inDTO.setDsrcNo(rfndDescVO.getDsrcNo());//예가수_번호

		inDTO.setLastProcEmpNo(rfndDescVO.getLastProcEmpNo()); //최종처리자사번

		try {
			exeCnt = rfndRsltMapper.updateDsrcStat(inDTO);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return exeCnt;
	}

    /**
   	 * <p>메소드명		: searchRfndDept</p>
   	 * <p>설명			: 환불부서조회</p>
   	 * <p>메소드리턴값	: 부서코드</p>
   	 * <p>예외처리		: SQLException</p>
   	 */
	private String searchRfndDept() throws Exception{

		CtCommCdDescDTO inDTO = new CtCommCdDescDTO();
		String sRtn = "";

		inDTO.setCdKindNo("R00038"); //공통코드 종류번호
		inDTO.setCdDescNo("1");

		try {
			CtCommCdDescDTO outDTO = rfndRsltMapper.searchRfndDept(inDTO);

			if(outDTO != null) {
				sRtn = outDTO.getClas1();
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return sRtn;
    }


	/**
   	 * <p>메소드명		: searchRfndAcnt</p>
   	 * <p>설명			: 환불모계좌조회</p>
   	 * <p>메소드인수1 	: Connection</p>
   	 * <p>메소드리턴값	: String[은행코드, 계좌번호]</p>
   	 * <p>예외처리		: SQLException</p>
   	 */
    private RfndDescVO searchRfndMoAcnt(RfndDescVO rfndDescVO) throws Exception {
    	StMoAcntBaseDTO inDTO = new StMoAcntBaseDTO();

    	RfndDescVO rtnVO = new RfndDescVO();

		inDTO.setBsnDivCd(Constants.PAY_DIV_RFND); // 환불지급

		try {
			StMoAcntBaseDTO outDTO = rfndRsltMapper.selectTrOrgMoAcnt(inDTO);

			if(outDTO != null) {
				rtnVO.setBankCd(outDTO.getBankCd());
				rtnVO.setAcntNo(outDTO.getMoAcntNo());
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			throw new Exception("환불모계좌정보가 등록되어 있지 않습니다. 시스템관리자에게 문의하세요.");
		}

		return rfndDescVO;
    }
}
