package hanalife.r.co.vo.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.AtFincClsDTO;
import hanalife.c.co.mapper.dto.RtClsBaseDTO;
import hanalife.c.co.mapper.dto.RtClsSubDescDTO;
import hanalife.c.co.mapper.dto.RtClsTrDescDTO;
import hanalife.r.co.vo.mapper.dto.ChkVochCreateBeforeINDTO;
import hanalife.r.co.vo.mapper.dto.ChkVochCreateBeforeOUTDTO;
import hanalife.r.co.vo.mapper.dto.ErrRqstVochDescOUTDTO;
import hanalife.r.co.vo.mapper.dto.ProcVochCreateINOUTDTO;
import hanalife.r.co.vo.mapper.dto.SearchDcAmtOUTDTO;
import hanalife.r.co.vo.mapper.dto.SearchTrTpINDTO;
import hanalife.r.co.vo.mapper.dto.SearchTrTpOUTDTO;



/**
 * <pre>
 * 클래스명    : VochCCMapper.java
 * 클래스설명  : 전표처리 Mapper
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 4. 18.
 * 작성자명    : 70279
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 18.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Mapper("vochCCMapper")
public interface VochCCMapper {

	/**
	 * 차대금액 확인
	 * @param RtClsSubDescDTO
	 * @return SearchDcAmtOUTDTO
	 * @throws Exception
	 */
	public SearchDcAmtOUTDTO searchDcAmt(RtClsSubDescDTO inDTO) throws Exception;

	/**
	 * 거래서브내역(계정내역) 조회
	 * @param RtClsSubDescDTO
	 * @return ErrRqstVochDescOUTDTO
	 * @throws Exception
	 */
	public List<ErrRqstVochDescOUTDTO> errRqstVochDesc(RtClsSubDescDTO inDTO) throws Exception;

	/**
	 * 이체유형 조회
	 * @param RtClsSubDescDTO
	 * @return RtClsSubDescDTO
	 * @throws Exception
	 */
	public List<RtClsSubDescDTO> searchTranTp(RtClsSubDescDTO inDTO) throws Exception;

	/**
	 * 마감정보(기본) 조회
	 * @param RtClsBaseDTO
	 * @return RtClsBaseDTO
	 * @throws Exception
	 */
	public RtClsBaseDTO searchClsInfo(RtClsBaseDTO inDTO) throws Exception;

	/**
	 * 마감기본 생성
	 * @param RtClsBaseDTO
	 * @return int
	 * @throws Exception
	 */
	int createClsBase(RtClsBaseDTO inDTO) throws Exception;

	/**
	 * 이체번호 수정
	 * @param RtClsSubDescDTO
	 * @return int
	 * @throws Exception
	 */
	int updateTranNo(RtClsSubDescDTO inDTO) throws Exception;

	/**
	 * 회계전표처리(이체)
	 * @param ProcVochCreateINOUTDTO
	 * @return ProcVochCreateINOUTDTO
	 * @throws Exception
	 */
	public ProcVochCreateINOUTDTO procVochCreate(ProcVochCreateINOUTDTO inDTO) throws Exception;


	/**
	 * 금액 항목번호별 금액 조회
	 * @param RtClsSubDescDTO
	 * @return long
	 * @throws Exception
	 */
	public List<RtClsTrDescDTO> chkSubDescAmt(RtClsTrDescDTO inDTO) throws Exception;

	/**
	 * 보조내역 등록 - 회계단위코드
	 * @param RtClsSubDescDTO
	 * @return int
	 * @throws Exception
	 */
	public int createSubDescWithAcctUnit(RtClsSubDescDTO inDTO) throws Exception;

	/**
	 * 거래내역번호 채번
	 * @param N/A
	 * @return int
	 * @throws Exception
	 */
	public int getMaxTrDescNo() throws Exception;

	/**
	 * 회계부서(일 마감정보) 조회
	 * @param AtFincClsDTO
	 * @return AtFincClsDTO
	 * @throws Exception
	 */
	public AtFincClsDTO searchAcctDept(AtFincClsDTO inDTO) throws Exception;

	/**
	 * 거래유형조회
	 * @param SearchTrTpINDTO
	 * @return SearchTrTpOUTDTO
	 * @throws Exception
	 */
	public List<SearchTrTpOUTDTO> searchTrTp(SearchTrTpINDTO inDTO) throws Exception;

	/**
	 * 전표 오류발생시 입력값을 로깅처리함
	 * @param SearchTrTpINDTO
	 * @return SearchTrTpOUTDTO
	 * @throws Exception
	 */
	public List<ChkVochCreateBeforeOUTDTO> chkVochCreateBefore(ChkVochCreateBeforeINDTO inDTO) throws Exception;

	/**
     * 전표이체처리를 위한 정보 조회(배치용)
     * @param ProcVochCreateINOUTDTO
     * @return ProcVochCreateINOUTDTO
     * @throws Exception
     */
    public List<ProcVochCreateINOUTDTO> searchVochTran(ProcVochCreateINOUTDTO inDTO) throws Exception;
}


