package hanalife.r.co.vo.service.impl;

import java.math.BigDecimal;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.RtClsTrDescMapper;
import hanalife.c.co.mapper.dto.AtFincClsDTO;
import hanalife.c.co.mapper.dto.RtClsBaseDTO;
import hanalife.c.co.mapper.dto.RtClsSubDescDTO;
import hanalife.c.co.mapper.dto.RtClsTrDescDTO;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.vo.mapper.VochCCMapper;
import hanalife.r.co.vo.mapper.dto.ChkVochCreateBeforeINDTO;
import hanalife.r.co.vo.mapper.dto.ChkVochCreateBeforeOUTDTO;
import hanalife.r.co.vo.mapper.dto.ErrRqstVochDescOUTDTO;
import hanalife.r.co.vo.mapper.dto.ProcVochCreateINOUTDTO;
import hanalife.r.co.vo.mapper.dto.SearchDcAmtOUTDTO;
import hanalife.r.co.vo.mapper.dto.SearchTrTpINDTO;
import hanalife.r.co.vo.mapper.dto.SearchTrTpOUTDTO;
import hanalife.r.co.vo.service.VochCCService;
import hanalife.r.co.vo.vo.ClsBaseVO;
import hanalife.r.co.vo.vo.ClsTrDescVO;
import hanalife.r.co.vo.vo.VochVO;
import hanalife.util.BizException;

/**
 * <pre>
 * 클래스명    : VochCCService.java
 * 클래스설명  : 전표처리CC, 입력된 거래를 등록하고 전표처리
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 4. 18.
 * 작성자명    : 70279 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("VochCCService")
public class VochCCServiceImpl implements VochCCService {

	private Logger log = LoggerFactory.getLogger(VochCCServiceImpl.class);

	@Autowired
	private CommBizService commBizService;
	@Autowired
	private VochCCMapper vochCCMapper;
	@Autowired
	private RtClsTrDescMapper rtClsTrDescMapper;

	/**
	 * <p>회계단위를 발생,관리로 구분하여 전표처리한다.
	 * @param inVO
	 * @param con
	 * @return
	 * @throws BizException
	 */
	@Override
	public VochVO procVochWithAcctUnit(VochVO inVO) throws Exception{
		try {

			inVO.setRsltCd(Constants.SUCCESS);

			// 제어할지 사용여부 코드
			if (commBizService.isChk("RCHECK", "AVO001")) {
				if (!commBizService.isWorkDt(inVO.getAcctDt())) {
					throw new Exception("휴일은 전표처리 할 수 없습니다.");
				}
			}
			log.info("################ procVochWithAcctUnit 1");
			//마감거래내역 등록
			//입력된 마감거래내역 리스트가 DB에 등록되고 거래내역번호가 채번된다.
			inVO = createClsTrDescWithAcctUnit(inVO);
			log.info("################ procVochWithAcctUnit2");
			//보조거래내역 등록
			inVO = createSubTrWithAcctUnit(inVO);
			log.info("################ procVochWithAcctUnit 3");
			//차대금액확인
			chkDcAmt(inVO);
			log.info("################ procVochWithAcctUnit 4");
			// 이체번호를 등록하고 회계이체처리를 한다.
			inVO = updateTranNo(inVO);
			log.info("################ procVochWithAcctUnit 5");
		} catch (Exception e) {
			throw new BizException("회계이체처리 오류발생: " + e.getMessage());
		}

		return inVO;
	}

	/**
	 * 회계구분에 따른 차대금액 체크
	 * @param inVO
	 * @param con
	 * @throws Exception
	 */
	private void chkDcAmt(VochVO inVO) throws Exception{
	    log.info("################ chkDcAmt 1 inVO["+inVO+"]");
		String procDivCd = inVO.getProcDivCd();
		log.info("################ chkDcAmt 2");
		if (Constants.ONLYKGAAP.equals(procDivCd)) { //IFRS 회계기준 구분(01:KGAPP + KIFRS, 02:KIFRS, 03:ONLYKGAAP) 2018-08-01 두비스 kgaap만 무조건 처리되도록 변경
			//KGAP
			searchDcAmt(inVO.getAcctDt(), inVO.getTrDescNo());

		} else if (Constants.KGAAP.equals(procDivCd)) {
			throw new BizException("회계처리구분이 잘못입력되었습니다.(IFRS 처리)");
		} else if (Constants.KIFRS.equals(procDivCd)) {
			throw new BizException("회계처리구분이 잘못입력되었습니다.(IFRS 처리)");
		} else {
			throw new BizException("KGAP/IFRS 처리구분이 없습니다.");
		}
		log.info("################ chkDcAmt 3");
	}

	/**
	 * 체크 후 오류 info 부분 추가
	 * 2018-08-01 홍일권 추가
	 */
	private void printErr(VochVO inVO, Throwable tr) {
		if (tr != null) {
			log.error("전표처리중 에러발생 (입력값 : " + inVO +")", tr);
		} else {
			log.error("전표처리중 에러발생 (입력값 : " + inVO +")");
		}
		try {
			errRqstVochDesc(tr, inVO.getAcctDt(), inVO.getTrDescNo());
		} catch (Exception ignore) {
			// 무시
		}
		if (inVO != null) {
			log.warn("전표처리중 에러발생 getAcctDt" + inVO.getAcctDt());
			log.warn("전표처리중 에러발생 getTrDescNo" + inVO.getTrDescNo());
		}
	}

	/**
	 * @param inVO
	 * @param con
	 * @return
	 * @throws Exception
	 */
	private VochVO updateTranNo(VochVO inVO) throws Exception {
	    log.info("################ updateTranNo 1");
		List clsTrListKGAP = new ArrayList();
		List clsTrListIFRS = new ArrayList();

		String acctDt = "";
		String acctDeptCd = "";
		String tranTpCd = "";
		int tranNo = 0;
		String acctUnitCd = "";
		String isrtEmpNo = "";
		log.info("################ updateTranNo 2");
		//IFRS여부 확인
		String procDivCd = inVO.getProcDivCd();
		if (Constants.KGAAP.equals(procDivCd) || Constants.ONLYKGAAP.equals(procDivCd)) {
		    log.info("################ updateTranNo 2-1");
			clsTrListKGAP = searchTranTp(inVO.getAcctDt(), inVO.getTrDescNo());
		}

		if (Constants.KGAAP.equals(procDivCd) || Constants.KIFRS.equals(procDivCd)) {
		    log.info("################ updateTranNo 2-2");
			throw new BizException("IFRS는 처리할수 없습니다.");
			// clsTrListIFRS = dao.searchTranTp_IFRS(inVO.getAcctDt(), inVO.getTrDescNo());
		}
		log.info("################ updateTranNo 3");
		//KGAP 보조거래내역이 없으면 IFRS 보조거래내역으로 처리한다.
		List clsTrList = mergeList(clsTrListKGAP,clsTrListIFRS);
		log.info("################ updateTranNo 4");
		//KGAP/IFRS 둘다 보조내역이 존재하지 않으면 에러!
		if (clsTrList == null || clsTrList.size() == 0) {
			log.error("전표처리중 에러발생-updateTranNo-- (입력값 : " + inVO +")");
			try {
				errRqstVochDesc(null, inVO.getAcctDt(), inVO.getTrDescNo());
			} catch (Exception ignore) {
				// 무시
			}
			throw new BizException("보조내역 생성건이 없습니다.");
		}
		log.info("################ updateTranNo 5");
		for (int i=0, n = clsTrList.size(); i<n;i++) {
		    log.info("################ updateTranNo 6");
			String clsInfo[] = (String[])clsTrList.get(i);

			ClsBaseVO clsBaseVO = searchClsInfo(clsInfo[1], clsInfo[2], clsInfo[3], clsInfo[4]);
			log.info("################ updateTranNo 6-1");
			if (clsBaseVO == null || "1".equals(clsBaseVO.getVochClsFg())) {
			    log.info("################ updateTranNo 6-2");
				clsBaseVO = new ClsBaseVO();
				clsBaseVO.setAcctDt(clsInfo[1]);
				clsBaseVO.setAcctUnitCd(clsInfo[2]);
				clsBaseVO.setAcctDeptCd(clsInfo[3]);
				clsBaseVO.setTranTpCd(clsInfo[4]);
				clsBaseVO.setTranNo(gvnoTranNo(clsInfo[1], clsInfo[2], clsInfo[3], clsInfo[4], inVO.getIsrtEmpNo()));
				clsBaseVO.setProcEmpNo(inVO.getIsrtEmpNo());
				createClsBase(clsBaseVO);
			}

			String div = clsInfo[0];
			log.info("################ updateTranNo 6-3");
			//KGAP 또는 공통일때
			if (Constants.KGAAP.equals(div) || Constants.ONLYKGAAP.equals(div)) {
				updateTranNo(clsBaseVO.getTranNo(), clsBaseVO.getAcctDt(), clsBaseVO.getAcctUnitCd(), inVO.getTrDescNo(), clsBaseVO.getAcctDeptCd());
			}

			//IFRS 또는 공통일때
			if (Constants.KGAAP.equals(div) || Constants.KIFRS.equals(div)) {
				throw new BizException("IFRS 처리는 할수 없습니다.");
//				dao.updateTranNo_IFRS(clsBaseVO.getTranNo(), clsBaseVO.getAcctDt(), clsBaseVO.getAcctUnitCd(), inVO.getTrDescNo(), clsBaseVO.getAcctDeptCd());
			}
			log.info("################ updateTranNo 6-4");
			//이체처리를 위해 변수 항목 저장
			acctDt = clsBaseVO.getAcctDt();
			acctDeptCd = clsBaseVO.getAcctDeptCd();
			tranTpCd = clsBaseVO.getTranTpCd();
			tranNo = clsBaseVO.getTranNo();
			acctUnitCd = clsBaseVO.getAcctUnitCd();
			isrtEmpNo = inVO.getIsrtEmpNo();

			/*
			 * 이체처리 프로시져 추가 2018-08-01 홍일권
			 *   AT_전표_기본, AT_전표_내역, AT_원천세, AT_총계정_원장 생성 및 반영
			 * DBSACCT.AP_AGAVO01_01(회계일자, 회계부서, 이체유형, 이체순번, 회계단위, 작업자, 에러메세지)
			 */
			log.info("################ updateTranNo 6-5");
			if (!"1".equals(inVO.getTranUnprocFg())) {
			    log.info("################ updateTranNo 6-6");
	            try {
	                log.info("################ updateTranNo 6-7");
	                procVochCreate(acctDt, acctDeptCd, tranTpCd, tranNo, acctUnitCd, isrtEmpNo);
	            } catch (Exception e) {
	                log.info("################ updateTranNo 6-8");
	                log.error(e.getMessage(), e);
	                // 오류발생시 입력값 로깅
	                traceVochCreateParams(acctDt, acctDeptCd, tranTpCd, tranNo, acctUnitCd);
	                throw e;
	            }
	        }
		}

		log.info("################ updateTranNo 7");
		return inVO;
	}

	/**
	 * 이체번호 채번
	 * @param acctDt
	 * @param acctUnitCd
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @param empNo
	 * @param tx
	 * @return
	 * @throws DAOException
	 */
	private int gvnoTranNo(String acctDt, String acctUnitCd, String acctDeptCd, String tranTpCd, String empNo) throws Exception {
		String tmpEmpNo = StringUtils.isBlank(empNo)?"system":empNo;
		String tmpAcctDt = StringUtils.remove(acctDt, "-");
		return StringUtil.parseInt(commBizService.getNextNumber("R002", tmpAcctDt, acctUnitCd, acctDeptCd, tranTpCd, "", "", tmpEmpNo));
	}

	/**
	 * 일반전표 처리에러 발생시 로깅
	 * @param acctDt
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @param tranNo
	 * @param acctUnitCd
	 * @param con
	 */
	private void traceVochCreateParams(String acctDt, String acctDeptCd, String tranTpCd, int tranNo, String acctUnitCd) {
		try {
			chkVochCreateBefore(acctDt, acctDeptCd, tranTpCd, tranNo, acctUnitCd);
		} catch (Exception ignore) {
			// 무시
		}
	}

	/**
	 * <p>회계단위로 보조내역등록
	 * @param inVO
	 * @param con
	 * @return
	 * @throws Exception
	 */
	private VochVO createSubTrWithAcctUnit(VochVO inVO) throws Exception {
	    log.info("################ createSubTrWithAcctUnit 1");
		//보조내역에 등록될 금액이 존재하는지 확인
		if (chkSubDescAmt(inVO.getAcctDt(), inVO.getTrDescNo()) == 0) {
			throw new BizException("보조내역에 금액이 등록되지 않았습니다.");
		}
		log.info("################ createSubTrWithAcctUnit 2");
		//보조내역 등록 (등록건이 없어도 에러가 아닌 경우가 있음)
		//IFRS여부 확인
		String procDivCd = inVO.getProcDivCd();
		if (Constants.KGAAP.equals(procDivCd) || Constants.ONLYKGAAP.equals(procDivCd)) {
		    log.info("################ createSubTrWithAcctUnit 1 procDivCd["+procDivCd+"]");
		    createSubDescWithAcctUnit(inVO.getIsrtEmpNo(), inVO.getAcctDt(), inVO.getTrDescNo());
		}

		if (Constants.KGAAP.equals(procDivCd) || Constants.KIFRS.equals(procDivCd)) {
			throw new BizException("IFRS 처리는 할수 없습니다.");
			// dao.createSubDescWithAcctUnit_IFRS(inVO.getIsrtEmpNo(), inVO.getAcctDt(), inVO.getTrDescNo());
		}
		log.info("################ createSubTrWithAcctUnit 3");

		return inVO;
	}

	/**
	 * <p>관리항목 체크 로직 수정
	 * @param inVO
	 * @param con
	 * @throws Exception
	 */
	private VochVO createClsTrDescWithAcctUnit(VochVO inVO) throws Exception {
	    log.info("################ createClsTrDescWithAcctUnit 1");
		if (!"1".equals(inVO.getAutoClsFg())) {
		    log.info("################ createClsTrDescWithAcctUnit 2");
			inVO = chkDeptCls(inVO.getIsrtDeptCd(), inVO.getAcctDt(),inVO);
		}

		String acctDt = StringUtil.nvl(inVO.getAcctDt());
		log.info("################ createClsTrDescWithAcctUnit 3");
		for (int i=0,n=inVO.sizeClsTrDesc();i<n;i++) {
			ClsTrDescVO trDesc = inVO.getClsTrDesc(i);
			log.info("################ createClsTrDescWithAcctUnit 4");
			//거래단계확인
			inVO = chkTrStag(trDesc.getTrTpCd(), trDesc.getTrStagCd(), trDesc, inVO);
			log.info("################ createClsTrDescWithAcctUnit 5");
			//마감가능 부서 확인
			if (!"1".equals(inVO.getAutoClsFg())) {
			    log.info("################ createClsTrDescWithAcctUnit 6");
				inVO = chkDeptCls(trDesc.getMngDeptCd(),trDesc.getAcctDt(),inVO);
			}

			//회계단위확인
			if ("".equals(trDesc.getAcctUnitCd())) {
			    log.info("################ createClsTrDescWithAcctUnit 7");
				throw new BizException("회계단위를 입력하세요.");
			}

			//회계일자 확인
			if (!acctDt.equals(trDesc.getAcctDt())) {
			    log.info("################ createClsTrDescWithAcctUnit8");
				throw new BizException("전표와 거래내역의 회계일자가 일치하지 않습니다.");
			}
		}

		//관리항목 체크 chkTrStag 내부에서 아래로 이동 2018-08-01 HSH
		if (inVO.isMngItemExistFg() && !inVO.isMngAmtOneMoreExistFg()) {
		    log.info("################ createClsTrDescWithAcctUnit 9");
			throw new BizException("관리항목에 최소 1개이상 금액이 입력되지 않았습니다.");
		}
		log.info("################ createClsTrDescWithAcctUnit 10");
		//거래내역 번호 채번
		inVO.setTrDescNo(getMaxTrDescNo());
		log.info("################ createClsTrDescWithAcctUnit 11 inVO["+inVO+"]");
		//마감거래내역 등록
		createClsTrDescList(inVO);
		log.info("################ createClsTrDescWithAcctUnit 12");
		return inVO;
	}

	/**
	 * <p>마감가능 부서, 이미 업무마감이 되었는지 확인한다.
	 * @param deptCd (발생,관리)회계부서
	 * @param acctDt 회계일자
	 * @param inVO I/O 결과코드를 넣는다.
	 * @param con
	 * @return VochVO - rsltCd가 "0000"이 아닐때 에러.
	 * @throws Exception
	 */
	@SuppressWarnings("unused")
	private VochVO chkDeptCls(String deptCd, String acctDt, VochVO inVO) throws Exception{
	    log.info("################ chkDeptCls 1");
		if (inVO.hasClsPossDept(deptCd)) { //캐쉬에 저장된 마감가능부서에 포함하는지 확인
			return inVO;
		}
		log.info("################ chkDeptCls 2");
		String bsnClsFg = searchAcctDept(acctDt, deptCd);

		bsnClsFg = Constants.NO; // TODO 테스트
		log.info("################ chkDeptCls 3");
		if (bsnClsFg == null) {
		    log.info("################ chkDeptCls 4");
			throw new BizException("해당 회계일자("+acctDt+")의 회계부서("+deptCd+")는 회계마감처리할수 없습니다.");
		} else {
		    log.info("################ chkDeptCls 5");
			if (Constants.YES.equals(bsnClsFg)) {
			    log.info("################ chkDeptCls 6");
				throw new BizException("해당부서는 이미 업무마감이 완료되었습니다.");
			}
		}
		log.info("################ chkDeptCls 7");
		//마감가능 부서를 Map에 저장하여 다음번 체크때 DB를 재조회하지 않게 함.
		inVO.addClsPossDept(deptCd);
		return inVO;
	}

	/**
	 * <p>이체유형얻기
	 * @param trTpCd 거래유형
	 * @param trStagDivCd 거래단계
	 * @param trDesc 조회된 이체유형을 입력
	 * @param inVO 처리중 결과(성공,실패-실패내용)을 셋팅
	 * @param con
	 * @return rsltCd가 "0000"이 아닐때 에러
	 * @throws Exception
	 */
	private VochVO chkTrStag(String trTpCd, String trStagDivCd, ClsTrDescVO trDesc, VochVO inVO) throws Exception {

		log.info("####### JJH chkTrStag 1");
		String tranTpCd ="";
		String trMngItemCd = "";
		String procDivCd = "";
		String trTp[]=null;

		//log.info("inVO.hasClsPossTrStat(trStagDivCd):::" + inVO.hasClsPossTrStat(trStagDivCd));
		if (inVO.hasClsPossTrStat(trStagDivCd)) {
			trTp = inVO.getTranTpCdByTrStagCd(trStagDivCd);
			tranTpCd    = trTp[0];
			trMngItemCd = trTp[1];
			procDivCd   = trTp[2];
		} else {
			trTp = searchTrTp(trTpCd, trStagDivCd);
			log.info("####### JJH chkTrStag 2 trTpCd ["+trTpCd+"] trStagDivCd ["+trStagDivCd+"]");

			if (trTp != null && trTp.length == 3) {
				tranTpCd    = StringUtils.trimToEmpty(trTp[0]);
				trMngItemCd = StringUtils.trimToEmpty(trTp[1]);
				procDivCd   = StringUtils.trimToEmpty(trTp[2]);
				log.info("####### JJH chkTrStag 2 tranTpCd ["+tranTpCd+"] trMngItemCd ["+trMngItemCd+"] procDivCd ["+procDivCd+"]");
			}
		}

		if ("".equals(tranTpCd)) {
			throw new BizException("정의된 거래유형(거래유형:"+trTpCd+",거래단계:"+trStagDivCd+")이 아닙니다.");
		}

		if (trMngItemCd.equals("01")) {
			// 거래내역 중 관리항목존재함. 거래내역 중 한개 이상 관리금액이 있어야함.
			inVO.setMngItemExistFg(true);
			if (trDesc.getMngAmt1() == 0) {
				throw new BizException("관리항목에 금액이 입력되지 않았습니다.[거래유형 : " + tranTpCd + ", 관리항목코드 : " + trMngItemCd + ", 관리금액1 : " + trDesc.getMngAmt1() + "]");
			} else {
				//거래내역 중 한개 이상 관리금액이 존재함.
				inVO.setMngAmtOneMoreExistFg(true);
			}
		}

		trDesc.setTranTpCd(tranTpCd);
		inVO.addClsPossTrStag(trStagDivCd, trTp);
		//04일때 사용자입력값으로 함.
		if (procDivCd.equals("04")) {
			inVO.setProcDivCd(inVO.getIsIFRS());
		} else {
			inVO.setProcDivCd(procDivCd);
		}
		return inVO;
	}

	/**
	 * <p>KGAP과 IFRS 마감단위 리스트를 mergy한다.
	 * @param kgapList
	 * @param ifrsList
	 * @return
	 * @throws Exception
	 */
	private List mergeList(List kgapList, List ifrsList) throws Exception{
	    log.info("################ mergeList 1");
		List result = new ArrayList();
		for (int i=0, n=kgapList.size();i<n; i++) {
		    log.info("################ mergeList 2");
			String[] strArr = (String[])kgapList.get(i);
			boolean isExist = false;
			for (int j=0, cnt=ifrsList.size();j<cnt; j++) {
				String[] right = (String[])ifrsList.get(j);
				if (strArr[0].equals(right[0])
						&& strArr[1].equals(right[1])
						&& strArr[2].equals(right[2])
						&& strArr[3].equals(right[3])) {
					isExist = true;
					break;
				}
			}

			String[] mergy = new String[5];
			if (isExist) {
				mergy[0] = Constants.KGAAP;
			} else {
				mergy[0] = Constants.ONLYKGAAP;
			}
			mergy[1] = strArr[0];
			mergy[2] = strArr[1];
			mergy[3] = strArr[2];
			mergy[4] = strArr[3];
			result.add(mergy);
		}
		log.info("################ mergeList 3");
		for (int i=0, n=ifrsList.size();i<n; i++) {
		    log.info("################ mergeList 4");
			String[] strArr = (String[])ifrsList.get(i);
			boolean isExist = false;
			for (int j=0, cnt=kgapList.size();j<cnt; j++) {
				String[] containStrArr = (String[])kgapList.get(j);
				if (strArr[0].equals(containStrArr[0]) && strArr[1].equals(containStrArr[1])
					&& strArr[2].equals(containStrArr[2]) && strArr[3].equals(containStrArr[3])) {
					isExist = true;
					break;
				}
			}

			if (!isExist) {
				String[] mergy = new String[5];
					mergy[0] = Constants.KIFRS;
					mergy[1] = strArr[0];
					mergy[2] = strArr[1];
					mergy[3] = strArr[2];
					mergy[4] = strArr[3];
				result.add(mergy);
			}
		}
		log.info("################ mergeList 5");
		return result;
	}


	/**
	 * 차대금액 확인
	 * @param acctDt
	 * @param trDescNo
	 * @param con
	 * @throws Exception
	 */
	private void searchDcAmt(String acctDt, int trDescNo) throws Exception {

		RtClsSubDescDTO inDTO = new RtClsSubDescDTO();

		try {

			inDTO.setAcctDt(acctDt);
			inDTO.setTrDescNo(trDescNo);

			SearchDcAmtOUTDTO outDTO = vochCCMapper.searchDcAmt(inDTO);

			if(outDTO != null) {
				String msg = "회계단위.부서(" + outDTO.getAcctUnitCd() + "."
						+ outDTO.getAcctDeptCd() + ")의 차변("
						+ String.valueOf(outDTO.getDrAmt()) + ")와 대변("
						+ String.valueOf(outDTO.getCrAmt()) + ")의 합계차이("
						+ String.valueOf(outDTO.getDcSum()) + ")가 있습니다";

				throw new BizException(msg);
			}

		} catch (Exception e) {
			throw new BizException("차대금액 조회오류", e);
		}

	}

	/**
	 * 거래내역 금액 체크 후 오류 시 거래보조내역 logger
	 * @param acctDt
	 * @param trDescNo
	 * @throws Exception
	 */
	private void errRqstVochDesc(Throwable error, String acctDt, int trDescNo) throws Exception {

		try {
			RtClsSubDescDTO inDTO = new RtClsSubDescDTO();
			inDTO.setAcctDeptCd(acctDt);
			inDTO.setTrDescNo(trDescNo);

			List<ErrRqstVochDescOUTDTO> outDTO = vochCCMapper.errRqstVochDesc(inDTO);

			String addMsg = "";

			List addSubDesc = new ArrayList(5);

			for (ErrRqstVochDescOUTDTO sourceIO : outDTO) {
				if( addSubDesc.size() < 7 ){
				    if( addSubDesc.size() < 1){
                        addSubDesc.add( sourceIO.getTrTpNm() + "(" + sourceIO.getTrTpCd() + ")");
                    }
					addSubDesc.add(  ("DR".equals(sourceIO.getDcDivCd())?"차변:":"대변:")
                            +  sourceIO.getAcctNm()
                            + "(" + sourceIO.getVochAmt() + ")");
				}
			}

			if( addSubDesc.size() > 0){
				addMsg = StringUtils.join(addSubDesc.iterator(), "\n,");
				throw new BizException(addMsg);
			}

		} catch (Exception e) {
			throw new BizException("거래내역 금액 체크 후 오류 시 거래보조내역 조회 오류!");
		}
	}

	/**
	 * 이체유형 조회
	 * @param acctDt
	 * @param trDescNo
	 * @return 회계일자, 회계단위코드, 회계부서코드, 이체유형코드
	 * @throws Exception
	 */
	private List searchTranTp(String acctDt, int trDescNo) throws Exception {
	    log.info("################ searchTranTp 1");
		List result = new ArrayList();

		try {
			RtClsSubDescDTO inDTO = new RtClsSubDescDTO();
			inDTO.setAcctDt(acctDt);
			inDTO.setTrDescNo(trDescNo);
			log.info("################ searchTranTp 2 acctDt["+acctDt+"] trDescNo["+trDescNo+"]");
			List<RtClsSubDescDTO> outDTO = vochCCMapper.searchTranTp(inDTO);
			log.info("################ searchTranTp 3");
			for (RtClsSubDescDTO sourceIO : outDTO) {
			    log.info("################ searchTranTp 4");
				String[] tranInfo = new String[4];

				tranInfo[0] = sourceIO.getAcctDt(); 	//회계일자
				tranInfo[1] = sourceIO.getAcctUnitCd(); //회계단위코드
				tranInfo[2] = sourceIO.getAcctDeptCd(); //회계부서코드
				tranInfo[3] = sourceIO.getTranTpCd(); 	//이체유형코드
				result.add(tranInfo);
				log.info("################ searchTranTp 5");
			}
			log.info("################ searchTranTp 6");
		} catch (Exception e) {
			throw new BizException("이체유형 조회 오류!"+e);
		}
		log.info("################ searchTranTp 7");
		return result;

	}

	/**
	 * 마감정보(기본) 조회
	 * @param acctDt
	 * @param acctUnitCd
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @return ClsBaseVO
	 * @throws Exception
	 */
	private ClsBaseVO searchClsInfo(String acctDt, String acctUnitCd, String acctDeptCd, String tranTpCd) throws Exception {

		ClsBaseVO clsBaseVO = null;

		try {

			RtClsBaseDTO inDTO = new RtClsBaseDTO();

			inDTO.setAcctDt(acctDt);
			inDTO.setAcctUnitCd(acctUnitCd);
			inDTO.setAcctDeptCd(acctDeptCd);
			inDTO.setTranTpCd(tranTpCd);

			RtClsBaseDTO outDTO = vochCCMapper.searchClsInfo(inDTO);

			if(outDTO != null) {
				clsBaseVO = new ClsBaseVO();
				clsBaseVO.setAcctDt(outDTO.getAcctDt()); 			// 회계_일자
				clsBaseVO.setAcctUnitCd(outDTO.getAcctUnitCd()); 	// 회계_단위_코드
				clsBaseVO.setAcctDeptCd(outDTO.getAcctDeptCd()); 	// 회계_부서_코드
				clsBaseVO.setTranTpCd(outDTO.getTranTpCd()); 		// 이체_유형_코드
				clsBaseVO.setTranNo((int)outDTO.getTranNo()); 		// 이체_번호
				clsBaseVO.setVochClsFg(outDTO.getVochClsFg()); 		// 전표_마감_여부
			}

		} catch (Exception e) {
			throw new BizException("마감정보(기본) 조회오류", e);
		}

		return clsBaseVO;

	}

	/**
	 * 마감기본 생성
	 * @param clsBaseVO
	 * @return int
	 * @throws Exception
	 */
	private int createClsBase(ClsBaseVO clsBaseVO) throws Exception {

		int exeCnt = 0;

		try {

			int tranNo = clsBaseVO.getTranNo();
			if (tranNo < 1) {
				tranNo = 1;
			}

			RtClsBaseDTO inDTO = new RtClsBaseDTO();

			inDTO.setAcctDt(clsBaseVO.getAcctDt());				// 회계_일자
			inDTO.setAcctUnitCd(clsBaseVO.getAcctUnitCd()); 	// 회계_단위_코드
			inDTO.setAcctDeptCd(clsBaseVO.getAcctDeptCd()); 	// 회계_부서_코드
			inDTO.setTranTpCd(clsBaseVO.getTranTpCd()); 		// 이체_유형_코드
			inDTO.setTranNo(tranNo); 							// 이체_번호
			inDTO.setFrstRegEmpNo(clsBaseVO.getProcEmpNo()); 	// 최초처리사원번호
			inDTO.setLastProcEmpNo(clsBaseVO.getProcEmpNo()); 	// 최초처리사원번호

			exeCnt = vochCCMapper.createClsBase(inDTO);

		} catch (Exception se) {
			throw new BizException("마감기본 생성실패", se);
		}

		return exeCnt;
	}

	/**
	 * 이체번호 수정
	 * @param tranNo
	 * @param acctDt
	 * @param acctUnitCd
	 * @param trDescNo
	 * @param acctDeptCd
	 * @return
	 * @throws Exception
	 */
	private int updateTranNo(int tranNo, String acctDt, String acctUnitCd, int trDescNo,	String acctDeptCd) throws Exception {

		int exeCnt = 0;

		try {

			RtClsSubDescDTO inDTO = new RtClsSubDescDTO();

			inDTO.setTranNo(tranNo); 							// 이체_번호
			inDTO.setAcctDt(acctDt);				// 회계_일자
			inDTO.setAcctUnitCd(acctUnitCd); 	// 회계_단위_코드
			inDTO.setAcctDeptCd(acctDeptCd); 	// 회계_부서_코드
			inDTO.setTrDescNo(trDescNo); 		// 이체_유형_코드

			exeCnt = vochCCMapper.updateTranNo(inDTO);

		} catch (Exception e) {
			throw new BizException("이체번호 수정중 DAO에러발생 : " + e.getMessage());
		}

		return exeCnt;
	}

	/**
	 * 회계전표처리(이체)
	 * @param acctDt
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @param tranNo
	 * @param acctUnitCd
	 * @param isrtEmpNo
	 * @return int
	 * @throws Exception
	 */
	@Override
	public void procVochCreate(String acctDt, String acctDeptCd, String tranTpCd, int tranNo, String acctUnitCd, String isrtEmpNo) throws Exception {
	    log.info("################ procVochCreate 1");
		try {
			ProcVochCreateINOUTDTO inDTO = new ProcVochCreateINOUTDTO();

			inDTO.setAcctDt(acctDt);
			inDTO.setAcctDeptCd(acctDeptCd);
			inDTO.setTranTpCd(tranTpCd);
			inDTO.setTranNo(tranNo);
			inDTO.setAcctUnitCd(acctUnitCd);
			inDTO.setIsrtEmpNo(isrtEmpNo);
			log.info("################ procVochCreate 2");
			ProcVochCreateINOUTDTO outDTO = vochCCMapper.procVochCreate(inDTO);
			log.info("################ procVochCreate 3");
			if(outDTO != null) {
			    log.info("################ procVochCreate 4");
				if( StringUtils.isNotEmpty(outDTO.getErrMsg())){
					throw new Exception(outDTO.getErrMsg());
				}
			}


		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new Exception("회계 이체처리 실패 : " + e.getMessage());
		}
		log.info("################ procVochCreate 5");

	}

	/**
	 * 보조금액 체크
	 * @param acctDt
	 * @param trDescNo
	 * @return long
	 * @throws Exception
	 */
	private long chkSubDescAmt(String acctDt, int trDescNo) throws Exception {

		long subDescAmt = 0;
		try {
			RtClsTrDescDTO inDTO = new RtClsTrDescDTO();

			inDTO.setAcctDt(acctDt);
			inDTO.setTrDescNo(trDescNo);

			List<RtClsTrDescDTO> outDTO = vochCCMapper.chkSubDescAmt(inDTO);

			for (RtClsTrDescDTO sourceIO : outDTO) {
				subDescAmt = sourceIO.getAmt().longValue();

				if (subDescAmt != 0) {
					return subDescAmt;
				} else {
					continue;
				}
			}

		} catch (Exception se) {
			throw new BizException("금액 항목번호별 금액 조회오류", se);
		}

		return subDescAmt;

	}

	/**
	 * <p>보조내역 등록 - 회계단위코드
	 * @param isrtEmpNo
	 * @param acctDt
	 * @param trDescNo
	 * @return int
	 * @throws Exception
	 */
	private int createSubDescWithAcctUnit(String isrtEmpNo, String acctDt, int trDescNo) throws Exception {

		int exeCnt = 0;
		log.info("################ createSubDescWithAcctUnit 1 isrtEmpNo["+isrtEmpNo+"] acctDt["+acctDt+"] trDescNo["+trDescNo+"]");
		try {

			RtClsSubDescDTO inDTO = new RtClsSubDescDTO();

			inDTO.setFrstRegEmpNo(isrtEmpNo);
			inDTO.setAcctDt(acctDt);
			inDTO.setTrDescNo(trDescNo);
			log.info("################ createSubDescWithAcctUnit 2");
			exeCnt = vochCCMapper.createSubDescWithAcctUnit(inDTO);
			log.info("################ createSubDescWithAcctUnit 3");
		} catch (Exception se) {
			throw new BizException("보조내역 등록오류", se);
		}

		log.info("################ createSubDescWithAcctUnit 4");

		return exeCnt;
	}

	/**
	 * 마감순번 채번
	 * @param con
	 * @return
	 * @throws Exception
	 */
	private int getMaxTrDescNo() throws Exception {

		int trDescNo = 0;

		try {

			trDescNo = vochCCMapper.getMaxTrDescNo();

		} catch (Exception se) {
			throw new BizException("보조내역 등록오류", se);
		}

		return trDescNo;
	}

	/**
	 * <p>마감거래내역
	 * @param inVO
	 * @return
	 * @throws Exception
	 */
	private int createClsTrDescList(VochVO inVO) throws Exception {

		ClsTrDescVO clsTrDescVO = null;
		int exeCnt = 0;
		log.info("################ createClsTrDescList 1");
		for (int i=0; i<inVO.sizeClsTrDesc(); i++) {
		    log.info("################ createClsTrDescList 2 inVO["+inVO+"]");
			clsTrDescVO = inVO.getClsTrDesc(i);
			RtClsTrDescDTO inDTO = new RtClsTrDescDTO();

			inDTO.setAcctDt(clsTrDescVO.getAcctDt());
			inDTO.setTrDescNo(inVO.getTrDescNo());
			inDTO.setTrSnum(i+1);
			inDTO.setTrTpCd(clsTrDescVO.getTrTpCd());
			inDTO.setTrStagCd(clsTrDescVO.getTrStagCd());
			inDTO.setTranTpCd(clsTrDescVO.getTranTpCd());
			inDTO.setIsrtDt(StringUtil.nvl(clsTrDescVO.getIsrtDt()));
			inDTO.setLoanNo(clsTrDescVO.getLoanNo());
			inDTO.setLoanSeq(clsTrDescVO.getLoanSeq());
			inDTO.setPrdtLrgeClasCd(clsTrDescVO.getPrdtLrgeClasCd());
			inDTO.setPrdtMidClasCd(clsTrDescVO.getPrdtMidClasCd());
			inDTO.setPrdtSmClasCd(StringUtil.nvl(clsTrDescVO.getPrdtSmClasCd()));
			inDTO.setAcctUnitCd(clsTrDescVO.getAcctUnitCd());
			inDTO.setLoanStatCd(clsTrDescVO.getLoanStatCd());
			inDTO.setBndStatCd(clsTrDescVO.getBndStatCd());
			inDTO.setOccrDeptCd(clsTrDescVO.getOccrDeptCd());
			inDTO.setMngDeptCd(clsTrDescVO.getMngDeptCd());
			inDTO.setDsrcOccrCd(StringUtil.nvl(clsTrDescVO.getDsrcOccrCd()));
			inDTO.setDsrcAdjCd(StringUtil.nvl(clsTrDescVO.getDsrcAdjCd()));
			inDTO.setBankCd(StringUtil.nvl(clsTrDescVO.getBankCd()));
			inDTO.setAcntNo(StringUtil.nvl(StringUtils.remove(clsTrDescVO.getAcntNo(),'-')));
			inDTO.setCprtComNo(StringUtil.nvl(clsTrDescVO.getCprtComNo()));
			inDTO.setBusiNo(StringUtil.nvl(clsTrDescVO.getBusiNo()));
			inDTO.setSetlAmt(new BigDecimal(clsTrDescVO.getSetlAmt()));
			inDTO.setDepo(new BigDecimal(clsTrDescVO.getDepo()));
			inDTO.setCash(new BigDecimal(clsTrDescVO.getCash()));
			inDTO.setDsrcAdjAmt(new BigDecimal(clsTrDescVO.getDsrcAdjAmt()));
			inDTO.setDsrcOccrAmt(new BigDecimal(clsTrDescVO.getDsrcOccrAmt()));
			inDTO.setPamt(new BigDecimal(clsTrDescVO.getPamt()));
			inDTO.setRamt(new BigDecimal(clsTrDescVO.getIntt()));
			inDTO.setDfee(new BigDecimal(clsTrDescVO.getDfee()));
			inDTO.setAdjDfee(new BigDecimal(clsTrDescVO.getAdjDfee()));
			inDTO.setPdueDiscDfee(new BigDecimal(clsTrDescVO.getPdueDiscDfee()));
			inDTO.setLeglActnCost(new BigDecimal(clsTrDescVO.getLeglActnCost()));
			inDTO.setMidRmbrFee(new BigDecimal(clsTrDescVO.getMidRmbrFee()));
			inDTO.setTrtFeeDisc(new BigDecimal(clsTrDescVO.getTrtFeeDisc()));
			inDTO.setEtcPrft(new BigDecimal(clsTrDescVO.getEtcPrft()));
			inDTO.setExmpPamt(new BigDecimal(clsTrDescVO.getExmpPamt()));
			inDTO.setExmpInt(new BigDecimal(clsTrDescVO.getExmpInt()));
			inDTO.setExmpDfee(new BigDecimal(clsTrDescVO.getExmpDfee()));
			inDTO.setExmpLeglActnCost(new BigDecimal(clsTrDescVO.getExmpLeglActnCost()));
			inDTO.setExmpMidRmbrFee(new BigDecimal(clsTrDescVO.getExmpMidRmbrFee()));
			inDTO.setCrdtRcvrUnrcvAmt(new BigDecimal(clsTrDescVO.getCrdtRcvrUnrcvAmt()));
			inDTO.setPsgInt(new BigDecimal(clsTrDescVO.getPsgInt()));
			inDTO.setPreRcptPamt(new BigDecimal(clsTrDescVO.getPreRcptPamt()));
			inDTO.setPreRcptInt(new BigDecimal(clsTrDescVO.getPreRcptInt()));
			inDTO.setPayAmt(new BigDecimal(clsTrDescVO.getPayAmt()));
			inDTO.setRetnAmt(new BigDecimal(clsTrDescVO.getRetnAmt()));
			inDTO.setChngBfFeeCostTrtFee(new BigDecimal(clsTrDescVO.getChngBfFeeCostTrtFee()));
			inDTO.setChngBfFeePrftTrtFee(new BigDecimal(clsTrDescVO.getChngBfFeePrftTrtFee()));
			inDTO.setChngBfPamt(new BigDecimal(clsTrDescVO.getChngBfPamt()));
			inDTO.setChngBfDferCostCprtFee(new BigDecimal(clsTrDescVO.getChngBfDferCostCprtFee()));
			inDTO.setChngBfDferCostTrtFee(new BigDecimal(clsTrDescVO.getChngBfDferCostTrtFee()));
			inDTO.setChngBfDferPrftCprtFee(new BigDecimal(clsTrDescVO.getChngBfDferPrftCprtFee()));
			inDTO.setChngBfDferPrftTrtFee(new BigDecimal(clsTrDescVO.getChngBfDferPrftTrtFee()));
			inDTO.setChngBfIntCostCprtFee(new BigDecimal(clsTrDescVO.getChngBfIntCostCprtFee()));
			inDTO.setChngBfIntPrftCprtFee(new BigDecimal(clsTrDescVO.getChngBfIntPrftCprtFee()));
			inDTO.setChngAfFeeCostTrtFee(new BigDecimal(clsTrDescVO.getChngAfFeeCostTrtFee()));
			inDTO.setChngAfFeePrftTrtFee(new BigDecimal(clsTrDescVO.getChngAfFeePrftTrtFee()));
			inDTO.setChngAfPamt(new BigDecimal(clsTrDescVO.getChngAfPamt()));
			inDTO.setChngAfDferCostCprtFee(new BigDecimal(clsTrDescVO.getChngAfDferCostCprtFee()));
			inDTO.setChngAfDferCostTrtFee(new BigDecimal(clsTrDescVO.getChngAfDferCostTrtFee()));
			inDTO.setChngAfDferPrftCprtFee(new BigDecimal(clsTrDescVO.getChngAfDferPrftCprtFee()));
			inDTO.setChngAfDferPrftTrtFee(new BigDecimal(clsTrDescVO.getChngAfDferPrftTrtFee()));
			inDTO.setChngAfIntCostCprtFee(new BigDecimal(clsTrDescVO.getChngAfIntCostCprtFee()));
			inDTO.setChngAfIntPrftCprtFee(new BigDecimal(clsTrDescVO.getChngAfIntPrftCprtFee()));
			inDTO.setFeeCostTrtFee(new BigDecimal(clsTrDescVO.getFeeCostTrtFee()));
			inDTO.setFeePrftTrtFee(new BigDecimal(clsTrDescVO.getFeePrftTrtFee()));
			inDTO.setDferCostCprtFee(new BigDecimal(clsTrDescVO.getDferCostCprtFee()));
			inDTO.setDferCostTrtFee(new BigDecimal(clsTrDescVO.getDferCostTrtFee()));
			inDTO.setDferPrftCprtFee(new BigDecimal(clsTrDescVO.getDferPrftCprtFee()));
			inDTO.setDferPrftTrtFee(new BigDecimal(clsTrDescVO.getDferPrftTrtFee()));
			inDTO.setIntCostCprtFee(new BigDecimal(clsTrDescVO.getIntCostCprtFee()));
			inDTO.setIntPrftCprtFee(new BigDecimal(clsTrDescVO.getIntPrftCprtFee()));
			inDTO.setNotaFee(new BigDecimal(clsTrDescVO.getNotaFee()));
			inDTO.setStmpFee(new BigDecimal(clsTrDescVO.getStmpFee()));
			inDTO.setHtax(new BigDecimal(clsTrDescVO.getHtax()));
			inDTO.setSetFee(new BigDecimal(clsTrDescVO.getSetFee()));
			inDTO.setItax(new BigDecimal(clsTrDescVO.getItax()));
			inDTO.setEtcFee(new BigDecimal(clsTrDescVO.getEtcFee()));
			inDTO.setDebtmanFee(new BigDecimal(clsTrDescVO.getDebtmanFee()));
			inDTO.setPrFee(new BigDecimal(clsTrDescVO.getPrFee()));
			inDTO.setTrtFee(new BigDecimal(clsTrDescVO.getTrtFee()));
			inDTO.setBadDebtApprAmt(new BigDecimal(clsTrDescVO.getBadDebtApprAmt()));
			inDTO.setBadDebtDeprCost(new BigDecimal(clsTrDescVO.getBadDebtDeprCost()));
			inDTO.setDepsAmt(new BigDecimal(clsTrDescVO.getDepsAmt()));
			inDTO.setFrstRegEmpNo(StringUtil.nvl(inVO.getIsrtEmpNo()));
			inDTO.setLastProcEmpNo(StringUtil.nvl(inVO.getIsrtEmpNo()));
			inDTO.setCardNo(StringUtil.nvl(clsTrDescVO.getCardNo()));
			inDTO.setMngAcctUnitCd(StringUtil.nvl(clsTrDescVO.getMngAcctUnitCd()));
			inDTO.setPpayInt(new BigDecimal(clsTrDescVO.getPpayInt()));
			inDTO.setAddInsuFee(new BigDecimal(clsTrDescVO.getAddInsuFee()));
			inDTO.setAddCartax(new BigDecimal(clsTrDescVO.getAddCartax()));
			inDTO.setAddEnvImprBrdnamt(new BigDecimal(clsTrDescVO.getAddEnvImprBrdnamt()));
			inDTO.setAddAsfee(new BigDecimal(clsTrDescVO.getAddAsfee()));
			inDTO.setIpayInsuFee(new BigDecimal(clsTrDescVO.getIpayInsuFee()));
			inDTO.setIpayCartax(new BigDecimal(clsTrDescVO.getIpayCartax()));
			inDTO.setIpayEnvImprBrdnamt(new BigDecimal(clsTrDescVO.getIpayEnvImprBrdnamt()));
			inDTO.setIpayPnltAmt(new BigDecimal(clsTrDescVO.getIpayPnltAmt()));
			inDTO.setIpayEtc(new BigDecimal(clsTrDescVO.getIpayEtc()));
			inDTO.setVtax(new BigDecimal(clsTrDescVO.getVtax()));
			inDTO.setLtrmBrcvAmt(new BigDecimal(clsTrDescVO.getLtrmBrcvAmt()));
			inDTO.setMngAsetCostDivCd(StringUtil.nvl(clsTrDescVO.getMngAsetCostDivCd()));
			inDTO.setUnrcvAmtKindCd(StringUtil.nvl(clsTrDescVO.getUnrcvAmtKindCd()));
			inDTO.setGuarAmt(new BigDecimal(clsTrDescVO.getGuarAmt()));
			inDTO.setNmChngGuarAmt(new BigDecimal(clsTrDescVO.getNmChngGuarAmt()));
			inDTO.setNmChngExmpGuarAmt(new BigDecimal(clsTrDescVO.getNmChngExmpGuarAmt()));
			inDTO.setCustCost(new BigDecimal(clsTrDescVO.getCustCost()));
			inDTO.setRetnOdueAmt(new BigDecimal(clsTrDescVO.getRetnDdueAmt()));
			inDTO.setOverDrvFee(new BigDecimal(clsTrDescVO.getOverDrvFee()));
			inDTO.setOrgupRcvrCost(new BigDecimal(clsTrDescVO.getOrgupRcvrCost()));
			inDTO.setCarsSellAmt(new BigDecimal(clsTrDescVO.getCarsSellAmt()));
			inDTO.setMidRmbrPamt(new BigDecimal(clsTrDescVO.getMidRmbrPamt()));
			inDTO.setMidRmbrInt(new BigDecimal(clsTrDescVO.getMidRmbrInt()));
			inDTO.setMidRmbrPpayInt(new BigDecimal(clsTrDescVO.getMidRmbrPpayInt()));
			inDTO.setMidRmbrAddInsuFee(new BigDecimal(clsTrDescVO.getMidRmbrAddInsuFee()));
			inDTO.setMidRmbrAddCartax(new BigDecimal(clsTrDescVO.getMidRmbrAddCartax()));
			inDTO.setMidRmbrAddEnvImprBrdnamt(new BigDecimal(clsTrDescVO.getMidRmbrAddEnvImprBrdnamt()));
			inDTO.setMidRmbrVtax(new BigDecimal(clsTrDescVO.getMidRmbrVtax()));
			inDTO.setDeprDeprTamt(new BigDecimal(clsTrDescVO.getDeprDeprTamt()));
			inDTO.setDspLossApprAmt(new BigDecimal(clsTrDescVO.getDspLossApprAmt()));
			inDTO.setOprLeasAset(new BigDecimal(clsTrDescVO.getOprLeasAset()));
			inDTO.setMngAmt1(new BigDecimal(clsTrDescVO.getMngAmt1()));
			inDTO.setExmpTrtFee(new BigDecimal(clsTrDescVO.getExmpTrtFee()));
			inDTO.setMidRmbrTrtFee(new BigDecimal(clsTrDescVO.getMidRmbrTrtFee()));
			inDTO.setIvltClosFg(StringUtil.nvl(clsTrDescVO.getIvltClosFg()));
			inDTO.setProcDivCd(StringUtil.nvl(inVO.getProcDivCd()));
			inDTO.setMidRmbrAddAsfee(new BigDecimal(clsTrDescVO.getMidRmbrAddAsfee()));
			inDTO.setIfRsltDesc(StringUtil.nvl(clsTrDescVO.getMoBankCd()));

			exeCnt = rtClsTrDescMapper.insert(inDTO);

			exeCnt += exeCnt;
		}
		log.info("################ createClsTrDescList 3");

		return exeCnt;
	}

	/**
	 * 회계부서 조회
	 * @param acctDt
	 * @param isrtDeptCd
	 * @return
	 * @throws Exception
	 */
	private String searchAcctDept(String acctDt, String isrtDeptCd) throws Exception {

		String bsnClsFg = null;
		log.info("########################## JJH searchAcctDept 1 acctDt["+acctDt+"] isrtDeptCd["+isrtDeptCd+"]");
		try {
			AtFincClsDTO inDTO = new AtFincClsDTO();

			inDTO.setAcctDt(acctDt);
			inDTO.setDeptCd(isrtDeptCd);
			inDTO.setDelFg(Constants.YES);

			AtFincClsDTO outDTO = vochCCMapper.searchAcctDept(inDTO);

			if(outDTO != null) {
				bsnClsFg = outDTO.getBsnClsFg();
			}

		} catch (SQLException e) {
			throw new Exception("회계부서 조회오류 1 SQL ["+e.getErrorCode()+"] ["+e.getMessage()+"]", e);
		} catch (Exception e) {
			throw new Exception("회계부서 조회오류 2 ["+e.getMessage()+"]", e);
		}

		return bsnClsFg;
	}

	/**
	 * <p>거래유형조회
	 * @param trTpCd
	 * @param trStagDivCd
	 * @return String[]
	 * @throws Exception
	 */
	@Override
	public String[] searchTrTp(String trTpCd, String trStagDivCd) throws Exception {

		String rslts[] = null;

		try {
			SearchTrTpINDTO inDTO = new SearchTrTpINDTO();

			inDTO.setTrTpDivCd(trTpCd);
			inDTO.setCdKindNo("A00068");
			log.info("################ searchTrTp 1");
			List<SearchTrTpOUTDTO> outDTO = vochCCMapper.searchTrTp(inDTO);

			//if(outDTO != null) {
			for(int i=0; i<outDTO.size(); i++) {
			    log.info("################ searchTrTp 2");
				rslts = new String[] {
						outDTO.get(i).getTranTpCd(),
						outDTO.get(i).getTrMngItemCd(),
						outDTO.get(i).getProcDiv()
				};
			}
			log.info("################ searchTrTp 3 rslts["+rslts+"]-");
		} catch (Exception e) {
			throw new BizException("거래유형조회오류", e);
		}
		log.info("################ searchTrTp 4");
		return rslts;
	}

	/**
	 * 전표 오류발생시 입력값을 로깅처리함.
	 * @param acctDt
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @param tranNo
	 * @param acctUnitCd
	 * @throws Exception
	 */
	@Override
	public void chkVochCreateBefore(String acctDt, String acctDeptCd,
									   String tranTpCd, int tranNo, String acctUnitCd) throws Exception{

		try {
			ChkVochCreateBeforeINDTO inDTO = new ChkVochCreateBeforeINDTO();

			inDTO.setAcctDt(acctDt);
			inDTO.setAcctDeptCd(acctDeptCd);
			inDTO.setTranTpCd(tranTpCd);
			inDTO.setTranNo(tranNo);
			inDTO.setAcctUnitCd(acctUnitCd);

			List<ChkVochCreateBeforeOUTDTO> outDTO = vochCCMapper.chkVochCreateBefore(inDTO);

			int cnt = 0;
			for (ChkVochCreateBeforeOUTDTO sourceIO : outDTO) {

				log.info("CHK => ACCT_DT: " + sourceIO.getAcctDt());
				log.info("CHK => ACCT_DEPT_CD: " + sourceIO.getAcctDeptCd());
				log.info("CHK => TR_DESC_NO: " + sourceIO.getTrDescNo());
				log.info("CHK => TR_SNUM: " + sourceIO.getTrSnum());
				log.info("CHK => SUB_SNUM: " + sourceIO.getSubSnum());
				log.info("CHK => ACCT_UNIT_CD: " + sourceIO.getAcctUnitCd());
				log.info("CHK => TRAN_TP_CD: " + sourceIO.getTranTpCd());
				log.info("CHK => TRAN_NO: " + sourceIO.getTranNo());
				log.info("CHK => DC_DIV_CD: " + sourceIO.getDcDivCd());
				log.info("CHK => ACCT_CD: " + sourceIO.getAcctCd());
				log.info("CHK => VOCH_AMT: " + sourceIO.getVochAmt());
				log.info("CHK => TR_TP_CD: " + sourceIO.getTrTpCd());
				log.info("CHK => TR_STAG_CD: " + sourceIO.getTrStagCd());
				log.info("CHK => ISRT_DT: " + sourceIO.getIsrtDt());
				log.info("CHK => LOAN_NO: " + sourceIO.getLoanNo());
				log.info("CHK => LOAN_SEQ: " + sourceIO.getLoanSeq());
				log.info("CHK => PRDT_LRGE_CLAS_CD: " + sourceIO.getPrdtLrgeClasCd());
				log.info("CHK => PRDT_MID_CLAS_CD: " + sourceIO.getPrdtMidClasCd());
				log.info("CHK => OCCR_DEPT_CD: " + sourceIO.getOccrDeptCd());
				log.info("CHK => MNG_DEPT_CD: " + sourceIO.getMngDeptCd());
				log.info("CHK => BANK_CD: " + sourceIO.getBankCd());
				log.info("CHK => ACNT_NO: " + sourceIO.getAcntNo());
				log.info("CHK => CPRT_COM_NO: " + sourceIO.getCprtComNo());
				log.info("CHK => MNG_NO_DIV_CD: " + sourceIO.getMngNoDivCd());
				log.info("CHK => MNG_NO: " + sourceIO.getMngNo());
				log.info("CHK => MNG_DT: " + sourceIO.getMngDt());
				log.info("CHK => BUSI_NO: " + sourceIO.getBusiNo());
				log.info("CHK => TR_MNG_ITEM_CD: " + sourceIO.getTrMngItemCd());
				log.info("CHK => NUM: " + sourceIO.getNum());

				cnt++;
			}

			if( cnt < 1){
				throw new Exception("해당 거래내역이 존재하지 않습니다.");
			}

		} catch (Exception se) {
			throw new BizException("거래내역 조회오류", se);
		}

	}

	/**
     * 전표이체처리를 위한 정보 조회(배치용)
     * @param jobDt
     * @return ProcVochCreateINOUTDTO
     * @throws Exception
     */
    @Override
    public List<ProcVochCreateINOUTDTO> searchVochTran(String jobDt) throws Exception {

        List<ProcVochCreateINOUTDTO> rtnListDTO = new ArrayList<ProcVochCreateINOUTDTO>();

        try {
            ProcVochCreateINOUTDTO inDTO = new ProcVochCreateINOUTDTO();

            inDTO.setAcctDt(jobDt);
            inDTO.setTranTpCd("R02");

            List<ProcVochCreateINOUTDTO> outDTO = vochCCMapper.searchVochTran(inDTO);

            for(ProcVochCreateINOUTDTO sourceIO : outDTO) {

                ProcVochCreateINOUTDTO rtnDTO = new ProcVochCreateINOUTDTO();

                rtnDTO.setAcctDt(sourceIO.getAcctDt());
                rtnDTO.setAcctDeptCd(sourceIO.getAcctDeptCd());
                rtnDTO.setTranTpCd(sourceIO.getTranTpCd());
                rtnDTO.setTranNo(sourceIO.getTranNo());
                rtnDTO.setAcctUnitCd(sourceIO.getAcctUnitCd());

                rtnListDTO.add(rtnDTO);

            }

        } catch (Exception e) {
            throw new BizException("전표이체처리를 위한 정보 조회 오류", e);
        }

        return rtnListDTO;
    }
}
