package hanalife.r.dm.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.StCustAddrEmalDTO;
import hanalife.c.co.util.StringUtil;
import hanalife.r.dm.dl.mapper.DlvrMapper;
import hanalife.r.dm.dl.mapper.dto.RDMDL01DSSD01OutDTO;
import hanalife.r.dm.dl.mapper.dto.RDMDL01DSSD02OutDTO;
import hanalife.r.dm.dl.mapper.dto.RDMDL01DSSD03OutDTO;
import hanalife.r.dm.dl.mapper.dto.RDMDLM01SrchDTO;
import hanalife.r.dm.dl.service.RDMDLM01Service;
import hanalife.r.dm.dl.vo.RDMDLM01DSSDDO01VO;
import hanalife.r.dm.dl.vo.RDMDLM01DSSDDO02VO;
import hanalife.r.dm.dl.vo.RDMDLM01DSSDDO03VO;
import hanalife.r.dm.dl.vo.RDMDLM01S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM01S01OutVO;

/**
 * <pre>
 * 클래스명    : RDMDLM01ServiceImpl.java Class
 * 클래스설명  : 수납상세 (RDMDLM01) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 09.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 2. 27.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("RDMDLM01Service")
public class RDMDLM01ServiceImpl implements RDMDLM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM01ServiceImpl.class);

    @Autowired
    private DlvrMapper dlvrMapper;

    /**
     * <p>메소드명      : getRDMDLM01S01 : 발송관리_대출정보 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 발송관리_대출정보를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RDMDLM01S01OutVO getRDMDLM01S01(RDMDLM01S01InVO inVo) throws Exception{
        // 조회 조건 셋팅
        RDMDLM01SrchDTO inSrchDto = new RDMDLM01SrchDTO();
        inSrchDto.setCustNo(inVo.getRDMDLM01DSSMVO().getCustNo());
        inSrchDto.setLoanNo(inVo.getRDMDLM01DSSMVO().getLoanNo());
        inSrchDto.setLoanSeq(inVo.getRDMDLM01DSSMVO().getLoanSeq());

        // 대출정보 조회
        RDMDLM01S01OutVO resultVo = new RDMDLM01S01OutVO();
        List<RDMDL01DSSD01OutDTO> outList = dlvrMapper.searchLoanDescList(inSrchDto);
        List<RDMDLM01DSSDDO01VO> returnList = new ArrayList<RDMDLM01DSSDDO01VO>();

        for( RDMDL01DSSD01OutDTO dto : outList ) {
            RDMDLM01DSSDDO01VO vo = new RDMDLM01DSSDDO01VO();

            vo.setLoanNo(dto.getLoanNo());
            vo.setLoanSeq(dto.getLoanSeq());
            vo.setContManNo(dto.getContManNo());
            vo.setCustNm(dto.getCustNm());
            vo.setLoanStatCd(dto.getLoanStatCd());
            vo.setLoanStatNm(dto.getLoanStatNm());
            vo.setLoanStatNm(dto.getBndStatNm());
            vo.setSetlDd(dto.getSetlDd());
            vo.setRlDueManNo(dto.getRlDueManNo());
            vo.setDlvrMan(dto.getDlvrMan());
            vo.setLoanRelCd(dto.getLoanRelCd());
            vo.setDlvrRel(dto.getDlvrRel());
            vo.setDlvrAddr(dto.getDlvrAddr());
            vo.setDlvrAddrSpec(dto.getDlvrAddrSpec());
            vo.setMngDeptCd(dto.getMngDeptCd());
            vo.setMngDeptNm(dto.getMngDeptNm());
            vo.setPrdtLrgeClasCd(dto.getPrdtLrgeClasCd());
            vo.setContManNoTran(dto.getContManNoTran());
            vo.setRlDueManNoTran(dto.getRlDueManNoTran());
            vo.setTrtFeeIstpFg(dto.getTrtFeeIstpFg());
            vo.setNewSoluPrdtFg(dto.getNewSoluPrdtFg());
            vo.setClasNm(dto.getClasNm());
            vo.setPrdtNm(dto.getPrdtNm());
            vo.setIvltClosStndDt(dto.getIvltClosStndDt());
            vo.setDlyCnt(dto.getDlyCnt());
            vo.setLoanDt(dto.getLoanDt());

            returnList.add(vo);
        }

        /* 출력 결과값 대입 */
        resultVo.setRDMDLM01DSSDDO01VO(returnList);

        return resultVo;
    }

    /**
     * <p>메소드명      : getRDMDLM01S02 : 발송관리_대출관계자정보 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 발송관리_대출관계자정보를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RDMDLM01S01OutVO getRDMDLM01S02(RDMDLM01S01InVO inVo) throws Exception{
        // 조회 조건 셋팅
        RDMDLM01SrchDTO inSrchDto = new RDMDLM01SrchDTO();
        inSrchDto.setLoanNo(inVo.getRDMDLM01DSSM2VO().getLoanNo());
        inSrchDto.setLoanSeq(inVo.getRDMDLM01DSSM2VO().getLoanSeq());

        // 대출관계자 정보 조회
        RDMDLM01S01OutVO resultVo = new RDMDLM01S01OutVO();
        List<RDMDL01DSSD02OutDTO> outList = dlvrMapper.searchLoanRelManList(inSrchDto);
        List<RDMDLM01DSSDDO02VO> returnList = new ArrayList<RDMDLM01DSSDDO02VO>();

        for( RDMDL01DSSD02OutDTO dto : outList ) {
            RDMDLM01DSSDDO02VO vo = new RDMDLM01DSSDDO02VO();

            vo.setLoanNo(dto.getLoanNo());
            vo.setLoanSeq(dto.getLoanSeq());
            vo.setLoanRelCd(dto.getLoanRelCd());
            vo.setLoanRelNm(dto.getLoanRelNm());
            vo.setCustNo(dto.getCustNo());
            vo.setCustNm(dto.getCustNm());
            vo.setRlDueManFg(dto.getRlDueManFg());
            vo.setAskPlcDivCd(dto.getAskPlcDivCd());
            vo.setAskPlc(dto.getAskPlc());
            vo.setRecvEmail(dto.getRecvEmail());
            vo.setBillDlvrManFg(dto.getBillDlvrManFg());
            vo.setCustNoTran(dto.getCustNoTran());

            // FAX 번호 조립
            String strFaxNo1 = StringUtil.trim(dto.getFaxNo1().toString());
            String strFaxNo2 = StringUtil.trim(dto.getFaxNo2().toString());
            String strFaxNo3 = StringUtil.trim(dto.getFaxNo3().toString());
            String strFaxNo = strFaxNo1.concat("-").concat(strFaxNo2).concat("-").concat(strFaxNo3);

            vo.setFaxNo1(strFaxNo1);
            vo.setFaxNo2(strFaxNo2);
            vo.setFaxNo3(strFaxNo3);
            if ( !StringUtil.isNullT(strFaxNo) ) {
                vo.setFaxNo(strFaxNo);
            }

            returnList.add(vo);
        }

        /* 출력 결과값 대입 */
        resultVo.setRDMDLM01DSSDDO02VO(returnList);

        return resultVo;
    }

    /**
     * <p>메소드명      : getRDMDLM01S03 : 발송관리_고객주소정보 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 발송관리_고객주소정보를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RDMDLM01S01OutVO getRDMDLM01S03(RDMDLM01S01InVO inVo) throws Exception{
        // 조회 조건 셋팅
        StCustAddrEmalDTO inSrchDto = new StCustAddrEmalDTO();
        inSrchDto.setCustNo(inVo.getRDMDLM01DSSM3VO().getCustNo());

        // 고객주소 정보 조회
        RDMDLM01S01OutVO resultVo = new RDMDLM01S01OutVO();
        List<RDMDL01DSSD03OutDTO> outList = dlvrMapper.searchCustAddrList(inSrchDto);
        List<RDMDLM01DSSDDO03VO> returnList = new ArrayList<RDMDLM01DSSDDO03VO>();

        for( RDMDL01DSSD03OutDTO dto : outList ) {
            RDMDLM01DSSDDO03VO vo = new RDMDLM01DSSDDO03VO();

            // 주소 정보 조립
            String strAddrCi = StringUtil.trim(dto.getAddrCi().toString());
            String strAddrGu = StringUtil.trim(dto.getAddrGu().toString());
            String strAddrDong = StringUtil.trim(dto.getAddrDong().toString());
            String strAddr = strAddrCi.concat(" ").concat(strAddrGu).concat(" ").concat(strAddrDong);

            vo.setAddrDivCd(dto.getAddrDivCd());
            vo.setAddrDivNm(dto.getAddrDivNm());
            vo.setZipCd(dto.getZipCd());
            vo.setAddrDong(strAddr);
            vo.setAddrSpec(dto.getAddrSpec());
            vo.setEmal(dto.getEmal());

            returnList.add(vo);
        }

        /* 출력 결과값 대입 */
        resultVo.setRDMDLM01DSSDDO03VO(returnList);

        return resultVo;
    }

//
//    /**
//     * <p>메소드명      : RRCRD0101I01 - 수납상세수정</p>
//     * <p>작성일자      : 2023. 2. 27.
//     * <p>작성자(author): 70317 / younghwe.kim
//     * <p>설명          : 수납상세수정</p>
//     * <p>메소드인수    : RRCRD0101U01InVo </p>
//     * <p>메소드리턴값  : RRCRD0101U01OutVo</p>
//     * <p>예외처리      : Exception</p>
//     */
//    public RRCRD0101U01OutVO modifyRRCRD0101U01(RRCRD0101U01InVO inVo) throws Exception;
//
//    /**
//     * <p>메소드명      : RRCRD0101D01 - 수납상세삭제</p>
//     * <p>작성일자      : 2023. 2. 27.
//     * <p>작성자(author): 70317 / younghwe.kim
//     * <p>설명          : 수납상세삭제</p>
//     * <p>메소드인수    : RRCRD0101D01InVo </p>
//     * <p>메소드리턴값  : RRCRD0101D01OutVo</p>
//     * <p>예외처리      : Exception</p>
//     */
//    public RRCRD0101D01OutVO removeRRCRD0101D01(RRCRD0101D01InVO inVo) throws Exception;

}
