package hanalife.r.dm.dl.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.dm.dl.service.RDMDLM04Service;
import hanalife.r.dm.dl.vo.RDMDLM04DSSM01VO;
import hanalife.r.dm.dl.vo.RDMDLM04S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM04S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RDMDLM04Controller.java Class
 * 클래스설명   : 발송내역 (RDMDLM04) Controller
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 26.][70366 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */


@Controller
@RequestMapping("r/dm/dl")
public class RDMDLM04Controller {



    @Resource(name = "RDMDLM04Service")
    private RDMDLM04Service RDMDLM04;

    private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM04Controller.class);


    /**
     * <p>
     * 메소드명 : 발송내역조회(SMS) /RDMDLM04S01.do
     * </p>
     * <p>
     * 작성일자 : 2023. 4. 26.
     * <p>
     * 작성자(author): 70366
     * <p>
     * 설명 : 발송내역조회(SMS) 한다.
     * </p>
     * <p>
     * 예외처리 : Exception
     * </p>
     */
    @RequestMapping("/RDMDLM04S01.do")
    public String RDMDLM04S01(HttpServletRequest request,  HttpServletResponse response, ModelMap model) {



        LOGGER.info("&&&&& RDMDLM04Controller RDMDLM04S01 START &&&&& ");

        try {

            /** XFrame5 UI 내에서 전달된 DS_SM01 DataSet 정보를 추출한다.*/
            Map<String, Object> xFrameInputMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM01", request, response, model);

            /** 발송내역조회 업무 서비스 호출 입력값 대입 */
            RDMDLM04DSSM01VO dssm01Vo = new RDMDLM04DSSM01VO();

            dssm01Vo.setDlvrDtFr((String)xFrameInputMap.get("dlvrDtFr"));       /** 발송_일자_시작일자 */
            dssm01Vo.setDlvrDtTo((String)xFrameInputMap.get("dlvrDtTo"));       /** 발송_일자_종료일자 */
            dssm01Vo.setDueDtFr((String)xFrameInputMap.get("dueDtFr"));       /** 납입_일자_시작일자 */
            dssm01Vo.setDueDtTo((String)xFrameInputMap.get("dueDtTo"));       /** 납입_일자_종료일자 */
            dssm01Vo.setLoanNo((String)xFrameInputMap.get("loanNo"));       /** 대출_번호 */
            dssm01Vo.setLoanSeq((String)xFrameInputMap.get("loanSeq"));       /** 대출_순서 */
            dssm01Vo.setHpNo1((String)xFrameInputMap.get("hpNo1"));       /** 휴대폰_번호1 */
            dssm01Vo.setHpNo2((String)xFrameInputMap.get("hpNo2"));       /** 휴대폰_번호2 */
            dssm01Vo.setHpNo3((String)xFrameInputMap.get("hpNo3"));       /** 휴대폰_번호3 */
            dssm01Vo.setSendStat((String)xFrameInputMap.get("sendStat"));       /** SMS_전송_상태 */

            /** SERVICE 호출을 위한 입력 InVO 객체에 DataSet VO 객체 대입*/
            RDMDLM04S01InVO inVo = new RDMDLM04S01InVO();
            inVo.setRDMDLM04DSSM01VO(dssm01Vo);

            /** 발송내역조회(SMS) 업무 서비스 호출 수행*/
            RDMDLM04S01OutVO outVo = RDMDLM04.searchDssm01List(inVo);

            XFrame5Util.setOutputData("DS_SD_01",outVo.getListRDMDLM04DSSD01VO(), model);
        }catch(Exception e) {
            LOGGER.error("ERROR >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("&&&&& RDMDLM04Controller RDMDLM04S01 EXCEPTION END &&&&& ");
        }
        return XFrame5View.XFRAME5_VIEW;
    }
}
