package hanalife.r.rc.mn.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.RtRcptRfndDescMapper;
import hanalife.c.co.mapper.dto.RtRcptDsrcBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptRfndDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.as.vo.TimsUnrcvVO;
import hanalife.r.co.rc.service.IamtUnrcvService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;
import hanalife.r.co.rc.vo.IntgDsrcDescVO;
import hanalife.r.co.sr.service.RfndRsltService;
import hanalife.r.co.sr.vo.RfndRsltVO;
import hanalife.r.rc.mn.mapper.RcptMidRmbrProcMapper;
import hanalife.r.rc.mn.mapper.dto.ProcPreRcptCnclINDTO;
import hanalife.r.rc.mn.mapper.dto.ProcPreRcptCnclOUTDTO;
import hanalife.r.rc.mn.service.RcptMidRmbrProcService;
import hanalife.util.IamtUtil;
import hanalife.util.format.ServerSysDate;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RcptMidRmbrProcService.java Class
 * 클래스설명   : 선납건을 취소하고 전액/부분 중도상환 처리 Service Interface
 * 작성일자     : 2023. 4. 11.
 * 작성자명     : 70279 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 11.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : searchCprtLim : 제휴약정 한도잔액 수정
 *              chkPrdtCd : 제휴약정 한도잔액 수정
 *          updateCprtLim : 제휴약정 한도잔액 수정
 * </pre>
 */
@Service("RcptMidRmbrProcService")
public class RcptMidRmbrProcServiceImpl implements RcptMidRmbrProcService {

	private static final Logger log = LoggerFactory.getLogger(RcptMidRmbrProcServiceImpl.class);
	private boolean isDebug = log.isDebugEnabled();

	@Autowired
	private IamtUnrcvService iamtUnrcvService;
	@Autowired
	private AskUnrcvProcService askUnrcvProcService;
	@Autowired
	private RfndRsltService rfndRsltService;
	@Autowired
	private RcptMidRmbrProcMapper rcptMidRmbrProcMapper;
	@Autowired
	private RtRcptRfndDescMapper rtRcptRfndDescMapper;

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    private List intgArr = null;




	/**
	 * <p>선납건을 취소하고 전액/부분 중도상환 처리를 한다.
	 * @param reqAskUnrcvVO
	 * @param reqIamtUnrcvVO
	 * @param intgDs
	 * @param con
	 * @return 결제번호
	 * @throws Exception
	 */
	@Override
	public int proc(AskUnrcvVO reqAskUnrcvVO, IamtUnrcvVO reqIamtUnrcvVO) throws Exception{

		intgArr = new ArrayList();

		long start = System.currentTimeMillis();

		log.info("■ 화면 예가수 잔액 일치 여부 확인");
		procDsrcRamtCheck(reqIamtUnrcvVO);

		log.info("■ 선수납건을 취소한다.");
		procPreRcptCncl(reqAskUnrcvVO, reqIamtUnrcvVO);

		//예가수발생건으로 기존건 수납
		procRcptWithDsrc(reqAskUnrcvVO, reqIamtUnrcvVO);

		//예가수 통합처리
		Map intgDsrc = procDsrcIntg(reqIamtUnrcvVO);

		//중도상환처리
		int setlNo = procMidRmbr(intgDsrc, reqAskUnrcvVO, reqIamtUnrcvVO);

		log.info("■ [중도상환] 수납처리 종료 : " + IamtUtil.intervalTime(start, System.currentTimeMillis()));

		intgArr = null;

		return setlNo;
	}

	/**
	 * 화면에서 넘어온 예가수들의 잔액이 현재 일치하는지 여부 체크.
	 * @param reqIamtUnrcvVO
	 * @param con
	 */
	@Override
	public void procDsrcRamtCheck(IamtUnrcvVO reqIamtUnrcvVO) throws Exception {


		IamtUnrcvObjVO reqIamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);

		String dsrcNo = "";		//화면에서 받아온 예가수 번호
		long dsrcRamt = 0;		//화면에서 받아온 예가수 잔액
		long dsrcRlRamt = 0;	//현재 조회 결과 예가수 잔액

		for (int i = 0 ; i < reqIamtUnrcvObjVO.sizeIntgDsrcDescVO() ; i++) {
			IntgDsrcDescVO intgDsrcDescVO = reqIamtUnrcvObjVO.getIntgDsrcDescVO(i);
			dsrcNo = intgDsrcDescVO.dsrcNo;
			dsrcRamt = intgDsrcDescVO.dsrcRamt;

			RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();
			inDTO.setDsrcNo(intgDsrcDescVO.dsrcNo);

			RtRcptDsrcBaseDTO outDTO = rcptMidRmbrProcMapper.procDsrcRamtCheck(inDTO);
			if(outDTO != null) {
				dsrcRlRamt = outDTO.getDsrcRamt().longValue();

				if (dsrcRamt != dsrcRlRamt) {
					String rtnMsg = "예가수 잔액이 일치하지 않습니다. 확인 예가수번호:"+dsrcNo + "\n" +
									"확인잔액:"+String.valueOf(dsrcRamt) + " / 현재잔액:"+String.valueOf(dsrcRlRamt);
					throw new Exception(rtnMsg);
				}
			}

		}
	}


	/**
	 * <p>선납 취소처리
	 * @param reqAskUnrcvVO
	 * @param reqIamtUnrcvVO
	 * @throws Exception
	 */
	@Override
	public void procCncl(IamtUnrcvVO reqIamtUnrcvVO, int orgSetlNo) throws Exception{

		//수납취소 요청객체 생성
		IamtUnrcvObjVO reqIamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);
			IamtUnrcvObjVO iamtUnrcvObjVO = new IamtUnrcvObjVO();
			iamtUnrcvObjVO.loanNo = reqIamtUnrcvObjVO.loanNo; //대출번호
			iamtUnrcvObjVO.loanSeq = reqIamtUnrcvObjVO.loanSeq; //대출순번
			iamtUnrcvObjVO.sysPathCd = reqIamtUnrcvObjVO.sysPathCd;
			iamtUnrcvObjVO.orgSetlNo = orgSetlNo;
			iamtUnrcvObjVO.cnclFg = Constants.YES; //취소여부
			iamtUnrcvObjVO.acctDt = reqIamtUnrcvObjVO.acctDt; //회계일자
			iamtUnrcvObjVO.cnclDt = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD_WITH_DELIMETER); //취소일자
			iamtUnrcvObjVO.acctUnitCd = reqIamtUnrcvObjVO.acctUnitCd; //회계단위
			iamtUnrcvObjVO.isrtDeptCd = reqIamtUnrcvObjVO.isrtDeptCd;
			iamtUnrcvObjVO.frstRegEmpNo = reqIamtUnrcvObjVO.frstRegEmpNo;
			iamtUnrcvObjVO.cnclAftDsrcForthOccrFg = Constants.YES;	//선수납건을 취소후 무조건 예가수로 발생시킨다.

		IamtUnrcvVO iamtUnrcvVO = new IamtUnrcvVO();
			iamtUnrcvVO.addIamtUnrcvObjVO(iamtUnrcvObjVO);

		//수납취소 처리
		iamtUnrcvService.procRcptCncl(iamtUnrcvVO);
		if (!iamtUnrcvVO.isSuccess()) {
			throw new Exception("선수납건 취소시 에러발생(" + iamtUnrcvVO.rsltCntn + ")");
		}

		log.debug("------------------------------------------------------------------------");
		log.debug("취소 결제번호 : " + iamtUnrcvObjVO.setlNo + "(원거래결제번호 : " + iamtUnrcvObjVO.orgSetlNo + ")");

		//취소후 생성된 예가수 번호 저장.
		intgArr.add(iamtUnrcvObjVO.dsrcNo);
		log.debug("취소후 생성된 예가수 번호::: "+intgArr);
	}

	/**
	 * <p>선수납건을 취소한다.
	 * @param reqAskUnrcvVO
	 * @param reqIamtUnrcvVO
	 * @param intgDs
	 * @throws Exception
	 */
	private void procPreRcptCncl(AskUnrcvVO reqAskUnrcvVO, IamtUnrcvVO reqIamtUnrcvVO) throws Exception {

		BndVO bndVO = reqAskUnrcvVO.getBndVO(0);
		IamtUnrcvObjVO iamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);

		ProcPreRcptCnclINDTO inDTO = new ProcPreRcptCnclINDTO();
		inDTO.setLoanNo(bndVO.loanNo);
		inDTO.setLoanSeq(bndVO.loanSeq);
		inDTO.setMidRmbrDueDt(bndVO.midRmbrDueDt);

		List<ProcPreRcptCnclOUTDTO> outDTO = rcptMidRmbrProcMapper.procPreRcptCncl(inDTO);

		//유효성 체크
		long exmpAmt = 0;
		long leglActnAmt = 0;
		//int midRmbrBfCnt = 0;
		String minSetlDt = "";
		String maxAcctDt = "";
		String dsrcSetlDt = "";

		int setlNo = 0;
		String setlFrstRankCd = "";

		int dsrcCnt = iamtUnrcvObjVO.sizeIntgDsrcDescVO();
		IntgDsrcDescVO intgDsrcDescVO= null;

		for(ProcPreRcptCnclOUTDTO sourceIO : outDTO) {
			exmpAmt = sourceIO.getExmpAmt();
			leglActnAmt = sourceIO.getLeglActnCost();
			minSetlDt = sourceIO.getMinSetlDt();
			maxAcctDt = sourceIO.getMaxAcctDt();
			setlNo = sourceIO.getSetlNo();
			setlFrstRankCd = sourceIO.getSetlFrstRankCd();

			for (int j = 0 ; j < dsrcCnt; j++) {
				intgDsrcDescVO = iamtUnrcvObjVO.getIntgDsrcDescVO(j);
				dsrcSetlDt = intgDsrcDescVO.setlDt;
				log.info("::::dsrcSetlDt::::"+dsrcSetlDt);

				//체크된(화면에서) 예가수의 결제일자가 수납취소대상의 결제일자보다 빠른경우 에러처리
				if (DateUtil.compareDate(dsrcSetlDt, minSetlDt, "yyyy-MM-dd") > 0) {
					throw new Exception("결제일자가 상이하여 중도상환 처리할 수 없습니다. 예가수결제일:"+dsrcSetlDt+" , 취소수납 결제일(MIN):"+minSetlDt);
				}
				//체크된(화면에서) 예가수의 결제일자가 중도상환수납 결제일자보다 늦은경우 에러처리
				if (DateUtil.compareDate(dsrcSetlDt, iamtUnrcvObjVO.setlDt, "yyyy-MM-dd") < 0) {
					throw new Exception("결제일자가 상이하여 중도상환 처리할 수 없습니다.예가수결제일:"+dsrcSetlDt+" , 중도상환결제일:"+iamtUnrcvObjVO.setlDt);
				}
			}

			//수납취소건의 회계일자가 중도상환수납 회계일자보다 늦은경우 에러처리
			if (DateUtil.compareDate(maxAcctDt, iamtUnrcvObjVO.acctDt, "yyyy-MM-dd") < 0) {
				throw new Exception("결제일자가 상이하여 중도상환 처리할 수 없습니다.취소수납 회계일(MAX):"+maxAcctDt+" , 중도상환결제일:"+iamtUnrcvObjVO.acctDt);
			}

			if ("1".equals(setlFrstRankCd)) {
				throw new Exception("선납 취소대상중 원금변제 수납건이 존재합니다.(수납결제번호 : " + setlNo + ")");
			}

			if (exmpAmt!=0) {
				throw new Exception("면제금 입금처리한 건은 취소할수 없습니다.(수납결제번호 : " + setlNo + ")");
			}

			if (leglActnAmt!=0) {
				throw new Exception("가지급금 입금처리한 건은 취소할수 없습니다.(수납결제번호 : " + setlNo + ")");
			}

			//회계팀 두비스 요청에 의해 주석처리. 후에 생길지 모르므로 로직은 그대로 둠.
//			if (midRmbrBfCnt > 2) {
//				throw new Exception("2회차전 수납건이 존재합니다.(수납결제번호 : " + getIntVal(obj.get("SETL_NO")) + ")");
//			}
		}

		int orgSetlNo = 0;

		for(ProcPreRcptCnclOUTDTO sourceIO : outDTO) {
			orgSetlNo = sourceIO.getSetlNo();
			log.debug("############## 취소대상 결제번호 " + orgSetlNo);

			//선납수납건을 취소한다.
			procCncl(reqIamtUnrcvVO, orgSetlNo);
		}
	}

	/**
	 * <p>기존예가수로 연체료 납부
	 * @param reqIamtUnrcvVO
	 * @param con
	 * @throws Exception
	 */
	private void procRcptWithDsrc(AskUnrcvVO reqAskUnrcvVO, IamtUnrcvVO reqIamtUnrcvVO) throws Exception {

		String midDueDt = "";
		AskUnrcvObjVO reqAskUnrcvObjVO = reqAskUnrcvVO.getAskUnrcvObj(0);

		//선납 취소후 받을 금액을 계산한다.
		AskUnrcvObjVO askUnrcvObjVO = new AskUnrcvObjVO();
			askUnrcvObjVO.loanNo = reqAskUnrcvObjVO.loanNo;
			askUnrcvObjVO.loanSeq = reqAskUnrcvObjVO.loanSeq;
			askUnrcvObjVO.setlDt = reqAskUnrcvObjVO.setlDt;

		AskUnrcvVO askUnrcvVO = new AskUnrcvVO();
			askUnrcvVO.bkrpExemCalcFg = reqAskUnrcvVO.bkrpExemCalcFg;
			askUnrcvVO.addAskUnrcvObj(askUnrcvObjVO);

		askUnrcvProcService.calcAskUnrcv(askUnrcvVO);

		BndVO bndVO = askUnrcvVO.getBndVO(0);
		if (bndVO==null) {
			throw new Exception("선납취소후 입금받을 금액이 없습니다.");
		}

		//2018-08-01 HSH 아래 조건은 납입일이 결제일이 되었을 경우 연체는 아닌데,
		//원리금수납은 해야하는 부분때문에 주석처리. 하단에 중도상환납입일과 회차납입일과 비교부분 있으므로 필요 없음.

//		//선납취소후 연체가 없을시 재수납은 하지 않아도 됨.
//		if (!bndVO.dlyFg.equals(AskUnrcvConst.YES)) {
//			return;
//		}

		List timsList = askUnrcvVO.getTimsUnrcvList();
		//입금받을 회차가 없을시 SKIP
		if (timsList==null) {
			return;
		}

		//중도상환일자가 없으면 안된다.
		if (StringUtil.isNull(bndVO.midRmbrDueDt)) {
			throw new Exception("중도상환 가능한 상태가 아닙니다.");
		}

		midDueDt = bndVO.midRmbrDueDt;

		String strDsrcNo = "";
		int dsrcCnt = intgArr.size();
		if (dsrcCnt<1) {
			log.info("선납취소후 발생된 예가수 없음");
			return;
		}

		//유효성 체크
		String dsrcNo = "";
		long dsrcRamt = 0;
		String setlDt = "";

		IamtUnrcvObjVO reqIamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);

		//입금처리 가능한 예가수 조회
		for (int i=0; i<dsrcCnt; i++) {

			RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();

			strDsrcNo = (String) intgArr.get(i);
			inDTO.setDsrcNo(strDsrcNo);

			log.info("쿼리에 입력할 예가수 번호 sql::"+strDsrcNo);

			RtRcptDsrcBaseDTO outDTO = rcptMidRmbrProcMapper.searchDsrcInfo(inDTO);

			if(outDTO != null) {
				dsrcRamt = outDTO.getDsrcRamt().longValue();
				dsrcNo   = outDTO.getDsrcNo();
				setlDt   = outDTO.getSetlDt();

				log.debug("### 중도상환회차전까지 수납::");
				log.debug("### dsrcNo::"+dsrcNo);
				log.debug("### setlDt::"+setlDt);
				log.debug("### dsrcRamt::"+dsrcRamt);

				//결제가능한 예가수로 중도상환전 받을금액만큼 수납처리한다.
				AskUnrcvObjVO askUnrcvObjVO1 = new AskUnrcvObjVO();
					askUnrcvObjVO1.loanNo = reqIamtUnrcvObjVO.loanNo;
					askUnrcvObjVO1.loanSeq = reqIamtUnrcvObjVO.loanSeq;
					askUnrcvObjVO1.setlDt = setlDt;
					askUnrcvObjVO1.dsrcNo = dsrcNo;

				AskUnrcvVO askUnrcvVO1 = new AskUnrcvVO();
					askUnrcvVO1.addAskUnrcvObj(askUnrcvObjVO1);

				askUnrcvProcService.calcAskUnrcv(askUnrcvVO1);

				//채권정보가 없으면 SKIP
				BndVO bndVO1 = askUnrcvVO1.getBndVO(0);
				if (bndVO1 == null) {
					return;
				}

				List timsList1 = askUnrcvVO.getTimsUnrcvList();
				long askAmt = 0;
				for (int j=0, n = timsList1.size(); j <n; j++) {
					TimsUnrcvVO tims = askUnrcvVO1.getTimsUnrcv(j);
					if (tims.dueDt.compareTo(midDueDt) < 0) {
						askAmt = askAmt + tims.askAmt;
					} else {
						break;
					}
				}

				//중도상환전 수납대상금액
				if (askAmt <= 0) {
					return;
				}

				long dsrcAdjAmt = bndVO1.dsrcRamt;

				if (dsrcAdjAmt > askAmt) {
					dsrcAdjAmt = askAmt;
				}

				//입금미수 요청객체 생성
				IamtUnrcvObjVO iamtUnrcvObjVO = new IamtUnrcvObjVO();
					iamtUnrcvObjVO.loanNo  = bndVO1.loanNo; //대출번호
					iamtUnrcvObjVO.loanSeq = bndVO1.loanSeq; //대출순번
					iamtUnrcvObjVO.setlDt  = bndVO1.setlDt; //결제일자
					iamtUnrcvObjVO.acctDt    = reqIamtUnrcvObjVO.acctDt; //회계일자
					iamtUnrcvObjVO.setlDivCd = Constants.SETL_DIV_PIAMT; //원리금 결제
					iamtUnrcvObjVO.rcptTpCd  = Constants.RCPT_DIV_DSRC_ARNG; //예가수정산
					iamtUnrcvObjVO.dsrcNo    = bndVO1.dsrcNo; //예가수 번호
					iamtUnrcvObjVO.dsrcOccrCd = bndVO1.dsrcOccrCd;
					iamtUnrcvObjVO.acctUnitCd = reqIamtUnrcvObjVO.acctUnitCd; //회계단위코드
					iamtUnrcvObjVO.isrtDeptCd = reqIamtUnrcvObjVO.isrtDeptCd; //입력 부서
					iamtUnrcvObjVO.dsrcAdjAmt = dsrcAdjAmt;
					iamtUnrcvObjVO.rcptAmt    = dsrcAdjAmt;
					iamtUnrcvObjVO.sysPathCd  = reqIamtUnrcvObjVO.sysPathCd;
					iamtUnrcvObjVO.frstRegEmpNo = reqIamtUnrcvObjVO.frstRegEmpNo;

				//입금미수 원리금 수납처리 호출
				IamtUnrcvVO iamtUnrcvVO = new IamtUnrcvVO();
					iamtUnrcvVO.addIamtUnrcvObjVO(iamtUnrcvObjVO);

				iamtUnrcvService.procRcpt(iamtUnrcvVO, askUnrcvVO1);
				if (!iamtUnrcvVO.isSuccess()) {
					throw new Exception("연체회차 수납처리실패(" + iamtUnrcvVO.rsltCntn +")");
				}

				log.info("------------------------------------------------------------------------");
				log.info("예가수로 정상회차까지수납 (결제번호 : " + iamtUnrcvObjVO.setlNo + ")" );
				log.info("예가수정산요청정보["+iamtUnrcvObjVO+"]" );
				log.info("------------------------------------------------------------------------");


			}

		}

	}

	/**
	 * <p>예가수 통합처리
	 * @param con
	 * @throws Exception
	 */
	private Map procDsrcIntg(IamtUnrcvVO reqIamtUnrcvVO) throws Exception{
		Map intgDsrc = new HashMap();

		String inptDsrcNo = "";
		long inptDsrcAdjAmt = 0;
		IamtUnrcvObjVO reqIamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);
		if (reqIamtUnrcvObjVO.dsrcAdjAmt > 0 && !reqIamtUnrcvObjVO.dsrcNo.equals("")) {
			inptDsrcNo = reqIamtUnrcvObjVO.dsrcNo;
			inptDsrcAdjAmt = reqIamtUnrcvObjVO.dsrcAdjAmt;
		}

		for (int i=0; i < reqIamtUnrcvObjVO.sizeIntgDsrcDescVO() ; i++) {
			intgArr.add(getStrVal(reqIamtUnrcvObjVO.getIntgDsrcDescVO(i).dsrcNo ));
		}

		String strDsrcNo = "";
		int dsrcCnt = intgArr.size();

		List<RtRcptDsrcBaseDTO> resultList = null;

		for (int i = 0; i < dsrcCnt ; i++) {

			RtRcptDsrcBaseDTO inDTO = new RtRcptDsrcBaseDTO();

			strDsrcNo = (String) intgArr.get(i);
			inDTO.setDsrcNo(strDsrcNo);

			RtRcptDsrcBaseDTO outDTO = rcptMidRmbrProcMapper.searchDsrcInfo(inDTO);

			if(outDTO != null) {
				resultList.add(outDTO);
			}
		}

		//통합할건이 없습니다.
		if (resultList.size() == 0) {
			return null;
		} else if (resultList.size() == 1) {

			String dsrcNo = resultList.get(0).getDsrcNo();
			long dsrcRamt = resultList.get(0).getDsrcRamt().longValue();

			long orgDsrcRamt = 0;
			intgDsrc.put("dsrcNo", dsrcNo);

			for (int i = 0 ; i < reqIamtUnrcvObjVO.sizeIntgDsrcDescVO() ; i++) {
				if (getStrVal(reqIamtUnrcvObjVO.getIntgDsrcDescVO(i).dsrcNo).equals(inptDsrcNo)) {
					orgDsrcRamt = reqIamtUnrcvObjVO.getIntgDsrcDescVO(i).dsrcRamt;
					break;
				}
			}

			//선납취소건 수납건이 예가수 정산 건일 경우 해당예가수는 취소 후 잔액이 늘어난다.
			//예가수정산금액 = 입력금액 + (실시간잔액 - 원예가수잔액)
			intgDsrc.put("dsrcAdjAmt" , inptDsrcAdjAmt + (dsrcRamt - orgDsrcRamt) );
			log.info("통합예가수1건::입력한금액+'/'+현재잔액+'/'+원예가수잔액");
			log.info(""+inptDsrcAdjAmt+'/'+dsrcRamt+'/'+orgDsrcRamt);

			return intgDsrc;
		}

		int rfndSnum = 0;
		int dsrcSnum = 0;
		long ramt = 0;
		long adjAmt = 0;
		long intgDsrcAdjAmt = 0;
		String dsrcNo = "";
		String currentDt = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD_WITH_DELIMETER);
		String intgDsrcSetlDt = "1111-11-11";	//통합할예가수의 결제일자는 통합할예가수 결제일자 중 MAX
		String setlDt = "";
		long dsrcRamt = 0;

		List params = null;

		RfndRsltVO inRfndVO = null;

		for (int i=0; i<resultList.size();i++) {


			dsrcNo   = resultList.get(i).getDsrcNo();
			rfndSnum = (int)resultList.get(i).getRfndSnum();
			dsrcSnum = (int)resultList.get(i).getDsrcSnum();
			dsrcRamt = resultList.get(i).getDsrcRamt().longValue();
			setlDt   = resultList.get(i).getSetlDt();

			ramt     = dsrcRamt;
			adjAmt   = dsrcRamt;


			//통합할예가수의 결제일자 세팅
			if (DateUtil.compareDate(intgDsrcSetlDt, setlDt, "yyyy-MM-dd") > 0) {
				intgDsrcSetlDt = setlDt;
			}

			rfndSnum++;
			dsrcSnum++;

			//입력받은 예가수이면
			if (inptDsrcNo.equals(dsrcNo)) {
				long orgDsrcRamt = 0;
				for (int j = 0 ; j < reqIamtUnrcvObjVO.sizeIntgDsrcDescVO() ; j++) {
					if (getStrVal(reqIamtUnrcvObjVO.getIntgDsrcDescVO(j).dsrcNo).equals(inptDsrcNo)) {
						orgDsrcRamt = reqIamtUnrcvObjVO.getIntgDsrcDescVO(j).dsrcRamt;
						break;
					}
				}
				adjAmt = inptDsrcAdjAmt + (ramt - orgDsrcRamt);

				if (isDebug) {
					log.debug("통합예가수중복시 ::입력한금액+'/'+현재잔액+'/'+원예가수잔액");
					log.debug(""+inptDsrcAdjAmt+'/'+dsrcRamt+'/'+orgDsrcRamt);
				}

			} else {
				adjAmt = ramt;
			}

			ramt = ramt - adjAmt;


			RtRcptRfndDescDTO inDescDTO = new RtRcptRfndDescDTO();

			inDescDTO.setDsrcNo(dsrcNo);
			inDescDTO.setRfndSnum(rfndSnum);
			inDescDTO.setRfndLoanNo(resultList.get(i).getAdjLoanNo());
			inDescDTO.setRfndLoanSeq(resultList.get(i).getAdjLoanSeq());
			inDescDTO.setRfndDt(currentDt);
			inDescDTO.setAcctDt(reqIamtUnrcvObjVO.acctDt);
			inDescDTO.setRfndStatCd(Constants.RFND_STAT_RFND_PROC_MID);
			inDescDTO.setRcptTpCd(Constants.RCPT_DIV_RFND_ACNT);
			inDescDTO.setRfndRsnCd("18");
			inDescDTO.setDsrcOccrAmt(resultList.get(i).getDsrcOccrAmt());
			inDescDTO.setDsrcRamt(new BigDecimal(ramt));
			inDescDTO.setDsrcAdjAmt(new BigDecimal(adjAmt));
			inDescDTO.setRfndRsltCd("000");
			inDescDTO.setIsrtDeptCd(reqIamtUnrcvObjVO.isrtDeptCd);
			inDescDTO.setAdjDeptCd(resultList.get(i).getAdjDeptCd());
			inDescDTO.setDsrcSnum(dsrcSnum);
			inDescDTO.setSysPathCd(reqIamtUnrcvObjVO.sysPathCd);
			inDescDTO.setFrstRegEmpNo(reqIamtUnrcvObjVO.frstRegEmpNo);
			inDescDTO.setLastProcEmpNo(reqIamtUnrcvObjVO.frstRegEmpNo);

			int iInsertCnt = rtRcptRfndDescMapper.insert(inDescDTO);

			if(iInsertCnt != 1) {
				throw new Exception("예가수통합처리실패(환불내역등록실패)");
			}


			RtRcptDsrcBaseDTO inBaseDTO = new RtRcptDsrcBaseDTO();

			inBaseDTO.setDsrcSnum(dsrcSnum);
			inBaseDTO.setDsrcNo(dsrcNo);

			int iUpdateCnt = rcptMidRmbrProcMapper.updateRtRcptDsrcBase(inBaseDTO);

			if(iUpdateCnt != 1) {
				throw new Exception("예가수통합처리실패(예가수기본수정실패)");
			}

			// 환불처리
			inRfndVO = new RfndRsltVO();
			inRfndVO.setDsrcNo(dsrcNo); //String dsrcNo; //예가수_번호
			inRfndVO.setRfndSnum(rfndSnum); //int rfndSnum; //환불일련번호
			inRfndVO.setDsrcSnum(dsrcSnum); //int dsrcSnum; //환불후 예가수일련번호 셋팅
			inRfndVO.setAcctDt(reqIamtUnrcvObjVO.acctDt); //int dsrcSnum; //환불후 예가수일련번호 셋팅
			inRfndVO.setProcEmpNo(reqIamtUnrcvObjVO.frstRegEmpNo); //String procEmpNo; //처리사원번호
			inRfndVO.setRfndRsltCd(Constants.SUCCESS);

			RfndRsltVO outRfndVO = rfndRsltService.procRfnd(inRfndVO);
			if (!Constants.SUCCESS.equals(outRfndVO.getRsltCd())) {
				throw new Exception("예가수환불처리중 오류[" + outRfndVO.getRsltCntn() + "]");
			}

			intgDsrcAdjAmt = intgDsrcAdjAmt + adjAmt;

		}

		//여러건의 예가수를 통합하여 하나의 예가수로 합친다.
		IamtUnrcvObjVO iamtUnrcvObjVO = new IamtUnrcvObjVO();
		iamtUnrcvObjVO.acctDt = reqIamtUnrcvObjVO.acctDt; //회계일자
		iamtUnrcvObjVO.setlDt = intgDsrcSetlDt; //결제일자
		iamtUnrcvObjVO.rcptTpCd =  Constants.RCPT_DIV_WID_RCPT_DEPO; //수납유형코드
		iamtUnrcvObjVO.setlDivCd = Constants.SETL_DIV_DSRC; //결제구분코드
		iamtUnrcvObjVO.dsrcOccrAmt = intgDsrcAdjAmt; //결제금액
		iamtUnrcvObjVO.dsrcOccrCd = Constants.DSRC_OCCR_INTG_DSRC; //예가수 발생코드
		iamtUnrcvObjVO.dsrcAdjCd = Constants.DSRC_DIV_DSRC_OCCR; //예가수 정산코드
		iamtUnrcvObjVO.setlAmt = intgDsrcAdjAmt; //결제금액
		iamtUnrcvObjVO.cashAmt = intgDsrcAdjAmt; //현금금액
		iamtUnrcvObjVO.adjDeptCd = reqIamtUnrcvObjVO.isrtDeptCd; //정산부서코드
		iamtUnrcvObjVO.loanNo = reqIamtUnrcvObjVO.loanNo; //대출번호
		iamtUnrcvObjVO.loanSeq = reqIamtUnrcvObjVO.loanSeq; //대출순번
		iamtUnrcvObjVO.rmk = "통합예가수발생"; //적요
		iamtUnrcvObjVO.acctUnitCd = reqIamtUnrcvObjVO.acctUnitCd; //회계단위
		iamtUnrcvObjVO.isrtDeptCd = reqIamtUnrcvObjVO.isrtDeptCd; //입력 부서
		iamtUnrcvObjVO.frstRegEmpNo = reqIamtUnrcvObjVO.frstRegEmpNo; //로긴사원번호
		iamtUnrcvObjVO.sysPathCd = reqIamtUnrcvObjVO.sysPathCd;

		IamtUnrcvVO iamtUnrcvVO = new IamtUnrcvVO();
		iamtUnrcvVO.addIamtUnrcvObjVO(iamtUnrcvObjVO);

		//입금미수 원리금 수납처리 호출
		iamtUnrcvVO = iamtUnrcvService.procRcpt(iamtUnrcvVO, null);
		//3.입금 미수 결과 확인
		if (!iamtUnrcvVO.isSuccess()) {
			// Error Message
			throw new Exception(iamtUnrcvVO.rsltCd + "||" + iamtUnrcvVO.rsltCntn);
		}

		intgDsrc.put("dsrcNo", iamtUnrcvObjVO.dsrcNo);
		intgDsrc.put("dsrcAdjAmt", Long.valueOf(""+intgDsrcAdjAmt));

		if (isDebug) {
			log.debug("통합한 예가수번호 : " + iamtUnrcvObjVO.dsrcNo);
		}


		return intgDsrc;
	}

	/**
	 * <p>중도상환처리
	 * @param intgDsrc
	 * @param con
	 * @throws Exception
	 */
	private int procMidRmbr(Map intgDsrc, AskUnrcvVO reqAskUnrcvVO, IamtUnrcvVO reqIamtUnrcvVO) throws Exception{

		String dsrcNo = "";
		long dsrcAdjAmt = 0;
		if (intgDsrc != null) {
			dsrcNo = getStrVal(intgDsrc.get("dsrcNo"));
			dsrcAdjAmt = getLongVal(intgDsrc.get("dsrcAdjAmt"));
		}

		AskUnrcvObjVO reqAskUnrcvObjVO = reqAskUnrcvVO.getAskUnrcvObj(0);

		// 청구미수 계산
		AskUnrcvObjVO askUnrcvObjVO = new AskUnrcvObjVO();
			askUnrcvObjVO.loanNo = reqAskUnrcvObjVO.loanNo;
			askUnrcvObjVO.loanSeq = reqAskUnrcvObjVO.loanSeq;
			askUnrcvObjVO.setlDt = reqAskUnrcvObjVO.setlDt;
			askUnrcvObjVO.dsrcNo = dsrcNo;
			askUnrcvObjVO.partRmbrPamt = reqAskUnrcvObjVO.partRmbrPamt;
			askUnrcvObjVO.leglUnCalcFg = reqAskUnrcvObjVO.leglUnCalcFg;
			askUnrcvObjVO.midRmbrFeeUnCalcFg = reqAskUnrcvObjVO.midRmbrFeeUnCalcFg;
			askUnrcvObjVO.addTermInt = reqAskUnrcvObjVO.addTermInt;

		AskUnrcvVO askUnrcvVO = new AskUnrcvVO();
			askUnrcvVO.bkrpExemCalcFg  = reqAskUnrcvVO.bkrpExemCalcFg;
			askUnrcvVO.addAskUnrcvObj(askUnrcvObjVO);

		askUnrcvProcService.calcAskUnrcv(askUnrcvVO);

		BndVO bndVO = askUnrcvVO.getBndVO(0);
		if (bndVO == null) {
			throw new Exception("중도상환 처리 중 상환할 대출에 수납받을 금액이 존재하지 않습니다.");
		}

		log.info("------------------------------------------------------------------------");

		IamtUnrcvObjVO reqIamtUnrcvObjVO = reqIamtUnrcvVO.getIamtUnrcvObjVO(0);

		//입금미수 요청객체 생성
		IamtUnrcvObjVO iamtUnrcvObjVO = new IamtUnrcvObjVO();
			iamtUnrcvObjVO.loanNo = reqIamtUnrcvObjVO.loanNo; //대출번호
			iamtUnrcvObjVO.loanSeq = reqIamtUnrcvObjVO.loanSeq; //대출순번
			iamtUnrcvObjVO.setlDt = bndVO.setlDt; //결제일자
			iamtUnrcvObjVO.acctDt = reqIamtUnrcvObjVO.acctDt; //회계일자

			iamtUnrcvObjVO.setlDivCd = reqIamtUnrcvObjVO.setlDivCd; //결제구분 --> 화면값
			iamtUnrcvObjVO.rcptTpCd = reqIamtUnrcvObjVO.rcptTpCd; //수납유형 코드

			iamtUnrcvObjVO.dsrcNo = bndVO.dsrcNo; //예가수 번호
		if (!StringUtil.isNull(iamtUnrcvObjVO.dsrcNo)) {
			iamtUnrcvObjVO.dsrcAdjCd = Constants.DSRC_DIV_DSRC_ADJ;
			iamtUnrcvObjVO.dsrcOccrCd = bndVO.dsrcOccrCd;
		}

			iamtUnrcvObjVO.acctUnitCd = reqIamtUnrcvObjVO.acctUnitCd; //회계단위코드
			iamtUnrcvObjVO.isrtDeptCd = reqIamtUnrcvObjVO.isrtDeptCd;

			iamtUnrcvObjVO.exmpConsNo = reqIamtUnrcvObjVO.exmpConsNo; //면제품의 번호
			iamtUnrcvObjVO.exmpAmt = reqIamtUnrcvObjVO.exmpAmt; //면제금액
			iamtUnrcvObjVO.exmpPamt = reqIamtUnrcvObjVO.exmpPamt; //면제원금
			iamtUnrcvObjVO.exmpInt = reqIamtUnrcvObjVO.exmpInt; //면제이자
			iamtUnrcvObjVO.exmpDfee = reqIamtUnrcvObjVO.exmpDfee; //면제연체료
			iamtUnrcvObjVO.exmpLeglActnCost = reqIamtUnrcvObjVO.exmpLeglActnCost; //면제법적조치비용
			iamtUnrcvObjVO.exmpMidRmbrFee = reqIamtUnrcvObjVO.exmpMidRmbrFee; //면제중도상환수수료
			iamtUnrcvObjVO.exmpTrtFee = reqIamtUnrcvObjVO.exmpTrtFee; //면제취급수수료

			iamtUnrcvObjVO.dsrcAdjAmt = dsrcAdjAmt; //예가수정산금액
			iamtUnrcvObjVO.cashAmt = reqIamtUnrcvObjVO.cashAmt; //현금금액
			iamtUnrcvObjVO.chkAmt = reqIamtUnrcvObjVO.chkAmt; //수표금액

			iamtUnrcvObjVO.setlAmt = iamtUnrcvObjVO.cashAmt + iamtUnrcvObjVO.chkAmt; //결제금액
			iamtUnrcvObjVO.rcptAmt = iamtUnrcvObjVO.dsrcAdjAmt + iamtUnrcvObjVO.setlAmt; //수납금액

			iamtUnrcvObjVO.sysPathCd = reqIamtUnrcvObjVO.sysPathCd;
			iamtUnrcvObjVO.frstRegEmpNo = reqIamtUnrcvObjVO.frstRegEmpNo;

			//수표내역 등록
			iamtUnrcvObjVO.setChkDescVOList(reqIamtUnrcvObjVO.getChkDescVOList());

		//입금미수 원리금 수납처리 호출
		IamtUnrcvVO iamtUnrcvVO = new IamtUnrcvVO();
			iamtUnrcvVO.addIamtUnrcvObjVO(iamtUnrcvObjVO);

		log.info("중도상환처리["+iamtUnrcvObjVO+"]" );
		log.info("------------------------------------------------------------------------");

		iamtUnrcvService.procRcpt(iamtUnrcvVO, askUnrcvVO);
		if (!iamtUnrcvVO.isSuccess()) {
			throw new Exception("중도상환 결제에러(" + iamtUnrcvVO.rsltCntn + ")");
		}
		return iamtUnrcvObjVO.setlNo;
	}

	private String getStrVal(Object obj) {
		return StringUtils.trimToEmpty(String.valueOf(obj));
	}

	private int getIntVal(Object obj) {
		return NumberUtils.toInt(String.valueOf(obj));
	}

	private long getLongVal(Object obj) {
		return NumberUtils.toLong(String.valueOf(obj));
	}

}
