package hanalife.r.rc.rc.service.impl;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.r.co.la.service.LoanInfoProcMngService;
import hanalife.r.co.la.vo.LoanInfoProcMngInVO;
import hanalife.r.co.la.vo.LoanInfoProcMngObjVO;
import hanalife.r.co.la.vo.LoanInfoProcMngOutVO;
import hanalife.r.rc.rc.mapper.RcptDescSpecReadMapper;
import hanalife.r.rc.rc.mapper.dto.RcptDescSpecReadDSRCPTDESCSD01DTO;
import hanalife.r.rc.rc.mapper.dto.RcptDescSpecReadDSRCPTDESCSD02DTO;
import hanalife.r.rc.rc.mapper.dto.RcptDescSpecReadDSRMBRSMDTO;
import hanalife.r.rc.rc.service.RRCRCM03Service;
import hanalife.r.rc.rc.vo.RRCRCM03DSLOANINFOVO;
import hanalife.r.rc.rc.vo.RRCRCM03DSRCPTDESCSD01VO;
import hanalife.r.rc.rc.vo.RRCRCM03DSRCPTDESCSD02VO;
import hanalife.r.rc.rc.vo.RRCRCM03S01InVO;
import hanalife.r.rc.rc.vo.RRCRCM03S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRCM03ServiceImpl.java Class
 * 클래스설명   : 수납내역상세조회 (RRCRCM03) Service Implements
 * 작성일자     : 2023. 3. 8.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 8.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRRCRCM03S01 : 수납내역상세조회
 * </pre>
 */
@Service("RRCRCM03Service")
public class RRCRCM03ServiceImpl implements RRCRCM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCM03ServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

	@Autowired
    private RcptDescSpecReadMapper rcptDescSpecReadMapper;

	@Resource(name = "LoanInfoProcMngService")
	private LoanInfoProcMngService loanInfoProcMngService;

	/**
	 * <p>메소드명      : getRRCRCM03S01 : 수납내역상세조회</p>
	 * <p>작성일자      : 2023. 3. 8.
	 * <p>작성자(author): 70322 / sungjin.park
	 * <p>설명          : 수납내역상세를 조회 한다.</p>
	 * <p>메소드인수    : RRCRCM03InVo </p>
	 * <p>메소드리턴값  : RRCRCM03OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RRCRCM03S01OutVO getRRCRCM03S01(RRCRCM03S01InVO inVo) throws Exception {

		LOGGER.info("##### RRCRCM03ServiceImpl getRRCRCM03S01 Start #####");

		/** 수납내역상세조회 서비스 결과값 객체 생성 */
		RRCRCM03S01OutVO resultVo = new RRCRCM03S01OutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /** 수납내역상세조회 조회 조건 입력값 객체 생성 및 대입 수행 */
		RcptDescSpecReadDSRMBRSMDTO i01Dto = new RcptDescSpecReadDSRMBRSMDTO();

		i01Dto.setLoanNo(inVo.getRRCRCM03DSRMBRSMVO().getLoanNo());		/**대출_번호*/
		i01Dto.setLoanSeq(inVo.getRRCRCM03DSRMBRSMVO().getLoanSeq());	/**대출_순번*/

		// DSLOANINFO - 대출정보 서비스 호출
		/** 수납내역상세조회 조회 쿼리 Mapper 호출 수행 */

		LoanInfoProcMngInVO InVO2 = new LoanInfoProcMngInVO();
		InVO2.setLoanNo(inVo.getRRCRCM03DSRMBRSMVO().getLoanNo()); /** 대출번호 */
		InVO2.setLoanSeq(inVo.getRRCRCM03DSRMBRSMVO().getLoanSeq()); /** 대출순번 */

        try {
    		LOGGER.info("##### RRCRCM03ServiceImpl DSLOANINFO Start #####");
        	//DSLOANINFO
        	LoanInfoProcMngOutVO resultLoanInfoS01 = loanInfoProcMngService.getLoanInfo(InVO2);

        	/** 수납내역상세조회 화면 출력을 위한 결과값 List VO 객체 생성 */
        	List<RRCRCM03DSLOANINFOVO> resultLoanInfoList = new ArrayList<RRCRCM03DSLOANINFOVO>();

        	for(LoanInfoProcMngObjVO sourceIO : resultLoanInfoS01.getListLoanInfoProcMngObjVO()) {
            	/** 수납내역상세조회 VO에 조회된 Mapper DTO 값을 대입 */
            	RRCRCM03DSLOANINFOVO targetIO = new RRCRCM03DSLOANINFOVO();
            	targetIO.setLoanNo(sourceIO.getLoanNo());					/**  */
            	targetIO.setLoanSeq(sourceIO.getLoanSeq());					/**  */
            	targetIO.setContManNo(sourceIO.getContManNo());				/**  */
            	targetIO.setCustNm(sourceIO.getCustNm());					/**  */
            	targetIO.setRlDueManNo(sourceIO.getRlDueManNo());			/**  */
            	targetIO.setRlDueManNm(sourceIO.getRlDueManNm());			/**  */
            	targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());	/**  */
            	targetIO.setPrdtLrgeClasNm(sourceIO.getPrdtLrgeClasNm());	/**  */
            	targetIO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd());		/**  */
            	targetIO.setPrdtMidClasNm(sourceIO.getPrdtMidClasNm());		/**  */
            	targetIO.setPrdtSmClasCd(sourceIO.getPrdtSmClasCd());		/**  */
            	targetIO.setPrdtSmClasNm(sourceIO.getPrdtSmClasNm());		/**  */
            	targetIO.setRmbrFrmlNm(sourceIO.getRmbrFrmlNm());			/**  */
            	targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd());			/**  */
            	targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm());			/**  */
            	targetIO.setMngDeptCd(sourceIO.getMngDeptCd());				/**  */
            	targetIO.setMngDeptNm(sourceIO.getMngDeptNm());				/**  */
            	targetIO.setLoanIntRt(sourceIO.getLoanIntRt());				/**  */
            	targetIO.setLoanTerm(sourceIO.getLoanTerm());				/**  */
            	targetIO.setLoanPamt(sourceIO.getLoanPamt());				/**  */
            	targetIO.setDfeeRt(sourceIO.getDfeeRt());					/**  */
            	targetIO.setTrtFeeRt(sourceIO.getTrtFeeRt());				/**  */
            	targetIO.setLoanStatCd(sourceIO.getLoanStatCd());			/**  */
            	targetIO.setLoanStatNm(sourceIO.getLoanStatNm());			/**  */
            	targetIO.setBndStatCd(sourceIO.getBndStatCd());				/**  */
            	targetIO.setBndStatNm(sourceIO.getBndStatNm());				/**  */
            	targetIO.setDeliDt(sourceIO.getDeliDt());					/**  */
            	targetIO.setLoanDt(sourceIO.getLoanDt());					/**  */
            	targetIO.setMidRmbrFeeRt(sourceIO.getMidRmbrFeeRt());		/**  */
            	targetIO.setMrtgSmClasNm(sourceIO.getMrtgSmClasNm());		/**  */
            	targetIO.setFcntDueDt(sourceIO.getFcntDueDt());				/**  */
            	targetIO.setEprtDt(sourceIO.getEprtDt());					/**  */
            	targetIO.setContCnt(sourceIO.getContCnt());					/**  */
            	targetIO.setGuarCnt(sourceIO.getGuarCnt());					/**  */
            	targetIO.setTrtFee(sourceIO.getTrtFee());					/**  */
            	targetIO.setRmbrTrtFee(sourceIO.getRmbrTrtFee());			/**  */
            	targetIO.setTrtFeeIstpFg(sourceIO.getTrtFeeIstpFg());		/**  */
            	/** 수납내역상세조회 List 객체에 추가하도록 수행 */
                resultLoanInfoList.add(targetIO);
            }

            /** 수납내역상세조회 화면 출력 결과값 대입 */
            resultVo.setListRRCRCM03DSLOANINFOVO(resultLoanInfoList);

            LOGGER.info("##### RRCRCM03ServiceImpl RRCRCM03S01 normal End #####");
        } catch (Exception e) {
        	LOGGER.error("[대출정보 조회 오류] : 대출 정보 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd("E001");
            resultVo.setRsltCntn("대출정보 조회 오류");
        	LOGGER.info("##### RRCRCM03ServiceImpl DSLOANINFO Exception End #####");
        	return resultVo;
        }

        try {
    		LOGGER.info("##### RRCRCM03ServiceImpl DSRCPTDESCSD01 Start #####");
        	// DSRCPTDESCSD01
         	/** 수납내역상세조회 조회 쿼리 Mapper 호출 수행 */
            List<RcptDescSpecReadDSRCPTDESCSD01DTO> resultRcptDescSd01DTO = rcptDescSpecReadMapper.searchRcptBaseList(i01Dto);

            /** 수납내역상세조회 화면 출력을 위한 결과값 List VO 객체 생성 */
            List<RRCRCM03DSRCPTDESCSD01VO> resultRcptDescSd01List = new ArrayList<RRCRCM03DSRCPTDESCSD01VO>();

            for(RcptDescSpecReadDSRCPTDESCSD01DTO sourceIO : resultRcptDescSd01DTO) {
            	/** 수납내역상세조회 VO에 조회된 Mapper DTO 값을 대입 */
             	RRCRCM03DSRCPTDESCSD01VO targetIO = new RRCRCM03DSRCPTDESCSD01VO();
             	targetIO.setSetlNo(sourceIO.getSetlNo()); /** 결제번호 */
             	targetIO.setAcctDt(sourceIO.getAcctDt()); /** 회계_일자 */
             	targetIO.setSetlDt(sourceIO.getSetlDt()); /** 결제_일자 */
             	targetIO.setIsrtDeptCd(sourceIO.getIsrtDeptCd()); /** 수납_부서_코드 */
             	targetIO.setRcptDeptNm(sourceIO.getRcptDeptNm()); /** 수납_부서_명 */
             	targetIO.setRcptTpCd(sourceIO.getRcptTpCd()); /** 수납_유형_코드 */
             	targetIO.setRcptTpNm(sourceIO.getRcptTpNm()); /** 수납_유형_명 */
             	targetIO.setSetlDivCd(sourceIO.getSetlDivCd()); /** 결제_구분_코드 */
             	targetIO.setSetlDivNm(sourceIO.getSetlDivNm()); /** 결제_구분_명 */
             	targetIO.setTims(sourceIO.getTims()); /** 회차 */
             	targetIO.setSetlAmt(sourceIO.getSetlAmt()); /** 결제_금액 */
             	targetIO.setCashAmt(sourceIO.getCashAmt()); /** 현금_금액 */
             	targetIO.setChkAmt(sourceIO.getChkAmt()); /** 수표_금액 */
             	targetIO.setDsrcAdjAmt(sourceIO.getDsrcAdjAmt()); /** 예가수_정산_금액 */
             	targetIO.setExmpAmt(sourceIO.getExmpAmt()); /** 면제_금액 */
             	targetIO.setRcptAmt(sourceIO.getRcptAmt()); /** 수납_금액 */
             	targetIO.setRcptPamt(sourceIO.getRcptPamt()); /** 수납_원금_원금 */
             	targetIO.setRcptInt(sourceIO.getRcptInt()); /** 수납_이자_이자 */
             	targetIO.setRcptDfee(sourceIO.getRcptDfee()); /** 수납_연체료_연체료 */
             	targetIO.setDiscAmt(sourceIO.getDiscAmt()); /** 할인_금액 */
             	targetIO.setPdueDiscDfee(sourceIO.getPdueDiscDfee()); /** 선납_할인_연체료 */
             	targetIO.setLeglActnCost(sourceIO.getLeglActnCost()); /** 법적_조치_비용_가지급금 */
             	targetIO.setMidRmbrFee(sourceIO.getMidRmbrFee()); /** 중도_상환_수수료 */
             	targetIO.setTrtFeeDisc(sourceIO.getTrtFeeDisc()); /** 취급_수수료_할인 */
             	targetIO.setDsrcOccrAmt(sourceIO.getDsrcOccrAmt()); /** 예가수_발생_금액 */
             	targetIO.setDsrcOccrCd(sourceIO.getDsrcOccrCd()); /** 예가수_발생_코드 */
             	targetIO.setDsrcOccrNm(sourceIO.getDsrcOccrNm()); /** 예가수_발생_명 */
             	targetIO.setDsrcAdjCd(sourceIO.getDsrcAdjCd()); /** 예가수_정산_코드 */
             	targetIO.setDsrcAdjNm(sourceIO.getDsrcAdjNm()); /** 예가수_정산_명 */
             	targetIO.setDsrcNo(sourceIO.getDsrcNo()); /** 예가수_번호 */
             	targetIO.setRfndRsnCd(sourceIO.getRfndRsnCd()); /** 환불_사유_코드 */
             	targetIO.setRfndRsnNm(sourceIO.getRfndRsnNm()); /** 환불_사유_명 */
             	targetIO.setBankCd(sourceIO.getBankCd()); /** 은행_코드 */
             	targetIO.setBankNm(sourceIO.getBankNm()); /** 환불_은행_명 */
             	targetIO.setAcntNo(sourceIO.getAcntNo()); /** 계좌번호_환불_계좌 */
             	targetIO.setExmpPamt(sourceIO.getExmpPamt()); /** 면제_원금 */
             	targetIO.setExmpInt(sourceIO.getExmpInt()); /** 면제_이자 */
             	targetIO.setExmpDfee(sourceIO.getExmpDfee()); /** 면제_연체료 */
             	targetIO.setExmpLeglActnCost(sourceIO.getExmpLeglActnCost()); /** 면제_법적_조치_비용_면제_가지급금 */
             	targetIO.setExmpMidRmbrFee(sourceIO.getExmpMidRmbrFee()); /** 면제_중도_상환_수수료 */
             	targetIO.setCnclFg(sourceIO.getCnclFg()); /** 취소 */
             	targetIO.setRfndFg(sourceIO.getRfndFg()); /** 환불 */
             	targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); /** 최초_등록_사원번호 */
             	targetIO.setFrstRegEmpNm(sourceIO.getFrstRegEmpNm()); /** 최초_등록_사원_명 */
             	targetIO.setFrstRegDtTm(sourceIO.getFrstRegDtTm()); /** 최초_등록_일자_시각 */
             	targetIO.setRcptTrtFee(sourceIO.getRcptTrtFee()); /** 수납취급수수료 */
             	targetIO.setExmpTrtFee(sourceIO.getExmpTrtFee()); /** 면제취급수수료 */
             	targetIO.setStmpFee(sourceIO.getStmpFee()); /** 인지세 */

             	/** 수납내역상세조회 List 객체에 추가하도록 수행 */
             	resultRcptDescSd01List.add(targetIO);
            }

            /** 수납내역상세조회 화면 출력 결과값 대입 */
            resultVo.setListRRCRCM03DSRCPTDESCSD01VO(resultRcptDescSd01List);

        } catch (Exception e) {
        	LOGGER.error("[결제정보, 수납정보, 예가수정보 조회 오류] : 결제정보, 수납정보, 예가수정보 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd("E002");
            resultVo.setRsltCntn("결제정보, 수납정보, 예가수정보 조회 오류");
        	LOGGER.info("##### RRCRCM03ServiceImpl DSRCPTDESCSD01 Exception End #####");
        	return resultVo;
        }

        try {
    		LOGGER.info("##### RRCRCM03ServiceImpl DSRCPTDESCSD02 Start #####");
        	// DSRCPTDESCSD02
            /** 수납내역상세조회 조회 쿼리 Mapper 호출 수행 */
            List<RcptDescSpecReadDSRCPTDESCSD02DTO> resultRcptDescSd02DTO = rcptDescSpecReadMapper.searchRcptDescList(i01Dto);

            /** 수납내역상세조회 화면 출력을 위한 결과값 List VO 객체 생성 */
            List<RRCRCM03DSRCPTDESCSD02VO> resultRcptDescSd02List = new ArrayList<RRCRCM03DSRCPTDESCSD02VO>();

            for(RcptDescSpecReadDSRCPTDESCSD02DTO sourceIO : resultRcptDescSd02DTO) {
            	/** 수납내역상세조회 VO에 조회된 Mapper DTO 값을 대입 */
    			RRCRCM03DSRCPTDESCSD02VO targetIO = new RRCRCM03DSRCPTDESCSD02VO();
    			targetIO.setTims(sourceIO.getTims()); /** 회차 */
    			targetIO.setDueDt(sourceIO.getDueDt()); /** 납입일자 */
    			targetIO.setTimsBfPamtRamt(sourceIO.getTimsBfPamtRamt()); /** 회차전원금잔액 */
    			targetIO.setTimsAfPamtRamt(sourceIO.getTimsAfPamtRamt()); /** 회차후원금잔액 */
    			targetIO.setMmPiamt(sourceIO.getMmPiamt()); /** 원리금 */
    			targetIO.setMmPamt(sourceIO.getMmPamt()); /** 원금 */
    			targetIO.setMmInt(sourceIO.getMmInt()); /** 이자 */
    			targetIO.setUnrcvPiamt(sourceIO.getUnrcvPiamt()); /** 미수원리금 */
    			targetIO.setUnrcvPamt(sourceIO.getUnrcvPamt()); /** 미수원금 */
    			targetIO.setUnrcvInt(sourceIO.getUnrcvInt()); /** 미수이자 */
    			targetIO.setSetlNo(sourceIO.getSetlNo()); /** 결제번호 */
    			targetIO.setSetlDivNm(sourceIO.getSetlDivNm()); /** 결제구분코드 */
    			targetIO.setSetlDt(sourceIO.getSetlDt()); /** 결제일자 */
    			targetIO.setRcptTot(sourceIO.getRcptTot()); /** 수납합계 */
    			targetIO.setRcptRamt(sourceIO.getRcptRamt()); /** 수납원금잔액 */
    			targetIO.setRcptPamt(sourceIO.getRcptPamt()); /** 수납원금 */
    			targetIO.setRcptInt(sourceIO.getRcptInt()); /** 수납이자 */
    			targetIO.setRcptDfee(sourceIO.getRcptDfee()); /** 수납연체료 */
    			targetIO.setMidRmbrInt(sourceIO.getMidRmbrInt()); /** 중도상환이자 */
    			targetIO.setMidRmbrFee(sourceIO.getMidRmbrFee()); /** 중도상환수수료 */
    			targetIO.setTrtFeeDisc(sourceIO.getTrtFeeDisc()); /** 취급수수료할인 */
    			targetIO.setMmTrtFee(sourceIO.getMmTrtFee()); /** 월취급수수료 */
    			targetIO.setUnrcvTrtFee(sourceIO.getUnrcvTrtFee()); /** 미수취급수수료 */
    			targetIO.setRcptTrtFee(sourceIO.getRcptTrtFee()); /** 수납취급수수료 */

    			/** 수납내역상세조회 List 객체에 추가하도록 수행 */
    			resultRcptDescSd02List.add(targetIO);
            }

            /** 수납내역상세조회 화면 출력 결과값 대입 */
            resultVo.setListRRCRCM03DSRCPTDESCSD02VO(resultRcptDescSd02List);

        } catch (Exception e) {
        	LOGGER.error("[계획대비수납정보 조회 오류] : 계획대비수납정보 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd("E003");
            resultVo.setRsltCntn("계획대비수납정보 조회 오류");
        	LOGGER.info("##### RRCRCM03ServiceImpl DSRCPTDESCSD02 Exception End #####");
        	return resultVo;
        }

		LOGGER.info("##### RRCRCM03ServiceImpl getRRCRCM03S01 Normal End #####");

		return resultVo;
	}

}
