package hanalife.r.rc.rc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.co.la.service.LoanInfoProcMngService;
import hanalife.r.rc.rc.service.RRCRCM03Service;
import hanalife.r.rc.rc.vo.RRCRCM03DSRMBRSMVO;
import hanalife.r.rc.rc.vo.RRCRCM03S01InVO;
import hanalife.r.rc.rc.vo.RRCRCM03S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRCM03Controller.java Class
 * 클래스설명   : 수납내역상세조회 (RRCRCM03) Controller
 * 작성일자     : 2023. 3. 8.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 8.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/rc/rc")
@Controller
public class RRCRCM03Controller {

	@Resource(name = "RRCRCM03Service")
	private RRCRCM03Service RRCRCM03;

	@Resource(name = "LoanInfoProcMngService")
	private LoanInfoProcMngService LoanInfoProcMngService;

	private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCM03Controller.class);

	/**
	 * <p>메소드명      : 수납내역상세조회 /RRCRCM03S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 수납내역상세조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RRCRCM03S01.do")
	public String RRCRCM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RRCRCM03Controller RRCRCM03S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_RMBR_SM", request, response, model);

			/** 수납내역상세조회 업무 서비스 호출 입력값 대입 */
			RRCRCM03DSRMBRSMVO targetVo = new RRCRCM03DSRMBRSMVO();
			targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
			targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RRCRCM03S01InVO InVO = new RRCRCM03S01InVO();
            InVO.setRRCRCM03DSRMBRSMVO(targetVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

			/** 수납내역상세조회 업무 서비스 호출 수행 */
			RRCRCM03S01OutVO resultRRCRCM03S01 = RRCRCM03.getRRCRCM03S01(InVO);

			if( "0000".equals(resultRRCRCM03S01.getRsltCd()) ) {
				/** 수납내역상세조회 DataSet 결과값 설정 */
				XFrame5Util.setOutputData("DS_LOANINFO", resultRRCRCM03S01.getListRRCRCM03DSLOANINFOVO(), model); /** 대출정보조회 */
				XFrame5Util.setOutputData("DS_RCPT_DESC_SD01", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD01VO(), model); /** 대출정보조회 */
				XFrame5Util.setOutputData("DS_RCPT_DESC_SD02", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD02VO(), model); /** 대출정보조회 */

				LOGGER.info("##### RRCRCM03Controller RRCRCM03S01 Normal End #####");
			} else {
				// 오류 메시지 정보 설정
				model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, resultRRCRCM03S01.getRsltCd());
				model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, resultRRCRCM03S01.getRsltCntn());

				LOGGER.info("##### RRCRCM03Controller RRCRCM03S01 getRsltCd ERR End #####");
			}

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RRCRCM03Controller RRCRCM03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}




}
