package hanalife.r.rc.rc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.rc.rc.service.RRCRCP02Service;
import hanalife.r.rc.rc.vo.RRCRCP02DSRMBRPLANSMVO;
import hanalife.r.rc.rc.vo.RRCRCP02S01InVO;
import hanalife.r.rc.rc.vo.RRCRCP02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 클래스명    : RRCRCP02Controller
 * 클래스설명  : 상환스케줄조회 (RRCRCP02) Controller
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023.02.24
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.02.24][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 상환스케줄조회 : /RRCRCP02S01.do
 * </pre>
 */
@RequestMapping("/r/rc/rc")
@Controller
public class RRCRCP02Controller {

    @Resource(name = "RRCRCP02Service")
    private RRCRCP02Service RRCRCP02;

    private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCP02Controller.class);

    /**
	 * <p>메소드명      : 상환스케줄 /RRCRCP02S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 상환스케줄 목록을 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
    @RequestMapping("/RRCRCP02S01.do")
    public String RRCRCP02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

    	LOGGER.info("##### RRCRCP02Controller RRCRCP02S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_RMBRPLAN_SM", request, response, model);

            /** 상환스케줄조회 업무 서비스 호출 입력값 대입 */
            RRCRCP02DSRMBRPLANSMVO targetVo = new RRCRCP02DSRMBRPLANSMVO();
            targetVo.setLoanNo((String)sourceMap.get("loanNo")); /*  */
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /*  */
            targetVo.setMngNo((String)sourceMap.get("mngNo")); /*  */
            RRCRCP02S01InVO inVo = new RRCRCP02S01InVO();
            inVo.setRRCRCP02DSRMBRPLANSM(targetVo);

            /** 상환스케줄조회 업무 서비스 호출 수행 */
            RRCRCP02S01OutVO resultRRCRCP02S01 = RRCRCP02.getRRCRCP02S01(inVo);

            XFrame5Util.setOutputData("DS_RMBRPLAN_SD01", resultRRCRCP02S01.getListRATMNM01DSRMBRPLANSD01VO(), model); /** 상환스케줄정보 조회 */
            XFrame5Util.setOutputData("DS_RMBRPLAN_SD02", resultRRCRCP02S01.getListRATMNM01DSRMBRPLANSD02VO(), model); /** 상환스케줄정보 조회 */

            LOGGER.info("##### RRCRCP02Controller RRCRCP02S01 Normal End #####");
        }
        catch (Exception e) {
        	LOGGER.error("Error >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

        	LOGGER.info("##### RRCRCP02Controller RRCRCP02S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
