package hanalife.r.rc.rd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.rc.rd.mapper.RcptMapper;
import hanalife.r.rc.rd.mapper.dto.RcptDescDSSDDO01DTO;
import hanalife.r.rc.rd.mapper.dto.RcptDescDSSDDO02DTO;
import hanalife.r.rc.rd.mapper.dto.SearchRcptDescListDTO;
import hanalife.r.rc.rd.service.RRCRCM02Service;
import hanalife.r.rc.rd.vo.RRCRCM02DSSDDO01VO;
import hanalife.r.rc.rd.vo.RRCRCM02DSSDDO02VO;
import hanalife.r.rc.rd.vo.RRCRCM02S01InVO;
import hanalife.r.rc.rd.vo.RRCRCM02S01OutVO;

/**
 * <pre>
 * 클래스명    : RRCRCM02ServiceImpl.java Class
 * 클래스설명  : 수납상세 (RRCRCM02) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 07
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 07.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RRCRCM02Service")
public class RRCRCM02ServiceImpl implements RRCRCM02Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCM02ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private RcptMapper rcptMapper;

    /**
     * <p>메소드명      : RRCRCM02S01 : 수납상세목록조회</p>
     * <p>작성일자      : 2023. 2. 27.
     * <p>작성자(author): 70317 / younghwe.kim
     * <p>설명          : 수납상세목록을 조회 한다.</p>
     * <p>메소드인수    : RRCRCM02S01InVo </p>
     * <p>메소드리턴값  : RRCRCM02S01OutVo</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("unchecked")
    @Override
    public RRCRCM02S01OutVO getRRCRCM02S01(RRCRCM02S01InVO inVo) throws Exception {

        /** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        RRCRCM02S01OutVO resultVo = new RRCRCM02S01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 검색조건 체크
        String strLoanNo = inVo.getRRCRCM02DSSMDOVO().getLoanNo().toString();
        String strLoanSeq = inVo.getRRCRCM02DSSMDOVO().getLoanSeq().toString();
        String strAcctDtFr = inVo.getRRCRCM02DSSMDOVO().getAcctDtFr().toString();
        String strAcctDtTo = inVo.getRRCRCM02DSSMDOVO().getAcctDtTo().toString();

        // 대출번호 체크
        if( StringUtils.isEmpty(strLoanNo) || StringUtils.isEmpty(strLoanSeq) ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getErrorCn());
        }

        // 입력일자 체크
        if( !StringUtils.isEmpty(strAcctDtFr) && !StringUtils.isEmpty(strAcctDtTo) ) {
            if( !DateUtil.isBeforeDate(strAcctDtFr, strAcctDtTo) ) {
                resultVo.setRsltCd(msgEnum.DATE_CHECK_ERROR.getErrorCd());
                resultVo.setRsltCntn(msgEnum.DATE_CHECK_ERROR.getErrorCn());
            }
        }

        // 대출정보 조회
        StLoanBaseDTO inDto = new StLoanBaseDTO();
        inDto.setLoanNo(inVo.getRRCRCM02DSSMDOVO().getLoanNo());
        inDto.setLoanSeq(inVo.getRRCRCM02DSSMDOVO().getLoanSeq());
        inDto.setLoanLastFg("1");

        List<RcptDescDSSDDO01DTO> loanInfoDTO = rcptMapper.selectLoanInfo(inDto);

        List<RRCRCM02DSSDDO01VO> resultList01 = new ArrayList<RRCRCM02DSSDDO01VO>();
        for( RcptDescDSSDDO01DTO outDto : loanInfoDTO ) {
            RRCRCM02DSSDDO01VO targetIO = new RRCRCM02DSSDDO01VO();

            targetIO.setLoanNo(outDto.getLoanNo());
            targetIO.setLoanSeq(outDto.getLoanSeq());
            targetIO.setContManNo(outDto.getContManNo());
            targetIO.setCustNm(outDto.getCustNm());
            targetIO.setRlDueManNo(outDto.getRlDueManNo());
            targetIO.setRlDueManNm(outDto.getRlDueManNm());
            targetIO.setPrdtLrgeClasCd(outDto.getPrdtLrgeClasCd());
            targetIO.setPrdtLrgeClasNm(outDto.getPrdtLrgeClasNm());
            targetIO.setPrdtMidClasCd(outDto.getPrdtMidClasCd());
            targetIO.setPrdtMidClasNm(outDto.getPrdtMidClasNm());
            targetIO.setPrdtSmClasCd(outDto.getPrdtSmClasCd());
            targetIO.setPrdtSmClasNm(outDto.getPrdtSmClasNm());
            targetIO.setMngDeptCd(outDto.getMngDeptCd());
            targetIO.setMngDeptNm(outDto.getMngDeptNm());
            targetIO.setLoanPiamt(outDto.getLoanPiamt());
            targetIO.setRmbrPiamt(outDto.getRmbrPiamt());
            targetIO.setRmbrFrmlNm(outDto.getRmbrFrmlNm());
            targetIO.setLoanStatCd(outDto.getLoanStatCd());
            targetIO.setLoanStatNm(outDto.getLoanStatNm());
            targetIO.setLoanPamt(outDto.getLoanPamt());
            targetIO.setRmbrPamt(outDto.getRmbrPamt());
            targetIO.setMrtgKindNm(outDto.getMrtgKindNm());
            targetIO.setLoanIntRt(outDto.getLoanIntRt());
            targetIO.setLoanInt(outDto.getLoanInt());
            targetIO.setRmbrInt(outDto.getRmbrInt());
            targetIO.setRmbrDfee(outDto.getRmbrDfee());
            targetIO.setDfeeRt(outDto.getDfeeRt());
            targetIO.setDueMethCd(outDto.getDueMethCd());
            targetIO.setDueMethNm(outDto.getDueMethNm());
            targetIO.setAcctUnitCd(outDto.getAcctUnitCd());
            targetIO.setAcctUnitNm(outDto.getAcctUnitNm());

            /** 대출기본조회 List 객체에 추가하도록 수행 */
            resultList01.add(targetIO);
        }

        // 수납내역 조회
        SearchRcptDescListDTO inSrchDto = new SearchRcptDescListDTO();
        inSrchDto.setLoanNo(inVo.getRRCRCM02DSSMDOVO().getLoanNo());
        inSrchDto.setLoanSeq(inVo.getRRCRCM02DSSMDOVO().getLoanSeq());
        inSrchDto.setAcctDtFr(inVo.getRRCRCM02DSSMDOVO().getAcctDtFr());
        inSrchDto.setAcctDtTo(inVo.getRRCRCM02DSSMDOVO().getAcctDtTo());
        inSrchDto.setSetlDiv(inVo.getRRCRCM02DSSMDOVO().getSetlDiv());

        List<RcptDescDSSDDO02DTO> rcptDescDTO = rcptMapper.selectRcptList(inSrchDto);

        List<RRCRCM02DSSDDO02VO> resultList02 = new ArrayList<RRCRCM02DSSDDO02VO>();
        for( RcptDescDSSDDO02DTO outDTO :  rcptDescDTO ) {
            RRCRCM02DSSDDO02VO targetIO = new RRCRCM02DSSDDO02VO();

            targetIO.setSetlNo(outDTO.getSetlNo());                        /** 결제번호 */
            targetIO.setAcctDt(outDTO.getAcctDt());                        /** 회계일자 */
            targetIO.setSetlDt(outDTO.getSetlDt());                        /** 결제일자 */
            targetIO.setIsrtDt(outDTO.getIsrtDt());                        /** 입력이자 */
            targetIO.setIsrtDeptCd(outDTO.getIsrtDeptCd());                /** 입력부서코드 */
            targetIO.setIsrtDeptNm(outDTO.getIsrtDeptNm());                /** 입력부서명 */
            targetIO.setRcptTpCd(outDTO.getRcptTpCd());                    /** 수납유형코드 */
            targetIO.setRcptTpNm(outDTO.getRcptTpNm());                    /** 수납유형명 */
            targetIO.setSetlDivCd(outDTO.getSetlDivCd());                  /** 결제구분코드 */
            targetIO.setSetlDivNm(outDTO.getSetlDivNm());                  /** 결제구분명 */
            targetIO.setSetlAmt(outDTO.getSetlAmt());                      /** 결제금액 */
            targetIO.setRcptAmt(outDTO.getRcptAmt());                      /** 수납금액 */
            targetIO.setCashAmt(outDTO.getCashAmt());                      /** 현금 */
            targetIO.setChkAmt(outDTO.getChkAmt());                        /** 수표금액 */
            targetIO.setExmpAmt(outDTO.getExmpAmt());                      /** 면제금애 */
            targetIO.setDsrcOccrAmt(outDTO.getDsrcOccrAmt());              /** 예가수발생금액 */
            targetIO.setDsrcAdjAmt(outDTO.getDsrcAdjAmt());                /** 예가수정산금액 */
            targetIO.setMidRmbrPamt(outDTO.getMidRmbrPamt());              /** 중도상환원금 */
            targetIO.setRcptPamt(outDTO.getRcptPamt());                    /** 수납원금 */
            targetIO.setRcptInt(outDTO.getRcptInt());                      /** 수납이자 */
            targetIO.setRcptDfee(outDTO.getRcptDfee());                    /** 수납연체료 */
            targetIO.setLeglActnCost(outDTO.getLeglActnCost());            /** 법조치비용 */
            targetIO.setMidRmbrFee(outDTO.getMidRmbrFee());                /** 중도상환수수료 */
            targetIO.setExmpPamt(outDTO.getExmpPamt());                    /** 면제원금 */
            targetIO.setExmpInt(outDTO.getExmpInt());                      /** 면제이자 */
            targetIO.setExmpDfee(outDTO.getExmpDfee());                    /** 면제수수료 */
            targetIO.setExmpLeglActnCost(outDTO.getExmpLeglActnCost());    /** 면제법조치비용 */
            targetIO.setExmpMidRmbrFee(outDTO.getExmpMidRmbrFee());        /** 면제중도상환수수료 */
            targetIO.setPdueDiscDfee(outDTO.getPdueDiscDfee());            /** 선납할인연체료 */
            targetIO.setTrtFeeDisc(outDTO.getTrtFeeDisc());                /** 취급수수료할인 */
            targetIO.setCnclFg(outDTO.getCnclFg());                        /** 취소여부 */
            targetIO.setRfndFg(outDTO.getRfndFg());                        /** 환불여부 */
            targetIO.setFrstRegEmpNo(outDTO.getFrstRegEmpNo());            /** 최초등록자사원번호 */
            targetIO.setFrstRegEmpNm(outDTO.getFrstRegEmpNm());            /** 최초등록자사원명 */
            targetIO.setFrstRegDt(outDTO.getFrstRegDt());                  /** 최초등록일자 */
            targetIO.setFrstRegTm(outDTO.getFrstRegTm());                  /** 최초등록시각 */
            targetIO.setStmpFee(outDTO.getStmpFee());                      /** 인지세 */

            /** 수납내역조회 List 객체에 추가하도록 수행 */
            resultList02.add(targetIO);
        }

        resultVo.setRRCRCM02DSSDDO01VO(resultList01);
        resultVo.setRRCRCM02DSSDDO02VO(resultList02);

        return resultVo;
    }

}