package hanalife.r.sr.sr.mapper;

import java.util.List;
import java.util.Map;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtDsrcChngHistDTO;
import hanalife.c.co.mapper.dto.RtRcptBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptDsrcBaseDTO;
import hanalife.c.co.mapper.dto.RtRcptDsrcDescDTO;
import hanalife.r.sr.sr.mapper.dto.DsrcSetlDtChngPopDSDSRCCHNGDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : DsrcSetlDtChngPopMapper.java Class
 * 클래스설명   : 예가수결제일자변경(Mapper)를(을) 위한 Interface Mapper
 * 작성일자     : 2023. 5. 16.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 16.][70366 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("DsrcSetlDtChngPopMapper")
public interface DsrcSetlDtChngPopMapper {

    /**
     * <pre>
     * 메소드명      : searchDsrcBases
     * 작성일자      : 2023. 5. 16.
     * 작성자(author): 70366 KangMinhyeok
     * 설명          : 예가수 결제일자 변경 전 변경할 예가수가 존재하는 지 확인하기 위하여 수납예가수기본을 조회한다.
     * 메소드인수1   : DsrcSetlDtChngPopDSDSRCCHNGDTO
     * 메소드리턴값  :  List<\RtRcptDsrcBaseDTO>\
     * 예외처리      : Exception
     * </pre>
     */
    List<RtRcptDsrcBaseDTO> searchDsrcBases(DsrcSetlDtChngPopDSDSRCCHNGDTO inDto);
    /**
     * <pre>
     * 메소드명      : update
     * 작성일자      : 2023. 5. 16.
     * 작성자(author): 70366 KangMinhyeok
     * 설명          : 예가수내역 결제일자를 업데이트 한다.
     * 메소드인수1   : Map<\String, RtRcptDsrcDescDTO>\
     * 메소드리턴값  :  Integer
     * 예외처리      : Exception
     * </pre>
     */
    Integer update(Map<String, RtRcptDsrcDescDTO> parameterMap);
    /**
     * <pre>
     * 메소드명      : update
     * 작성일자      : 2023. 5. 16.
     * 작성자(author): 70366 KangMinhyeok
     * 설명          : 수납기본을 수정한다..
     * 메소드인수1   : RtRcptBaseDTO
     * 메소드리턴값  :  Integer
     * 예외처리      : Exception
     * </pre>
     */
    Integer updateRcptBc(RtRcptBaseDTO rcptBase);
    /**
     * <pre>
     * 메소드명      : update
     * 작성일자      : 2023. 5. 16.
     * 작성자(author): 70366 KangMinhyeok
     * 설명          : 변경 이력을 등록한다.
     * 메소드인수1   : RtDsrcChngHistDTO
     * 메소드리턴값  :  Integer
     * 예외처리      : Exception
     * </pre>
     */
    Integer createDsrcChngHist(RtDsrcChngHistDTO chngHist);
}
