package hanalife.r.sr.sr.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.StringUtil;
import hanalife.r.sr.sr.mapper.DsrcMapper;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSD01DTO;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSD02DTO;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSMDTO;
import hanalife.r.sr.sr.service.RSRSRM04Service;
import hanalife.r.sr.sr.vo.RSRSRM04DSSD01VO;
import hanalife.r.sr.sr.vo.RSRSRM04DSSD02VO;
import hanalife.r.sr.sr.vo.RSRSRM04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRM04ServiceImpl.java Class
 * 클래스설명   : 예/가수환불현황조회 (RSRSRM04) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRSRSRM04S01 : 예/가수환불현황조회
 * </pre>
 */
@Service("RSRSRM04Service")
public class RSRSRM04ServiceImpl implements RSRSRM04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRM04ServiceImpl.class);

	@Autowired
	private DsrcMapper dsrcMapper;

	/**
	 * <p>메소드명      : getRSRSRM04S01 : 예/가수환불현황조회</p>
	 * <p>작성일자      : 2023. 3. 7.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 예/가수환불현황조회 한다.</p>
	 * <p>메소드인수    : RSRSRM04S01InVo </p>
	 * <p>메소드리턴값  : RSRSRM04S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RSRSRM04S01OutVO getRSRSRM04S01(Map<String,Object> inVo) throws Exception {

		RSRSRM04S01OutVO resultVo = new RSRSRM04S01OutVO();

		DsrcDSSMDTO inDto = new DsrcDSSMDTO();

		String prdtMidClasCd = (String) inVo.get("prdtCd");
		String largeCd = null;
		String mdCd = null;
		if (prdtMidClasCd != null && prdtMidClasCd.length() > 2) {
			largeCd = prdtMidClasCd.substring(0, 1);
			mdCd = prdtMidClasCd.substring(1, 3);
		}

		inDto.setRfndDtFr((String) inVo.get("rfndDtFr")); 		                                /** 환불일자시작 */
		inDto.setRfndDtTo((String) inVo.get("rfndDtTo")); 		                                /** 환불일자종료 */
		inDto.setMngDeptCd((String) inVo.get("mngDeptCd"));		                                /** 관리부서코드 */
		inDto.setDsrcOccrCd((String) inVo.get("dsrcOccrCd"));	                                /** 예가수발생코드 */
		inDto.setRfndStat((String) inVo.get("rfndStat"));		                                /** 환불상태 */
		inDto.setPrdtLrgeClasCd(largeCd);	  					                                /** 상품대분류코드 */
		inDto.setPrdtMidClasCd(mdCd);	 	 			 		                                /** 상품중분류코드 */
		inDto.setRfndRsnCd((String) inVo.get("rfndRsnCd"));  							        /** 환불사유 */
		inDto.setSumDivDt(StringUtil.nullToZero((String) inVo.get("sumDivDt")));   		        /** 합계구분_환불일자 */
		inDto.setSumDivIsrtDept(StringUtil.nullToZero((String) inVo.get("sumDivIsrtDept"))); 	/** 합계구분_입력사유 */
		inDto.setSumDivDept(StringUtil.nullToZero((String) inVo.get("sumDivDept"))); 			/** 합계구분_관리부서 */
		inDto.setSumDivDsrc(StringUtil.nullToZero((String) inVo.get("sumDivDsrc"))); 			/** 합계구분_예가수발생 */
		inDto.setSumDivPrdt(StringUtil.nullToZero((String) inVo.get("sumDivPrdt"))); 			/** 합계구분_상품명 */
		inDto.setSumDivRfnd(StringUtil.nullToZero((String) inVo.get("sumDivRfnd"))); 			/** 합계구분_환불사유 */

		List<DsrcDSSD01DTO> resultDTO = dsrcMapper.searchRfndReptForSpclBnd(inDto);	/** 환불현황리스트*/

		List<RSRSRM04DSSD01VO> resultList = new ArrayList<RSRSRM04DSSD01VO>();

		for (DsrcDSSD01DTO sourceIO : resultDTO) {
			RSRSRM04DSSD01VO targetIO = new RSRSRM04DSSD01VO();
			targetIO.setRfndDt(sourceIO.getRfndDt()); /** 환불일자 */
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서명 */
			targetIO.setPrdtCd(sourceIO.getPrdtCd()); /** 상품코드 */
			targetIO.setPrdtNm(sourceIO.getPrdtNm()); /** 상품명 */
			targetIO.setRfndRsnCd(sourceIO.getRfndRsnCd()); /** 환불사유코드 */
			targetIO.setRfndRsnNm(sourceIO.getRfndRsnNm()); /** 환불사유 */
			targetIO.setDsrcOccrCd(sourceIO.getDsrcOccrCd()); /** 예가수발생코드 */
			targetIO.setDsrcOccrNm(sourceIO.getDsrcOccrNm()); /** 예가수발생 */
			targetIO.setRfndReqCnt(sourceIO.getRfndReqCnt()); /** 환불의뢰건수 */
			targetIO.setRfndReqAmt(sourceIO.getRfndReqAmt()); /** 환불의뢰금액 */
			targetIO.setRfndScsCnt(sourceIO.getRfndScsCnt()); /** 환불성공건수 */
			targetIO.setRfndScsAmt(sourceIO.getRfndScsAmt()); /** 환불성공금액 */
			targetIO.setRfndErrCnt(sourceIO.getRfndErrCnt()); /** 환불에러건수 */
			targetIO.setRfndErrAmt(sourceIO.getRfndErrAmt()); /** 환불에러금액 */
			targetIO.setRfndDtFrSm(sourceIO.getRfndDtFrSm()); /** 환불일자시작 */
			targetIO.setRfndDtToSm(sourceIO.getRfndDtToSm()); /** 환불일자종료 */
			targetIO.setMngDeptCdSm(sourceIO.getMngDeptCdSm()); /** 관리부서코드 */
			targetIO.setRfndRsnCdSm(sourceIO.getRfndRsnCdSm()); /** 환불사유코드 */
			targetIO.setDsrcCdSm(sourceIO.getDsrcCdSm()); /** 예가수발생코드 */
			targetIO.setPrdtCdSm(sourceIO.getPrdtCdSm()); /** 상품코드 */
			targetIO.setRfndStat(sourceIO.getRfndStat()); /** 환불상태 */
			targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd()); /**  */
			targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm()); /**  */
			targetIO.setIsrtDeptCd(sourceIO.getIsrtDeptCd()); /** 입력부서코드 */
			targetIO.setIsrtDeptNm(sourceIO.getIsrtDeptNm()); /** 입력부서명 */
			targetIO.setMngPlcDivCd(sourceIO.getMngPlcDivCd()); /**  */
			targetIO.setMngPlcDivNm(sourceIO.getMngPlcDivNm()); /**  */

			resultList.add(targetIO);
		}

		resultVo.setRSRSRM04DSSD01VO(resultList);	/** 환불현황리스트*/

		return resultVo;
	}

	@Override
	public RSRSRM04S01OutVO getRSRSRM04S02(Map<String, Object> inVo) throws Exception {
		RSRSRM04S01OutVO resultVo = new RSRSRM04S01OutVO();

		DsrcDSSMDTO inDto = new DsrcDSSMDTO();

		String prdtMidClasCd = (String) inVo.get("prdtCd");
		String largeCd = null;
		String mdCd = null;
		if (prdtMidClasCd != null && prdtMidClasCd.length() > 2) {
			largeCd = prdtMidClasCd.substring(0, 1);
			mdCd = prdtMidClasCd.substring(1, 3);
		}

		inDto.setRfndDtFr((String) inVo.get("rfndDtFr")); 		                                /** 환불일자시작 */
		inDto.setRfndDtTo((String) inVo.get("rfndDtTo")); 		                                /** 환불일자종료 */
		inDto.setMngDeptCd((String) inVo.get("mngDeptCd"));		                                /** 관리부서코드 */
		inDto.setDsrcOccrCd((String) inVo.get("dsrcOccrCd"));	                                /** 예가수발생코드 */
		inDto.setRfndStat((String) inVo.get("rfndStat"));		                                /** 환불상태 */
		inDto.setPrdtLrgeClasCd(largeCd);	  					                                /** 상품대분류코드 */
		inDto.setPrdtMidClasCd(mdCd);	 	 			 		                                /** 상품중분류코드 */
		inDto.setRfndRsnCd((String) inVo.get("rfndRsnCd"));  							        /** 환불사유 */

		List<DsrcDSSD02DTO> resultDTO = dsrcMapper.searchRfndDescForSpclBnd(inDto);	/** 환불현황리스트*/

		List<RSRSRM04DSSD02VO> resultList = new ArrayList<RSRSRM04DSSD02VO>();

		for (DsrcDSSD02DTO sourceIO : resultDTO) {

			RSRSRM04DSSD02VO targetIO = new RSRSRM04DSSD02VO();

			targetIO.setRfndDt(sourceIO.getRfndDt()); 	                /** 환불일자 */
			targetIO.setDsrcNo(sourceIO.getDsrcNo()); 	                /** 예가수번호 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); 	                /** 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq());                 /** 대출순번 */
			targetIO.setCustNm(sourceIO.getCustNm()); 	                /** 대출순번 */
			targetIO.setRfndAmt(sourceIO.getRfndAmt());                 /** 환불금액 */
			targetIO.setRfndRsn(sourceIO.getRfndRsn());                 /** 환불사유 */
			targetIO.setDsrcOccr(sourceIO.getDsrcOccr()); 				/** 예가수발생 */
			targetIO.setRfndBank(sourceIO.getRfndBank()); 				/** 환불은행 */
			targetIO.setRfndAcnt(sourceIO.getRfndAcnt()); 				/** 환불계좌 */
			targetIO.setDepoOwnNm(sourceIO.getDepoOwnNm()); 			/** 예금주명 */
			targetIO.setDepoOwnRel(sourceIO.getDepoOwnRel()); 			/** 예금주관계 */
			targetIO.setIsrtDept(sourceIO.getIsrtDept());				/** 입력부서 */
			targetIO.setIsrtManEmpNo(sourceIO.getIsrtManEmpNo()); 		/** 입력자사번 */
			targetIO.setIsrtManNm(sourceIO.getIsrtManNm()); 			/** 입력자명 */
			targetIO.setRfndStat(sourceIO.getRfndStat()); 				/** 환불상태 */
			targetIO.setMngDept(sourceIO.getMngDept()); 				/** 관리부서 */
			targetIO.setSysPath(sourceIO.getSysPath()); 				/** 시스템경로 */
			targetIO.setMngPlcDivCd(sourceIO.getMngPlcDivCd()); 		/** 관리처코드 */
			targetIO.setMngPlcDivNm(sourceIO.getMngPlcDivNm()); 		/** 관리처명 */
			targetIO.setAcntNoFormatted(sourceIO.getAcntNoFormatted()); /** 계좌노포맷 */

			resultList.add(targetIO);
		}

		resultVo.setRSRSRM04DSSD02VO(resultList);	/** 환불현황리스트*/

		return resultVo;
	}

}
