package hanalife.r.sr.sr.service.impl;

import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.StringUtil;
import hanalife.framework.comm.util.SessionUtil;
import hanalife.framework.comm.vo.UserSessionVO;
import hanalife.r.sr.sr.service.RSRSRP03Service;
import hanalife.r.sr.zz.service.DsrcService;
import hanalife.r.sr.zz.vo.DsrcVO;

/**
 * <pre>
 * 프로젝트명  	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명   	: RSRSRP03ServiceImpl.java Class
 * 클래스설명  	: 예가수강제정산팝업 (RSRSRP03) Service Implements
 * 작성일자   	: 2023. 5. 30.
 * 작성자명   	: 70326 / YHS / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 30.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRSRSRP03I01 : 예가수강제정산 처리
 * </pre>
 */
@Service("RSRSRP03Service")
public class RSRSRP03ServiceImpl implements RSRSRP03Service {

	private static final Logger log = LoggerFactory.getLogger(RSRSRP03ServiceImpl.class);

	@Autowired
	private DsrcService dsrcService;

	/**
	 * <p>메소드명      : getRSRSRP02S01 </p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 예가수변경이력팝업 조회한다.</p>
	 * <p>메소드인수    : RSRSRP02S01InVo </p>
	 * <p>메소드리턴값  : RSRSRP02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public void ivltAdjDsrc(Map<String, Object> inMap) throws Exception {

		log.info("■ dsrcAdjCd = " + (String) inMap.get("dsrcAdjCd"));

		UserSessionVO sessionVO = (UserSessionVO) SessionUtil.getAttribute("UserSessionVO");
		String empNo = sessionVO.getUserNo();
		String deptCd = sessionVO.getOnworkDeptCd();

		log.info("■ empNo = " + empNo);
		log.info("■ deptCd = " + deptCd);

		DsrcVO adjVO = new DsrcVO();
			adjVO.dsrcNo   = (String) inMap.get("dsrcNo");
			adjVO.setlDt   = (String) inMap.get("setlDt");
			adjVO.acctDt   = (String) inMap.get("acctDt");
			adjVO.adjCd    = (String) inMap.get("dsrcAdjCd");
			adjVO.adjAmt   = StringUtil.parseLong(inMap.get("dsrcAdjAmt")) ;
			adjVO.vochExFg = "1"; //smdo.getString("vochExFg");
			adjVO.deptCd   = StringUtil.nvl(inMap.get("deptCd"), empNo);
			adjVO.empNo    = StringUtil.nvl(inMap.get("empNo") , deptCd);
			adjVO.dsrcRmk  = (String) inMap.get("rmk");
		log.info("adjVO : " + adjVO);

		dsrcService.adjDsrc(adjVO);
	}

}