package hanalife.r.sr.sr.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.sr.sr.service.RSRSRM04Service;
import hanalife.r.sr.sr.vo.RSRSRM04S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRM04Controller.java Class
 *
 * 클래스설명   : 예/가수환불현황조회 (RSRSRM04) Controller
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/sr/sr")
@Controller
public class RSRSRM04Controller {

	@Resource(name = "RSRSRM04Service")
	private RSRSRM04Service RSRSRM04;

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRM04Controller.class);

	/**
	 * <p>메소드명      	: RSRSRM04S01.do </p>
	 * <p>작성일자      	: 2023. 2. 27.
	 * <p>작성자(author)	: 70317
	 * <p>설명          	: 예/가수환불현황조회 한다.</p>
	 * <p>예외처리      	: Exception</p>
	 */
	@RequestMapping("/RSRSRM04S01.do")
	public String RSRSRM04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RSRSRM04Controller RSRSRM04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 예/가수환불현황조회내역조회 업무 서비스 호출 수행 */
			RSRSRM04S01OutVO resultRSRSRM04S01 = RSRSRM04.getRSRSRM04S01(sourceMap);

			XFrame5Util.setOutputData("DS_SD01", resultRSRSRM04S01.getRSRSRM04DSSD01VO(), model);

			LOGGER.info("##### RSRSRM04Controller RSRSRM04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RSRSRM04Controller RSRSRM04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      	: RSRSRM04S02 </p>
	 * <p>작성일자      	: 2023. 5. 31.
	 * <p>작성자(author)	: 70326
	 * <p>설명          	: 예/가수환불 내역조회 한다.</p>
	 * <p>예외처리      	: Exception</p>
	 */
	@RequestMapping("/RSRSRM04S02.do")
	public String RSRSRM04S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RSRSRM04Controller RSRSRM04S02 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM02", request, response, model);

			/** 예/가수환불현황조회내역조회 업무 서비스 호출 수행 */
			RSRSRM04S01OutVO resultRSRSRM04S02 = RSRSRM04.getRSRSRM04S02(sourceMap);

			XFrame5Util.setOutputData("DS_SD02", resultRSRSRM04S02.getRSRSRM04DSSD02VO(), model);

			LOGGER.info("##### RSRSRM04Controller RSRSRM04S02 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RSRSRM04Controller RSRSRM04S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}
