package hanalife.r.sr.sr.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.r.sr.sr.service.RSRSRP02Service;
import hanalife.r.sr.sr.vo.RSRSRP02DSSMVO;
import hanalife.r.sr.sr.vo.RSRSRP02S01InVO;
import hanalife.r.sr.sr.vo.RSRSRP02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRP02Controller.java Class
 *
 * 클래스설명   : 예가수변경이력팝업 (RSRSRP02) Controller
 * 작성일자     : 2023. 5. 9.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 9.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/sr/sr")
@Controller
public class RSRSRP02Controller {

	@Resource(name = "RSRSRP02Service")
	private RSRSRP02Service RSRSRP02;

	@Resource(name = "callSpService")
	private callSpService callSp;

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRP02Controller.class);

	/**
	 * <p>메소드명      : 예가수변경이력팝업조회 /RSRSRP02S01.do </p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323
	 * <p>설명          : 예가수변경이력팝업 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RSRSRP02S01.do")
	public String RSRSRP02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RSRSRP02Controller RSRSRP02S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 예가수변경이력팝업내역조회 업무 서비스 호출 입력값 대입 */
			RSRSRP02S01InVO targetVo = new RSRSRP02S01InVO();
			RSRSRP02DSSMVO smVo = new RSRSRP02DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setRSRSRP02DSSMVO(smVo);

			/** 예가수변경이력팝업내역조회 업무 서비스 호출 수행 */
			RSRSRP02S01OutVO resultRSRSRP02S01 = RSRSRP02.getRSRSRP02S01(targetVo);

			XFrame5Util.setOutputData("DS_UNARNG_HIST", resultRSRSRP02S01.getRSRSRP02DSUNARNGHISTVO(), model);	/** 미정리변경내역 */
			XFrame5Util.setOutputData("DS_RMRK_HIST", resultRSRSRP02S01.getRSRSRP02DSRMRKHISTVO(), model);		/** 적요변경내역 */
			XFrame5Util.setOutputData("DS_SETL_HIST", resultRSRSRP02S01.getRSRSRP02DSSETLHISTVO(), model);		/** 예가수결제일자변경이력 */

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultRSRSRP02S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultRSRSRP02S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### RSRSRP02Controller RSRSRP02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RSRSRP02Controller RSRSRP02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
