package hanalife.r.sr.zz.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.rc.service.IamtUnrcvService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;
import hanalife.r.sr.sr.mapper.DsrcMapper;
import hanalife.r.sr.sr.mapper.dto.DsrcSearchDTO;
import hanalife.r.sr.zz.service.DsrcService;
import hanalife.r.sr.zz.vo.DsrcVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : DsrcServiceImpl.java Class
 * 클래스설명   : 예/가수금 처리를(을) 위한 Service Implements
 * 작성일자     : 2023. 3. 20.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 20.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("dsrcService")
public class DsrcServiceImpl implements DsrcService {

    private static final Logger LOGGER = LoggerFactory.getLogger(DsrcServiceImpl.class);

    @Autowired
    private CommBizService commBizService;

    /** 예/가수금 Mapper 지역 객체 선언 */
    @Autowired
    private DsrcMapper dsrcMapper;

    @Autowired
    private IamtUnrcvService iamtUnrcvService;

    /**
     * <p>메소드명  : occrDsrc</p>
     * <p>설　　명  : 예가수 강제발생 (가수통합용)</p>
     * <p>메소드인수 : Connection, DsrcVO</p>
     * <p>리　턴　값 : DsrcVO</p>
     */
    @Override
	public DsrcVO occrDsrc(DsrcVO dsrcVO) throws Exception {

        LOGGER.info("■ DsrcCC.occrDsrc] 가수발생 시작");

        // Check Params - 사용 필드 [대출번호(K), 대출순번(K), 발생코드, 발생금액(K), 결제일자, 부서, 사번, 적요]
        StringUtil.chkNull(dsrcVO.occrLoanNo , "대출번호는 필수값입니다.");
        StringUtil.chkNull(dsrcVO.occrLoanSeq, "대출순번은 필수값입니다.");
        StringUtil.chkZero(dsrcVO.occrAmt    , "예가수발생금액은 필수값입니다.");

        // 가수발생 - 은행,계좌 필수
        if (StringUtil.in(dsrcVO.adjCd, "01")) {
            StringUtil.chkNull(dsrcVO.bankCd, "은행코드는 필수값입니다.");
            StringUtil.chkNull(dsrcVO.acntNo, "계좌번호는 필수값입니다.");
        }

        // Params Value 보완
        dsrcVO.adjCd = Constants.DSRC_DIV_DSRC_OCCR;   // 예가수정산코드
        if (StringUtil.isNull(dsrcVO.rcptTpCd))  dsrcVO.rcptTpCd = Constants.RCPT_DIV_DSRC_ARNG;        // 수납유형
        if (StringUtil.isNull(dsrcVO.occrCd))    dsrcVO.occrCd   = Constants.DSRC_OCCR_OVER_AMT;        // 예가수발생코드
        if (StringUtil.isNull(dsrcVO.setlDt))    dsrcVO.setlDt   = DateUtil.getCurrentDateString();   // 결제일자 미입력 시 현재일자
        if (StringUtil.isNull(dsrcVO.acctDt))    dsrcVO.acctDt   = dsrcVO.setlDt;            // 회계일자 미입력 시 결제일자
        if (StringUtil.isNull(dsrcVO.dsrcRmk))   dsrcVO.dsrcRmk  = "예가수발생CC";        // 적요 미입력 시
        if (StringUtil.isNull(dsrcVO.deptCd))    dsrcVO.deptCd   = commBizService.getCodeNm("R00038", "1", "clas1"); // 부서 미입력 시
        if (StringUtil.isNull(dsrcVO.empNo))     dsrcVO.empNo    = commBizService.getCodeNm("R00038", "1", "clas2"); // 사번 미입력 시

        //입금미수 요청객체 생성
//        IamtUnrcvObjVO objVO = new IamtUnrcvObjVO();
//            objVO.loanNo  = dsrcVO.occrLoanNo;                  //대출번호
//            objVO.loanSeq = dsrcVO.occrLoanSeq;                 //대출순번
//            objVO.acctDt  = StringUtil.getFmtDt(dsrcVO.acctDt);      //회계일자
//            objVO.setlDt  = StringUtil.getFmtDt(dsrcVO.setlDt);      //결제일자
//            objVO.setlDivCd = Constants.SETL_DIV_DSRC;     //결제구분코드
//            objVO.rcptTpCd  = dsrcVO.rcptTpCd;                  //수납유형코드
//
//            objVO.dsrcOccrCd  = dsrcVO.occrCd;  //예가수 발생코드
//            objVO.dsrcAdjCd   = dsrcVO.adjCd;   //예가수 정산코드
//            objVO.dsrcOccrAmt = dsrcVO.occrAmt; //예가수발생금액
//            objVO.setlAmt     = dsrcVO.occrAmt; //결제금액
//            objVO.rmk         = dsrcVO.dsrcRmk; //적요
//
//            objVO.acctUnitCd = "W01";
//            objVO.bankCd     = dsrcVO.bankCd;
//            objVO.acntNo     = dsrcVO.acntNo;
//            objVO.sysPathCd  = Constants.SYS_PATH_SWIS;
//            objVO.isrtDeptCd = dsrcVO.deptCd;
//            objVO.adjDeptCd  = dsrcVO.deptCd;
//            objVO.frstRegEmpNo = dsrcVO.empNo;
//
//        if (StringUtil.in(dsrcVO.occrCd, "44,21")) {
//            LOGGER.info("가수통합, 대출번호수정인 경우 (수납유형:가수통합발생)");
//            objVO.rcptTpCd = Constants.RCPT_DIV_DSRC_INTG_OCCR;
//        }
//
//        //예가수 발생처리
//        IamtUnrcvVO iamtVO = new IamtUnrcvVO();
//            iamtVO.vochUnprocFg = dsrcVO.vochExFg;
//            iamtVO.autoSetlFg   = "1";
//            iamtVO.addIamtUnrcvObjVO(objVO);
//        iamtVO = IamtUnrcvCC.procRcpt(iamtVO, null, con);
//        if (!iamtVO.isSuccess()) {
//            throw new DAOException(iamtVO.rsltCd + "||" + iamtVO.rsltCntn);
//        }

//        dsrcVO.setlNo = objVO.setlNo;
//        dsrcVO.dsrcNo = objVO.dsrcNo;

        return dsrcVO;
    }

    /**
     * <p>메소드명  : adjDsrc</p>
     * <p>설　　명  : 예가수 강제정산 (가수통합용)</p>
     * <p>메소드인수 : Connection, DsrcVO</p>
     * <p>리　턴　값 : DsrcVO</p>
     */
    @Override
	public DsrcVO adjDsrc(DsrcVO dsrcVO) throws Exception {

        LOGGER.info("■ DsrcCC.adjDsrc] 가수정산 시작");

        // Check Params - 사용 필드 [예가수번호(K), 결제일자, 예가수정산코드, 정산금액, 부서, 사번, 적요]
        StringUtil.chkNull(dsrcVO.dsrcNo, "예가수번호는 필수값입니다.");

        /** 예가수조회 입력값 Mapper DTO 객체 생성 및 입력값 대입 */
        DsrcSearchDTO inDto = new DsrcSearchDTO();
        inDto.setSetlDt(dsrcVO.getSetlDt()); /* 결제일자 */
        inDto.setDsrcNo(dsrcVO.getDsrcNo()); /* 예가수번호 */

        /** 청구미수.예가수잔액조회 출력 Mapper DTO 객체 생성 */
        DsrcSearchDTO resultDto = this.calcDsrc(inDto);

        // Params Value 보완
        dsrcVO.adjLoanNo    = resultDto.getBfLoanNo();
        dsrcVO.adjLoanSeq   = resultDto.getBfLoanSeq();
        dsrcVO.occrCd       = resultDto.getDsrcOccrCd();   // 예가수발생코드

        if (StringUtil.isNull(dsrcVO.rcptTpCd))  dsrcVO.rcptTpCd = Constants.RCPT_DIV_DSRC_ARNG;	// 수납유형
		if (StringUtil.isNull(dsrcVO.adjCd))     dsrcVO.adjCd    = Constants.DSRC_DIV_DSRC_ADJ;		// 예가수정산코드
		if (dsrcVO.adjAmt==0)               dsrcVO.adjAmt   = resultDto.getDsrcRamt();		// 정산금액 미입력 시 전체정산
        if (StringUtil.isNull(dsrcVO.setlDt))    dsrcVO.setlDt   = DateUtil.getCurrentDateString();   // 결제일자 미입력 시 현재일자
        if (StringUtil.isNull(dsrcVO.acctDt))    dsrcVO.acctDt   = dsrcVO.setlDt;            // 회계일자 미입력 시 결제일자
        if (StringUtil.isNull(dsrcVO.dsrcRmk))   dsrcVO.dsrcRmk  = "예가수정산CC";        // 적요 미입력 시
        if (StringUtil.isNull(dsrcVO.deptCd))    dsrcVO.deptCd   = commBizService.getCodeNm("R00038", "1", "clas1"); // 부서 미입력 시
        if (StringUtil.isNull(dsrcVO.empNo))     dsrcVO.empNo    = commBizService.getCodeNm("R00038", "1", "clas2"); // 사번 미입력 시

        //청구미수 대상정보 셋팅
        AskUnrcvObjVO askObjVO = new AskUnrcvObjVO();
            askObjVO.loanNo  = resultDto.getBfLoanNo();
            askObjVO.loanSeq = resultDto.getBfLoanSeq();
            askObjVO.dsrcNo  = resultDto.getDsrcNo();

        AskUnrcvVO askUnrcvVO = new AskUnrcvVO();
            askUnrcvVO.addAskUnrcvObj(askObjVO);
            askUnrcvVO.addBndVO(resultDto);

        //입금미수 요청객체 생성
        IamtUnrcvObjVO objVO = new IamtUnrcvObjVO();
            objVO.loanNo    = resultDto.getBfLoanNo();
            objVO.loanSeq   = resultDto.getBfLoanSeq();
            objVO.setlDt    = StringUtil.getFmtDt(dsrcVO.acctDt);    //결제일자
            objVO.acctDt    = StringUtil.getFmtDt(dsrcVO.setlDt);    //회계일자
            objVO.setlDivCd = Constants.SETL_DIV_DSRC;     //결제구분코드
            objVO.rcptTpCd  = dsrcVO.rcptTpCd;                  //수납유형코드

            objVO.dsrcNo     = dsrcVO.dsrcNo;       //예가수번호
            objVO.dsrcOccrCd = dsrcVO.occrCd;       //예가수 발생코드
            objVO.dsrcAdjCd  = dsrcVO.adjCd;        //예가수 정산코드
            objVO.dsrcAdjAmt = dsrcVO.adjAmt;       //예가수정산금액
            objVO.setlAmt    = dsrcVO.adjAmt;       //예가수정산금액
            objVO.rmk        = dsrcVO.dsrcRmk;      //적요

            objVO.acctUnitCd = "W01";
            objVO.sysPathCd  = Constants.SYS_PATH_SWIS;
            objVO.isrtDeptCd = dsrcVO.deptCd;
            objVO.adjDeptCd  = dsrcVO.deptCd;
            objVO.frstRegEmpNo = dsrcVO.empNo;

        if (StringUtil.in(dsrcVO.adjCd, "05,06,21")) {
            LOGGER.info("가수통합, 대출번호수정인 경우 (수납유형:가수통합정산)");
            objVO.rcptTpCd = Constants.RCPT_DIV_DSRC_INTG_ADJ;
        }

        //예가수 정산처리
        IamtUnrcvVO iamtVO = new IamtUnrcvVO();
            iamtVO.vochUnprocFg = dsrcVO.vochExFg;
            iamtVO.autoSetlFg   = "1";
            iamtVO.addIamtUnrcvObjVO(objVO);
        iamtVO = iamtUnrcvService.procRcptDsrcAdj(iamtVO, askUnrcvVO);
        if (!iamtVO.isSuccess()) {
            throw new Exception(iamtVO.rsltCd + "||" + iamtVO.rsltCntn);
        }
        dsrcVO.setlNo = objVO.setlNo;

        return dsrcVO;
    }

    /**
     * <p>메소드명  : cnclRfnd</p>
     * <p>설　　명  : 환불취소</p>
     * <p>메소드인수 : Connection, DsrcVO</p>
     * <p>리　턴　값 : N/A</p>
     */
    public void cnclRfnd(DsrcVO dsrcVO) throws Exception {
        LOGGER.info("■ DsrcCC.cnclRfnd] 환불취소 시작");

        // Check Params - 사용 필드 [예가수번호(K), 결제일자, 예가수정산코드, 정산금액, 부서, 사번, 적요]
        StringUtil.chkNull(dsrcVO.adjLoanNo , "대출번호는 필수값입니다.");
        StringUtil.chkNull(dsrcVO.adjLoanSeq, "대출순번은 필수값입니다.");
        StringUtil.chkZero(dsrcVO.setlNo    , "결제번호는 필수값입니다.");

        String deptCd = StringUtil.nvlT(dsrcVO.deptCd, commBizService.getCodeNm("R00038", "1", "clas1"));
        String empNo  = StringUtil.nvlT(dsrcVO.empNo, "SYSTEM");

//        // 입금미수 수납취소로 환불취소 처리한다.
//        IamtUnrcvObjVO objVO = new IamtUnrcvObjVO();
//            objVO.loanNo     = dsrcVO.adjLoanNo;    //대출번호
//            objVO.loanSeq    = dsrcVO.adjLoanSeq;   //대출순번
//            objVO.orgSetlNo  = dsrcVO.setlNo;       //결제번호
//            objVO.acctDt     = StringUtil.nvlT(dsrcVO.acctDt, StringUtil.getKSTDate());   //회계일자
//            objVO.cnclDt     = StringUtil.nvlT(dsrcVO.setlDt, StringUtil.getKSTDate());   //취소일자
//            objVO.cnclFg     = Constants.YES;  //취소여부
//            objVO.ivltCnclFg = Constants.YES;  //강제취소여부
//            objVO.acctUnitCd = "W01";               //회계단위 (입금미수에서 자동세팅)
//            objVO.sysPathCd  = "03";        // BATCH
//            objVO.isrtDeptCd   = deptCd;    //입력부서
//            objVO.frstRegEmpNo = empNo;     //입력사번
//        IamtUnrcvVO iamtVO = new IamtUnrcvVO();
//            iamtVO.vochUnprocFg = dsrcVO.vochExFg;  // 전표미처리여부
//            iamtVO.addIamtUnrcvObjVO(objVO);
//        IamtUnrcvCC.procRcptCncl(iamtVO, con);
//        if (!iamtVO.isSuccess()) {
//            throw new DAOException(iamtVO.rsltCd + "||" + iamtVO.rsltCntn);
//        }

    }

    /**
     * <p>메소드명  : calcDsrc</p>
     * <p>설　　명  :  청구미수.예가수잔액조회 </p>
     * <p>메소드인수 : 예가수금번호, 대출번호, 대출순번, 결제일자</p>
     * <p>리　턴　값 : N/A</p>
     */
    private DsrcSearchDTO calcDsrc(DsrcSearchDTO inDto) throws Exception {

        /** 청구미수.예가수잔액조회 출력 Mapper DTO 객체 생성 */
        DsrcSearchDTO resultDto = new DsrcSearchDTO();

        /** 예가수금번호 입력 값 존재여부에 따른 쿼리 수행 */
        if ( StringUtils.isEmpty(inDto.getDsrcNo()) == false ) {
            /** 입력값 : 결제일자, 예가수번호 */
            resultDto = dsrcMapper.dsrcSearchByDsrcNo(inDto);
        }
        else {
            /** 입력값 : 결제일자, 대출번호, 대출순번 */
            resultDto = dsrcMapper.dsrcSearch(inDto);
        }

        return resultDto;

    }

}
