package hanalife.r.va.va.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.framework.comm.exception.HLFLException;
import hanalife.r.co.im.service.ImgAcntProcService;
import hanalife.r.co.im.vo.ImgAcntProcInVO;
import hanalife.r.co.im.vo.ImgAcntProcOutVO;
import hanalife.r.va.va.mapper.ImgAcntMapper;
import hanalife.r.va.va.mapper.dto.ImgAcntDSSD01DTO;
import hanalife.r.va.va.mapper.dto.ImgAcntDSSD02DTO;
import hanalife.r.va.va.mapper.dto.ImgAcntDSSM01DTO;
import hanalife.r.va.va.mapper.dto.ImgAcntDSSM02DTO;
import hanalife.r.va.va.service.RVAVAM03Service;
import hanalife.r.va.va.vo.RVAVAM03D01InVO;
import hanalife.r.va.va.vo.RVAVAM03DSSD01VO;
import hanalife.r.va.va.vo.RVAVAM03DSSD02VO;
import hanalife.r.va.va.vo.RVAVAM03S01InVO;
import hanalife.r.va.va.vo.RVAVAM03S01OutVO;
import hanalife.r.va.va.vo.RVAVAM03U01InVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RVAVAM03ServiceImpl.java Class
 * 클래스설명   : 가상계좌변경관리 (RVAVAM03) Service Implements
 * 작성일자     : 2023. 3. 9.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRVAVAM03S01    : 가상계좌대출정보
 *           getRVAVAM03S02    : 가상계좌변경이력
 *           modifyRVAVAM03U01 : 가상계좌변경관리수정
 *           removeRVAVAM03U01 : 가상계좌변경관리삭제
 * </pre>
 */
@Service("RVAVAM03Service")
public class RVAVAM03ServiceImpl implements RVAVAM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAM03ServiceImpl.class);

	/** 오류 메시지 전역 변수 선언 */
	private MsgEnum msgEnum;

	/** 가상계좌등록, 해지 관리 서비스 전역 변수 선언 */
	@Autowired
	private ImgAcntProcService imgAcntProcService;

	@Autowired
	private ImgAcntMapper imgAcntMapper;



	/**
	 * <p>메소드명      : getRVAVAM03S01 : 가상계좌대출정보</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 가상계좌대출정보 조회한다.</p>
	 * <p>메소드인수    : RVAVAM03S01InVo </p>
	 * <p>메소드리턴값  : RVAVAM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RVAVAM03S01OutVO getRVAVAM03S01(RVAVAM03S01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 가상계좌대출정보조회 서비스결과값 객체생성
		 *************************************************/
		RVAVAM03S01OutVO resultVo = new RVAVAM03S01OutVO();


		/*************************************************
		 * ■ 가상계좌대출정보조회 조건입력값 객체생성 및 대입수행
		 *************************************************/
		ImgAcntDSSM01DTO inDto = new ImgAcntDSSM01DTO();

		inDto.setLoanNo(inVo.getRVAVAM03DSSM01VO().getLoanNo());        // 대출번호
		inDto.setLoanSeq(inVo.getRVAVAM03DSSM01VO().getLoanSeq());      // 대출순번
		inDto.setCustNo(inVo.getRVAVAM03DSSM01VO().getCustNo());        // 고객번호
		inDto.setImgAcntNo(inVo.getRVAVAM03DSSM01VO().getImgAcntNo());  // 가상계좌번호


		/*************************************************
		 * ■ 가상계좌대출정보조회
		 *************************************************/
		List<ImgAcntDSSD01DTO> resultDTO = imgAcntMapper.searchImgAcntLoanInfo(inDto);


		/*************************************************
		 * ■ 화면출력을 위한 결과값 ListVO 객체 생성
		 *************************************************/
		List<RVAVAM03DSSD01VO> resultList = new ArrayList<RVAVAM03DSSD01VO>();

		for (ImgAcntDSSD01DTO sourceIO : resultDTO) {

			/****************************************
			 * □ VO에 조회된 MapperDTO 값을 대입
			 ****************************************/
			RVAVAM03DSSD01VO targetIO = new RVAVAM03DSSD01VO();

			targetIO.setChngSnum(sourceIO.getChngSnum());              //
			targetIO.setLoanNo(sourceIO.getLoanNo());                  // 대출번호
			targetIO.setLoanSeq(sourceIO.getLoanSeq());                // 대출순번
			targetIO.setCustNm(sourceIO.getCustNm());                  // 고객명
			targetIO.setImgAcntBankCd(sourceIO.getImgAcntBankCd());    // 가상계좌은행코드
			targetIO.setImgAcntBankNm(sourceIO.getImgAcntBankNm());    // 가상계좌은행명
			targetIO.setImgAcntNo(sourceIO.getImgAcntNo());            // 가상계좌번호
			targetIO.setClasCd(sourceIO.getClasCd());                  // 상품코드
			targetIO.setClasNm(sourceIO.getClasNm());                  // 상품명
			targetIO.setLoanDt(sourceIO.getLoanDt());                  // 대출일자
			targetIO.setEprtDt(sourceIO.getEprtDt());                  // 만기일자
			targetIO.setLoanPamt(sourceIO.getLoanPamt());              // 대출금액
			targetIO.setLoanPamtRamt(sourceIO.getLoanPamtRamt());      // 원금잔액
			targetIO.setDueMethCd(sourceIO.getDueMethCd());            // 납입방법코드
			targetIO.setDueMeth(sourceIO.getDueMeth());                // 납입방법
			targetIO.setSetlDd(sourceIO.getSetlDd());                  // 결제일
			targetIO.setLoanIntRt(sourceIO.getLoanIntRt());            // 이자율
			targetIO.setLoanStatCd(sourceIO.getLoanStatCd());          // 대출상태코드
			targetIO.setLoanStat(sourceIO.getLoanStat());              // 대출상태
			targetIO.setBndStat(sourceIO.getBndStat());                // 채권상태
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd());            // 관리부서코드
			targetIO.setDeptNm(sourceIO.getDeptNm());                  // 관리부서
			targetIO.setLoanBankCd(sourceIO.getLoanBankCd());          // 대출은행코드
			targetIO.setLoanBankNm(sourceIO.getLoanBankNm());          // 대출은행명
			targetIO.setLoanAcntNo(sourceIO.getLoanAcntNo());          // 대출계좌번호
			targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd());          //
			targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm());          //

			resultList.add(targetIO);
		}


		/*************************************************
		 * ■ 가상계좌대출정보조회 화면출력 결과값 대입
		 *************************************************/
		resultVo.setRVAVAM03DSSD01VO(resultList);

		return resultVo;

	}


	/**
	 * <p>메소드명      : getRVAVAM03S02 : 가상계좌변경이력</p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 가상계좌변경이력 조회한다.</p>
	 * <p>메소드인수    : RVAVAM03S01InVo </p>
	 * <p>메소드리턴값  : RVAVAM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RVAVAM03S01OutVO getRVAVAM03S02(RVAVAM03S01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 가상계좌변경이력조회 서비스결과값 객체생성
		 *************************************************/
		RVAVAM03S01OutVO resultVo = new RVAVAM03S01OutVO();


		/*************************************************
		 * ■ 가상계좌변경이력조회 조건입력값 객체생성 및 대입수행
		 *************************************************/
		ImgAcntDSSM02DTO inDto = new ImgAcntDSSM02DTO();

		inDto.setLoanNo(inVo.getRVAVAM03DSSM02VO().getLoanNo());     // 대출번호
		inDto.setLoanSeq(inVo.getRVAVAM03DSSM02VO().getLoanSeq());   // 대출순번


		/*************************************************
		 * ■ 가상계좌변경이력조회
		 *************************************************/
		List<ImgAcntDSSD02DTO> resultDTO = imgAcntMapper.searchImgAcntChngHist(inDto);


		/*************************************************
		 * ■ 화면출력을 위한 결과값 ListVO 객체 생성
		 *************************************************/
		List<RVAVAM03DSSD02VO> resultList = new ArrayList<RVAVAM03DSSD02VO>();

		for (ImgAcntDSSD02DTO sourceIO : resultDTO) {

			/****************************************
			 * □ VO에 조회된 MapperDTO 값을 대입
			 ****************************************/
			RVAVAM03DSSD02VO targetIO = new RVAVAM03DSSD02VO();

			targetIO.setSnum(sourceIO.getSnum());                      // 순번
			targetIO.setImgAcntBankCd(sourceIO.getImgAcntBankCd());    // 가상계좌은행코드
			targetIO.setImgAcntBankNm(sourceIO.getImgAcntBankNm());    // 가상계좌은행명
			targetIO.setImgAcntNo(sourceIO.getImgAcntNo());            // 가상계좌번호
			targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo());      // 등록자사번
			targetIO.setFrstRegEmpNm(sourceIO.getFrstRegEmpNm());      // 등록자명
			targetIO.setFrstRegDt(sourceIO.getFrstRegDt());            // 등록일자
			targetIO.setFrstRegTm(sourceIO.getFrstRegTm());            // 등록시간
			targetIO.setLastProcEmpNo(sourceIO.getLastProcEmpNo());    // 해지자사번
			targetIO.setLastProcEmpNm(sourceIO.getLastProcEmpNm());    // 해지자명
			targetIO.setLastProcDt(sourceIO.getLastProcDt());          // 해지일자
			targetIO.setLastProcTm(sourceIO.getLastProcTm());          // 해지시간
			targetIO.setLoanNo(sourceIO.getLoanNo());                  // 대출번호
			targetIO.setLoanSeq(sourceIO.getLoanSeq());                // 대출순번
			targetIO.setCustNm(sourceIO.getCustNm());                  // 고객명
			targetIO.setLoanStatNm(sourceIO.getLoanStatNm());          // 대출상태
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm());            // 관리부서
			targetIO.setUseCmplDt(sourceIO.getUseCmplDt());            // 완료일자
			targetIO.setCurBankCd(sourceIO.getCurBankCd());            // 현가상계좌은행코드
			targetIO.setCurBankNm(sourceIO.getCurBankNm());            // 현가상계좌은행명
			targetIO.setCurAcntNo(sourceIO.getCurAcntNo());            // 현가상계좌번호

			resultList.add(targetIO);
		}


		/*************************************************
		 * ■ 가상계좌변경이력조회 화면출력 결과값 대입
		 *************************************************/
		resultVo.setRVAVAM03DSSD02VO(resultList);

		return resultVo;

	}


	/**
     * <p>메소드명      : modifyRVAVAM03U01 - 가상계좌변경관리수정</p>
     * <p>작성일자      : 2023. 3. 9.
     * <p>작성자(author): 70323 / HeoHyemi
     * <p>설명          : 가상계좌변경관리수정</p>
     * <p>메소드인수    : RVAVAM03U01InVo </p>
     * <p>메소드리턴값  : List</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public void modifyRVAVAM03U01(RVAVAM03U01InVO inVo) throws Exception {

    	/*************************************************
		 * ■ 등록처리를 위한 서비스(내부인터페이스) 입력값 VO 객체 생성
		 *************************************************/
        ImgAcntProcInVO inProcVo = new ImgAcntProcInVO();

        inProcVo.setApplDivCd("1");                                              // 신청구분코드
        inProcVo.setLoanNo(inVo.getRVAVAM03DSSM02VO().getLoanNo());              // 대출번호
        inProcVo.setLoanSeq(inVo.getRVAVAM03DSSM02VO().getLoanSeq());            // 대출순번
        inProcVo.setRegEmpNo(inVo.getRVAVAM03DSSM02VO().getLogInEmpNo());        // 등록사원번호
        inProcVo.setBfImgAcntBankCd(inVo.getRVAVAM03DSSM02VO().getBfBankCd());   // 변경전은행코드
        inProcVo.setBfImgAcntNo(inVo.getRVAVAM03DSSM02VO().getBfAcntNo());       // 변경전계좌번호
        inProcVo.setAfImgAcntBankCd(inVo.getRVAVAM03DSSM02VO().getAfBankCd());   // 변경후은행코드


        /*************************************************
		 * ■ 가상계좌 등록처리를 위한 서비스(내부인터페이스) 호출
		 *************************************************/
        ImgAcntProcOutVO result = imgAcntProcService.imgAcntReg(inProcVo);


        /*************************************************
		 * ■ 결과값에 따른 오류 조건 수행
		 *************************************************/
        if ( msgEnum.SUCCESS.getErrorCd().equals(result.getRsltCd()) == false ) {
            LOGGER.info("가상계좌해지시 오류");
            throw new HLFLException(result.getRsltCd(), result.getRsltCntn());
        }

    }


    /**
     * <p>메소드명      : removeRVAVAM03D01 - 가상계좌변경관리해지</p>
     * <p>작성일자      : 2023. 3. 9.
     * <p>작성자(author): 70323 / HeoHyemi
     * <p>설명          : 가상계좌변경관리해지</p>
     * <p>메소드인수    : RVAVAM03D01InVo </p>
     * <p>메소드리턴값  : List</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public void removeRVAVAM03D01(RVAVAM03D01InVO inVo) throws Exception {

    	/*************************************************
		 * ■ 해지처리를 위한 서비스(내부인터페이스) 입력값 VO 객체 생성
		 *************************************************/
        ImgAcntProcInVO inProcVo = new ImgAcntProcInVO();

        inProcVo.setApplDivCd("2");                                              // 신청구분코드
        inProcVo.setLoanNo(inVo.getRVAVAM03DSSM02VO().getLoanNo());              // 대출번호
        inProcVo.setLoanSeq(inVo.getRVAVAM03DSSM02VO().getLoanSeq());            // 대출순번
        inProcVo.setRegEmpNo(inVo.getRVAVAM03DSSM02VO().getLogInEmpNo());        // 등록사원번호
        inProcVo.setBfImgAcntBankCd(inVo.getRVAVAM03DSSM02VO().getBfBankCd());   // 변경전은행코드
        inProcVo.setBfImgAcntNo(inVo.getRVAVAM03DSSM02VO().getBfAcntNo());       // 변경전계좌번호
        inProcVo.setAfImgAcntBankCd(inVo.getRVAVAM03DSSM02VO().getAfBankCd());   // 변경후은행코드

        /*************************************************
		 * ■ 가상계좌 해지처리를 위한 서비스(내부인터페이스) 호출 수행
		 *************************************************/
        ImgAcntProcOutVO result = imgAcntProcService.imgAcntReg(inProcVo);


        /*************************************************
		 * ■ 결과값에 따른 오류 조건 수행
		 *************************************************/
        if ( msgEnum.SUCCESS.getErrorCd().equals(result.getRsltCd()) == false ) {
            LOGGER.info("가상계좌해지시 오류");
            throw new HLFLException(result.getRsltCd(), result.getRsltCntn());
        }

    }

}
