package hanalife.r.va.va.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.r.va.va.mapper.ImgAcntMngReptMapper;
import hanalife.r.va.va.mapper.dto.ImgAcntMngReptDSPOPUPSDDTO;
import hanalife.r.va.va.mapper.dto.ImgAcntMngReptDSPOPUPSMDTO;
import hanalife.r.va.va.service.RVAVAP01Service;
import hanalife.r.va.va.vo.RVAVAP01DSPOPUPSDVO;
import hanalife.r.va.va.vo.RVAVAP01S01InVO;
import hanalife.r.va.va.vo.RVAVAP01S01OutVO;



/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RVAVAP01S05ServiceImpl.java Class
 * 클래스설명   : 가상계좌거래내역조회 (RVAVAP01S05) Service Implements
 * 작성일자     : 2023. 3. 14.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRVAVAP01S05 : 가상계좌거래내역조회
 * </pre>
 */
@Service("RVAVAP01Service")
public class RVAVAP01ServiceImpl implements RVAVAP01Service{

    private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAP01ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private ImgAcntMngReptMapper imgAcntMngReptMapper;


    /**
     * <p>메소드명      : searchImgAcnt : 수납내역상세조회</p>
     * <p>작성일자      : 2023. 3. 21.
     * <p>작성자(author): 70322 / sungjin.park
     * <p>설명          : 가상계좌거래내역을 조회 한다.</p>
     * <p>메소드인수    : RVAVAP01S05InVO </p>
     * <p>메소드리턴값  : RVAVAP01S05OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public RVAVAP01S01OutVO getRVAVAP01S01(RVAVAP01S01InVO inVo) throws Exception {

        LOGGER.info("##### RVAVAP01ServiceImpl getRVAVAP01S05 Start #####");

        /** 가상계좌거래내역 서비스 결과값 객체 생성 */
        RVAVAP01S01OutVO resultVo = new RVAVAP01S01OutVO();

        ImgAcntMngReptDSPOPUPSMDTO inDto = new ImgAcntMngReptDSPOPUPSMDTO();

        inDto.setStndDt(inVo.getRVAVAP01DSPOPUPSMVO().getStndDt());


        List<ImgAcntMngReptDSPOPUPSDDTO> resultDTO = imgAcntMngReptMapper.searchImgAcntRept(inDto);

        List<RVAVAP01DSPOPUPSDVO> resultList = new ArrayList<RVAVAP01DSPOPUPSDVO>();

        for(ImgAcntMngReptDSPOPUPSDDTO sourceIO : resultDTO) {

            RVAVAP01DSPOPUPSDVO targetIO = new RVAVAP01DSPOPUPSDVO();

            targetIO.setBankCd(sourceIO.getBankCd());
            targetIO.setBankNm(sourceIO.getBankNm());
            targetIO.setDisuCnt(sourceIO.getDisuCnt());
            targetIO.setTotCnt(sourceIO.getTotCnt());
            targetIO.setUnUseCnt(sourceIO.getUnUseCnt());
            targetIO.setUseCnt(sourceIO.getUseCnt());


            resultList.add(targetIO);
        }
        resultVo.setListRVAVAP01DSPOPUPSDVO(resultList);

        return resultVo;
    }




}
