package hanalife.s.ag.bs.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.ag.bs.mapper.SrOrgMngMapper;
import hanalife.s.ag.bs.mapper.dto.srOrgMngDSSDCDTO;
import hanalife.s.ag.bs.mapper.dto.srOrgMngDSSDDTO;
import hanalife.s.ag.bs.service.SAGBSM01Service;
import hanalife.s.ag.bs.vo.SAGBSM01DSSDVO;
import hanalife.s.ag.bs.vo.SAGBSM01I01InVO;
import hanalife.s.ag.bs.vo.SAGBSM01I01OutVO;
import hanalife.s.ag.bs.vo.SAGBSM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SAGBSM01ServiceImpl.java Class
 * 클래스설명   : SR기관관리 (SAGBSM01) Service Implements
 * 작성일자     : 2023. 4. 12.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 12.][70323 ][최초작성]
 * [2023. 4. 14.][70323 ][조회 조건 입력 삭제]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSAGBSM01S01 : SR기관관리목록조회
 * 				registerSAGBSM01S01 : SR기관관리등록
 * 				modifySAGBSM01S01 : SR기관관리수정
 * </pre>
 */
@Service("SAGBSM01Service")
public class SAGBSM01ServiceImpl implements SAGBSM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SAGBSM01ServiceImpl.class);

	private MsgEnum msgEnum;

	@Autowired
	private SrOrgMngMapper srOrgMngMapper;

	/**
	 * <p>메소드명      : getSAGBSM01S01 : SR기관관리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR기관관리 조회 한다.</p>
	 * <p>메소드인수    : SAGBSM01S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	//public SAGBSM01S01OutVO getSAGBSM01S01(SAGBSM01S01InVO inVo) throws Exception {
	public SAGBSM01S01OutVO getSAGBSM01S01() throws Exception {

		SAGBSM01S01OutVO resultVo = new SAGBSM01S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		//srOrgMngDSSMDTO inDto = new srOrgMngDSSMDTO();

		//inDto.setSrCorpNm(inVo.getSAGBSM01DSSMVO().getReprName()); /** SR법인명 */
		//inDto.setSrCorpNm(inVo.getSAGBSM01DSSMVO().getSrCorpNm()); /** SR성명 */

		//List<srOrgMngDSSDDTO> resultDTO = srOrgMngMapper.searchSrOrgMngList(inDto);	/** SR기관관리리스트*/
		List<srOrgMngDSSDDTO> resultDTO = srOrgMngMapper.searchSrOrgMngList();	/** SR기관관리리스트*/

		List<SAGBSM01DSSDVO> resultList = new ArrayList<SAGBSM01DSSDVO>();

		for (srOrgMngDSSDDTO sourceIO : resultDTO) {
			SAGBSM01DSSDVO targetIO = new SAGBSM01DSSDVO();
			targetIO.setSrCorpCd(sourceIO.getSrCorpCd()); 							/** SR법인코드 */
			targetIO.setSrCorpDivCd(sourceIO.getSrCorpDivCd()); 					/** SR법인구분코드 */
			targetIO.setSrCorpNm(sourceIO.getSrCorpNm()); 							/** SR법인명 */
			targetIO.setBizNo(sourceIO.getBizNo()); 								/** 사업자번호 */
			targetIO.setCorpNo(sourceIO.getCorpNo()); 								/** 법인번호 */
			targetIO.setReprName(sourceIO.getReprName()); 							/** 대표자성명 */
			targetIO.setMaskReprName(this.nameMasking(sourceIO.getReprName())); 	/** 대표자성명_마스킹 */
			targetIO.setBztp(sourceIO.getBztp()); 									/** 업태 */
			targetIO.setItm(sourceIO.getItm()); 									/** 종목 */
			targetIO.setBzit(sourceIO.getBzit()); 									/** 업종 */
			targetIO.setTelNo1(sourceIO.getTelNo1()); 								/** 전화번호_지역 */
			targetIO.setTelNo2(sourceIO.getTelNo2()); 								/** 전화번호_국번 */
			targetIO.setMaskTelNo2("****"); 										/** 전화번호_국번_마스킹 */
			targetIO.setTelNo3(sourceIO.getTelNo3()); 								/** 전화번호_호 */
			targetIO.setFaxNo1(sourceIO.getFaxNo1()); 								/** 팩스번호_지역 */
			targetIO.setFaxNo2(sourceIO.getFaxNo2()); 								/** 팩스번호_국번 */
			targetIO.setFaxNo3(sourceIO.getFaxNo3()); 								/** 팩스번호_호 */

			String emailAddr = sourceIO.getEmailAddr();
			String emailId = "";
			String emailDomn = "";

			if(emailAddr != null) {
				int idx = emailAddr.indexOf("@");			// @ 위치
				emailId = emailAddr.substring(0, idx);		// 이메일 아이디
				emailDomn = emailAddr.substring(idx + 1);	// 이메일 도메인 주소
			}

			targetIO.setEmailId(emailId); 											/** E-MAIL아이디 */
			targetIO.setEmailDomn(emailDomn); 										/** E-MAIL도메인 */
			targetIO.setBankcd(sourceIO.getBankcd()); 								/** 은행코드 */

			/** 계좌번호 마스킹처리 */
			String acntNo = sourceIO.getAcntNo();
			String maskAcntNo = "";
			if(acntNo.length() > 4) {
				maskAcntNo = acntNo.substring(0, acntNo.length() -4) + "****";
			}

			targetIO.setAcntNo(acntNo); 											/** 계좌번호 */
			targetIO.setMaskAcntNo(maskAcntNo); 									/** 계좌번호_마스킹 */
			targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm()); 						/** 예금주명 */
			targetIO.setMaskDepoOwnnm(this.nameMasking(sourceIO.getDepoOwnnm())); 	/** 예금주명_마스킹 */

			resultList.add(targetIO);
		}

		resultVo.setSAGBSM01DSSDVO(resultList);		/** SR기관관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;

	}

	/**
	 * <p>메소드명      : registerSAGBSM01S01 : SR기관관리등록</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR기관관리 등록 한다.</p>
	 * <p>메소드인수    : SAGBSM01S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM01I01OutVO registerSAGBSM01S01(SAGBSM01I01InVO inVo) throws Exception {

		SAGBSM01I01OutVO resultVo = new SAGBSM01I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		srOrgMngDSSDCDTO inDto = new srOrgMngDSSDCDTO();

		int insResult = 0;

		inDto.setSrCorpCd(inVo.getSAGBSM01DSSDCVO().getSrCorpCd());				/** SR법인코드 */
		inDto.setSrCorpDivCd(inVo.getSAGBSM01DSSDCVO().getSrCorpDivCd());		/** SR법인구분코드 */
		inDto.setSrCorpNm(inVo.getSAGBSM01DSSDCVO().getSrCorpNm());				/** SR법인명 */
		inDto.setBizNo(inVo.getSAGBSM01DSSDCVO().getBizNo());					/** 사업자번호 */
		inDto.setCorpNo(inVo.getSAGBSM01DSSDCVO().getCorpNo());					/** 법인번호 */
		inDto.setReprName(inVo.getSAGBSM01DSSDCVO().getReprName());				/** 대표자성명 */
		inDto.setBztp(inVo.getSAGBSM01DSSDCVO().getBztp());						/** 업태 */
		inDto.setItm(inVo.getSAGBSM01DSSDCVO().getItm());						/** 종목 */
		inDto.setBzit(inVo.getSAGBSM01DSSDCVO().getBzit());						/** 업종 */
		inDto.setTelNo1(inVo.getSAGBSM01DSSDCVO().getTelNo1());					/** 전화번호_지역 */
		inDto.setTelNo2(inVo.getSAGBSM01DSSDCVO().getTelNo2());					/** 전화번호_국번 */
		inDto.setTelNo3(inVo.getSAGBSM01DSSDCVO().getTelNo3());					/** 전화번호_호 */
		inDto.setFaxNo1(inVo.getSAGBSM01DSSDCVO().getFaxNo1());					/** 팩스번호_지역 */
		inDto.setFaxNo2(inVo.getSAGBSM01DSSDCVO().getFaxNo2());					/** 팩스번호_국번 */
		inDto.setFaxNo3(inVo.getSAGBSM01DSSDCVO().getFaxNo3());					/** 팩스번호_호 */
		inDto.setEmailAddr(inVo.getSAGBSM01DSSDCVO().getEmailAddr());			/** E-MAIL */
		inDto.setBankcd(inVo.getSAGBSM01DSSDCVO().getBankcd());					/** 은행코드 */
		inDto.setAcntNo(inVo.getSAGBSM01DSSDCVO().getAcntNo());					/** 계좌번호 */
		inDto.setDepoOwnnm(inVo.getSAGBSM01DSSDCVO().getDepoOwnnm());			/** 예금주명 */
		inDto.setLogInEmpNo(inVo.getSAGBSM01DSSDCVO().getLogInEmpNo());			/** 로그인사원번호 */

		insResult = srOrgMngMapper.registerSrOrgMngList(inDto);

		if(insResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : modifySAGBSM01S01 : SR기관관리수정</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR기관관리 수정 한다.</p>
	 * <p>메소드인수    : SAGBSM01S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM01I01OutVO modifySAGBSM01S01(SAGBSM01I01InVO inVo) throws Exception {

		SAGBSM01I01OutVO resultVo = new SAGBSM01I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		srOrgMngDSSDCDTO inDto = new srOrgMngDSSDCDTO();

		int updResult = 0;

		inDto.setSrCorpCd(inVo.getSAGBSM01DSSDCVO().getSrCorpCd());				/** SR법인코드 */
		inDto.setSrCorpDivCd(inVo.getSAGBSM01DSSDCVO().getSrCorpDivCd());		/** SR법인구분코드 */
		inDto.setSrCorpNm(inVo.getSAGBSM01DSSDCVO().getSrCorpNm());				/** SR법인명 */
		inDto.setBizNo(inVo.getSAGBSM01DSSDCVO().getBizNo());					/** 사업자번호 */
		inDto.setCorpNo(inVo.getSAGBSM01DSSDCVO().getCorpNo());					/** 법인번호 */
		inDto.setReprName(inVo.getSAGBSM01DSSDCVO().getReprName());				/** 대표자성명 */
		inDto.setBztp(inVo.getSAGBSM01DSSDCVO().getBztp());						/** 업태 */
		inDto.setItm(inVo.getSAGBSM01DSSDCVO().getItm());						/** 종목 */
		inDto.setBzit(inVo.getSAGBSM01DSSDCVO().getBzit());						/** 업종 */
		inDto.setTelNo1(inVo.getSAGBSM01DSSDCVO().getTelNo1());					/** 전화번호_지역 */
		inDto.setTelNo2(inVo.getSAGBSM01DSSDCVO().getTelNo2());					/** 전화번호_국번 */
		inDto.setTelNo3(inVo.getSAGBSM01DSSDCVO().getTelNo3());					/** 전화번호_호 */
		inDto.setFaxNo1(inVo.getSAGBSM01DSSDCVO().getFaxNo1());					/** 팩스번호_지역 */
		inDto.setFaxNo2(inVo.getSAGBSM01DSSDCVO().getFaxNo2());					/** 팩스번호_국번 */
		inDto.setFaxNo3(inVo.getSAGBSM01DSSDCVO().getFaxNo3());					/** 팩스번호_호 */
		inDto.setEmailAddr(inVo.getSAGBSM01DSSDCVO().getEmailAddr());			/** E-MAIL */
		inDto.setBankcd(inVo.getSAGBSM01DSSDCVO().getBankcd());					/** 은행코드 */
		inDto.setAcntNo(inVo.getSAGBSM01DSSDCVO().getAcntNo());					/** 계좌번호 */
		inDto.setDepoOwnnm(inVo.getSAGBSM01DSSDCVO().getDepoOwnnm());			/** 예금주명 */
		inDto.setLogInEmpNo(inVo.getSAGBSM01DSSDCVO().getLogInEmpNo());			/** 로그인사원번호 */

		updResult = srOrgMngMapper.modifySrOrgMngList(inDto);

		if(updResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}
}
