package hanalife.s.ag.bs.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.ag.bs.mapper.SrMngMapper;
import hanalife.s.ag.bs.mapper.dto.srMngDSCDSRORGCDDTO;
import hanalife.s.ag.bs.mapper.dto.srMngDSSDCDTO;
import hanalife.s.ag.bs.mapper.dto.srMngDSSDDTO;
import hanalife.s.ag.bs.mapper.dto.srMngDSSMDTO;
import hanalife.s.ag.bs.service.SAGBSM02Service;
import hanalife.s.ag.bs.vo.SAGBSM02DSCDSRORGCDDTO;
import hanalife.s.ag.bs.vo.SAGBSM02DSSDVO;
import hanalife.s.ag.bs.vo.SAGBSM02I01InVO;
import hanalife.s.ag.bs.vo.SAGBSM02I01OutVO;
import hanalife.s.ag.bs.vo.SAGBSM02S01InVO;
import hanalife.s.ag.bs.vo.SAGBSM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SAGBSM02ServiceImpl.java Class
 * 클래스설명   : SR관리 (SAGBSM02) Service Implements
 * 작성일자     : 2023. 4. 12.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 12.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSAGBSM02S01 : SR관리목록조회
 * 				registerSAGBSM02S01 : SR관리등록
 * 				modifySAGBSM02S01 : SR관리수정
 * 				deleteSAGBSM02S01 : SR관리삭제
 * </pre>
 */
@Service("SAGBSM02Service")
public class SAGBSM02ServiceImpl implements SAGBSM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SAGBSM02ServiceImpl.class);

	private MsgEnum msgEnum;

	@Autowired
	private SrMngMapper srMngMapper;

	/**
	 * <p>메소드명      : getSAGBSM02S01 : SR관리기관코드조회</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR관리 기관코드 조회 한다.</p>
	 * <p>메소드인수    : </p>
	 * <p>메소드리턴값  : SAGBSM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM02S01OutVO getSAGBSM02S01() throws Exception {

		SAGBSM02S01OutVO resultVo = new SAGBSM02S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		List<srMngDSCDSRORGCDDTO> resultDTO = srMngMapper.searchSrOrgCdList();	/** SR관리기관코드리스트*/

		List<SAGBSM02DSCDSRORGCDDTO> resultList = new ArrayList<SAGBSM02DSCDSRORGCDDTO>();

		for (srMngDSCDSRORGCDDTO sourceIO : resultDTO) {
			SAGBSM02DSCDSRORGCDDTO targetIO = new SAGBSM02DSCDSRORGCDDTO();
			targetIO.setSalesTeamGbCd(sourceIO.getSalesTeamGbCd()); /** SR팀구분코드 */
			targetIO.setSrCorpNm(sourceIO.getSrCorpNm()); /** SR법인명 */

			resultList.add(targetIO);
		}

		resultVo.setSAGBSM02DSCDSRORGCDDTO(resultList);	/** SR관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : getSAGBSM02S01 : SR관리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR관리 조회 한다.</p>
	 * <p>메소드인수    : SAGBSM02S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM02S01OutVO getSAGBSM02S02(SAGBSM02S01InVO inVo) throws Exception {

		SAGBSM02S01OutVO resultVo = new SAGBSM02S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		srMngDSSMDTO inDto = new srMngDSSMDTO();

		inDto.setSalesTeamGbCd(inVo.getSAGBSM02DSSMVO().getSalesTeamGbCd()); 	/** SR법인구분코드 */
		inDto.setSalesNm(inVo.getSAGBSM02DSSMVO().getSalesNm()); 				/** SR성명 */

		List<srMngDSSDDTO> resultDTO = srMngMapper.searchSrMngList(inDto);	/** SR관리리스트*/

		List<SAGBSM02DSSDVO> resultList = new ArrayList<SAGBSM02DSSDVO>();

		for (srMngDSSDDTO sourceIO : resultDTO) {
			SAGBSM02DSSDVO targetIO = new SAGBSM02DSSDVO();
			targetIO.setSalesCode(sourceIO.getSalesCode()); 				/** SR-ID */
			targetIO.setSalesTeamGbCd(sourceIO.getSalesTeamGbCd()); 		/** SALES팀구분코드 */
			targetIO.setSalesGbCode(sourceIO.getSalesGbCode()); 			/** SALES구분코드 */
			targetIO.setSalesNm(sourceIO.getSalesNm()); 					/** SALES성명 */
			targetIO.setDsaRegiNo(sourceIO.getDsaRegiNo()); 				/** 상담사등록번호 */
			targetIO.setResiDt(sourceIO.getResiDt()); 						/** 위촉일자 */
			targetIO.setCloseDt(sourceIO.getCloseDt()); 					/** 해촉일자 */
			targetIO.setDsaEdcnDt(sourceIO.getDsaEdcnDt()); 				/** 상담사교육이수일자 */
			targetIO.setMobArea(sourceIO.getMobArea()); 					/** 휴대폰지역번호 */
			targetIO.setMobHeadNum(sourceIO.getMobHeadNum()); 				/** 휴대폰국번 */
			targetIO.setMaskMobHeadNum("****"); 							/** 휴대폰국번_마스킹 */
			targetIO.setMobSerialNum(sourceIO.getMobSerialNum()); 			/** 휴대폰일련번호 */

			targetIO.setResId(sourceIO.getResId()); 						/** SR생년월일 */
			targetIO.setSalesMemo(sourceIO.getSalesMemo()); 				/** SALES */
			targetIO.setChgrSeqNo(sourceIO.getChgrSeqNo()); 				/** 변경일련번호 */
			targetIO.setSalesGbCd(sourceIO.getSalesGbCd()); 				/** SALES구분코드 */
			targetIO.setSalesPw(sourceIO.getSalesPw()); 					/** SALES비밀번호 */
			targetIO.setDsaGbCd(sourceIO.getDsaGbCd()); 					/** DSA구분코드 */
			targetIO.setSalesPosGbCd(sourceIO.getSalesPosGbCd()); 			/** SALES직급구분코드 */
			targetIO.setSalesZipcd(sourceIO.getSalesZipcd()); 				/** SALES우편번호 */
			targetIO.setSalesAddr(sourceIO.getSalesAddr()); 				/** SALES주소 */
			targetIO.setSalesDetailAddr(sourceIO.getSalesDetailAddr()); 	/** SALES상세주소 */
			targetIO.setStatusGbCd(sourceIO.getStatusGbCd()); 				/** 재직상태구분코드 */
			targetIO.setRegiDt(sourceIO.getRegiDt()); 						/** 계약일자 */
			targetIO.setExpyDt(sourceIO.getExpyDt()); 						/** 만기일자 */
			targetIO.setCloseThinkCd(sourceIO.getCloseThinkCd()); 			/** 해촉사유구분코드 */
			targetIO.setCertifiGbCd(sourceIO.getCertifiGbCd()); 			/** 보증방식구분코드 */
			targetIO.setCertifiExpyDt(sourceIO.getCertifiExpyDt()); 		/** 신원보증보험만기일자 */
			targetIO.setCertifiAmt(sourceIO.getCertifiAmt()); 				/** 신원보증보험금액 */
			targetIO.setGrntNm(sourceIO.getGrntNm()); 						/** 신원보증인성명 */
			targetIO.setBankCd(sourceIO.getBankCd()); 						/** 결제은행코드 */
			targetIO.setBankAccount(sourceIO.getBankAccount()); 			/** 결제계좌번호 */
			targetIO.setBankDeposNm(sourceIO.getBankDeposNm()); 			/** 결제예금주명 */
			targetIO.setTelcoCd(sourceIO.getTelcoCd()); 					/** 통신사코드 */
			targetIO.setTelAreaNo(sourceIO.getTelAreaNo()); 				/** 전화지역번호 */
			targetIO.setTelHeadNo(sourceIO.getTelHeadNo()); 				/** 전화국번호 */
			targetIO.setTelSerialNo(sourceIO.getTelSerialNo()); 			/** 전화일련번호 */
			targetIO.setTelInnerNo(sourceIO.getTelInnerNo()); 				/** 내선번호 */
			targetIO.setFaxAreaNo(sourceIO.getFaxAreaNo()); 				/** FAX지역번호 */
			targetIO.setFaxHeadNo(sourceIO.getFaxHeadNo()); 				/** FAX국번호 */
			targetIO.setFaxSerialNo(sourceIO.getFaxSerialNo()); 			/** FAX일련번호 */
			targetIO.setMailId(sourceIO.getMailId()); 						/** 이메일ID */
			targetIO.setMailHostCd(sourceIO.getMailHostCd()); 				/** 이메일HOST코드 */
			targetIO.setMailHostEtc(sourceIO.getMailHostEtc()); 			/** 이메일HOST기타 */
			targetIO.setTrmYn(sourceIO.getTrmYn()); 						/** 단말기지급여부 */
			targetIO.setTrmDcd(sourceIO.getTrmDcd()); 						/** 단말기구분코드 */
			targetIO.setTrmImeNo(sourceIO.getTrmImeNo()); 					/** 단말기IME번호 */
			targetIO.setTrmAreaNo(sourceIO.getTrmAreaNo()); 				/** 단말기지역번호 */
			targetIO.setTrmHeadNo(sourceIO.getTrmHeadNo()); 				/** 단말기국번호 */
			targetIO.setTrmSerialNo(sourceIO.getTrmSerialNo()); 			/** 단말기일련번호 */

			resultList.add(targetIO);
		}

		resultVo.setSAGBSM02DSSDVO(resultList);	/** SR관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : registerSAGBSM02S01 : SR관리등록</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR관리 등록 한다.</p>
	 * <p>메소드인수    : SAGBSM02S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM02I01OutVO registerSAGBSM02S01(SAGBSM02I01InVO inVo) throws Exception {

		SAGBSM02I01OutVO resultVo = new SAGBSM02I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		srMngDSSDCDTO inDto = new srMngDSSDCDTO();

		int insResult = 0;

		/** 화면용 */
		inDto.setSalesCode(inVo.getSAGBSM02DSSDCVO().getSalesCode()); 				/** SR_ID */
		inDto.setSalesNm(inVo.getSAGBSM02DSSDCVO().getSalesNm()); 					/** SALES성명 */
		inDto.setResId(inVo.getSAGBSM02DSSDCVO().getResId()); 						/** SR주민번호_암호화 */
		inDto.setDsaRegiNo(inVo.getSAGBSM02DSSDCVO().getDsaRegiNo()); 				/** 상담사등록번호 */
		inDto.setSalesTeamGbCd(inVo.getSAGBSM02DSSDCVO().getSalesTeamGbCd()); 		/** SALES팀구분코드 */
		inDto.setResiDt(inVo.getSAGBSM02DSSDCVO().getResiDt()); 					/** 위촉일자 */
		inDto.setCloseDt(inVo.getSAGBSM02DSSDCVO().getCloseDt()); 					/** 해촉일자 */
		inDto.setCloseThinkCd(inVo.getSAGBSM02DSSDCVO().getCloseThinkCd()); 		/** 해촉사유구분코드 */
		inDto.setDsaEdcnDt(inVo.getSAGBSM02DSSDCVO().getDsaEdcnDt()); 				/** 상담사교육이수일자 */
		inDto.setMobArea(inVo.getSAGBSM02DSSDCVO().getMobArea()); 					/** 휴대폰지역번호 */
		inDto.setMobHeadNum(inVo.getSAGBSM02DSSDCVO().getMobHeadNum()); 			/** 휴대폰국번 */
		inDto.setMobSerialNum(inVo.getSAGBSM02DSSDCVO().getMobSerialNum()); 		/** 휴대폰일련번호 */
		inDto.setMailId(inVo.getSAGBSM02DSSDCVO().getMailId()); 					/** 이메일ID */
		inDto.setMailHostCd(inVo.getSAGBSM02DSSDCVO().getMailHostCd()); 			/** 이메일HOST코드 */
		inDto.setMailHostEtc(inVo.getSAGBSM02DSSDCVO().getMailHostEtc()); 			/** 이메일HOST기타 */
		inDto.setSalesMemo(inVo.getSAGBSM02DSSDCVO().getSalesMemo()); 				/** SALES메모 */
		inDto.setLogInEmpNo(inVo.getSAGBSM02DSSDCVO().getLogInEmpNo()); 			/** 로그인사원번호 */

		/** DB용 */
		inDto.setChgrSeqNo(inVo.getSAGBSM02DSSDCVO().getChgrSeqNo()); 				/** 변경일련번호 */
		inDto.setSalesGbCd(inVo.getSAGBSM02DSSDCVO().getSalesGbCd()); 				/** SALES구분코드 */
		inDto.setSalesPw(inVo.getSAGBSM02DSSDCVO().getSalesPw()); 					/** SALES비밀번호 */
		inDto.setDsaGbCd(inVo.getSAGBSM02DSSDCVO().getDsaGbCd()); 					/** DSA구분코드 */
		inDto.setSalesPosGbCd(inVo.getSAGBSM02DSSDCVO().getSalesPosGbCd()); 		/** SALES직급구분코드 */
		inDto.setSalesZipcd(inVo.getSAGBSM02DSSDCVO().getSalesZipcd()); 			/** SALES우편번호 */
		inDto.setSalesAddr(inVo.getSAGBSM02DSSDCVO().getSalesAddr()); 				/** SALES주소 */
		inDto.setSalesDetailAddr(inVo.getSAGBSM02DSSDCVO().getSalesDetailAddr()); 	/** SALES상세주소 */
		inDto.setStatusGbCd(inVo.getSAGBSM02DSSDCVO().getStatusGbCd()); 			/** 재직상태구분코드 */
		inDto.setRegiDt(inVo.getSAGBSM02DSSDCVO().getRegiDt()); 					/** 계약일자 */
		inDto.setExpyDt(inVo.getSAGBSM02DSSDCVO().getExpyDt()); 					/** 만기일자 */
		inDto.setCertifiGbCd(inVo.getSAGBSM02DSSDCVO().getCertifiGbCd()); 			/** 보증방식구분코드 */
		inDto.setCertifiExpyDt(inVo.getSAGBSM02DSSDCVO().getCertifiExpyDt()); 		/** 신원보증보험만기일자 */
		inDto.setCertifiAmt(inVo.getSAGBSM02DSSDCVO().getCertifiAmt()); 			/** 신원보증보험금액 */
		inDto.setGrntNm(inVo.getSAGBSM02DSSDCVO().getGrntNm()); 					/** 신원보증인성명 */
		inDto.setBankCd(inVo.getSAGBSM02DSSDCVO().getBankCd()); 					/** 결제은행코드 */
		inDto.setBankAccount(inVo.getSAGBSM02DSSDCVO().getBankAccount()); 			/** 결제계좌번호 */
		inDto.setBankDeposNm(inVo.getSAGBSM02DSSDCVO().getBankDeposNm()); 			/** 결제예금주명 */
		inDto.setTelcoCd(inVo.getSAGBSM02DSSDCVO().getTelcoCd()); 					/** 통신사코드 */
		inDto.setTelAreaNo(inVo.getSAGBSM02DSSDCVO().getTelAreaNo()); 				/** 전화지역번호 */
		inDto.setTelHeadNo(inVo.getSAGBSM02DSSDCVO().getTelHeadNo()); 				/** 전화국번호 */
		inDto.setTelSerialNo(inVo.getSAGBSM02DSSDCVO().getTelSerialNo()); 			/** 전화일련번호 */
		inDto.setTelInnerNo(inVo.getSAGBSM02DSSDCVO().getTelInnerNo()); 			/** 내선번호 */
		inDto.setFaxAreaNo(inVo.getSAGBSM02DSSDCVO().getFaxAreaNo()); 				/** FAX지역번호 */
		inDto.setFaxHeadNo(inVo.getSAGBSM02DSSDCVO().getFaxHeadNo()); 				/** FAX국번호 */
		inDto.setFaxSerialNo(inVo.getSAGBSM02DSSDCVO().getFaxSerialNo()); 			/** FAX일련번호 */
		inDto.setTrmYn(inVo.getSAGBSM02DSSDCVO().getTrmYn()); 						/** 단말기지급여부 */
		inDto.setTrmDcd(inVo.getSAGBSM02DSSDCVO().getTrmDcd()); 					/** 단말기구분코드 */
		inDto.setTrmImeNo(inVo.getSAGBSM02DSSDCVO().getTrmImeNo()); 				/** 단말기IME번호 */
		inDto.setTrmAreaNo(inVo.getSAGBSM02DSSDCVO().getTrmAreaNo()); 				/** 단말기지역번호 */
		inDto.setTrmHeadNo(inVo.getSAGBSM02DSSDCVO().getTrmHeadNo()); 				/** 단말기국번호 */
		inDto.setTrmSerialNo(inVo.getSAGBSM02DSSDCVO().getTrmSerialNo()); 			/** 단말기일련번호 */

		insResult = srMngMapper.registerSrMngList(inDto);

		if(insResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : modifySAGBSM02S01 : SR관리수정</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : SR관리 수정 한다.</p>
	 * <p>메소드인수    : SAGBSM02S01InVo </p>
	 * <p>메소드리턴값  : SAGBSM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SAGBSM02I01OutVO modifySAGBSM02S01(SAGBSM02I01InVO inVo) throws Exception {

		SAGBSM02I01OutVO resultVo = new SAGBSM02I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		srMngDSSDCDTO inDto = new srMngDSSDCDTO();

		int updResult = 0;

		inDto.setSalesCode(inVo.getSAGBSM02DSSDCVO().getSalesCode()); 				/** SR_ID */
		inDto.setSalesNm(inVo.getSAGBSM02DSSDCVO().getSalesNm()); 					/** SALES성명 */
		inDto.setResId(inVo.getSAGBSM02DSSDCVO().getResId()); 						/** SR주민번호_암호화 */
		inDto.setDsaRegiNo(inVo.getSAGBSM02DSSDCVO().getDsaRegiNo()); 				/** 상담사등록번호 */
		inDto.setSalesTeamGbCd(inVo.getSAGBSM02DSSDCVO().getSalesTeamGbCd()); 		/** SALES팀구분코드 */
		inDto.setResiDt(inVo.getSAGBSM02DSSDCVO().getResiDt()); 					/** 위촉일자 */
		inDto.setCloseDt(inVo.getSAGBSM02DSSDCVO().getCloseDt()); 					/** 해촉일자 */
		inDto.setCloseThinkCd(inVo.getSAGBSM02DSSDCVO().getCloseThinkCd()); 		/** 해촉사유구분코드 */
		inDto.setDsaEdcnDt(inVo.getSAGBSM02DSSDCVO().getDsaEdcnDt()); 				/** 상담사교육이수일자 */
		inDto.setMobArea(inVo.getSAGBSM02DSSDCVO().getMobArea()); 					/** 휴대폰지역번호 */
		inDto.setMobHeadNum(inVo.getSAGBSM02DSSDCVO().getMobHeadNum()); 			/** 휴대폰국번 */
		inDto.setMobSerialNum(inVo.getSAGBSM02DSSDCVO().getMobSerialNum()); 		/** 휴대폰일련번호 */
		inDto.setMailId(inVo.getSAGBSM02DSSDCVO().getMailId()); 					/** 이메일ID */
		inDto.setMailHostCd(inVo.getSAGBSM02DSSDCVO().getMailHostCd()); 			/** 이메일HOST코드 */
		inDto.setMailHostEtc(inVo.getSAGBSM02DSSDCVO().getMailHostEtc()); 			/** 이메일HOST기타 */
		inDto.setSalesMemo(inVo.getSAGBSM02DSSDCVO().getSalesMemo()); 				/** SALES메모 */
		inDto.setLogInEmpNo(inVo.getSAGBSM02DSSDCVO().getLogInEmpNo()); 			/** 로그인사원번호 */

		/** DB용 */
		inDto.setChgrSeqNo(inVo.getSAGBSM02DSSDCVO().getChgrSeqNo()); 				/** 변경일련번호 */
		inDto.setSalesGbCd(inVo.getSAGBSM02DSSDCVO().getSalesGbCd()); 				/** SALES구분코드 */
		inDto.setSalesPw(inVo.getSAGBSM02DSSDCVO().getSalesPw()); 					/** SALES비밀번호 */
		inDto.setDsaGbCd(inVo.getSAGBSM02DSSDCVO().getDsaGbCd()); 					/** DSA구분코드 */
		inDto.setSalesPosGbCd(inVo.getSAGBSM02DSSDCVO().getSalesPosGbCd()); 		/** SALES직급구분코드 */
		inDto.setSalesZipcd(inVo.getSAGBSM02DSSDCVO().getSalesZipcd()); 			/** SALES우편번호 */
		inDto.setSalesAddr(inVo.getSAGBSM02DSSDCVO().getSalesAddr()); 				/** SALES주소 */
		inDto.setSalesDetailAddr(inVo.getSAGBSM02DSSDCVO().getSalesDetailAddr()); 	/** SALES상세주소 */
		inDto.setStatusGbCd(inVo.getSAGBSM02DSSDCVO().getStatusGbCd()); 			/** 재직상태구분코드 */
		inDto.setRegiDt(inVo.getSAGBSM02DSSDCVO().getRegiDt()); 					/** 계약일자 */
		inDto.setExpyDt(inVo.getSAGBSM02DSSDCVO().getExpyDt()); 					/** 만기일자 */
		inDto.setCertifiGbCd(inVo.getSAGBSM02DSSDCVO().getCertifiGbCd()); 			/** 보증방식구분코드 */
		inDto.setCertifiExpyDt(inVo.getSAGBSM02DSSDCVO().getCertifiExpyDt()); 		/** 신원보증보험만기일자 */
		inDto.setCertifiAmt(inVo.getSAGBSM02DSSDCVO().getCertifiAmt()); 			/** 신원보증보험금액 */
		inDto.setGrntNm(inVo.getSAGBSM02DSSDCVO().getGrntNm()); 					/** 신원보증인성명 */
		inDto.setBankCd(inVo.getSAGBSM02DSSDCVO().getBankCd()); 					/** 결제은행코드 */
		inDto.setBankAccount(inVo.getSAGBSM02DSSDCVO().getBankAccount()); 			/** 결제계좌번호 */
		inDto.setBankDeposNm(inVo.getSAGBSM02DSSDCVO().getBankDeposNm()); 			/** 결제예금주명 */
		inDto.setTelcoCd(inVo.getSAGBSM02DSSDCVO().getTelcoCd()); 					/** 통신사코드 */
		inDto.setTelAreaNo(inVo.getSAGBSM02DSSDCVO().getTelAreaNo()); 				/** 전화지역번호 */
		inDto.setTelHeadNo(inVo.getSAGBSM02DSSDCVO().getTelHeadNo()); 				/** 전화국번호 */
		inDto.setTelSerialNo(inVo.getSAGBSM02DSSDCVO().getTelSerialNo()); 			/** 전화일련번호 */
		inDto.setTelInnerNo(inVo.getSAGBSM02DSSDCVO().getTelInnerNo()); 			/** 내선번호 */
		inDto.setFaxAreaNo(inVo.getSAGBSM02DSSDCVO().getFaxAreaNo()); 				/** FAX지역번호 */
		inDto.setFaxHeadNo(inVo.getSAGBSM02DSSDCVO().getFaxHeadNo()); 				/** FAX국번호 */
		inDto.setFaxSerialNo(inVo.getSAGBSM02DSSDCVO().getFaxSerialNo()); 			/** FAX일련번호 */
		inDto.setTrmYn(inVo.getSAGBSM02DSSDCVO().getTrmYn()); 						/** 단말기지급여부 */
		inDto.setTrmDcd(inVo.getSAGBSM02DSSDCVO().getTrmDcd()); 					/** 단말기구분코드 */
		inDto.setTrmImeNo(inVo.getSAGBSM02DSSDCVO().getTrmImeNo()); 				/** 단말기IME번호 */
		inDto.setTrmAreaNo(inVo.getSAGBSM02DSSDCVO().getTrmAreaNo()); 				/** 단말기지역번호 */
		inDto.setTrmHeadNo(inVo.getSAGBSM02DSSDCVO().getTrmHeadNo()); 				/** 단말기국번호 */
		inDto.setTrmSerialNo(inVo.getSAGBSM02DSSDCVO().getTrmSerialNo()); 			/** 단말기일련번호 */

		updResult = srMngMapper.modifySrMngList(inDto);

		if(updResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}
}
