package hanalife.s.ag.bs.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.ag.bs.service.SAGBSM02Service;
import hanalife.s.ag.bs.vo.SAGBSM02DSSDCVO;
import hanalife.s.ag.bs.vo.SAGBSM02DSSMVO;
import hanalife.s.ag.bs.vo.SAGBSM02I01InVO;
import hanalife.s.ag.bs.vo.SAGBSM02I01OutVO;
import hanalife.s.ag.bs.vo.SAGBSM02S01InVO;
import hanalife.s.ag.bs.vo.SAGBSM02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SAGBSM02Controller.java Class
 *
 * 클래스설명   : SR관리 (SAGBSM02) Controller
 * 작성일자     : 2023. 4. 12.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 12.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/ag/bs")
@Controller
public class SAGBSM02Controller {

	@Resource(name = "SAGBSM02Service")
	private SAGBSM02Service SAGBSM02;

	private static final Logger LOGGER = LoggerFactory.getLogger(SAGBSM02Controller.class);

	/**
	 * <p>메소드명      : SR관리 기관코드 조회 /SAGBSM02S01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR관리 기관코드 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM02S01.do")
	public String SAGBSM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** SR관리내역조회 업무 서비스 호출 수행 */
			SAGBSM02S01OutVO resultSAGBSM02S01 = SAGBSM02.getSAGBSM02S01();

			XFrame5Util.setOutputData("DS_CD_SR_ORG_CD", resultSAGBSM02S01.getSAGBSM02DSCDSRORGCDDTO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM02S01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM02S01.getRsltCntn());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SR관리 /SAGBSM02S01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM02S02.do")
	public String SAGBSM02S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** SR관리내역조회 업무 서비스 호출 입력값 대입 */
			SAGBSM02S01InVO targetVo = new SAGBSM02S01InVO();
			SAGBSM02DSSMVO smVo = new SAGBSM02DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setSAGBSM02DSSMVO(smVo);

			/** SR관리내역조회 업무 서비스 호출 수행 */
			SAGBSM02S01OutVO resultSAGBSM02S01 = SAGBSM02.getSAGBSM02S02(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSAGBSM02S01.getSAGBSM02DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM02S01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM02S01.getRsltCntn());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SR관리등록 /SAGBSM02I01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR관리 등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM02I01.do")
	public String SAGBSM02I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM02Controller SAGBSM02I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** SR관리내역조회 업무 서비스 호출 입력값 대입 */
			SAGBSM02I01InVO targetVo = new SAGBSM02I01InVO();
			SAGBSM02DSSDCVO sdcVo = new SAGBSM02DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSAGBSM02DSSDCVO(sdcVo);

			/** SR관리내역조회 업무 서비스 호출 수행 */
			SAGBSM02I01OutVO resultSAGBSM02I01 = SAGBSM02.registerSAGBSM02S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM02I01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM02I01.getRsltCntn());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SR관리수정 /SAGBSM02U01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR관리 수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM02U01.do")
	public String SAGBSM02U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM02Controller SAGBSM02U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** SR관리내역조회 업무 서비스 호출 입력값 대입 */
			SAGBSM02I01InVO targetVo = new SAGBSM02I01InVO();
			SAGBSM02DSSDCVO sdcVo = new SAGBSM02DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSAGBSM02DSSDCVO(sdcVo);

			/** SR관리내역조회 업무 서비스 호출 수행 */
			SAGBSM02I01OutVO resultSAGBSM02U01 = SAGBSM02.modifySAGBSM02S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM02U01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM02U01.getRsltCntn());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM02Controller SAGBSM02U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
