package hanalife.s.as.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.s.as.as.mapper.CnslListReadMapper;
import hanalife.s.as.as.mapper.dto.CnslListReadDSSDDTO;
import hanalife.s.as.as.mapper.dto.CnslListReadDSSMDTO;
import hanalife.s.as.as.service.SASASM01Service;
import hanalife.s.as.as.vo.SASASM01DSSDVO;
import hanalife.s.as.as.vo.SASASM01S01InVO;
import hanalife.s.as.as.vo.SASASM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SASASM01ServiceImpl.java Class
 * 클래스설명   : 상담목록조회 (SASASM01) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSASASM01S01 : 상담목록조회목록조회

 * </pre>
 */
@Service("SASASM01Service")
public class SASASM01ServiceImpl implements SASASM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SASASM01ServiceImpl.class);

	@Autowired
	private CnslListReadMapper cnslListReadMapper;

	/**
	 * <p>메소드명      : getSASASM01S01 : 상담목록조회</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 상담목록조회 한다.</p>
	 * <p>메소드인수    : SASASM01S01InVo </p>
	 * <p>메소드리턴값  : SASASM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SASASM01S01OutVO getSASASM01S01(SASASM01S01InVO inVo) throws Exception {

		SASASM01S01OutVO resultVo = new SASASM01S01OutVO();

		CnslListReadDSSMDTO inDto = new CnslListReadDSSMDTO();

		inDto.setCnslDtFr(inVo.getSASASM01DSSMVO().getCnslDtFr()); /** 상담일자시작 */
		inDto.setCnslDtTo(inVo.getSASASM01DSSMVO().getCnslDtTo()); /** 상담일자종료 */
		inDto.setChnlPrgsStatCd(inVo.getSASASM01DSSMVO().getChnlPrgsStatCd()); /** 모바일진행상태코드 */
		inDto.setChnlPrgsStatNm(inVo.getSASASM01DSSMVO().getChnlPrgsStatNm()); /** 모바일진행상태명 */

		List<CnslListReadDSSDDTO> resultDTO = cnslListReadMapper.searchCnslReadList(inDto);	/** 상담목록조회리스트*/

		List<SASASM01DSSDVO> resultList = new ArrayList<SASASM01DSSDVO>();

		for (CnslListReadDSSDDTO sourceIO : resultDTO) {
			SASASM01DSSDVO targetIO = new SASASM01DSSDVO();
			targetIO.setCnslDt(sourceIO.getCnslDt()); /** 상담일자 */
			targetIO.setCnslNo(sourceIO.getCnslNo()); /** 상담번호 */
			targetIO.setCustNo(sourceIO.getCustNo()); /** 고객번호 */
			targetIO.setCustNm(sourceIO.getCustNm()); /** 고객명 */
			targetIO.setCustResiNo(sourceIO.getCustResiNo()); /** 주민등록번호 */
			targetIO.setInitStrgRslt(sourceIO.getInitStrgRslt()); /** 초기전략결과 */
			targetIO.setMciEntrQlfcFg(sourceIO.getMciEntrQlfcFg()); /** MCI가입적격여부 */
			targetIO.setApplAmt(sourceIO.getApplAmt()); /** 신청금액 */
			targetIO.setLoanTerm(sourceIO.getLoanTerm()); /** 대출기간 */
			targetIO.setSrCustNo(sourceIO.getSrCustNo()); /** SR고객번호 */
			targetIO.setSrCustNm(sourceIO.getSrCustNm()); /** SR고객명 */
			targetIO.setChnlPrgsStatCd(sourceIO.getChnlPrgsStatCd()); /** 모바일진행상태코드 */
			targetIO.setChnlPrgsStatNm(sourceIO.getChnlPrgsStatNm()); /** 모바일진행상태명 */
			targetIO.setFamMembAgrFg(sourceIO.getFamMembAgrFg()); /** 세대원동의여부 */
			targetIO.setSrAgrFg(sourceIO.getSrAgrFg()); /** SR동의여부 */
			targetIO.setEsttAgrFg(sourceIO.getEsttAgrFg()); /** 부동산동의여부 */
			targetIO.setCnslCntn(sourceIO.getCnslCntn()); /** 상담내용 */

			resultList.add(targetIO);
		}

		resultVo.setSASASM01DSSDVO(resultList);	/** 상담목록조회리스트 */

		return resultVo;
	}

}
