package hanalife.s.cp.ct.service.impl;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.StCprtContDTO;
import hanalife.c.co.mapper.dto.StCprtLimChngHistDTO;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.mapper.dto.StLoanCprtBranDTO;
import hanalife.c.co.mapper.dto.StLoanDocDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.s.cp.ct.mapper.CprtContMngMdulCTMapper;
import hanalife.s.cp.ct.mapper.dto.CprtContMngMdulINDTO;
import hanalife.s.cp.ct.mapper.dto.SearchCprtLimOUTDTO;
import hanalife.s.cp.ct.mapper.dto.SearchLoanPrdtCdOUTDTO;
import hanalife.s.cp.ct.mapper.dto.SearchPrdtCdOUTDTO;
import hanalife.s.cp.ct.service.CprtContMngMudlService;
import hanalife.s.cp.ct.vo.CprtContMngMdulObj;



/**
 * <pre>
 * 클래스　명 : CprtContMngMudlServiceImpl
 * 클래스설명 : 제휴약정관리모듈ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("CprtContMngMudlService")
public class CprtContMngMudlServiceImpl implements CprtContMngMudlService {

	private static final Logger log = LoggerFactory.getLogger(CprtContMngMudlServiceImpl.class);

	@Autowired
	private CprtContMngMdulCTMapper cprtContMngMdulCTMapper;

	@Override
	public CprtContMngMdulObj searchCprtLim(CprtContMngMdulObj contMngMdulObj) throws Exception {
		//필수데이타 체크
		checkObjBlank("SEARCH", contMngMdulObj);

		//대출 상품 조회
		chkPrdtCd(contMngMdulObj);
		if (!contMngMdulObj.prdtLrgeClasCd.equals("1")) {
			contMngMdulObj.loanAblFg = "1";
			return contMngMdulObj;
		}

		//중고차 약정제외 2018-08-01 두비스
		if (contMngMdulObj.prdtMidClasCd.equals("02")) {
			contMngMdulObj.loanAblFg = "1";
			return contMngMdulObj;
		}

		//대출제휴점의 제휴약정 조회
		searchCprtCont(contMngMdulObj);
		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.cprtBranCd = "0";
			searchCprtCont(contMngMdulObj);
		}

		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "02";
			return contMngMdulObj;
		}

		//약정해지여부가 '1'
		if (contMngMdulObj.contClosFg.equals("1")) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "03";
			return contMngMdulObj;
		}

		//한도관리여부가 '0'
		if (contMngMdulObj.limMngFg.equals("0")) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "1";
			contMngMdulObj.ipssRsnCd = "00";
			return contMngMdulObj;
		}

		//한도잔액과 대출금 차액 계산
		long rAmt = contMngMdulObj.limRamt - contMngMdulObj.loanPamt;
		contMngMdulObj.limCnt = 0;

		if (rAmt >= 0) {
			contMngMdulObj.limRamt = rAmt;
			contMngMdulObj.loanAblFg = "1";
			contMngMdulObj.ipssRsnCd = "00";
			return contMngMdulObj;
		} else {
			contMngMdulObj.limRamt = rAmt;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "04";
			return contMngMdulObj;
		}
	}

	/**
	* <p>메소드명	: chkPrdtCd</p>
	* <p>설명		: 제휴한도 조회</p>
	* <p>메소드인수1	: String[] condArr - [0] : 제휴사번호
	        [1] : 제휴점코드
	        [2] : 상품코드
	        [3] : 대출금액</p>
	* <p>메소드인수2	: ITransaction tx - 트랜젝션 객체</p>
	* <p>메소드리턴값	: void </p>
	*/
	@Override
	public void chkPrdtCd(CprtContMngMdulObj contMdulObj) throws Exception {

		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setPrdtCd(contMdulObj.prdtCd);

			List<SearchPrdtCdOUTDTO> outDTO = cprtContMngMdulCTMapper.searchPrdtCd(inDTO);

			for (SearchPrdtCdOUTDTO sourceIO : outDTO) {
				contMdulObj.prdtLrgeClasCd = sourceIO.getLrgeClasCd();
				contMdulObj.prdtMidClasCd = sourceIO.getMidClasCd();
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("상품 코드 조회중 오류!!");
		}
	}

	/**
	* <p>메소드명	: updateCprtCont</p>
	* <p>설명		: 제휴약정 한도잔액 수정</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void updateCprtCont(CprtContMngMdulObj contMdulObj) throws Exception {
		int exeCnt = 0;

		StCprtContDTO inDTO = new StCprtContDTO();

		inDTO.setLimRamt(new BigDecimal(contMdulObj.limRamt));
		inDTO.setLastProcDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));
		inDTO.setLastProcTm(DateUtil.getServerDate(DateUtil.HHMMSS));
		inDTO.setLastProcEmpNo(contMdulObj.empNo);

		inDTO.setCprtComNo(contMdulObj.cprtComNo);
		inDTO.setCprtBranCd(contMdulObj.cprtBranCd);
		inDTO.setPrdtClasCd(contMdulObj.prdtLrgeClasCd + contMdulObj.prdtMidClasCd);


		try {
			exeCnt = cprtContMngMdulCTMapper.updateCprtLim(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - throw new Exception("제휴약정 한도 수정 중 오류");
			throw new Exception("제휴약정 한도 수정 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchCprtCont</p>
	* <p>설명		: 제휴약정 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void searchCprtCont(CprtContMngMdulObj contMdulObj) throws Exception {

		int limCnt = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setCprtComNo(contMdulObj.cprtComNo);
			inDTO.setPrdtCd(contMdulObj.prdtCd);
			inDTO.setCprtBranCd(contMdulObj.cprtBranCd);

			List<SearchCprtLimOUTDTO> outDTO = cprtContMngMdulCTMapper.searchCprtLim(inDTO);

			contMdulObj.limCnt = limCnt;
			for (SearchCprtLimOUTDTO sourceIO : outDTO) {
				contMdulObj.limMngFg = sourceIO.getLimMngFg();
				contMdulObj.limAmt = sourceIO.getLimAmt();
				contMdulObj.limRamt = sourceIO.getLimRamt();
				contMdulObj.prdtClasCd = sourceIO.getPrdtClasCd();
				contMdulObj.contClosFg = sourceIO.getContClosFg();
				limCnt += 1;
				contMdulObj.limCnt = limCnt;
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("제휴약정 조회 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchLoanPrdtCd</p>
	* <p>설명		: 대출 상품 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void searchLoanPrdtCd(CprtContMngMdulObj contMdulObj) throws Exception {
		int limCnt = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setLoanNo(contMdulObj.loanNo);
			inDTO.setLoanSeq(contMdulObj.loanSeq);

			List<SearchLoanPrdtCdOUTDTO> outDTO = cprtContMngMdulCTMapper.searchLoanPrdtCd(inDTO);

			contMdulObj.limCnt = limCnt;
			for (SearchLoanPrdtCdOUTDTO sourceIO : outDTO) {
				contMdulObj.prdtLrgeClasCd = sourceIO.getLrgeClasCd();
				contMdulObj.prdtMidClasCd = sourceIO.getMidClasCd();
				contMdulObj.prdtCd = sourceIO.getPrdtCd();
				contMdulObj.contManNo = sourceIO.getContManNo();
				limCnt += 1;
				contMdulObj.limCnt = limCnt;
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("대출상품 조회 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchRegLdgr</p>
	* <p>설명		: 대출 제휴점 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void searchRegLdgr(CprtContMngMdulObj contMdulObj) throws Exception {
		int limCnt = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setLoanNo(contMdulObj.loanNo);
			inDTO.setLoanSeq(contMdulObj.loanSeq);
			inDTO.setContManNo(contMdulObj.contManNo);

			List<StLoanDocDTO> outDTO = cprtContMngMdulCTMapper.searchRegLdgr(inDTO);

			contMdulObj.limCnt = limCnt;
			for (StLoanDocDTO sourceIO : outDTO) {
				contMdulObj.regLdgrFg = sourceIO.getRegLdgrFg();
				limCnt += 1;
				contMdulObj.limCnt = limCnt;
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("등록원부 조회 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchLoanAprvDt</p>
	* <p>설명		: 대출 승인일 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void searchLoanAprvDt(CprtContMngMdulObj contMdulObj) throws Exception {
		int limCnt = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setLoanNo(contMdulObj.loanNo);
			inDTO.setLoanSeq(contMdulObj.loanSeq);

			List<StLoanBaseDTO> outDTO = cprtContMngMdulCTMapper.searchLoanAprvDt(inDTO);

			contMdulObj.limCnt = limCnt;
			for (StLoanBaseDTO sourceIO : outDTO) {
				contMdulObj.loanPamt = sourceIO.getLoanContAmt().longValue();
				contMdulObj.aprvDt = sourceIO.getAprvDt();
				limCnt += 1;
				contMdulObj.limCnt = limCnt;
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("대출승인일 조회 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchLoanCprtBran</p>
	* <p>설명		: 대출 제휴점 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void searchLoanCprtBran(CprtContMngMdulObj contMdulObj) throws Exception {
		int limCnt = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setLoanNo(contMdulObj.loanNo);
			inDTO.setLoanSeq(contMdulObj.loanSeq);

			List<StLoanCprtBranDTO> outDTO = cprtContMngMdulCTMapper.searchLoanCprtBran(inDTO);

			contMdulObj.limCnt = limCnt;
			for (StLoanCprtBranDTO sourceIO : outDTO) {
				contMdulObj.cprtComNo = sourceIO.getCprtComNo();
				contMdulObj.cprtBranCd = sourceIO.getCprtBranCd();
				limCnt += 1;
				contMdulObj.limCnt = limCnt;
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("대출제휴점 조회 중 오류");
		}
	}

	/**
	* <p>메소드명	: searchMaxSnum</p>
	* <p>설명		: 한도증감이력 MAX Snum 조회</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private int searchMaxSnum(CprtContMngMdulObj contMdulObj) throws Exception {
		int maxSnum = 0;
		try {
			CprtContMngMdulINDTO inDTO = new CprtContMngMdulINDTO();
			inDTO.setCprtComNo(contMdulObj.cprtComNo);
			inDTO.setCprtBranCd(contMdulObj.cprtBranCd);
			inDTO.setPrdtClasCd(contMdulObj.prdtClasCd);

			maxSnum = cprtContMngMdulCTMapper.searchMaxSnum(inDTO);

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("한도증감이력 일련번호 조회 중 오류");
		}
		return maxSnum;
	}

	/**
	* <p>메소드명	: insertLimChngHist</p>
	* <p>설명		: 한도증감이력 등록</p>
	* <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	* <p>메소드인수2	: Connection con</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void insertLimChngHist(CprtContMngMdulObj contMdulObj, int snum, String incrFg) throws Exception {

		int exeCnt = 0;

		StCprtLimChngHistDTO inDTO = new StCprtLimChngHistDTO();

		inDTO.setCprtComNo(contMdulObj.cprtComNo); // 제휴사번호
		inDTO.setCprtBranCd(contMdulObj.cprtBranCd); // 제휴점코드
		inDTO.setPrdtClasCd(contMdulObj.prdtClasCd); // 상품분류코드
		inDTO.setChngBfLimAmt(new BigDecimal(contMdulObj.limAmt)); // con한도금액
		inDTO.setLimAmt(new BigDecimal(contMdulObj.limRamt)); // 한도잔액
		inDTO.setSnum(snum); // 일련번호
		inDTO.setIncrAmtFg(incrFg); // 한도증감여부
		inDTO.setFrstRegDt(DateUtil.getServerDate(DateUtil.YYYYMMDD)); // 최초등록일자
		inDTO.setFrstRegTm(DateUtil.getServerDate(DateUtil.HHMMSS)); // 최초등록시간
		inDTO.setFrstRegEmpNo(contMdulObj.empNo); // 최초등록사원번호

		try {
			exeCnt = cprtContMngMdulCTMapper.insertCprtLimChng(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - throw new Exception("제휴약정한도증감이력 등록중 오류!!");
			throw new Exception("제휴약정한도증감이력 등록중 오류!!");
		}
	}

	/**
	* <p>메소드명	: updateCprtLim</p>
	* <p>설명		: 제휴한도 조회</p>
	* <p>메소드인수1	: String[] condArr - [0] : 업무구분
	        [1] : 대출번호
	        [2] : 대출순번
	        [3] : 금액
	        [4] : 처리자사원번호</p>
	* <p>메소드인수2	: ITransaction tx - 트랜젝션 객체</p>
	* <p>메소드리턴값	: CprtContMngMdulObj contMngMdulObj </p>
	*/
	@Override
	public CprtContMngMdulObj updateCprtLim(CprtContMngMdulObj contMngMdulObj) throws Exception {
		String incrFg = "0";
		long rAmt = 0;

		// 필수데이타 체크
		checkObjBlank("UPDATE", contMngMdulObj);

		// 대출상품 검색
		searchLoanPrdtCd(contMngMdulObj);

		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "05";
			return contMngMdulObj;
		} else {
			if (!contMngMdulObj.prdtLrgeClasCd.equals("1")) {
				contMngMdulObj.loanAblFg = "1";
				return contMngMdulObj;
			}

			// 중고차 약정제외 2018-08-01 두비스
			if (contMngMdulObj.prdtMidClasCd.equals("02")) {
				contMngMdulObj.loanAblFg = "1";
				return contMngMdulObj;
			}
		}

		// 대출제휴점 검색
		searchLoanCprtBran(contMngMdulObj);
		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "06";
			return contMngMdulObj;
		}

		searchCprtCont(contMngMdulObj);
		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.cprtBranCd = "0";
			searchCprtCont(contMngMdulObj);
		}

		if (contMngMdulObj.limCnt == 0) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "02";
			return contMngMdulObj;
		}

		// 승인처리 및 대출확정
		if (contMngMdulObj.bizDivCd.equals("1")) {
			if (contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo)) {
				incrFg = "0";
			} else {
				searchRegLdgr(contMngMdulObj);
				if (contMngMdulObj.limCnt == 0) {
					incrFg = "0";
				} else {
					if (contMngMdulObj.regLdgrFg.equals("1")) {
						contMngMdulObj.loanAblFg = "1";
						return contMngMdulObj;
					} else if (contMngMdulObj.regLdgrFg.equals("0")) {
						incrFg = "0";
					}
				}
			}
		} else if (contMngMdulObj.bizDivCd.equals("2")) {
			// 승인취소 및 대출취소
			if (contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo)) {
				incrFg = "1";
			} else {
				searchRegLdgr(contMngMdulObj);
				if (contMngMdulObj.limCnt == 0) {
					incrFg = "1";
				} else {
					if (contMngMdulObj.regLdgrFg.equals("1")) {
						contMngMdulObj.loanAblFg = "1";
						return contMngMdulObj;
					} else if (contMngMdulObj.regLdgrFg.equals("0")) {
						incrFg = "1";
					}
				}
			}
		} else if (contMngMdulObj.bizDivCd.equals("3")) {
			// 등록원부 등록
			searchLoanAprvDt(contMngMdulObj);
			if (contMngMdulObj.limCnt == 0) {
				contMngMdulObj.limAmt = 0;
				contMngMdulObj.limRamt = 0;
				contMngMdulObj.loanAblFg = "0";
				contMngMdulObj.ipssRsnCd = "05";
				return contMngMdulObj;
			} else {
				if (contMngMdulObj.aprvDt == null || contMngMdulObj.aprvDt.equals("")) {
					contMngMdulObj.loanAblFg = "1";
					return contMngMdulObj;
				} else {
					if (!contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo)) {
						incrFg = "1";
					}
				}
			}
		} else if (contMngMdulObj.bizDivCd.equals("4")) {
			// 등록원부 등록 취소
			searchLoanAprvDt(contMngMdulObj);
			if (contMngMdulObj.limCnt == 0) {
				contMngMdulObj.limAmt = 0;
				contMngMdulObj.limRamt = 0;
				contMngMdulObj.loanAblFg = "0";
				contMngMdulObj.ipssRsnCd = "05";
				return contMngMdulObj;
			} else {
				if (contMngMdulObj.aprvDt == null || contMngMdulObj.aprvDt.equals("")) {
					contMngMdulObj.loanAblFg = "1";
					return contMngMdulObj;
				} else {
					if (!contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo))
						incrFg = "0";
				}
			}
		} else if (contMngMdulObj.bizDivCd.equals("5")) {
			// 수납처리
			if (contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo)) {
				incrFg = "1";
			} else {
				contMngMdulObj.loanAblFg = "1";
				return contMngMdulObj;
			}
		} else if (contMngMdulObj.bizDivCd.equals("6")) {
			// 수납취소
			if (contMngMdulObj.contManNo.equals(contMngMdulObj.cprtComNo)) {
				incrFg = "0";
			} else {
				contMngMdulObj.loanAblFg = "1";
				return contMngMdulObj;
			}
		} else {
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "06";
			return contMngMdulObj;
		}

		// 업무구분이 '1', 약정해지여부가 '1'
		if (contMngMdulObj.bizDivCd.equals("1") && contMngMdulObj.contClosFg.equals("1")) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "08";
			return contMngMdulObj;
		}

		// 한도관리여부가 '0'
		if (contMngMdulObj.limMngFg.equals("0")) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "1";
			contMngMdulObj.ipssRsnCd = "00";
			return contMngMdulObj;
		}

		// 증가여부 '1'-> 한도잔액=한도잔액 + 금액/'0'-> 한도잔액=한도잔액-금액
		if (incrFg.equals("1")) {
			rAmt = contMngMdulObj.limRamt + contMngMdulObj.loanPamt;
		} else if (incrFg.equals("0")) {
			rAmt = contMngMdulObj.limRamt - contMngMdulObj.loanPamt;
		}

		if (rAmt < 0 || contMngMdulObj.limAmt < contMngMdulObj.limRamt) {
			contMngMdulObj.limAmt = 0;
			contMngMdulObj.limRamt = 0;
			contMngMdulObj.loanAblFg = "0";
			contMngMdulObj.ipssRsnCd = "09";
			return contMngMdulObj;
		}

		contMngMdulObj.limRamt = rAmt;

		// 한도 수정 처리
		updateCprtCont(contMngMdulObj);

		// 한도증감이력 처리
		int maxSnum = searchMaxSnum(contMngMdulObj);
		insertLimChngHist(contMngMdulObj, maxSnum + 1, incrFg);

		contMngMdulObj.loanAblFg = "1";
		contMngMdulObj.ipssRsnCd = "00";

		return contMngMdulObj;
	}

	/**
	* <p>메소드명	: checkObjBlank</p>
	* <p>설명		: 한도약정체크에서 필요한 필수데이타를 체크 한다.</p>
	* <p>메소드인수1	: DfeeRtObj dfeeRtObj</p>
	* <p>메소드리턴값	: N/A</p>
	*/
	private void checkObjBlank(String procDiv, CprtContMngMdulObj contMdulObj) throws Exception {
		// 데이터 필수입력 체크

		if (procDiv.equals("UPDATE")) {
			if (contMdulObj.bizDivCd == null || contMdulObj.bizDivCd.equals("")) {
				throw new Exception("[제휴약정한도수정] 업무구분을 찾을 수 없습니다.");
			}
			if (contMdulObj.loanNo == null || contMdulObj.loanNo.equals("")) {
				throw new Exception("[제휴약정한도수정] 대출번호를 찾을 수 없습니다.");
			}
			if (contMdulObj.loanSeq == null || contMdulObj.loanSeq.equals("")) {
				throw new Exception("[제휴약정한도수정] 대출순번을 찾을 수 없습니다.");
			}

			if (!(contMdulObj.bizDivCd.equals("3") || contMdulObj.bizDivCd.equals("4"))) {
				if (contMdulObj.loanPamt == 0) {
					throw new Exception("[제휴약정한도수정] 대출금액을 찾을 수 없습니다.");
				}
			}
		} else {
			if (contMdulObj.cprtComNo == null || contMdulObj.cprtComNo.equals("")) {
				throw new Exception("[제휴약정한도조회] 제휴사번호를 찾을 수 없습니다.");
			}
			if (contMdulObj.cprtBranCd == null || contMdulObj.cprtBranCd.equals("")) {
				throw new Exception("[제휴약정한도조회] 제휴점코드를 찾을 수 없습니다.");
			}
			if (contMdulObj.prdtCd == null || contMdulObj.prdtCd.equals("")) {
				throw new Exception("[제휴약정한도조회] 상품코드를 찾을 수 없습니다.");
			}
			if (contMdulObj.loanPamt == 0) {
				throw new Exception("[제휴약정한도조회] 대출금액을 찾을 수 없습니다.");
			}

		}
	}
}
