package hanalife.s.ln.pm.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.StDferIncdPrftBaseDTO;
import hanalife.c.co.mapper.dto.StDferIncdPrftDescDTO;
import hanalife.c.co.mapper.dto.StDferIncdPrftDistDescDTO;
import hanalife.c.co.mapper.dto.StRmbrPlanDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.s.ln.lm.service.RmbrPlanCrteService;
import hanalife.s.ln.lm.vo.LoanBaseObj;
import hanalife.s.ln.lm.vo.LoanPiamtObj;
import hanalife.s.ln.lm.vo.RmbrPlanObj;
import hanalife.s.ln.pm.mapper.DferIncdPrftMapper;
import hanalife.s.ln.pm.mapper.dto.LoanBaseReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanBaseReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.LoanChngConsReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanChngConsReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.LoanPayDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanPayDescReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.PrFeePayDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.PrFeePayDescReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.SelectTrtDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.SelectTrtDescReadOUTDTO;
import hanalife.s.ln.pm.service.DferIncdPrftCrteService;
import hanalife.s.ln.pm.vo.DferIncdPrftBaseObj;
import hanalife.s.ln.pm.vo.DferIncdPrftDescObj;

/**
 * <pre>
 * 클래스　명 : DferIncdPrftCrteServImpl
 * 클래스설명 : DferIncdPrftCrteServImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [	변경일자	][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("DferIncdPrftCrteService")
public class DferIncdPrftCrteServiceImpl implements DferIncdPrftCrteService {

	private static final Logger log = LoggerFactory.getLogger(DferIncdPrftCrteServiceImpl.class);
	@Autowired
	private DferIncdPrftMapper dferIncdPrftMapper;
	@Autowired
	private RmbrPlanCrteService rmbrPlanCrteService;

	/**
	 * <P>메소드명 : callDfreIncdPrftCrte</P>
	 * <P>설명 : 대출기본 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 사용자사번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	@Override
	public void callDfreIncdPrftCrte(String loanNo, String loanSeq, String empNo) throws Exception {
		// 대출번호,순번을 조건으로 대출기본,상품기본 조회
		DferIncdPrftBaseObj obj = loanBaseRead(loanNo, loanSeq);
		obj.empNo = empNo;
		obj.minusFlag = false;

		// 3개월이하면 생성 안함
		/*
		 * if (obj.loanTerm <= 3) { return; }
		 */

		// 제휴수수료 이연처리
		if ("1".equals(obj.cprtFeeDferProcFg) && obj.cprtFee != 0) {
			obj.dferIncdPrftDivCd = "1"; // 제휴수수료
			if (obj.cprtFee < 0) {
				obj.minusFlag = true; // 저장시 - 로 변환
				obj.totAmt = obj.cprtFee * -1;
			} else {
				obj.totAmt = obj.cprtFee; // 이연처리총금액
			}

			// 상환계획시뮬레이션,내부수익율
			List descList = rmbrPlanSimul(obj);

			// 이연스케줄 생성
			makeDferIncdPrftDesc(obj, descList);

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);
			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}
		// 취급수수료 이연처리 여부
		if ("1".equals(obj.trtFeeDferProcFg) && obj.trtFee != 0) {
			obj.dferIncdPrftDivCd = "3"; // 취급수수료
			if (obj.trtFee < 0) {
				obj.minusFlag = true; // 저장시 - 로 변환
				obj.totAmt = obj.trtFee * -1;
			} else {
				obj.minusFlag = false;
				obj.totAmt = obj.trtFee; // 이연처리총금액
			}

			// 상환계획조회
			List descList = rmbrPlanDescRead(obj);

			// 이연스케줄 생성
			makeIntRateDferIncdPrftDesc(obj, descList);

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);
			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}

		// 주택,부동산 중 설정+권원 회사부담인 경우 이연스케줄 생성(비용이므로 - 가 기본)
		if ((obj.prdtMidClasCd.trim().equals("10") || obj.prdtMidClasCd.trim().equals("11")) && obj.setFee != 0) {
			obj.dferIncdPrftDivCd = "4"; // 설정+권원
			if (obj.setFee < 0) {
				obj.minusFlag = false;
				obj.totAmt = obj.setFee * -1;
			} else {
				obj.minusFlag = true; // 저장시 - 로 변환
				obj.totAmt = obj.setFee; // 이연처리총금액
			}

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);

			// 상환계획조회
			List descList = rmbrPlanDescRead(obj);

			// 이연스케줄 생성
			makeIntRateDferIncdPrftDesc(obj, descList);

			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}
	}

	private static void makeDferIncdPrftDesc(DferIncdPrftBaseObj obj, List descList) throws Exception {
		int size = descList.size();

		// 현가 = 대출원금 - 처리금액(수수료)
		long cprce = obj.loanPamt - obj.totAmt;
		// long cprce = obj.loanPamt;
		// 월처리금액합계
		long totDiscDifAmt = 0;
		// 회차 증가 변수
		int addTims = 0;

		for (int i = 0; i < size; i++) {
			DferIncdPrftDescObj descObj = (DferIncdPrftDescObj) descList.get(i);
			// 회차 재설정
			descObj.tims = descObj.tims + addTims;
			// 처리예정일자
			descObj.procSchdDt = DateUtil.lastDayOfMonth(descObj.dueDt);
			// 잔여 현가
			descObj.balCprce = cprce;
			// descObj.balCprce = cprce - (obj.totAmt - totDiscDifAmt);

			if (totDiscDifAmt == obj.totAmt) {
				continue;
			}

			// 유효 이자
			descObj.vald_int = (long) Math.floor(descObj.balCprce * (obj.intnPrftRt * 0.01) / 12);
			/*
			 * if (descObj.tims == 1 && !"1".equals(obj.fcntMopaCalcFg)) { descObj.vald_int
			 * = (long) Math.floor(descObj.balCprce * (obj.intnPrftRt * 0.01) *
			 * DateUtil.daysBetween(obj.loanDt, descObj.dueDt) / 365); } else {
			 * descObj.vald_int = (long) Math.floor(descObj.balCprce * (obj.intnPrftRt *
			 * 0.01) / 12); } System.out.print(" * 회차 : " + descObj.tims);
			 * System.out.print(" * 유효 이자 : " + descObj.vald_int);
			 * System.out.print(" * 월 이자 : " + descObj.mm_int);
			 */
			// 할인차금
			if (i == size - 1) {
				// 종료회차일때 월처리금액 = 총금액-월처리금액합계
				descObj.discDifAmt = obj.totAmt - totDiscDifAmt;
			} else {
				descObj.discDifAmt = descObj.vald_int - descObj.mm_int;
			}

			cprce = cprce + descObj.discDifAmt - descObj.mm_pamt;
			if (descObj.discDifAmt < 0) {
				descObj.discDifAmt = Math.abs(descObj.discDifAmt);
				// descObj.discDifAmt = 0;
			}
			// 월처리금액합계
			totDiscDifAmt += descObj.discDifAmt;

			if ((obj.totAmt > 0 && totDiscDifAmt > obj.totAmt) || (obj.totAmt < 0 && totDiscDifAmt < obj.totAmt)) {
				descObj.discDifAmt = obj.totAmt - (totDiscDifAmt - descObj.discDifAmt);
				totDiscDifAmt = obj.totAmt;
			}

			// System.out.println(" * 월처리금액 : " + descObj.discDifAmt);
			// 잔여현가 = 잔여현가+할인차금-월원금
			// cprce = cprce + descObj.discDifAmt - descObj.mm_pamt;
			// cprce = cprce - descObj.mm_pamt;

			// System.out.println(" * 잔여현가 : " + cprce);

			// 1회차의 경우 대출일자 와 초회납입일의 달이 틀릴 경우
			// (납일일자 이전의 비어있는 달의 회차를 생성) : 2018-08-01 추가 (이재진차장님요청)
			if (descObj.tims == 1) {
				addTims = DateUtil.monthsBetween(obj.loanDt.substring(0, 6), descObj.procSchdDt.substring(0, 6),
						"yyyyMM");
				if (addTims > 0) {
					String calcStrtDt = obj.loanDt;
					long fcntDiscDifAmt = descObj.discDifAmt;
					for (int j = 0; j < addTims; j++) {
						DferIncdPrftDescObj fcntDescObj = new DferIncdPrftDescObj();
						fcntDescObj.loanNo = descObj.loanNo;
						fcntDescObj.loanSeq = descObj.loanSeq;
						fcntDescObj.dferIncdPrftDivCd = descObj.dferIncdPrftDivCd;
						fcntDescObj.tims = j + 1; // 회차
						fcntDescObj.dueDt = descObj.dueDt;
						fcntDescObj.procSchdDt = DateUtil.lastDayOfMonth(DateUtil.addMonth(obj.loanDt, j));

						// 초회의 기간분으로 기간을 나누어서 월처리금액 생성
						fcntDescObj.discDifAmt = (long) Math.floor(
								fcntDiscDifAmt * ((double) DateUtil.daysBetween(calcStrtDt, fcntDescObj.procSchdDt)
										/ (double) DateUtil.daysBetween(obj.loanDt, descObj.procSchdDt)));

						// 계산시작일 변경
						calcStrtDt = fcntDescObj.procSchdDt;

						if ((obj.totAmt > 0 && fcntDescObj.discDifAmt < 0)
								|| (obj.totAmt < 0 && fcntDescObj.discDifAmt > 0)) {
							fcntDescObj.discDifAmt = 0;
						}
						descList.add(fcntDescObj);
						// 할인차금 차감
						descObj.discDifAmt = descObj.discDifAmt - fcntDescObj.discDifAmt;
					}
					// 기존 1 회차 재설정
					descObj.tims = descObj.tims + addTims;
					// System.out.print(" * tims : " + descObj.tims);
					// System.out.print(" * fcntDiscDifAmt : " + fcntDiscDifAmt);
					// System.out.print(" * descObj.discDifAmt : " + descObj.discDifAmt);
				}
			}
		}
	}

	private static void makeIntRateDferIncdPrftDesc(DferIncdPrftBaseObj obj, List descList) throws Exception {
		int size = descList.size();

		// 월처리금액합계
		long totDiscDifAmt = 0;
		// 회차 증가 변수
		int addTims = 0;

		for (int i = 0; i < size; i++) {
			DferIncdPrftDescObj descObj = (DferIncdPrftDescObj) descList.get(i);
			// 회차 재설정
			descObj.tims = descObj.tims + addTims;
			// 처리예정일자
			descObj.procSchdDt = DateUtil.lastDayOfMonth(descObj.dueDt);

			if (totDiscDifAmt == obj.totAmt) {
				continue;
			}

			// 유효 이자

			if (obj.totLoanInt == 0) {
				descObj.vald_int = (long) Math.floor(obj.totAmt * descObj.mm_pamt / obj.loanPamt);

			} else {
				descObj.vald_int = (long) Math.floor(obj.totAmt * descObj.mm_int / obj.totLoanInt);
			}

			/*
			 * if (descObj.tims == 1 && !"1".equals(obj.fcntMopaCalcFg)) { descObj.vald_int
			 * = (long) Math.floor(descObj.balCprce * (obj.intnPrftRt * 0.01) *
			 * DateUtil.daysBetween(obj.loanDt, descObj.dueDt) / 365); } else {
			 * descObj.vald_int = (long) Math.floor(descObj.balCprce * (obj.intnPrftRt *
			 * 0.01) / 12); } System.out.print(" * 회차 : " + descObj.tims);
			 * System.out.print(" * 유효 이자 : " + descObj.vald_int);
			 * System.out.print(" * 월 이자 : " + descObj.mm_int);
			 */
			// 할인차금
			if (i == size - 1) {
				// 종료회차일때 월처리금액 = 총금액-월처리금액합계
				descObj.discDifAmt = obj.totAmt - totDiscDifAmt;
			} else {
				descObj.discDifAmt = descObj.vald_int;
			}

			if (descObj.discDifAmt < 0) {
				descObj.discDifAmt = Math.abs(descObj.discDifAmt);
				// descObj.discDifAmt = 0;
			}
			// 월처리금액합계
			totDiscDifAmt += descObj.discDifAmt;

			if ((obj.totAmt > 0 && totDiscDifAmt > obj.totAmt) || (obj.totAmt < 0 && totDiscDifAmt < obj.totAmt)) {
				descObj.discDifAmt = obj.totAmt - (totDiscDifAmt - descObj.discDifAmt);
				totDiscDifAmt = obj.totAmt;
			}

			// System.out.println(" * 월처리금액 : " + descObj.discDifAmt);
			// 잔여현가 = 잔여현가+할인차금-월원금
			// cprce = cprce + descObj.discDifAmt - descObj.mm_pamt;
			// cprce = cprce - descObj.mm_pamt;

			// System.out.println(" * 잔여현가 : " + cprce);

			// 1회차의 경우 대출일자 와 초회납입일의 달이 틀릴 경우
			// (납일일자 이전의 비어있는 달의 회차를 생성) : 2018-08-01 추가 (이재진차장님요청)
			if (descObj.tims == 1) {
				addTims = DateUtil.monthsBetween(obj.loanDt.substring(0, 6), descObj.procSchdDt.substring(0, 6),
						"yyyyMM");
				if (addTims > 0) {
					String calcStrtDt = obj.loanDt;
					long fcntDiscDifAmt = descObj.discDifAmt;
					for (int j = 0; j < addTims; j++) {
						DferIncdPrftDescObj fcntDescObj = new DferIncdPrftDescObj();
						fcntDescObj.loanNo = descObj.loanNo;
						fcntDescObj.loanSeq = descObj.loanSeq;
						fcntDescObj.dferIncdPrftDivCd = descObj.dferIncdPrftDivCd;
						fcntDescObj.tims = j + 1; // 회차
						fcntDescObj.dueDt = descObj.dueDt;
						fcntDescObj.procSchdDt = DateUtil.lastDayOfMonth(DateUtil.addMonth(obj.loanDt, j));

						// 초회의 기간분으로 기간을 나누어서 월처리금액 생성
						fcntDescObj.discDifAmt = (long) Math.floor(
								fcntDiscDifAmt * ((double) DateUtil.daysBetween(calcStrtDt, fcntDescObj.procSchdDt)
										/ (double) DateUtil.daysBetween(obj.loanDt, descObj.procSchdDt)));

						// 계산시작일 변경
						calcStrtDt = fcntDescObj.procSchdDt;

						if ((obj.totAmt > 0 && fcntDescObj.discDifAmt < 0)
								|| (obj.totAmt < 0 && fcntDescObj.discDifAmt > 0)) {
							fcntDescObj.discDifAmt = 0;
						}
						descList.add(fcntDescObj);
						// 할인차금 차감
						descObj.discDifAmt = descObj.discDifAmt - fcntDescObj.discDifAmt;
					}
					// 기존 1 회차 재설정
					descObj.tims = descObj.tims + addTims;
					// System.out.print(" * tims : " + descObj.tims);
					// System.out.print(" * fcntDiscDifAmt : " + fcntDiscDifAmt);
					// System.out.print(" * descObj.discDifAmt : " + descObj.discDifAmt);
				}
			}
		}
	}

	/**
	 * <P>메소드명 : rmbrPlanDescRead</P>
	 * <P>설명 : 회차별 상환계획 조회</P>
	 * <P>메소드인수1 : DferIncdPrftBaseObj</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List rmbrPlanDescRead(DferIncdPrftBaseObj obj) throws Exception {
		// 대출번호, 대출순번으로 상환계획내역의 회차별 합계 조회
		List descList = new ArrayList();

		try {
			StRmbrPlanDescDTO inDTO = new StRmbrPlanDescDTO();
			inDTO.setLoanNo(obj.loanNo);
			inDTO.setLoanSeq(obj.loanSeq);

			List<StRmbrPlanDescDTO> outDTO = dferIncdPrftMapper.rmbrPlanDescRead(inDTO);

			for (StRmbrPlanDescDTO sourceIO : outDTO) {
				DferIncdPrftDescObj descObj = new DferIncdPrftDescObj();
		        descObj.loanNo = obj.loanNo;
		        descObj.loanSeq = obj.loanSeq;
		        descObj.dferIncdPrftDivCd = obj.dferIncdPrftDivCd;
		        descObj.tims = (int)sourceIO.getTims();
		        descObj.dueDt = sourceIO.getDueDt();
		        descObj.mm_pamt = sourceIO.getMmPamt().longValue();
		        descObj.mm_int = sourceIO.getMmInt().longValue();

		        obj.totLoanInt += descObj.mm_int;

				descList.add(descObj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [상환계획] 조회 오류!");
		}
		return descList;
	}

	/**
	 * <P>메소드명 : loanBaseRead</P>
	 * <P>설명 : 대출기본 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	private DferIncdPrftBaseObj loanBaseRead(String loanNo, String loanSeq) throws Exception {
		DferIncdPrftBaseObj obj = null;

		try {
			LoanBaseReadINDTO inDTO = new LoanBaseReadINDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);

			LoanBaseReadOUTDTO outDTO = dferIncdPrftMapper.loanBaseRead(inDTO);

			if (outDTO != null) {
				obj = new DferIncdPrftBaseObj();

		        obj.loanNo = loanNo;
		        obj.loanSeq = loanSeq;
		        obj.trtFeeDferProcFg   = outDTO.getTrtFeeDferProcFg();
		        obj.cprtFeeDferProcFg  = outDTO.getCprtFeeDferProcFg();
		        obj.trtFee             = outDTO.getTrtFee();
		        obj.cprtFee            = outDTO.getCprtFee();
		        obj.loanTerm           = outDTO.getLoanTerm();
		        obj.loanPamt           = outDTO.getLoanPamt();
		        obj.loanStatCd         = outDTO.getLoanStatCd();
		        obj.intnPrftRt         = outDTO.getIntnPrftRt();
		        obj.loanDt             = outDTO.getLoanDt();
		        obj.fcntMopaCalcFg     = outDTO.getFcntMopaCalcFg();
		        obj.payDt              = outDTO.getPayDt();
		        obj.prdtLrgeClasCd     = outDTO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd      = outDTO.getPrdtMidClasCd();
		        obj.setFee             = outDTO.getSetFee();
		        obj.fcntDueDt          = outDTO.getFcntDueDt();
		        obj.loanIntRt          = outDTO.getLoanIntRt();

				if (obj.payDt == null || obj.payDt.trim().equals("")) {
					obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
				}
				if (obj.loanDt == null || obj.loanDt.trim().equals("")) {
					obj.loanDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
				}
			}

			return obj;
		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [대출기본] 조회 오류!");
		}
	}

	/**
	 * <P>메소드명 : dferIncdPrftBaseCrte</P>
	 * <P>설명 : 이연부대수익기본 저장</P>
	 * <P>메소드인수1 : DferIncdPrftBaseObj</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private void dferIncdPrftBaseCrte(DferIncdPrftBaseObj obj) throws Exception {

		int exeCnt = 0;

		try {

			StDferIncdPrftBaseDTO inDTO = new StDferIncdPrftBaseDTO();

			// 시스템일자
			String yyyymmdd = DateUtil.getServerDate(DateUtil.YYYYMMDD);
			// 시스템시간
			String hhmmss = DateUtil.getServerDate(DateUtil.HHMMSS);
			// 일련번호 조회
			obj.snum = maxSnumRead(obj.loanNo, obj.loanSeq, obj.dferIncdPrftDivCd);

			inDTO.setLoanNo(obj.loanNo);//대출번호
			inDTO.setLoanSeq(obj.loanSeq);//대출순번
			inDTO.setDferIncdPrftDivCd(obj.dferIncdPrftDivCd);//이연처리구분
			inDTO.setSnum(obj.snum);//일련번호
			inDTO.setOccrDt(yyyymmdd);//발생일자
			inDTO.setLoanTerm(obj.loanTerm);//대출기간
			inDTO.setTotAmt(new BigDecimal(obj.minusFlag?obj.totAmt*-1:obj.totAmt));//이연처리금액(총금액)
			inDTO.setPreProcTims(0);//기처리회차
			inDTO.setPreProcAmt(new BigDecimal(0));//기처리금액
			inDTO.setBalAmt(new BigDecimal(obj.minusFlag?obj.totAmt*-1:obj.totAmt));//총금액
			inDTO.setLoanStatCd(obj.loanStatCd);//대출상태코드
			inDTO.setLoanEndDt(" ");
			inDTO.setLoanEndCnclDt(" ");
			inDTO.setCmplFg("0");
			inDTO.setCmplDt(" ");
			inDTO.setFrstRegDt(yyyymmdd);//최초등록일자
			inDTO.setFrstRegTm(hhmmss);//최초등록시간
			inDTO.setFrstRegEmpNo(StringUtil.trimToStr(obj.empNo));//최초등록자사번
			inDTO.setLastProcDt(yyyymmdd);//최종처리일자
			inDTO.setLastProcTm(hhmmss);//최종처리시간
			inDTO.setLastProcEmpNo(StringUtil.trimToStr(obj.empNo));//최종처리자사번

			exeCnt = dferIncdPrftMapper.dferIncdPrftBaseCrte(inDTO);

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [이연부대수익기본] 저장 오류! : " + e.getMessage());
		}
	}

	/**
	 * <P>메소드명 : dferIncdPrftDescCrte</P>
	 * <P>설명 : 이연부대수익내역 저장</P>
	 * <P>메소드인수1 : DferIncdPrftBaseObj</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private void dferIncdPrftDescCrte(DferIncdPrftBaseObj obj, List descList) throws Exception {

		try {
			int exeCnt = 0;

			String yyyymmdd = DateUtil.getServerDate(DateUtil.YYYYMMDD);
			String hhmmss = DateUtil.getServerDate(DateUtil.HHMMSS);

			for (int i = 0; i < descList.size(); i++) {
				DferIncdPrftDescObj descObj = (DferIncdPrftDescObj) descList.get(i);
				StDferIncdPrftDescDTO inDTO = new StDferIncdPrftDescDTO();

				inDTO.setLoanNo(obj.loanNo); //대출번호
				inDTO.setLoanSeq(obj.loanSeq); //대출순번
				inDTO.setDferIncdPrftDivCd(obj.dferIncdPrftDivCd); //이연처리구분
				inDTO.setSnum(obj.snum); //일련번호
				inDTO.setTims(descObj.tims); //회차
				inDTO.setProcSchdDt(descObj.procSchdDt); //처리예정일자
				inDTO.setMmProcAmt(obj.minusFlag ? new BigDecimal(descObj.discDifAmt * -1) : new BigDecimal(descObj.discDifAmt)); //월처리금액(할인차금)
				inDTO.setProcDt(" "); //처리일자
				inDTO.setDferIntnVochNo(" "); //이연내부전표번호
				inDTO.setCnclIntnVochNo(" "); //취소내부전표번호
				inDTO.setFrstRegDt(yyyymmdd); //최초등록일자
				inDTO.setFrstRegTm(hhmmss); //최초등록시간
				inDTO.setFrstRegEmpNo(StringUtil.trimToStr(obj.empNo)); //최초등록자사번
				inDTO.setLastProcDt(yyyymmdd); //최종처리일자
				inDTO.setLastProcTm(hhmmss); //최종처리시간
				inDTO.setLastProcEmpNo(StringUtil.trimToStr(obj.empNo)); //최종처리자사번

				exeCnt = dferIncdPrftMapper.dferIncdPrftDescCrte(inDTO);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [이연부대수익내역] 저장 오류!");
		}
	}

	@Override
	public void dferIncdPrftUpdt(String loanNo, String loanSeq, String loanStatCd, String loanEndDt,
			String endCnclDt, String userEmpNo) throws Exception {
		String[] updtArr = new String[6];
		updtArr[0] = loanNo;
		updtArr[1] = loanSeq;
		updtArr[2] = loanStatCd;
		updtArr[3] = loanEndDt;
		updtArr[4] = endCnclDt;
		updtArr[5] = userEmpNo;

		List dferUpList = new ArrayList();
		dferUpList.add(updtArr);

		dferIncdPrftUpdt(dferUpList);
	}

	/**
	 * <P>메소드명 : dferIncdPrftUpdt</P>
	 * <P>설명 : 이연부대수익 기본 갱신</P>
	 * <P>메소드인수1 : 대출번호, 대출순번, 대출상태코드, 대출종료일자, 종료취소일자, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void dferIncdPrftUpdt(List dferUpList) throws Exception {

		int exeCnt = 0;

		try {

			String nowDate = DateUtil.getServerDate(DateUtil.YYYYMMDD);
			String nowTime = DateUtil.getServerDate(DateUtil.HHMMSS);

			for (int i = 0; i < dferUpList.size(); i++) {

				DferIncdPrftDescObj descObj = (DferIncdPrftDescObj) dferUpList.get(i);

		        String[] updtArr = (String[]) dferUpList.get(i);
		        String loanNo = updtArr[0];
		        String loanSeq = updtArr[1];
		        String loanStatCd = updtArr[2];
		        String loanEndDt = updtArr[3];
		        String endCnclDt = updtArr[4];
		        String userEmpNo = updtArr[5];

		        StDferIncdPrftBaseDTO inDTO = new StDferIncdPrftBaseDTO();

				inDTO.setLoanStatCd(loanStatCd);
				inDTO.setLoanEndDt(loanEndDt);
				inDTO.setLoanEndCnclDt(endCnclDt);

				inDTO.setLastProcDt(nowDate);
				inDTO.setLastProcTm(nowTime);
				inDTO.setLastProcEmpNo(StringUtil.trimToStr(userEmpNo));

				inDTO.setLoanNo(loanNo);
				inDTO.setLoanSeq(loanSeq);

				exeCnt = dferIncdPrftMapper.dferIncdPrftBaseUpdt(inDTO);
			}

		} catch (Exception se) {
			se.printStackTrace();
			throw new Exception("[이연부대수익처리] : [이연_부대_수익_기본] 수정 중 오류 : " + se.getMessage());
		}
	}

	/**
	 * <P>메소드명 : loanBaseRead</P>
	 * <P>설명 : 대출기본 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	private int maxSnumRead(String loanNo, String loanSeq, String dferIncdPrftDivCd) throws Exception {
		int exeCnt = 0;
		try {

			StDferIncdPrftBaseDTO inDTO = new StDferIncdPrftBaseDTO();


			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setDferIncdPrftDivCd(dferIncdPrftDivCd);

			exeCnt = dferIncdPrftMapper.maxSumRead(inDTO);

			return exeCnt;

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : MAX(SNUM)+1 조회 오류!");
		}
	}

	/**
	 * <P>메소드명 : addDferIncdPrftCrte</P>
	 * <P>설명 : 추가 이연부대수익생성</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void addDferIncdPrftCrte(String loanNo, String loanSeq, String snum, String empNo) throws Exception {
		// 대출번호,순번을 조건으로 대출기본,상품기본 조회
		DferIncdPrftBaseObj obj = loanPayDescRead(loanNo, loanSeq, snum);
		obj.empNo = empNo;
		obj.minusFlag = false;

		/*
		 * //3개월이하면 생성 안함 if (obj.loanTerm <= 3) { return; }
		 */

		// 제휴수수료 이연처리
		if ("1".equals(obj.cprtFeeDferProcFg) && obj.cprtFee != 0) {
			obj.dferIncdPrftDivCd = "1"; // 제휴수수료
			if (obj.cprtFee < 0) {
				obj.minusFlag = true; // 저장시 - 로 변환
				obj.totAmt = obj.cprtFee * -1;
			} else {
				obj.totAmt = obj.cprtFee; // 이연처리총금액
			}
			// 상환계획시뮬레이션,내부수익율
			List descList = rmbrPlanSimul(obj);

			// 이연스케줄 생성
			makeDferIncdPrftDesc(obj, descList);

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);
			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}
		// 취급수수료 이연처리 여부
		if ("1".equals(obj.trtFeeDferProcFg) && obj.trtFee != 0) {
			obj.dferIncdPrftDivCd = "3"; // 취급수수료
			if (obj.trtFee < 0) {
				obj.minusFlag = true; // 저장시 - 로 변환
				obj.totAmt = obj.trtFee * -1;
			} else {
				obj.totAmt = obj.trtFee; // 이연처리총금액
			}

			// 상환계획조회
			List descList = rmbrPlanDescRead(obj);

			// 이연스케줄 생성
			makeIntRateDferIncdPrftDesc(obj, descList);

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);
			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}
	}

	/**
	 * <P>메소드명 : loanPayDescRead</P>
	 * <P>설명 : 대출지급내역 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	private DferIncdPrftBaseObj loanPayDescRead(String loanNo, String loanSeq, String snum) throws Exception {

		DferIncdPrftBaseObj obj = null;

		try {

			LoanPayDescReadINDTO inDTO = new LoanPayDescReadINDTO();

			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setSnum(snum);

			LoanPayDescReadOUTDTO outDTO = dferIncdPrftMapper.loanPayDescRead(inDTO);

			if(outDTO != null) {
		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo = loanNo;
		        obj.loanSeq = loanSeq;
		        obj.trtFeeDferProcFg = outDTO.getTrtFeeDferProcFg();
		        obj.cprtFeeDferProcFg = outDTO.getCprtFeeDferProcFg();
		        obj.trtFee = outDTO.getTrtFee();
		        obj.cprtFee = outDTO.getCprtFee();
		        obj.loanTerm       = outDTO.getLoanTerm();
		        obj.loanPamt       = outDTO.getLoanPamt();
		        obj.loanStatCd     = outDTO.getLoanStatCd();
		        obj.intnPrftRt     = outDTO.getIntnPrftRt();
		        obj.loanDt         = outDTO.getLoanDt();
		        obj.fcntMopaCalcFg = outDTO.getFcntMopaCalcFg();
		        obj.payDt          = outDTO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.fcntDueDt      = outDTO.getFcntDueDt();
		        obj.loanIntRt      = outDTO.getLoanIntRt();
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [대출지급내역] 조회 오류!");
		}

		return obj;
	}

	/**
	 * <P>메소드명 : prFeeDferIncdPrftCrte</P>
	 * <P>설명 : MC수수료 이연부대수익생성</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void prFeeDferIncdPrftCrte(String loanNo, String loanSeq, String snum, String empNo) throws Exception {
		// 대출번호,순번을 조건으로 대출기본,판촉수수료 조회
		DferIncdPrftBaseObj obj = prFeePayDescRead(loanNo, loanSeq, snum);
		obj.empNo = empNo;
		obj.minusFlag = false;

		// 주택,부동산만 가능
		if (obj.prdtMidClasCd == null
				|| (!obj.prdtMidClasCd.trim().equals("10") && !obj.prdtMidClasCd.trim().equals("11"))) {
			return;
		}

		/*
		 * //3개월이하면 생성 안함 if (obj.loanTerm <= 3) { return; }
		 */

		// MC수수료 이연처리
		if (obj.prPayFee > 0) {
			obj.dferIncdPrftDivCd = "5"; // MC수수료
			obj.totAmt = obj.prPayFee; // MC수수료
			obj.minusFlag = true; // 저장시 - 로 변환

			// 상환계획조회
			List descList = rmbrPlanDescRead(obj);

			// 이연스케줄 생성
			makeIntRateDferIncdPrftDesc(obj, descList);

			// 이연부대수익기본 저장
			dferIncdPrftBaseCrte(obj);
			// 이연스케줄 저장
			dferIncdPrftDescCrte(obj, descList);
		}
	}

	/**
	 * <P>메소드명 : prFeePayDescRead</P>
	 * <P>설명 : 판촉수수료 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	private DferIncdPrftBaseObj prFeePayDescRead(String loanNo, String loanSeq, String snum) throws Exception {

		DferIncdPrftBaseObj obj = null;

		try {

			PrFeePayDescReadINDTO inDTO = new PrFeePayDescReadINDTO();

			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setSnum(snum);

			PrFeePayDescReadOUTDTO outDTO = dferIncdPrftMapper.prFeePayDescRead(inDTO);

			if(outDTO != null) {
		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo = loanNo;
		        obj.loanSeq = loanSeq;
		        obj.loanTerm       = outDTO.getLoanTerm();
		        obj.loanPamt       = outDTO.getLoanPamt();
		        obj.loanStatCd     = outDTO.getLoanStatCd();
		        obj.intnPrftRt     = outDTO.getIntnPrftRt();
		        obj.loanDt         = outDTO.getLoanDt();
		        obj.fcntMopaCalcFg = outDTO.getFcntMopaCalcFg();
		        obj.payDt          = outDTO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = outDTO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = outDTO.getPrdtMidClasCd();
		        obj.prPayFee       = outDTO.getPrFee();
		        obj.fcntDueDt      = outDTO.getFcntDueDt();
		        obj.loanIntRt      = outDTO.getLoanIntRt();
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [판촉수수료지급내역] 조회 오류!");
		}

		return obj;
	}

	private List rmbrPlanSimul(DferIncdPrftBaseObj obj) throws Exception {
		List descList = new ArrayList();

		// 상환계획생성 모듈 호출
		LoanBaseObj loanBaseObj = new LoanBaseObj();
		loanBaseObj.loanNo = obj.loanNo;
		loanBaseObj.loanSeq = obj.loanSeq;
		loanBaseObj.prdtLrgeClasCd = obj.prdtLrgeClasCd;
		loanBaseObj.prdtMidClasCd = obj.prdtMidClasCd;
		loanBaseObj.rmbrPlanTypeDivCd = "2";
		loanBaseObj.loanPamt = obj.loanPamt;
		loanBaseObj.loanTerm = obj.loanTerm;
		loanBaseObj.loanDt = obj.loanDt;
		loanBaseObj.fcntDueDt = obj.fcntDueDt;
		loanBaseObj.fcntMopaCalcFg = "1";
		// 비용은 수수료로 통일
		loanBaseObj.custTrtFee = obj.totAmt;

		List loanPiamtList = new ArrayList();

		LoanPiamtObj loanPiamtObj = new LoanPiamtObj();
		loanPiamtObj.loanNo = obj.loanNo;
		loanPiamtObj.loanSeq = obj.loanSeq;
		loanPiamtObj.trSnum = 1;
		loanPiamtObj.frstRank = 1;
		loanPiamtObj.rmbrFrmlCd = "1";
		loanPiamtObj.loanPamt = obj.loanPamt;
		loanPiamtObj.term = obj.loanTerm;
		loanPiamtObj.strtTims = 1;
		loanPiamtObj.intRt = obj.loanIntRt;
		loanPiamtObj.dueCycl = 1;
		loanPiamtObj.dueStrtTims = 1;
		loanPiamtList.add(loanPiamtObj);
		loanBaseObj.piamtObjList = loanPiamtList;

		loanBaseObj = rmbrPlanCrteService.createRmblPlan(loanBaseObj);
		obj.intnPrftRt = Math.floor(loanBaseObj.intnPrftRt * 100) / 100;

		LoanPiamtObj loanPiamt = (LoanPiamtObj) loanBaseObj.piamtObjList.get(0);

		for (int i = 0; i < loanPiamt.rmbrObjList.size(); i++) {
			RmbrPlanObj rmbrObj = (RmbrPlanObj) loanPiamt.rmbrObjList.get(i);
			DferIncdPrftDescObj descObj = new DferIncdPrftDescObj();

			descObj.loanNo = obj.loanNo;
			descObj.loanSeq = obj.loanSeq;
			descObj.dferIncdPrftDivCd = obj.dferIncdPrftDivCd;
			descObj.tims = rmbrObj.tims;
			descObj.dueDt = rmbrObj.dueDt;
			descObj.mm_pamt = rmbrObj.mmPamt;
			descObj.mm_int = rmbrObj.mmInt;

			descList.add(descObj);
		}
		return descList;
	}

	/**
	 * <P>메소드명 : prPayFeeDferIncdPrftCrte</P>
	 * <P>설명 : MC,MR 수수료 이연부대수익생성</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	public void prPayFeeDferIncdPrftCrte(String stndYyMm, String mngDeptCd, String resiNo, long payAmt,
			String empNo) throws Exception {
		// 기준년월,관리부서,사원주민번호을 조건으로 [ST_모기지_모집인_취급_내역] 조회
		List rsltList = moggRcrpManTrtDescRead(stndYyMm, mngDeptCd, resiNo);

		if (rsltList == null || rsltList.size() == 0) {
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다.");
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// MC수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "5"; // 모집인수수료
				obj.totAmt = obj.prPayFee; // MC수수료
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 상환계획조회
				List descList = rmbrPlanDescRead(obj);

				// 이연스케줄 생성
				makeIntRateDferIncdPrftDesc(obj, descList);

				// 이연부대수익기본 저장
				dferIncdPrftBaseCrte(obj);
				// 이연스케줄 저장
				dferIncdPrftDescCrte(obj, descList);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : moggRcrpManTrtDescRead</P>
	 * <P>설명 : 모기지모집인 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List moggRcrpManTrtDescRead(String stndYyMm, String mngDeptCd, String resiNo) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setResiNo(resiNo);
			inDTO.setMngDeptCd(mngDeptCd);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.moggRcrpManTrtDescRead(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [모기지_모집인_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : ucarFeeDferIncdPrftCrte</P>
	 * <P>설명 : 중고차 판촉 수수료 이연부대수익 스케줄 생성</P>
	 * <P>메소드인수1 : 기준년월, 관리부서, 제휴사, 제휴점, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void ucarFeeDferIncdPrftCrte(String stndYyMm, String mngDeptCd, String cprtComNo, String cprtBranCd,
			long payAmt, String empNo) throws Exception {
		// 기준년월,관리부서,제휴사,제휴점을 조건으로 [ST_중고차_판촉_수수료_내역_내역] 조회
		List rsltList = ucarMmTrtDescRead(stndYyMm, mngDeptCd, cprtComNo, cprtBranCd);

		if (rsltList == null || rsltList.size() == 0) {
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다.");
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// 중고차 수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "6"; // 중고차수수료
				obj.totAmt = obj.prPayFee; // MC수수료
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 상환계획조회
				List descList = rmbrPlanDescRead(obj);

				// 이연스케줄 생성
				makeIntRateDferIncdPrftDesc(obj, descList);

				// 이연부대수익기본 저장
				dferIncdPrftBaseCrte(obj);
				// 이연스케줄 저장
				dferIncdPrftDescCrte(obj, descList);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : ucarFeeDferIncdPrftCrte</P>
	 * <P>설명 : 중고차 판촉 수수료 이연부대수익 스케줄 생성</P>
	 * <P>메소드인수1 : 기준년월, 관리부서, 제휴사, 제휴점, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void ucarFeeDferIncdPrftCrte(String loanNo, String loanSeq, long payAmt, String empNo)
			throws Exception {
		// 기준년월,관리부서,제휴사,제휴점을 조건으로 [ST_중고차_판촉_수수료_내역_내역] 조회
		List rsltList = ucarMmTrtDescRead(loanNo, loanSeq);

		if (rsltList == null || rsltList.size() == 0) {
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다.");
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// 중고차 수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "6"; // 중고차수수료
				obj.totAmt = obj.prPayFee; // MC수수료
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 상환계획조회
				List descList = rmbrPlanDescRead(obj);

				// 이연스케줄 생성
				makeIntRateDferIncdPrftDesc(obj, descList);

				// 이연부대수익기본 저장
				dferIncdPrftBaseCrte(obj);
				// 이연스케줄 저장
				dferIncdPrftDescCrte(obj, descList);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : plFeeDferIncdPrftCrte</P>
	 * <P>설명 : LC 수수료 이연부대수익 스케줄 생성</P>
	 * <P>메소드인수1 : 기준년월, LC사번, 요율수당, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void plFeeDferIncdPrftCrte(String stndYyMm, String lcEmpNo, long payAmt, String empNo) throws Exception {
		if (payAmt == 0) {
			return;
		}
		// 기준년월,관리부서를 조건으로 [ST_대출_기본] 조회
		List rsltList = plTrtDescRead(stndYyMm, lcEmpNo);

		if (rsltList == null || rsltList.size() == 0) {
			System.out.println("전월취급실적이 없는건	" + lcEmpNo);
			rsltList = plTrtDescRead2(stndYyMm, lcEmpNo);
			// throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다."+stndYyMm+""+lcEmpNo);
		}

		if (rsltList == null || rsltList.size() == 0) // 09WL0350 12월꺼 없네
		{
			System.out.println("모집인에 실적이 없는것	" + lcEmpNo);
			rsltList = plTrtDescRead3(stndYyMm, lcEmpNo);
			// throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다."+stndYyMm+""+lcEmpNo);
		}

		if (rsltList == null || rsltList.size() == 0) // 09WL0350 12월꺼 없네
		{
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다." + stndYyMm + "" + lcEmpNo);
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// pl 수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "7"; // pl수수료
				obj.totAmt = obj.prPayFee; // MC수수료
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 상환계획조회
				List descList = rmbrPlanDescRead(obj);

				// 이연스케줄 생성
				makeIntRateDferIncdPrftDesc(obj, descList);

				// 이연부대수익기본 저장
				dferIncdPrftBaseCrte(obj);
				// 이연스케줄 저장
				dferIncdPrftDescCrte(obj, descList);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : moggRcrpManTrtDescRead</P>
	 * <P>설명 : 모기지모집인 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List ucarMmTrtDescRead(String stndYyMm, String mngDeptCd, String cprtComNo, String cprtBranCd) throws Exception {

		List rsltList = new ArrayList();

		try {

			// TODO 파라미터 매핑 안맞음 미사용으로 간주

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [중고차_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : moggRcrpManTrtDescRead</P>
	 * <P>설명 : 모기지모집인 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List ucarMmTrtDescRead(String loanNo, String loanSeq) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.ucarMmTrtDescRead(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [중고차_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : plTrtDescRead</P>
	 * <P>설명 : PL 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List plTrtDescRead(String stndYyMm, String lcEmpNo) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setLcEmpNo(lcEmpNo);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.plMmTrtDescRead(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [PL_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : plTrtDescRead2</P>
	 * <P>설명 : PL 취급 내역 조회 - 전월취급이 없을경우 전체 취급</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List plTrtDescRead2(String stndYyMm, String lcEmpNo) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setLcEmpNo(lcEmpNo);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.plMmTrtDescRead2(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [PL_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : plTrtDescRead3</P>
	 * <P>설명 : PL 취급 내역 조회 - 전월취급이 없을경우 전체 취급</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List plTrtDescRead3(String stndYyMm, String lcEmpNo) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setLcEmpNo(lcEmpNo);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.plMmTrtDescRead3(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [PL_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : moggLtrmContFeeTrtDescRead</P>
	 * <P>설명 : 모기지모집인 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List moggLtrmContFeeTrtDescRead(String payYyMm, String mngDeptCd, String resiNo) throws Exception {

		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setPayYyMm(payYyMm);
			inDTO.setResiNo(resiNo);
			inDTO.setMngDeptCd(mngDeptCd);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.moggLtrmContFeeTrtDescRead(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [모기지_모집인_장기근속수수료_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : moggLtrmContFeeDferIncdPrftCrte</P>
	 * <P>설명 : 모기지장기근속수수료 이연부대수익생성</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	public void moggLtrmContFeeDferIncdPrftCrte(String payYyMm, String mngDeptCd, String resiNo, long payAmt,
			String empNo) throws Exception {
		// 기준년월,관리부서,사원주민번호을 조건으로 [ST_모기지_모집인_취급_내역] 조회
		List rsltList = moggLtrmContFeeTrtDescRead(payYyMm, mngDeptCd, resiNo);

		if (rsltList == null || rsltList.size() == 0) {
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다.");
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// MC수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "5"; // 모집인수수료
				obj.totAmt = obj.prPayFee; // MC수수료
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 상환계획조회
				List descList = rmbrPlanDescRead(obj);

				// 이연스케줄 생성
				makeIntRateDferIncdPrftDesc(obj, descList);

				// 이연부대수익기본 저장
				dferIncdPrftBaseCrte(obj);
				// 이연스케줄 저장
				dferIncdPrftDescCrte(obj, descList);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : condChngDferIncdPrftCrte</P>
	 * <P>설명 : 조변후이연부대수익생성(취급수수료만 추가</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void condChngDferIncdPrftCrte(String loanNo, String loanSeq, long trtFee, String snum, String empNo)
			throws Exception {
		// 대출번호,순번을 조건으로 대출기본,상품기본 조회
		DferIncdPrftBaseObj obj = loanChngConsRead(loanNo, loanSeq, snum);
		obj.empNo = empNo;
		obj.minusFlag = false;
		obj.trtFee = trtFee;

		obj.dferIncdPrftDivCd = "3"; // 취급수수료
		if (obj.trtFee < 0) {
			obj.minusFlag = true; // 저장시 - 로 변환
			obj.totAmt = obj.trtFee * -1;
		} else {
			obj.totAmt = obj.trtFee; // 이연처리총금액
		}

		// 상환계획조회
		List descList = rmbrPlanDescRead(obj);

		// 이연스케줄 생성
		makeIntRateDferIncdPrftDesc(obj, descList);

		// 이연부대수익기본 저장
		dferIncdPrftBaseCrte(obj);
		// 이연스케줄 저장
		dferIncdPrftDescCrte(obj, descList);
	}

	/**
	 * <P>메소드명 : loanChngConsRead</P>
	 * <P>설명 : 대출변경품의 조회</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번</P>
	 * <P>메소드리턴값 : DferIncdPrftBaseObj</P>
	 */
	private DferIncdPrftBaseObj loanChngConsRead(String loanNo, String loanSeq, String snum) throws Exception {
		DferIncdPrftBaseObj obj = null;

		try {

			LoanChngConsReadINDTO inDTO = new LoanChngConsReadINDTO();

			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setSnum(snum);

			LoanChngConsReadOUTDTO outDTO = dferIncdPrftMapper.loanChngConsRead(inDTO);

			if(outDTO != null) {
		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo = loanNo;
		        obj.loanSeq = loanSeq;
		        obj.trtFeeDferProcFg = outDTO.getTrtFeeDferProcFg();
		          obj.loanTerm = outDTO.getChngAfLoanTerm();
		          obj.loanPamt = outDTO.getChngAfLoanPamt();
		          obj.loanStatCd = outDTO.getLoanStatCd();
		          obj.intnPrftRt = outDTO.getChngAfIntnPrftRt();
		          obj.loanDt = outDTO.getLoanDt();
		          obj.fcntMopaCalcFg = outDTO.getFcntMopaCalcFg();
		          obj.fcntDueDt = outDTO.getChngAfFcntDueDt();
		          obj.loanIntRt = outDTO.getChngAfLoanIntRt();
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);

			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [대출변경품의] 조회 오류!");
		}

		return obj;
	}

	/**
	 * <P>메소드명 : prFeeDferIncdPrftCrte2</P>
	 * <P>설명 : 판촉수수료이연부대수익처리</P>
	 * <P>메소드인수1 : String - 대출번호, 대출순번, 일련번호, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void prFeeDferIncdPrftCrte2(String loanNo, String loanSeq, String snum, String empNo) throws Exception {
		// 대출번호,순번을 조건으로 대출기본,상품기본 조회
		DferIncdPrftBaseObj obj = prFeePayDescRead(loanNo, loanSeq, snum);
		obj.empNo = empNo;
		obj.minusFlag = false;

		obj.dferIncdPrftDivCd = "9"; // 판촉수수료

		if (obj.prPayFee < 0) {
			obj.minusFlag = false; //
			obj.totAmt = obj.prPayFee * -1;
		} else {
			obj.minusFlag = true; //
			obj.totAmt = obj.prPayFee; // 이연처리총금액
		}

		// 상환계획조회
		List descList = rmbrPlanDescRead(obj);

		// 이연스케줄 생성
		makeIntRateDferIncdPrftDesc(obj, descList);

		// 이연부대수익기본 저장
		dferIncdPrftBaseCrte(obj);
		// 이연스케줄 저장
		dferIncdPrftDescCrte(obj, descList);
	}

	/**
	 * <P>메소드명 : acFeeDferIncdPrftCrte</P>
	 * <P>설명 : AC 수수료 이연부대수익 스케줄 생성</P>
	 * <P>메소드인수1 : 기준년월, LC사번, 요율수당, 사용자사번</P>
	 * <P>메소드리턴값 : void</P>
	 */
	@Override
	public void acFeeDferIncdPrftCrte(String stndYyMm, String lnDivsEmpNo, long payAmt, String empNo) throws Exception {
		if (payAmt == 0) {
			return;
		}
		// 기준년월,관리부서를 조건으로 [ST_대출_기본] 조회

		List rsltList = acTrtDescRead(stndYyMm, lnDivsEmpNo);

		if (rsltList == null || rsltList.size() == 0) {
			System.out.println("전월취급실적이 없는건	" + lnDivsEmpNo);
			rsltList = acTrtDescRead2(stndYyMm, lnDivsEmpNo);
		}

		if (rsltList == null || rsltList.size() == 0) {
			throw new Exception("[이연부대수익생성 오류] : 기준월 대출 실적이 없습니다." + stndYyMm + "" + lnDivsEmpNo);
		}

		// 취소의 경우에는 지급과 반대로 생성
		boolean minusFg = true;
		if (payAmt < 0) {
			minusFg = false;
			payAmt = payAmt * -1;
		}

		int loanCnt = rsltList.size();
		long saleTotAmt = 0;
		long feeTotAmt = payAmt;
		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			saleTotAmt += obj.loanPamt;
		}

		for (int i = 0; i < rsltList.size(); i++) {
			DferIncdPrftBaseObj obj = (DferIncdPrftBaseObj) rsltList.get(i);
			obj.empNo = empNo;
			obj.minusFlag = false;

			if (i == loanCnt - 1) {
				obj.prPayFee = feeTotAmt;
			} else {
				obj.prPayFee = (long) Math.floor(payAmt * obj.loanPamt / saleTotAmt);
				if (obj.prPayFee > feeTotAmt) {
					obj.prPayFee = feeTotAmt;
					feeTotAmt = 0;
				} else {
					feeTotAmt = feeTotAmt - obj.prPayFee;
				}
			}

			// AC 수수료 이연처리
			if (obj.prPayFee > 0) {
				obj.dferIncdPrftDivCd = "8"; // AC수수료
				obj.totAmt = obj.prPayFee; //
				obj.minusFlag = minusFg; // 저장시 - 로 변환

				// 리스는 이연처리안함
				if (!obj.prdtLrgeClasCd.equals("3") && !obj.prdtLrgeClasCd.equals("4")) {
					// 상환계획조회
					List descList = rmbrPlanDescRead(obj);

					// 이연스케줄 생성
					makeIntRateDferIncdPrftDesc(obj, descList);

					// 이연부대수익기본 저장
					dferIncdPrftBaseCrte(obj);
					// 이연스케줄 저장
					dferIncdPrftDescCrte(obj, descList);
				}
				// 이연스케줄배분내역저장
				dferIncdPrftDistDescCrte(stndYyMm, lnDivsEmpNo, obj);
			}

			if (feeTotAmt == 0) {
				break;
			}
		}
	}

	/**
	 * <P>메소드명 : acTrtDescRead</P>
	 * <P>설명 : AC 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List acTrtDescRead(String stndYyMm, String empNo) throws Exception {
		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setLcEmpNo(empNo);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.acMmTrtDescRead(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [AC_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : acTrtDescRead</P>
	 * <P>설명 : AC 취급 내역 조회</P>
	 * <P>메소드인수1 : String - 기준일자, 모집인주민번호</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private List acTrtDescRead2(String stndYyMm, String empNo) throws Exception {
		List rsltList = new ArrayList();

		try {

			SelectTrtDescReadINDTO inDTO = new SelectTrtDescReadINDTO();

			inDTO.setStndYyMm(stndYyMm);
			inDTO.setLcEmpNo(empNo);

			List<SelectTrtDescReadOUTDTO> outDTO = dferIncdPrftMapper.acMmTrtDescRead2(inDTO);

			for (SelectTrtDescReadOUTDTO sourceIO : outDTO) {

				DferIncdPrftBaseObj obj = new DferIncdPrftBaseObj();

		        obj = new DferIncdPrftBaseObj();
		        obj.loanNo 			= sourceIO.getLoanNo();
		        obj.loanSeq 		= sourceIO.getLoanSeq();
		        obj.loanTerm       	= sourceIO.getLoanTerm();
		        obj.loanPamt       	= sourceIO.getLoanPamt();
		        obj.loanStatCd     	= sourceIO.getLoanStatCd();
		        obj.intnPrftRt     	= sourceIO.getIntnPrftRt();
		        obj.loanDt         	= sourceIO.getLoanDt();
		        obj.fcntMopaCalcFg 	= sourceIO.getFcntMopaCalcFg();
		        obj.payDt          	= sourceIO.getPayDt();
		        if (obj.payDt == null || obj.payDt.trim().equals(""))
		        {
		          obj.payDt = DateUtil.getServerDate(DateUtil.YYYYMMDD);
		        }
		        obj.prdtLrgeClasCd = sourceIO.getPrdtLrgeClasCd();
		        obj.prdtMidClasCd  = sourceIO.getPrdtMidClasCd();
		        obj.prPayFee       = sourceIO.getPrFee();
		        obj.fcntDueDt      = sourceIO.getFcntDueDt();
		        obj.loanIntRt      = sourceIO.getLoanIntRt();

		        rsltList.add(obj);
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [AC_취급_내역] 조회 오류!");
		}

		return rsltList;
	}

	/**
	 * <P>메소드명 : dferIncdPrftDistDescCrte</P>
	 * <P>설명 : ST_이연_부대_수익_배분_내역 저장</P>
	 * <P>메소드인수1 : DferIncdPrftBaseObj</P>
	 * <P>메소드리턴값 : List</P>
	 */
	private void dferIncdPrftDistDescCrte(String stndYyMm, String lnDivsEmpNo, DferIncdPrftBaseObj obj) throws Exception {

		int exeCnt = 0;

		try {

			String yyyymmdd = DateUtil.getServerDate(DateUtil.YYYYMMDD);
			String hhmmss = DateUtil.getServerDate(DateUtil.HHMMSS);

			StDferIncdPrftDistDescDTO inDTO = new StDferIncdPrftDistDescDTO();

			inDTO.setStndYymm(stndYyMm); //기준년월
			inDTO.setEmpNo(lnDivsEmpNo); //담당자번호
			inDTO.setLoanNo(obj.loanNo); //대출번호
			inDTO.setLoanSeq(obj.loanSeq); //대출순번
			inDTO.setDferIncdPrftDivCd(obj.dferIncdPrftDivCd); //이연처리구분
			inDTO.setSnum(obj.snum); //일련번호
			inDTO.setTotAmt(new BigDecimal(obj.totAmt)); //총금액
		      if(!obj.prdtLrgeClasCd.equals("3") && !obj.prdtLrgeClasCd.equals("4")){
		    	  inDTO.setDferFg(Constants.YES); //이연여부
		      }else{
		    	  inDTO.setDferFg(Constants.NO); //이연여부
		      }
			inDTO.setFrstRegDt(yyyymmdd); //최초등록일자
			inDTO.setFrstRegTm(hhmmss); //최초등록시간
			inDTO.setFrstRegEmpNo(StringUtil.trimToStr(obj.empNo)); //최초등록자사번
			inDTO.setLastProcDt(yyyymmdd); //최종처리일자
			inDTO.setLastProcTm(hhmmss); //최종처리시간
			inDTO.setLastProcEmpNo(StringUtil.trimToStr(obj.empNo)); //최종처리자사번

			exeCnt = dferIncdPrftMapper.dferIncdPrftDistDescCrte(inDTO);

		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("[이연부대수익생성] : [ST_이연_부대_수익_배분_내역] 저장 오류! : " + e.getMessage());
		}
	}

}
