package hanalife.s.mo.in.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.mo.in.mapper.MciReptReadMapper;
import hanalife.s.mo.in.mapper.dto.mciReptReadDSSDDTO;
import hanalife.s.mo.in.mapper.dto.mciReptReadDSSMDTO;
import hanalife.s.mo.in.service.SMOINM03Service;
import hanalife.s.mo.in.vo.SMOINM03DSSDVO;
import hanalife.s.mo.in.vo.SMOINM03S01InVO;
import hanalife.s.mo.in.vo.SMOINM03S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM03ServiceImpl.java Class
 * 클래스설명   : MCI현황조회 (SMOINM03) Service Implements
 * 작성일자     : 2023. 4. 6.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 6.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSMOINM03S01 : MCI현황조회목록조회

 * </pre>
 */
@Service("SMOINM03Service")
public class SMOINM03ServiceImpl implements SMOINM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM03ServiceImpl.class);

	private MsgEnum msgEnum;
	private Constants constants;

	@Autowired
	private MciReptReadMapper mciReptReadMapper;

	/**
	 * <p>메소드명      : getSMOINM03S01 : MCI현황조회</p>
	 * <p>작성일자      : 2023. 4. 6.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : MCI현황조회 조회 한다.</p>
	 * <p>메소드인수    : SMOINM03S01InVo </p>
	 * <p>메소드리턴값  : SMOINM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SMOINM03S01OutVO getSMOINM03S01(SMOINM03S01InVO inVo) throws Exception {

		SMOINM03S01OutVO resultVo = new SMOINM03S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		mciReptReadDSSMDTO inDto = new mciReptReadDSSMDTO();

		inDto.setApplDtFr(inVo.getSMOINM03DSSMVO().getApplDtFr()); 		/** 신청접수일자시작 */
		inDto.setApplDtTo(inVo.getSMOINM03DSSMVO().getApplDtTo()); 		/** 신청접수일자종료 */
		inDto.setLoanApplNo(inVo.getSMOINM03DSSMVO().getLoanApplNo()); 	/** 대출신청번호 */
		inDto.setCustBirth(inVo.getSMOINM03DSSMVO().getCustBirth()); 	/** 고객생년월일 */
		inDto.setCustNm(inVo.getSMOINM03DSSMVO().getCustNm()); 			/** 고객명 */
		inDto.setBsnDivCd(inVo.getSMOINM03DSSMVO().getBsnDivCd()); 		/** 업무구분코드 */

		List<mciReptReadDSSDDTO> resultDTO = mciReptReadMapper.searchMciReptReadList(inDto);	/** MCI현황조회리스트*/

		List<SMOINM03DSSDVO> resultList = new ArrayList<SMOINM03DSSDVO>();

		for (mciReptReadDSSDDTO sourceIO : resultDTO) {
			SMOINM03DSSDVO targetIO = new SMOINM03DSSDVO();

			String custResiNo = sourceIO.getCustResiNo();					/** 고객주민등록번호_복호화 */
			String maskResiNo = "";											/** 고객주민등록번호_마스킹처리 */

			if(custResiNo.length() > 8) {
				maskResiNo = custResiNo.substring(0, 8) + "******";			/** 고객주민등록번호_마스킹 */
			}

			String rsltCd = sourceIO.getRsltCd();							/** 결과코드 */
			String bsnDivCd = sourceIO.getBsnDivCd();						/** 업무구분코드 */
			String rsltNm = "";												/** 결과명 */
			String bsnDivNm = "";											/** 업무구분명 */
			String subsPrgsStat = "";										/** 청약진행상태 */

			targetIO.setLoanApplNo(sourceIO.getLoanApplNo()); 				/** 대출신청번호 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); 						/** 대출번호 */
			targetIO.setCustNm(this.nameMasking(sourceIO.getCustNm())); 	/** 고객명 */
			targetIO.setCustResiNo(maskResiNo); 							/** 고객주민등록번호_복호화 */
			targetIO.setGuarBondNo(sourceIO.getGuarBondNo()); 				/** 보증서번호(보증보험증권번호) */
			targetIO.setApplRealStsCd(sourceIO.getApplRealStsCd()); 		/** 신청현재진행상태코드 */
			targetIO.setBsnDivCd(bsnDivCd); 								/** 업무구분코드 */
			targetIO.setDisbHopeDt(sourceIO.getDisbHopeDt()); 				/** 대출희망일자 */
			targetIO.setLoanApplAmt(sourceIO.getLoanApplAmt()); 			/** 대출신청금액 */
			targetIO.setRepayTypeGbCd(sourceIO.getRepayTypeGbCd()); 		/** 상환방식구분코드 */
			targetIO.setInsuTermEndDt(sourceIO.getInsuTermEndDt()); 		/** 보험기간종료일자(당초,변경전) */
			targetIO.setMciEntrAmt(sourceIO.getMciEntrAmt()); 				/** MCI가입금액 */
			targetIO.setRsltCd(rsltCd); 									/** 결과코드 */

			if(constants.RSLT_CD_SUCCESS.equals(rsltCd)) {
				rsltNm = "적격";
			}else{
				rsltNm = "부적격";
			}

			if(constants.BSDCD_A100.equals(bsnDivCd)){
				bsnDivNm = "사전조회";
			}else if(constants.BSDCD_A101.equals(bsnDivCd)){
				bsnDivNm = "청약";
			}else if(constants.BSDCD_A102.equals(bsnDivCd)){
				bsnDivNm = "청약취소";
			}

			subsPrgsStat = bsnDivNm + "(" + rsltNm + ")";
			targetIO.setSubsPrgsStat(subsPrgsStat);					/** 청약진행상태(적격여부) */

			resultList.add(targetIO);
		}

		resultVo.setSMOINM03DSSDVO(resultList);	/** MCI현황조회리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;

	}

}
