package hanalife.s.mo.in.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.mo.in.service.SMOINM01Service;
import hanalife.s.mo.in.vo.SMOINM01DSSMVO;
import hanalife.s.mo.in.vo.SMOINM01S01InVO;
import hanalife.s.mo.in.vo.SMOINM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM01Controller.java Class
 *
 * 클래스설명   : 권원보험현황조회 (SMOINM01) Controller
 * 작성일자     : 2023. 4. 03.
 * 작성자명     : 70319  / ShinJeongSeon / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("s/mo/in")
@Controller
public class SMOINM01Controller {

	@Resource(name = "SMOINM01Service")
	private SMOINM01Service SMOINM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM01Controller.class);

	/**
	 * <p>메소드명      : 권원보험현황조회 /SMOINM01S01.do </p>
	 * <p>작성일자      : 2023. 4. 03.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험현황조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SMOINM01S01.do")
	public String SMOINM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SMOINM01Controller SMOINM01S01 Start #####");

		try {
			/*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/*************************************************
             * ■ 권원보험현황조회내역조회 업무 서비스 호출 입력값 대입
             *************************************************/
			SMOINM01S01InVO targetVo = new SMOINM01S01InVO();
			SMOINM01DSSMVO  smVo     = new SMOINM01DSSMVO();

            // ■ 조회일자시작, 조회일자종료
			BeanUtil.mapToBean(sourceMap, smVo);
			//smVo.setReadDtFr((String)sourceMap.get("readDtFr")); /** 조회일자시작 */
			//smVo.setReadDtTo((String)sourceMap.get("readDtTo")); /** 조회일자종료 */

			targetVo.setSMOINM01DSSMVO(smVo);

			/*************************************************
             * ■ 권원보험현황조회내역조회 업무 서비스 호출 수행
             *************************************************/
			SMOINM01S01OutVO resultSMOINM01S01 = SMOINM01.getSMOINM01S01(targetVo);

			/*************************************************
             * ■ 역할관리조회 DataSet 결과값 설정
             *************************************************/
            model.addAttribute(XFrame5View.XFRAME5_MSG_CODE  , resultSMOINM01S01.getRsltCd()  );
            model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSMOINM01S01.getRsltCntn());

			XFrame5Util.setOutputData("DS_SDDO01", resultSMOINM01S01.getSMOINM01DSSDDO01VO(), model);

			LOGGER.info("##### SMOINM01Controller SMOINM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			/*************************************************
             * ■ 오류 메시지 정보 설정
             *************************************************/
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SMOINM01Controller SMOINM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
