package hanalife.s.mo.in.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.mo.in.service.SMOINM03Service;
import hanalife.s.mo.in.vo.SMOINM03DSSMVO;
import hanalife.s.mo.in.vo.SMOINM03S01InVO;
import hanalife.s.mo.in.vo.SMOINM03S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM03Controller.java Class
 *
 * 클래스설명   : MCI현황조회 (SMOINM03) Controller
 * 작성일자     : 2023. 4. 6.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 6.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/mo/in")
@Controller
public class SMOINM03Controller {

	@Resource(name = "SMOINM03Service")
	private SMOINM03Service SMOINM03;

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM03Controller.class);

	/**
	 * <p>메소드명      : MCI현황조회조회 /SMOINM03S01.do </p>
	 * <p>작성일자      : 2023. 4. 6.
	 * <p>작성자(author): 70323
	 * <p>설명          : MCI현황조회 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SMOINM03S01.do")
	public String SMOINM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SMOINM03Controller SMOINM03S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** MCI현황조회내역조회 업무 서비스 호출 입력값 대입 */
			SMOINM03S01InVO targetVo = new SMOINM03S01InVO();
			SMOINM03DSSMVO smVo = new SMOINM03DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);

			LOGGER.info("##### SMOINM03Controller smVo Start ##### : " + smVo);

//			smVo.setBsnDivCd((String)sourceMap.get("bsnDivCd")); /** 업무구분코드 */
//			smVo.setLoanApplNo((String)sourceMap.get("loanApplNo")); /** 대출신청번호 */

			targetVo.setSMOINM03DSSMVO(smVo);

			/** MCI현황조회내역조회 업무 서비스 호출 수행 */
			SMOINM03S01OutVO resultSMOINM03S01 = SMOINM03.getSMOINM03S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSMOINM03S01.getSMOINM03DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSMOINM03S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSMOINM03S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### SMOINM03Controller SMOINM03S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SMOINM03Controller SMOINM03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
