package hanalife.s.mo.in.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.framework.comm.vo.UserSessionVO;
import hanalife.s.mo.in.service.SMOINM04Service;
import hanalife.s.mo.in.vo.SMOINM04DSSDCVO;
import hanalife.s.mo.in.vo.SMOINM04DSSMVO;
import hanalife.s.mo.in.vo.SMOINM04I01InVO;
import hanalife.s.mo.in.vo.SMOINM04I01OutVO;
import hanalife.s.mo.in.vo.SMOINM04S01InVO;
import hanalife.s.mo.in.vo.SMOINM04S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM04Controller.java Class
 *
 * 클래스설명   : MCI관리 (SMOINM04) Controller
 * 작성일자     : 2023. 4. 3.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 3.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/mo/in")
@Controller
public class SMOINM04Controller {

	@Resource(name = "SMOINM04Service")
	private SMOINM04Service SMOINM04;

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM04Controller.class);

	/**
	 * <p>메소드명      : MCI관리조회 /SMOINM04S01.do </p>
	 * <p>작성일자      : 2023. 4. 3.
	 * <p>작성자(author): 70323
	 * <p>설명          : MCI관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SMOINM04S01.do")
	public String SMOINM04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SMOINM04Controller SMOINM04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** MCI관리내역조회 업무 서비스 호출 입력값 대입 */
			SMOINM04S01InVO targetVo = new SMOINM04S01InVO();
			SMOINM04DSSMVO smVo = new SMOINM04DSSMVO();

			smVo.setBsnDivCd((String)sourceMap.get("bsnDivCd")); /** 업무구분코드 */
			smVo.setLoanApplNo((String)sourceMap.get("loanApplNo")); /** 대출신청번호 */

			targetVo.setSMOINM04DSSMVO(smVo);

			/** MCI관리내역조회 업무 서비스 호출 수행 */
			SMOINM04S01OutVO resultSMOINM04S01 = SMOINM04.getSMOINM04S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSMOINM04S01.getSMOINM04DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSMOINM04S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSMOINM04S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### SMOINM04Controller SMOINM04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SMOINM04Controller SMOINM04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : MCI관리전문송신 /SMOINM04I01.do </p>
	 * <p>작성일자      : 2023. 4. 3.
	 * <p>작성자(author): 70323
	 * <p>설명          : MCI관리 전문 송신 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SMOINM04I01.do")
	public String SMOINM04I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SMOINM04Controller SMOINM04I01 Start #####");

		try {
			/** 세션 정보 호출 */
			HttpSession session = request.getSession();
			UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

			/** 데이터셋 로그 출력 */
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			//parameter로 활용할 dataset 정보를 가져온다.
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** MCI관리전문송신 업무 서비스 호출 입력값 대입 */
			SMOINM04I01InVO targetVo = new SMOINM04I01InVO();
			SMOINM04DSSDCVO sgVo = new SMOINM04DSSDCVO();
			//TIFSGON001VO sgVo = new TIFSGON001VO();	/** 영업전문용VO */

			/** 전문 송신할 값 대입 */
			BeanUtil.mapToBean(sourceMap, sgVo);

//			sgVo.setLoanCnslNo(					(String)sourceMap.get("loanCnslNo")									); 		/** 대출상담번호 */
//			sgVo.setLoanApplNo(					(String)sourceMap.get("loanApplNo")									); 		/** 대출신청번호 */
//			sgVo.setCustNo(						(String)sourceMap.get("custNo")										); 		/** 고객번호 */
//			sgVo.setInsrdUse(					(String)sourceMap.get("insrdUse")									); 		/** 은행용도 */
//			sgVo.setBsdcd(						(String)sourceMap.get("bsdcd")										); 		/** 업무구분코드 */
//			sgVo.setCmpnyDvscd(					(String)sourceMap.get("cmpnyDvscd")									); 		/** 회사구분코드 */
//			sgVo.setDprtmCode(					(String)sourceMap.get("dprtmCode")									); 		/** 대출취급점포코드 */
//			sgVo.setBndno(						(String)sourceMap.get("bndno")										); 		/** SGI보험증권번호 */
//			sgVo.setRsnCode(					(String)sourceMap.get("rsnCode")									); 		/** 사유코드 */
//			sgVo.setRsnDate(					(String)sourceMap.get("rsnDate")									); 		/** 사유발생일자 */
//			sgVo.setMzdbRsrno(					(String)sourceMap.get("mzdbRsrno")									); 		/** 주채무자주민등록번호 */
//			sgVo.setClltrRlesKndcd(				(String)sourceMap.get("clltrRlesKndcd")								); 		/** 담보부동산종류 */
//			sgVo.setClltrLctnZpcd(				(String)sourceMap.get("clltrLctnZpcd")								); 		/** 담보소재지우편번호 */
//			sgVo.setClltrLctnAddrs(				(String)sourceMap.get("clltrLctnAddrs") 							);		/** 담보부동산소재지 */
//			sgVo.setRoomCount(					(String)sourceMap.get("roomCount") 									);		/** 방칸수 */
//			sgVo.setPrvusAreaSqrmt(				(String)sourceMap.get("prvusAreaSqrmt")								); 		/** 전용면적 */
//			sgVo.setOrofpStupAmnt(				Long.valueOf(RUtil.nvl((String)sourceMap.get("orofpStupAmnt"),"0"))	); 		/** 선순위설정금액 */
//			sgVo.setRlesEsvam(					Long.valueOf(RUtil.nvl((String)sourceMap.get("rlesEsvam"),"0"))		); 		/** 부동산평가금액 */
//			sgVo.setLoanPssam(					Long.valueOf(RUtil.nvl((String)sourceMap.get("loanPssam"),"0"))		); 		/** 총대출가능금액 */
//			sgVo.setLoanRqstAmnt(				Long.valueOf(RUtil.nvl((String)sourceMap.get("loanRqstAmnt"),"0"))	); 		/** 대출신청금액 */
//			sgVo.setVldtyClltrAmnt(				Long.valueOf(RUtil.nvl((String)sourceMap.get("vldtyClltrAmnt"),"0"))); 		/** 유효(가용)담보가 */
//			sgVo.setMciRlesVztnMthcd(			(String)sourceMap.get("mciRlesVztnMthcd")							); 		/** 부동산평가방법 */
//			sgVo.setLnprStrdt(					(String)sourceMap.get("lnprStrdt")									); 		/** 대출기간개시일자 */
//			sgVo.setAftchLnprEnddt(				(String)sourceMap.get("lnprEnddt")									); 		/** 대출기간종료일자 */
//			sgVo.setAftchLnprEnddt(				(String)sourceMap.get("aftchLnprEnddt")								); 		/** 대출기간종료일자(보험료계산용도) */
//			sgVo.setRpmcd(						(String)sourceMap.get("rpmcd")										); 		/** 상환방법 */
//			sgVo.setT1hRpyam(					Long.valueOf(RUtil.nvl((String)sourceMap.get("t1hRpyam"),"0"))		); 		/** 1회상환금액 */
//			sgVo.setLoanIntrt(					Double.valueOf(RUtil.nvl((String)sourceMap.get("loanIntrt"),"0"))	); 		/** 대출이자율 */
//			sgVo.setFrscnRpedt(					(String)sourceMap.get("frscnRpedt")									);		/** 초회상환일자 */
//			sgVo.setRpyunMntcn(					(String)sourceMap.get("rpyunMntcn")									); 		/** 상환단위 */
//			sgVo.setApplcDate(					(String)sourceMap.get("applcDate")									); 		/** 보험청약일자 */
//			sgVo.setMzdbName(					(String)sourceMap.get("mzdbName")									); 		/** 주채무자성명 */
//			sgVo.setMzdbQlfctCode(				(String)sourceMap.get("mzdbQlfctCode")								); 		/** 주채무자자격 */
//			sgVo.setMzdbAddrsZpcd(				(String)sourceMap.get("mzdbAddrsZpcd")								); 		/** 주채무자주민등록주소우편번호 */
//			sgVo.setMzdbAddrs(					(String)sourceMap.get("mzdbAddrs")									); 		/** 주채무자주민등록주소 */
//			sgVo.setMzdbTlpno(					(String)sourceMap.get("mzdbTlpno")									); 		/** 주채무자주민등록주소전화번호 */
//			sgVo.setMzdbMbpno(					(String)sourceMap.get("mzdbMbpno")									); 		/** 주채무자휴대폰번호 */
//			sgVo.setElctrDate(					(String)sourceMap.get("elctrDate")									); 		/** 전송일자 */
//			sgVo.setElctrTime(					(String)sourceMap.get("elctrTime")									); 		/** 전송시각 */
//			sgVo.setRnwlCntrcYn(				(String)sourceMap.get("rnwlCntrcYn")								); 		/** 보험갱신계약여부 */
//			sgVo.setTotalVllgCount(				(String)sourceMap.get("totalVllgCount")								); 		/** 총동수 */
//			sgVo.setTotalGnrtnCount(			(String)sourceMap.get("totalGnrtnCount")							); 		/** 총세대수 */
//			sgVo.setIncmAmnt(					Long.valueOf(RUtil.nvl((String)sourceMap.get("incmAmnt"),"0"))		); 		/** 소득금액 */
//			sgVo.setMciRlesVztnOrgcd(			(String)sourceMap.get("mciRlesVztnOrgcd")							); 		/** 부동산평가기관 */
//			sgVo.setLntvLmtrt(					Double.valueOf(RUtil.nvl((String)sourceMap.get("lntvLmtrt"),"0"))	); 		/** LTV한도 */
//			sgVo.setSmlamTnncyGrnam(			Long.valueOf(RUtil.nvl((String)sourceMap.get("smlamTnncyGrnam"),"0"))); 	/** 소액임차보증금해당액 */
//			sgVo.setCnorcJbccd(					(String)sourceMap.get("cnorcJbccd")									); 		/** 직업군코드 */
//			sgVo.setEtcSmlamTnncyGrnam(			(String)sourceMap.get("smlamTnncyGrnam")							); 		/** 기타주택보증가능한소액임차보증금(공제대상방수)  : 소액임차보증금과 같은 값 */
//			sgVo.setCrdhsRfrncAgreeYn1(			(String)sourceMap.get("crdhsRfrncAgreeYn1")							); 		/** 채무자신용정보조회동의여부 */
//			sgVo.setOfferEssntAgryn1((			String)sourceMap.get("offerEssntAgryn1")							); 		/** 채무자신용정보제공필수동의여부 */
//			sgVo.setOfferSlctnAgryn1(			(String)sourceMap.get("offerSlctnAgryn1")							); 		/** 채무자신용정보제공선택동의여부 */
//			sgVo.setGthrUseEssntAgryn1(			(String)sourceMap.get("gthrUseEssntAgryn1")							); 		/** 채무자신용정보수집이용필수동의여부 */
//			sgVo.setGthrUseSlctnAgryn1(			(String)sourceMap.get("gthrUseSlctnAgryn1")							); 		/** 채무자신용정보수집이용선택동의여부 */
//			sgVo.setCstmrIdnifAgryn1(			(String)sourceMap.get("cstmrIdnifAgryn1")							); 		/** 채무자고객식별정보동의여부 */
//			sgVo.setClltrLctnAddrsDvscd(		(String)sourceMap.get("clltrLctnAddrsDvscd")						); 		/** 담보소재지주소구분코드 */
//			sgVo.setClltrLctnLodnmPrmad(		(String)sourceMap.get("clltrLctnLodnmPrmad")						); 		/** 담보소재지도로명기본주소 */
//			sgVo.setClltrLctnLodnmEtcad(		(String)sourceMap.get("clltrLctnLodnmEtcad")						); 		/** 담보소재지도로명기타주소 */
//			sgVo.setMzdbRsdrgAddrsOrgcpDvscd(	(String)sourceMap.get("mzdbRsdrgAddrsOrgcpDvscd")					); 		/** 주채무자주소구분코드 */
//			sgVo.setMzdbRsdrgLodnmPrmad(		(String)sourceMap.get("mzdbRsdrgLodnmPrmad")						); 		/** 주채무자도로명기본주소 */
//			sgVo.setMzdbRsdrgLodnmEtcad(		(String)sourceMap.get("mzdbRsdrgLodnmEtcad")						); 		/** 주채무자도로명기타주소 */
//			sgVo.setClltrregno(					(String)sourceMap.get("clltrregno")									); 		/** 부동산고유번호 */
//			sgVo.setLogInEmpNo(					sessionVO.getEmpNo().toString()										); 		/** 로그인사원번호 */

			targetVo.setSMOINM04DSSDCVO(sgVo);

			/** MCI관리전문송신 업무 서비스 호출 수행 */
			//전문 서비스 호출, 리턴 값 받아서 거래내역 테이블에 적재
			//SMOINM04I01OutVO resultSMOINM04I01 = SMOINM04.registerSMOINM04I01(targetVo);	/** 전문 서비스 호출 */

			SMOINM04I01OutVO resultSMOINM04I01 = SMOINM04.registerSMOINM04I01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, "A000");		/** 결과코드 : 전문 개발 전까진 성공으로 하드코딩 */
			//model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSMOINM04I01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSMOINM04I01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### SMOINM04Controller SMOINM04I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SMOINM04Controller SMOINM04I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
