package hanalife.s.mo.lc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.mo.lc.mapper.ElecRegReptReadMapper;
import hanalife.s.mo.lc.mapper.dto.ElecRegReptReadDSSDDTO;
import hanalife.s.mo.lc.mapper.dto.ElecRegReptReadDSSMDTO;
import hanalife.s.mo.lc.service.SMOLCM01Service;
import hanalife.s.mo.lc.vo.SMOLCM01DSSDVO;
import hanalife.s.mo.lc.vo.SMOLCM01S01InVO;
import hanalife.s.mo.lc.vo.SMOLCM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOLCM01ServiceImpl.java Class
 * 클래스설명   : 전자등기현황조회 (SMOLCM01) Service Implements
 * 작성일자     : 2023. 5. 02.
 * 작성자명     : 70319 / ShinJeongSeon / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 02.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSMOLCM01S01 : 전자등기현황조회목록조회

 * </pre>
 */
@Service("SMOLCM01Service")
public class SMOLCM01ServiceImpl implements SMOLCM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(SMOLCM01ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private ElecRegReptReadMapper elecRegReptReadMapper;

    /**
     * <p>메소드명       	: getSMOLCM01S01 : 전자등기현황조회</p>
     * <p>작성일자       	: 2023. 3. 21.
     * <p>작성자(author)	: 70319 / ShinJeongSeon
     * <p>설명          	: 전자등기현황조회 한다.</p>
     * <p>메소드인수     	: SMOLCM01S01InVo </p>
     * <p>메소드리턴값    	: SMOLCM01S01OutVo</p>
     * <p>예외처리       	: Exception</p>
     */
    @Override
    public SMOLCM01S01OutVO getSMOLCM01S01(SMOLCM01S01InVO inVo) throws Exception {

        /*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
        SMOLCM01S01OutVO resultVo = new SMOLCM01S01OutVO();
        ElecRegReptReadDSSMDTO inDto = new ElecRegReptReadDSSMDTO();

        resultVo.setRsltCd  (msgEnum.SUCCESS.getErrorCd()    );
        resultVo.setRsltCntn(msgEnum.SUCCESS.getDescription());

        /*************************************************
         * ■ 검색조건 셋팅
         *************************************************/
        inDto.setReadDtFr     (inVo.getSMOLCM01DSSMVO().getReadDtFr()     );    /** 조회일자시작 */
        inDto.setReadDtTo     (inVo.getSMOLCM01DSSMVO().getReadDtTo()     );    /** 조회일자종료 */
        inDto.setApplNo       (inVo.getSMOLCM01DSSMVO().getApplNo()       );    /** 신청번호 */
        inDto.setCustResiNo   (inVo.getSMOLCM01DSSMVO().getCustResiNo()   );    /** 생년월일 */
        inDto.setCustNo       (inVo.getSMOLCM01DSSMVO().getCustNo()       );    /** 고객번호 */
        inDto.setCustNm       (inVo.getSMOLCM01DSSMVO().getCustNm()       );    /** 고객명 */
        inDto.setRegPrgsStatCd(inVo.getSMOLCM01DSSMVO().getRegPrgsStatCd());    /** 등기진행상태코드 */
        inDto.setRegPrgsStatNm(inVo.getSMOLCM01DSSMVO().getRegPrgsStatNm());    /** 등기진행상태명 */

        /*************************************************
         * ■ 전자등기현황조회
         *************************************************/
        List<ElecRegReptReadDSSDDTO> resultDTO = elecRegReptReadMapper.searchElecRegReptReadList(inDto);

        List<SMOLCM01DSSDVO> resultList = new ArrayList<SMOLCM01DSSDVO>();

        try {
        	for (ElecRegReptReadDSSDDTO sourceIO : resultDTO) {
        		SMOLCM01DSSDVO targetIO = new SMOLCM01DSSDVO();

        		//----------------------------------------------------------
        		// □ 이름 마스킹처리
        		//----------------------------------------------------------
        		String strMaskCustNm = this.nameMasking(sourceIO.getCustNm().toString());

        		targetIO.setApplNo        (sourceIO.getApplNo()        );    /** 신청번호 */
        		targetIO.setApplDt        (sourceIO.getApplDt()        );    /** 신청일자 */
        		targetIO.setAprvDt        (sourceIO.getAprvDt()        );    /** 승인일자 */
        		targetIO.setLoanNo        (sourceIO.getLoanNo()        );    /** 대출번호 */
        		targetIO.setLoanSeq       (sourceIO.getLoanSeq()       );    /** 대출순번 */
        		targetIO.setCustNo        (sourceIO.getCustNo()        );    /** 고객번호 */
        		targetIO.setCustNm        (strMaskCustNm               );    /** 고객명 */
        		targetIO.setCustResiNo    (sourceIO.getCustResiNo()    );    /** 주민등록번호 */
        		targetIO.setSetNo         (sourceIO.getSetNo()         );    /** 설정번호 */
        		targetIO.setLoanPrgsStatCd(sourceIO.getLoanPrgsStatCd());    /** 대출진행상태코드 */
        		//targetIO.setLoanPrgsStatNm(sourceIO.getLoanPrgsStatNm());    /** 대출진행상태명 */
        		targetIO.setRegPrgsStatCd (sourceIO.getRegPrgsStatCd() );    /** 등기진행상태코드 */
        		//targetIO.setRegPrgsStatNm (sourceIO.getRegPrgsStatNm() );    /** 등기진행상태명 */
        		targetIO.setLoanAmt       (sourceIO.getLoanAmt()       );    /** 대출금액 */
        		targetIO.setSetAmt        (sourceIO.getSetAmt()        );    /** 설정금액 */

        		/*************************************************
        		 * ■ List 객체에 추가하도록 수행
        		 *************************************************/
        		resultList.add(targetIO);
        	}
        } catch (Exception e) {
            LOGGER.error("[전자등기현황조회 오류] : 전자등기현황조회 중 오류  " + e.getMessage() + " > " + e.toString() );
            resultVo.setRsltCd  ( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        /*************************************************
         * ■ 화면 리턴 리스트 셋팅
         *************************************************/
        resultVo.setSMOLCM01DSSDVO(resultList);

        return resultVo;
    }

    /**
     * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
     * <p>작성일자      : 2023. 4. 12.
     * <p>작성자(author): 70323 / HeoHyemi
     * <p>설명          : 성명 마스킹 처리 한다.</p>
     * <p>메소드인수    : String</p>
     * <p>메소드리턴값  : String</p>
     * <p>예외처리      : Exception</p>
     */
    private String nameMasking(String name) {

        String maskName = "";

        if(name.length() <= 0) {
            return maskName;
        }

        String fstName = name.substring(0, 1);                    // 성
        String midName = name.substring(1, name.length() -1);    // 가운데 이름
        String lstName = name.substring(name.length() -1);        // 마지막 글자

        String midMask = "";    // 중간 마스킹 처리

        for(int i = 0; i < midName.length(); i++) {
            midMask += "*";
        }

        if(midName.equals("")) {    // 외자일 경우
            maskName = fstName + "*";
        }else {
            maskName = fstName + midMask + lstName;
        }

        return maskName;
    }

}
