package hanalife.s.mo.lc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.mo.lc.service.SMOLCM01Service;
import hanalife.s.mo.lc.vo.SMOLCM01DSSMVO;
import hanalife.s.mo.lc.vo.SMOLCM01S01InVO;
import hanalife.s.mo.lc.vo.SMOLCM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOLCM01Controller.java Class
 * 클래스설명   : 전자등기현황조회 (SMOLCM01) Controller
 * 작성일자     : 2023. 5. 02.
 * 작성자명     : 70319 / ShinJeongSeon / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 02.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/mo/lc")
@Controller
public class SMOLCM01Controller {

	@Resource(name = "SMOLCM01Service")
	private SMOLCM01Service SMOLCM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOLCM01Controller.class);

	/**
	 * <p>메소드명      : 전자등기현황조회 /SMOLCM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70323
	 * <p>설명          : 전자등기현황조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SMOLCM01S01.do")
	public String SMOLCM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SMOLCM01Controller SMOLCM01S01 Start #####");

		try {
			/*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
        	Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

        	XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			Map<String, Object> sourceMap = XFrame5Util.getDataMap(reqMap, "DS_SM", 0);

			/*************************************************
             * ■ 전자등기현황조회내역조회 업무 서비스 호출 입력값 대입
             *************************************************/
			SMOLCM01S01InVO targetVo = new SMOLCM01S01InVO();
			SMOLCM01DSSMVO  smVo     = new SMOLCM01DSSMVO();

//			smVo.setReadDtFr((String)sourceMap.get("readDtFr")); /** 조회일자시작 */
//			smVo.setReadDtTo((String)sourceMap.get("readDtTo")); /** 조회일자종료 */
//			smVo.setApplNo((String)sourceMap.get("applNo")); /** 신청번호 */
//			smVo.setCustResiNo((String)sourceMap.get("custResiNo")); /** 주민등록번호 */
//			smVo.setCustNo((String)sourceMap.get("custNo")); /** 고객번호 */
//			smVo.setCustNm((String)sourceMap.get("custNm")); /** 고객명 */
//			smVo.setRegPrgsStatCd((String)sourceMap.get("regPrgsStatCd")); /** 등기진행상태코드 */
//			smVo.setRegPrgsStatNm((String)sourceMap.get("regPrgsStatNm")); /** 등기진행상태명 */

			LOGGER.info("##### SMOLCM01S01 ReadDtFr      > " + sourceMap.get("readDtFr").toString() );
			LOGGER.info("##### SMOLCM01S01 ReadDtTo      > " + sourceMap.get("readDtTo").toString() );
			LOGGER.info("##### SMOLCM01S01 ApplNo        > " + sourceMap.get("applNo").toString() );
			LOGGER.info("##### SMOLCM01S01 CustResiNo    > " + sourceMap.get("custResiNo").toString() );
			LOGGER.info("##### SMOLCM01S01 CustNo        > " + sourceMap.get("custNo").toString() );
			LOGGER.info("##### SMOLCM01S01 CustNm        > " + sourceMap.get("custNm").toString() );
			LOGGER.info("##### SMOLCM01S01 RegPrgsStatCd > " + sourceMap.get("regPrgsStatCd").toString() );
			LOGGER.info("##### SMOLCM01S01 RegPrgsStatNm > " + sourceMap.get("regPrgsStatNm").toString() );

			// ■ 조회일자시작, 조회일자종료
			BeanUtil.mapToBean(sourceMap, smVo);
			targetVo.setSMOLCM01DSSMVO(smVo);

			/*************************************************
             * ■ 전자등기현황조회내역조회 업무 서비스 호출 수행
             *************************************************/
			SMOLCM01S01OutVO resultSMOLCM01S01 = SMOLCM01.getSMOLCM01S01(targetVo);

			/*************************************************
             * ■ 전자등기현황조회내역조회 DataSet 결과값 설정
             *************************************************/
            model.addAttribute(XFrame5View.XFRAME5_MSG_CODE  , resultSMOLCM01S01.getRsltCd()  );
            model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSMOLCM01S01.getRsltCntn());

			XFrame5Util.setOutputData("DS_SD", resultSMOLCM01S01.getSMOLCM01DSSDVO(), model);

			LOGGER.info("##### SMOLCM01Controller SMOLCM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			/*************************************************
             * ■ 오류 메시지 정보 설정
             *************************************************/
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"        );
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SMOLCM01Controller SMOLCM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
