package hanalife.s.pd.pd.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD01OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD03OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD04OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD05OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD12OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD13OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD14OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SM02OutDTO;
import hanalife.s.pd.pd.vo.SPDPDM02InVO;

/**
 * <pre>
 * 클래스명    : PrdtMngMapper.java Class
 * 클래스설명  : 상품관리 Mapper
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------ㄲ
 * [2023. 3. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 * @param <SPDPDM02InVO>
 */
@Mapper("prdtMngMapper")
public interface PrdtMngMapper {
	/**
     * <p>메소드명      : searchPrdtMng</p>
     * <p>설명          : 상품관리 상품기본정보를 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 기본정보 내역 조회 결과 SPDPDM02SM02OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SM02OutDTO> searchPrdtMng(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPiamtCond</p>
     * <p>설명          : 상품관리 원리금구성조건을 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 기본정보 내역 조회 결과 SPDPDM02SM02OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD01OutDTO> searchPiamtCond(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPrdtCond</p>
     * <p>설명          : 상품관리 상품구성조건을 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 상품구성조건 조회 결과 SPDPDM02SD03OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD03OutDTO> searchPrdtCond(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPrdtCondDesc</p>
     * <p>설명          : 상품관리 상품구성조건내역을 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 상품구성조건내역 조회 결과 SPDPDM02SD04OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD04OutDTO> searchPrdtCondDesc(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPrdtCondSpec</p>
     * <p>설명          : 상품관리 상품구성조건상세를 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 상품구성조건상세 조회 결과 SPDPDM02SD05OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD05OutDTO> searchPrdtCondSpec(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchMidRmbrFeeRt</p>
     * <p>설명          : 상품관리 중도상환수수료울 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 중도상환수수료울 조회 결과 SPDPDM02SD12OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD12OutDTO> searchMidRmbrFeeRt(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPrdtOper</p>
     * <p>설명          : 상품관리 상품운영조건을 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 상품운영조건 조회 결과 SPDPDM02SD12OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD13OutDTO> searchPrdtOper(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : searchPrdtOperSpec</p>
     * <p>설명          : 상품관리 상품운영조건상세를 조회 한다.</p>
     * <p>메소드인수1   : SPDPDM02InVO inDto </p>
     * <p>메소드리턴값  : 상품운영조건상세 조회 결과 SPDPDM02SD12OutDTO list</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SPDPDM02SD14OutDTO> searchPrdtOperSpec(SPDPDM02InVO inDto) throws Exception;

    /**
     * <p>메소드명      : insertPrdtMng</p>
     * <p>설명          : 상품관리를 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SM02OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertPrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : updatePrdtMng</p>
     * <p>설명          : 상품관리를 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SM02OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updatePrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : deletePrdtMng</p>
     * <p>설명          : 상품관리를 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SM02OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deletePrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : insertPiamtInfo</p>
     * <p>설명          : 상품관리 원리금정보를 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD01OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertPiamtInfo(SPDPDM02SD01OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : updatePiamtInfo</p>
     * <p>설명          : 상품관리 원리금정보를 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD01OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updatePiamtInfo(SPDPDM02SD01OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : deletePiamtInfo</p>
     * <p>설명          : 상품관리 원리금정보를 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD01OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deletePiamtInfo(SPDPDM02SD01OutDTO inVo) throws Exception;

    /**
     * <p>메소드명      : insertCondBase</p>
     * <p>설명          : 상품관리 상품조건을 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD03OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertCondBase(SPDPDM02SD03OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : updateCondBase</p>
     * <p>설명          : 상품관리 상품조건을 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD03OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updateCondBase(SPDPDM02SD03OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : deleteCondBase</p>
     * <p>설명          : 상품관리 상품조건을 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD03OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deleteCondBase(SPDPDM02SD03OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : insertCondDesc</p>
     * <p>설명          : 상품관리 상품조건내역을 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD04OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : updateCondDesc</p>
     * <p>설명          : 상품관리 상품조건내역을 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD04OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updateCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : deleteCondDesc</p>
     * <p>설명          : 상품관리 상품조건내역을 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD04OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deleteCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : insertCondSpec</p>
     * <p>설명          : 상품관리 상품조건상세를 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD05OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : updateCondSpec</p>
     * <p>설명          : 상품관리 상품조건상세를 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD05OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updateCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : deleteCondSpec</p>
     * <p>설명          : 상품관리 상품조건상세를 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD05OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deleteCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : insertMidRmbrFeeRt</p>
     * <p>설명          : 상품관리 중도상환수수료울을 등록 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD12OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void insertMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : updateMidRmbrFeeRt</p>
     * <p>설명          : 상품관리 중도상환수수료울을 수정 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD12OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void updateMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception;

    /**
     * <p>메소드명      : deleteMidRmbrFeeRt</p>
     * <p>설명          : 상품관리 중도상환수수료울을 삭제 한다.</p>
     * <p>메소드인수1   : SPDPDM02SD12OutDTO inDTO </p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public void deleteMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception;
}
