package hanalife.s.pd.pd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.pd.pd.mapper.PrdtClasMapper;
import hanalife.s.pd.pd.mapper.dto.SPDPDM01DSSDOutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM01SrchDTO;
import hanalife.s.pd.pd.service.SPDPDM01Service;
import hanalife.s.pd.pd.vo.SPDPDM01DSDDSSVO;
import hanalife.s.pd.pd.vo.SPDPDM01InVO;
import hanalife.s.pd.pd.vo.SPDPDM01OutVO;

/**
 * <pre>
 * 클래스명    : SPDPDM01ServiceImpl.java Class
 * 클래스설명  : 상품분류관리 (SPDPDM01) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("SPDPDM01Service")
public class SPDPDM01ServiceImpl implements SPDPDM01Service {

    @SuppressWarnings("unused")
	private static final Logger LOGGER = LoggerFactory.getLogger(SPDPDM01ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private PrdtClasMapper prdtClasMapper;                      // 상푼분류

    /**
     * <p>메소드명      : getSelectMainInfo : 상품분류관리를 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 조회 한다.</p>
     * <p>메소드인수    : SPDPDM01InVO </p>
     * <p>메소드리턴값  : SPDPDM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("static-access")
	@Override
    public SPDPDM01OutVO getSelectMainInfo(SPDPDM01InVO inVo) throws Exception{

    	LOGGER.info("##### SPDPDM01ServiceImpl SPDPDM01S01 Start #####");
    	SPDPDM01OutVO resultVo = new SPDPDM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 결과 리턴 List
        List<SPDPDM01DSDDSSVO> returnList = new ArrayList<SPDPDM01DSDDSSVO>();

        // 검색조건 세팅
        SPDPDM01SrchDTO srchDTO = new SPDPDM01SrchDTO();
        srchDTO.setLrgeClasCd(inVo.getSPDPDM01DSSMVO().getLrgeClasCd());	// 상품대분류
        srchDTO.setMidClasCd(inVo.getSPDPDM01DSSMVO().getMidClasCd());      // 상품중분류
        srchDTO.setSmClasCd(inVo.getSPDPDM01DSSMVO().getSmClasCd());        // 상품소분류
        srchDTO.setClasNm(inVo.getSPDPDM01DSSMVO().getClasNm());            // 상품분류명

        // 기본정보 조회
        List<SPDPDM01DSSDOutDTO> outList01 = prdtClasMapper.searchPrdtClas(srchDTO);

        for( SPDPDM01DSSDOutDTO dto : outList01 ) {
        	SPDPDM01DSDDSSVO vo = new SPDPDM01DSDDSSVO();

            vo.setPrdtClasCd(dto.getPrdtClasCd());          // 상품분류코드
            vo.setLrgeClasCd(dto.getLrgeClasCd());          // 상품대분류
            vo.setMidClasCd(dto.getMidClasCd());            // 상품중분류
            vo.setSmClasCd(dto.getSmClasCd());              // 상품소분류
            vo.setClasDivCd(dto.getClasDivCd());            // 분류구분코드
            vo.setClasNm(dto.getClasNm());            		// 분류명

            returnList.add(vo);
        }

        /* 출력 결과값 대입 */
        resultVo.setSPDPDM01DSDDSSVO(returnList);

        LOGGER.info("##### SPDPDM01ServiceImpl SPDPDM01S01 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : registerMainInfo : 상품분류관리를 등록</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 등록 한다.</p>
     * <p>메소드인수    : SPDPDM01InVO </p>
     * <p>메소드리턴값  : SPDPDM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
	@SuppressWarnings("static-access")
	@Override
	public SPDPDM01OutVO registerMainInfo(SPDPDM01InVO inVo) throws Exception {
		SPDPDM01OutVO resultVo = new SPDPDM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        int procCnt = inVo.getSPDPDM01DSDDSSVO().size();
        String empNo = inVo.getSPDPDM01DSSMVO().getUserNo();

        if(procCnt > 0) {
        	for(int i=0; i<procCnt; i++) {
	        	SPDPDM01SrchDTO srchDTO = new SPDPDM01SrchDTO();

	            srchDTO.setPrdtClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getPrdtClasCd());	 // 상품분류코드
	            srchDTO.setLrgeClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getLrgeClasCd());	 // 상품대분류
	            srchDTO.setMidClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getMidClasCd());      // 상품중분류
	            srchDTO.setSmClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getSmClasCd());        // 상품소분류
	            srchDTO.setClasDivCd(inVo.getSPDPDM01DSDDSSVO().get(i).getClasDivCd());      // 분류구분코드
	            srchDTO.setClasNm(inVo.getSPDPDM01DSDDSSVO().get(i).getClasNm());            // 상품분류명
	            srchDTO.setDdayPrftLoseFg(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseFg());
	            srchDTO.setDdayPrftLoseDivCd(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseDivCd());
	            srchDTO.setDdayPrftLoseDivVal(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseDivVal());
	            srchDTO.setDdayPrftLosePamtRamtRt(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLosePamtRamtRt());
	            srchDTO.setEmpNo(empNo);

	            prdtClasMapper.insertPrdtClas(srchDTO);
        	}
        }

		return resultVo;
	}

	 /**
     * <p>메소드명      : updateMainInfo : 상품분류관리를 수정</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 수정 한다.</p>
     * <p>메소드인수    : SPDPDM01InVO </p>
     * <p>메소드리턴값  : SPDPDM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
	@SuppressWarnings("static-access")
	@Override
	public SPDPDM01OutVO updateMainInfo(SPDPDM01InVO inVo) throws Exception {
		SPDPDM01OutVO resultVo = new SPDPDM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        int procCnt = inVo.getSPDPDM01DSDDSSVO().size();
        String empNo = inVo.getSPDPDM01DSSMVO().getUserNo();

        if(procCnt > 0) {
        	for(int i=0; i<procCnt; i++) {
	        	SPDPDM01SrchDTO srchDTO = new SPDPDM01SrchDTO();

	        	srchDTO.setPrdtClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getPrdtClasCd());	 // 상품분류코드
	            srchDTO.setClasDivCd(inVo.getSPDPDM01DSDDSSVO().get(i).getClasDivCd());      // 분류구분코드
	            srchDTO.setClasNm(inVo.getSPDPDM01DSDDSSVO().get(i).getClasNm());            // 상품분류명
	            srchDTO.setDdayPrftLoseFg(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseFg());
                srchDTO.setDdayPrftLoseDivCd(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseDivCd());
                srchDTO.setDdayPrftLoseDivVal(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLoseDivVal());
                srchDTO.setDdayPrftLosePamtRamtRt(inVo.getSPDPDM01DSDDSSVO().get(i).getDdayPrftLosePamtRamtRt());
	            srchDTO.setEmpNo(empNo);

	            prdtClasMapper.updatePrdtClas(srchDTO);
        	}
        }

		return resultVo;
	}

	 /**
     * <p>메소드명      : deleteMainInfo : 상품분류관리를 삭제</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 삭제 한다.</p>
     * <p>메소드인수    : SPDPDM01InVO </p>
     * <p>메소드리턴값  : SPDPDM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
	@SuppressWarnings("static-access")
	@Override
	public SPDPDM01OutVO deleteMainInfo(SPDPDM01InVO inVo) throws Exception {
		SPDPDM01OutVO resultVo = new SPDPDM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        int procCnt = inVo.getSPDPDM01DSDDSSVO().size();
        String empNo = inVo.getSPDPDM01DSSMVO().getUserNo();

        if(procCnt > 0) {
        	for(int i=0; i<procCnt; i++) {
	        	SPDPDM01SrchDTO srchDTO = new SPDPDM01SrchDTO();

	        	srchDTO.setPrdtClasCd(inVo.getSPDPDM01DSDDSSVO().get(i).getPrdtClasCd());	 // 상품분류코드

	            prdtClasMapper.deletePrdtClas(srchDTO);
        	}
        }

		return resultVo;
	}
}