package hanalife.s.pd.pd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.pd.pd.mapper.PrdtMngMapper;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD01OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD03OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD04OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD05OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD12OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD13OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SD14OutDTO;
import hanalife.s.pd.pd.mapper.dto.SPDPDM02SM02OutDTO;
import hanalife.s.pd.pd.service.SPDPDM02Service;
import hanalife.s.pd.pd.vo.SPDPDM02InVO;
import hanalife.s.pd.pd.vo.SPDPDM02OutVO;

/**
 * <pre>
 * 클래스명    : SPDPDM02ServiceImpl.java Class
 * 클래스설명  : 상품관리 (SPDPDM02) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("SPDPDM02Service")
public class SPDPDM02ServiceImpl implements SPDPDM02Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(SPDPDM02ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private PrdtMngMapper prdtMngMapper;                      // 상푼관리

    /**
     * <p>메소드명      : getSelectMainInfo : 상품관리를 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품관리를 조회 한다.</p>
     * <p>메소드인수    : SPDPDM02InVO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */

    @Override
    @SuppressWarnings("static-access")
    public SPDPDM02OutVO getSelectMainInfo(SPDPDM02InVO inVo) throws Exception{

    	LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02S01 Start #####");
    	SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        List<SPDPDM02SM02OutDTO> mainInfoOutList = new ArrayList<SPDPDM02SM02OutDTO>(); 	// 상품관리
        List<SPDPDM02SD01OutDTO> piamtCondOutList = new ArrayList<SPDPDM02SD01OutDTO>();	// 원리금구성조건
        List<SPDPDM02SD03OutDTO> prdtCondOutList = new ArrayList<SPDPDM02SD03OutDTO>();		// 상품구성조건
        List<SPDPDM02SD04OutDTO> prdtCondDescOutList = new ArrayList<SPDPDM02SD04OutDTO>();	// 상품구성조건내역
        List<SPDPDM02SD05OutDTO> prdtCondSpecOutList = new ArrayList<SPDPDM02SD05OutDTO>();	// 상품구성조건상세
        List<SPDPDM02SD12OutDTO> midRmbrFeeRtOutList = new ArrayList<SPDPDM02SD12OutDTO>();	// 중도상환수수료율
        List<SPDPDM02SD13OutDTO> prdtOperOutList = new ArrayList<SPDPDM02SD13OutDTO>();		// 상품운영조건
        List<SPDPDM02SD14OutDTO> prdtOperSpecOutList = new ArrayList<SPDPDM02SD14OutDTO>();	// 상품운영조건내역

        // 기본정보 조회
        LOGGER.info("##### 기본정보 조회 Start #####");
        mainInfoOutList = prdtMngMapper.searchPrdtMng(inVo);
        LOGGER.info("##### 기본정보 조회 End #####");

        // 원리금구성조건 조회
        LOGGER.info("##### 원리금구성조건 조회 Start #####");
    	piamtCondOutList = prdtMngMapper.searchPiamtCond(inVo);
    	LOGGER.info("##### 원리금구성조건 조회 Start #####");

        // 상품구성조건 조회
    	LOGGER.info("##### 상품구성조건 조회 Start #####");
    	prdtCondOutList = prdtMngMapper.searchPrdtCond(inVo);
    	LOGGER.info("##### 상품구성조건 조회 End #####");

        if(prdtCondOutList.size() > 0) {
        	// inVO조건번호 SET
            inVo.setCondNo(prdtCondOutList.get(0).getCondNo());

            // 상품구성조건내역 조회
            LOGGER.info("##### 상품구성조건내역 조회 Start #####");
            prdtCondDescOutList = prdtMngMapper.searchPrdtCondDesc(inVo);
            LOGGER.info("##### 상품구성조건내역 조회 End #####");

            if(prdtCondDescOutList.size() > 0 ) {
                // inVO조건번호 SET
                inVo.setCondAplyNo(prdtCondDescOutList.get(0).getCondAplyNo());
                // 상품구성조건상세 조회
                LOGGER.info("##### 상품구성조건상세 조회 Start #####");
                prdtCondSpecOutList = prdtMngMapper.searchPrdtCondSpec(inVo);
                LOGGER.info("##### 상품구성조건상세 조회 End #####");
            }
    	}

    	// 중도상환수수료울 조건 조회
    	LOGGER.info("##### 중도상환수수료울 조회 Start #####");
    	midRmbrFeeRtOutList = prdtMngMapper.searchMidRmbrFeeRt(inVo);
    	LOGGER.info("##### 중도상환수수료울 조회 End #####");

    	// 상품운영조건 조회
    	LOGGER.info("##### 상품운영조건 조회 Start #####");
    	prdtOperOutList = prdtMngMapper.searchPrdtOper(inVo);
    	LOGGER.info("##### 상품운영조건 조회 End #####");

    	if(prdtOperOutList.size() > 0) {
    		// inVO운영조건번호 SET
            inVo.setOperCondNo(prdtOperOutList.get(0).getOperCondNo());

            LOGGER.info("##### 상품운영조건상세 조회 Start #####");
        	prdtOperSpecOutList = prdtMngMapper.searchPrdtOperSpec(inVo);
        	LOGGER.info("##### 상품운영조건상세 조회 End #####");
        }

        /* 기본정보 조회출력 결과값 대입 */
        resultVo.setSPDPDM02SM02OutDTO(mainInfoOutList);
        /* 원리금구성조건 출력 결과값 대입 */
        resultVo.setSPDPDM02SD01OutDTO(piamtCondOutList);
        /* 상품구성조건 출력 결과값 대입 */
        resultVo.setSPDPDM02SD03OutDTO(prdtCondOutList);
        /* 상품구성조건내역 출력 결과값 대입 */
        resultVo.setSPDPDM02SD04OutDTO(prdtCondDescOutList);
        /* 상품구성조건상세 출력 결과값 대입 */
        resultVo.setSPDPDM02SD05OutDTO(prdtCondSpecOutList);
        /* 중도상환수수료울 출력 결과값 대입 */
        resultVo.setSPDPDM02SD12OutDTO(midRmbrFeeRtOutList);
        /* 상품운영조건 출력 결과값 대입 */
        resultVo.setSPDPDM02SD13OutDTO(prdtOperOutList);
        /* 상품운영조건상세 출력 결과값 대입 */
        resultVo.setSPDPDM02SD14OutDTO(prdtOperSpecOutList);

        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02S01 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : getSelectMidRmbrFeeRt : 상품관리 중도상환수수료율을 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품관리 중도상환수수료율을 조회 한다.</p>
     * <p>메소드인수    : SPDPDM02InVO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */

    @Override
    public SPDPDM02OutVO getSelectMidRmbrFeeRt(SPDPDM02InVO inVo) throws Exception {

        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02S01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        List<SPDPDM02SD12OutDTO> midRmbrFeeRtOutList = new ArrayList<SPDPDM02SD12OutDTO>(); // 중도상환수수료율

        // 중도상환수수료울 조건 조회
        LOGGER.info("##### 중도상환수수료울 조회 Start #####");
        midRmbrFeeRtOutList = prdtMngMapper.searchMidRmbrFeeRt(inVo);
        LOGGER.info("##### 중도상환수수료울 조회 End #####");

        /* 중도상환수수료울 출력 결과값 대입 */
        resultVo.setSPDPDM02SD12OutDTO(midRmbrFeeRtOutList);

        return resultVo;
    }

    /**
     * <p>메소드명      : insertPrdtMng : 상품관리 등록</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 등록한다.</p>
     * <p>메소드인수    : SPDPDM02SM02OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertPrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 등록 Start #####");
        prdtMngMapper.insertPrdtMng(inVo);
        LOGGER.info("##### 상품관리 등록 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updatePrdtMng : 상품관리 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02InVO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updatePrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 수정 Start #####");
        prdtMngMapper.updatePrdtMng(inVo);
        LOGGER.info("##### 상품관리 수정 End #####");

        return resultVo;
    }


    /**
     * <p>메소드명      : deletePrdtMng : 상품관리 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD01OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deletePrdtMng(SPDPDM02SM02OutDTO inVo) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 삭제 Start #####");
        prdtMngMapper.deletePrdtMng(inVo);
        LOGGER.info("##### 상품관리 삭제 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : insertPiamtInfo : 상품관리 원리금정보 생성</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 생성한다.</p>
     * <p>메소드인수    : SPDPDM02SD01OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertPiamtInfo(SPDPDM02SD01OutDTO inVo) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 원리금정보 등록 Start #####");
        prdtMngMapper.insertPiamtInfo(inVo);
        LOGGER.info("##### 상품관리 원리금정보 등록 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updatePiamtInfo : 상품관리 원리금정보 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02SD01OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updatePiamtInfo(SPDPDM02SD01OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 원리금정보 수정 Start #####");
        prdtMngMapper.updatePiamtInfo(inVO);
        LOGGER.info("##### 상품관리 원리금정보 수정 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : deletePiamtInfo : 상품관리 원리금정보 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD01OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deletePiamtInfo(SPDPDM02SD01OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 원리금정보 삭제 Start #####");
        prdtMngMapper.deletePiamtInfo(inVO);
        LOGGER.info("##### 상품관리 원리금정보 삭제 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : insertCondBase : 상품관리 상품조건 생성</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 생성한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertCondBase(SPDPDM02SD03OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건 생성 Start #####");
        prdtMngMapper.insertCondBase(inVO);
        LOGGER.info("##### 상품관리 상품조건 생성 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updateCondBase : 상품관리 상품조건 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updateCondBase(SPDPDM02SD03OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건 수정 Start #####");
        prdtMngMapper.updateCondBase(inVO);
        LOGGER.info("##### 상품관리 상품조건 수정 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : deleteCondBase : 상품관리 상품조건 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deleteCondBase(SPDPDM02SD03OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건 삭제 Start #####");
        prdtMngMapper.deleteCondBase(inVO);
        LOGGER.info("##### 상품관리 상품조건 삭제 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : insertCondDesc : 상품관리 상품조건내역 생성</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 생성한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건내역 생성 Start #####");
        prdtMngMapper.insertCondDesc(inVO);
        LOGGER.info("##### 상품관리 상품조건내역 생성 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updateCondDesc : 상품관리 상품조건내역 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updateCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건내역 수정 Start #####");
        prdtMngMapper.updateCondDesc(inVO);
        LOGGER.info("##### 상품관리 상품조건내역 수정 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : deleteCondDesc : 상품관리 상품조건내역 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deleteCondDesc(SPDPDM02SD04OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건내역 삭제 Start #####");
        prdtMngMapper.deleteCondDesc(inVO);
        LOGGER.info("##### 상품관리 상품조건내역 삭제 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : insertCondSpec : 상품관리 상품조건상세 생성</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 생성한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건상세 생성 Start #####");
        prdtMngMapper.insertCondSpec(inVO);
        LOGGER.info("##### 상품관리 상품조건상세 생성 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updateCondSpec : 상품관리 상품조건상세 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updateCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건상세 수정 Start #####");
        prdtMngMapper.updateCondSpec(inVO);
        LOGGER.info("##### 상품관리 상품조건상세 수정 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : deleteCondSpec : 상품관리 상품조건상세 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deleteCondSpec(SPDPDM02SD05OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 상품조건상세 삭제 Start #####");
        prdtMngMapper.deleteCondSpec(inVO);
        LOGGER.info("##### 상품관리 상품조건상세 삭제 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : insertMidRmbrFeeRt : 상품관리 중도상환수수료율 생성</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 생성한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO insertMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 중도상환수수료율 생성 Start #####");
        prdtMngMapper.insertMidRmbrFeeRt(inVO);
        LOGGER.info("##### 상품관리 중도상환수수료율 생성 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : updateMidRmbrFeeRt : 상품관리 중도상환수수료율 수정</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 수정한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO updateMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 중도상환수수료율 수정 Start #####");
        prdtMngMapper.updateMidRmbrFeeRt(inVO);
        LOGGER.info("##### 상품관리 중도상환수수료율 수정 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : deleteMidRmbrFeeRt : 상품관리 중도상환수수료율 삭제</p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 입력받은 데이터를 1건 삭제한다.</p>
     * <p>메소드인수    : SPDPDM02SD03OutDTO </p>
     * <p>메소드리턴값  : SPDPDM02OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    public SPDPDM02OutVO deleteMidRmbrFeeRt(SPDPDM02SD12OutDTO inVO) throws Exception {
        LOGGER.info("##### SPDPDM02ServiceImpl SPDPDM02I01 Start #####");
        SPDPDM02OutVO resultVo = new SPDPDM02OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        LOGGER.info("##### 상품관리 중도상환수수료율 삭제 Start #####");
        prdtMngMapper.deleteMidRmbrFeeRt(inVO);
        LOGGER.info("##### 상품관리 중도상환수수료율 삭제 End #####");

        return resultVo;
    }
}