package hanalife.s.rm.rm.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.rm.rm.service.SRMRMM01Service;
import hanalife.s.rm.rm.service.SRMRMM02Service;
import hanalife.s.rm.rm.vo.SRMRMM01DSSTPRODIRULEVO;
import hanalife.s.rm.rm.vo.SRMRMM01InVO;
import hanalife.s.rm.rm.vo.SRMRMM01OutVO;
import hanalife.s.rm.rm.vo.SRMRMM02DSSTRULEMAINVO;
import hanalife.s.rm.rm.vo.SRMRMM02InVO;
import hanalife.s.rm.rm.vo.SRMRMM02OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명    : SRMRMM01Controller.java Class
 * 클래스설명    : RULE 관리 (SRMRMM01) Controller
 * 작성일자    : 2023.04.13.
 * 작성자명    : 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][70280][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/rm/rm")
@Controller
public class SRMRMM01Controller
{
    @Resource(name = "SRMRMM01Service")
    private SRMRMM01Service SRMRMM01;

    @Resource(name = "SRMRMM02Service")
    private SRMRMM02Service SRMRMM02;

    private static final Logger LOGGER = LoggerFactory.getLogger(SRMRMM01Controller.class);

    /**
     * <p>메소드명            : 룰관리내역 조회 /SRMRMM01S01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰관리내역을 조회한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM01S01.do")
    public String SRMRMM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_MAIN_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM02DSSTRULEMAINVO oSearchVo = new SRMRMM02DSSTRULEMAINVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim()       );
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM02InVO InVO = new SRMRMM02InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM02DSSTRULEMAINVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM02OutVO resultListVo = SRMRMM02.SRMRMM02S01(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_MAIN", resultListVo.getListSRMRMM02DSSTRULEMAINVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S01  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명            : 룰관리내역 조회 /SRMRMM01S01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰관리내역을 조회한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM01S02.do")
    public String SRMRMM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S02 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S02 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_PRDT_BASE_SEARCH", request, response, model); // 사용하지 않음. 오류 방지를 위함.

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM01InVO InVO = new SRMRMM01InVO();

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01OutVO resultListVo = SRMRMM01.SRMRMM01S02(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_PRDT_BASE", resultListVo.getListSRMRMM01DSSTPRODIRULEVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S02  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S02 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S02 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    @RequestMapping("/SRMRMM01S03.do")
    public String SRMRMM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S03 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S03 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_PROD_IRULE_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM01DSSTPRODIRULEVO oSearchVo = new SRMRMM01DSSTPRODIRULEVO();
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM01InVO InVO = new SRMRMM01InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM01DSSTPRODIRULEVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01OutVO resultListVo = SRMRMM01.SRMRMM01S03(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_PROD_RULE_LIST", resultListVo.getListSRMRMM01DSSTPRODIRULEVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S03  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S03 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S03 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    @RequestMapping("/SRMRMM01S04.do")
    public String SRMRMM01S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S04 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S04 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_PROD_IRULE_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM01DSSTPRODIRULEVO oSearchVo = new SRMRMM01DSSTPRODIRULEVO();
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM01InVO InVO = new SRMRMM01InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM01DSSTPRODIRULEVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01OutVO resultListVo = SRMRMM01.SRMRMM01S04(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_PROD_PARAM_LIST", resultListVo.getListSRMRMM03DSSTRULESUBVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S04  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S04 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S04 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    @RequestMapping("/SRMRMM01S05.do")
    public String SRMRMM01S05(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S05 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S05 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_PROD_IRULE_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM01DSSTPRODIRULEVO oSearchVo = new SRMRMM01DSSTPRODIRULEVO();
            oSearchVo.setProdCd       (searchMap.get("prodCd").toString().trim()         );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM01InVO InVO = new SRMRMM01InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM01DSSTPRODIRULEVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01OutVO resultListVo = SRMRMM01.SRMRMM01S05(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_PROD_IRULE", resultListVo.getListSRMRMM01DSSTPRODIRULEVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S05  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01S05 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01S05 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    @RequestMapping("/SRMRMM01I01.do")
    public String SRMRMM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM01 Controller SRMRMM01I01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM01 Controller SRMRMM01I01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_PROD_IRULE_SEARCH", request, response, model);
            List<Map<String, Object>> sourceMapIrule = XFrame5DataSetUtil.getXFrameDataSetList("DS_ST_PROD_IRULE", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM01DSSTPRODIRULEVO oSearchVo = new SRMRMM01DSSTPRODIRULEVO();
            oSearchVo.setProdCd       (searchMap.get("prodCd").toString().trim()         );

            List<SRMRMM01DSSTPRODIRULEVO> oInVoList = new ArrayList<SRMRMM01DSSTPRODIRULEVO>();

            if (sourceMapIrule.size() > 0)
            {
                for (int i = 0; i < sourceMapIrule.size(); i++)
                {
                    Map<String, Object> inMap = sourceMapIrule.get(i);

                    SRMRMM01DSSTPRODIRULEVO oInVo = new SRMRMM01DSSTPRODIRULEVO();
                    oInVo.setProdCd        (oSearchVo.getProdCd()                        ); // 주의
                    oInVo.setRuleType      (inMap.get("ruleType").toString().trim()      );
                    oInVo.setRuleId        (inMap.get("ruleId").toString().trim()        );
                    oInVo.setRuleNm        (inMap.get("ruleNm").toString().trim()        );
                    oInVo.setRemark        (inMap.get("remark").toString().trim()        );
                    oInVo.setContent       (inMap.get("content").toString().trim()       );
                    oInVo.setRecSttsCd     (inMap.get("recSttsCd").toString().trim()     );
                    oInVo.setFrstRegDt     (inMap.get("frstRegDt").toString().trim()     );
                    oInVo.setFrstRegTm     (inMap.get("frstRegTm").toString().trim()     );
                    oInVo.setFrstRegEmpNo  (inMap.get("frstRegEmpNo").toString().trim()  );
                    oInVo.setLastProcDt    (inMap.get("lastProcDt").toString().trim()    );
                    oInVo.setLastProcTm    (inMap.get("lastProcTm").toString().trim()    );
                    oInVo.setLastProcEmpNo (inMap.get("lastProcEmpNo").toString().trim() );

                    oInVoList.add(oInVo);
                }
            }

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM01InVO InVO = new SRMRMM01InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM01DSSTPRODIRULEVO(oSearchVo);
            InVO.setListSRMRMM01DSSTPRODIRULEVO(oInVoList);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01.SRMRMM01I01(InVO);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM01OutVO resultListVo = SRMRMM01.SRMRMM01S05(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_PROD_IRULE", resultListVo.getListSRMRMM01DSSTPRODIRULEVO(), model);

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01I01  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM01 Controller SRMRMM01I01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM01 Controller SRMRMM01I01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }
}