package hanalife.s.sp.as.service;

import hanalife.s.sp.as.vo.SSPASM02I01InVO;
import hanalife.s.sp.as.vo.SSPASM02InVO;
import hanalife.s.sp.as.vo.SSPASM02OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASM02Service.java Class
 * 클래스설명	: 특수지역관리 (SSPASM02) Service Interface
 * 작성일자	: 2023.04.13.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASM02S01	: 시도명 조회
 *			getSSPASM02S02	: 시군구명 조회
 *			getSSPASM02S03	: 읍면동명 조회
 *			getSSPASM02S04	: 리명 조회
 *			getSSPASM02S05	: 특수지역관리내역 조회
 *			saveSSPASM02	: 특수지역관리내역 등록
 *			deleteSSPASM02	: 특수지역관리내역 삭제
 * </pre>
 */

public interface SSPASM02Service
{
	/**
	 * <p> 메소드명		: getSSPASM02S01 - 시도명 조회 </p>
	 * <p> 작성일자		: 2023.04.13. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 시도명 내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASM02OutVO getSSPASM02S01(SSPASM02InVO inVo) throws Exception;

	/**
	 * <p> 메소드명		: getSSPASM02S02 : 시군구명 조회 </p>
	 * <p> 작성일자		: 2023.04.13. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 시군구명 내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASM02OutVO getSSPASM02S02(SSPASM02InVO inVo) throws Exception;

	/**
	 * <p> 메소드명		: getSSPASM02S03 - 읍면동명 조회 </p>
	 * <p> 작성일자		: 2023.04.13. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 읍면동명 내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASM02OutVO getSSPASM02S03(SSPASM02InVO inVo) throws Exception;

	/**
	 * <p> 메소드명		: getSSPASM02S04 - 리명 조회 </p>
	 * <p> 작성일자		: 2023.04.13. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 리명 내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		 Exception </p>
	 */
    public SSPASM02OutVO getSSPASM02S04(SSPASM02InVO inVo) throws Exception;


	/**
	 * <p> 메소드명		: getSSPASM02S05 - 특수지역관리내역 조회 </p>
	 * <p> 작성일자		: 2023.04.13. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 특수지역관리내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASM02OutVO getSSPASM02S05(SSPASM02InVO inVo) throws Exception;

    /**
     * <p> 메소드명		: saveSSPASM02 - 특수지역관리내역 등록 </p>
	 * <p> 작성일자		: 2023.04.20. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 특수지역관리내역을 등록한다.</p>
	 * <p> 메소드인수		: SSPASM02I01InVo </p>
	 * <p> 메소드리턴값		: SSPASM02OutVo </p>
	 * <p> 예외처리		: Exception </p>
     */
    public SSPASM02OutVO saveSSPASM02(SSPASM02I01InVO inVo) throws Exception;

    /**
     * <p> 메소드명		: deleteSSPASM02 - 특수지역고관리내역 삭제 </p>
	 * <p> 작성일자		: 2023.04.20. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 특수지역관리내역을 삭제한다. </p>
	 * <p> 메소드인수		: SSPASM02I01InVo </p>
	 * <p> 메소드리턴값		: SSPASM02OutVo </p>
	 * <p> 예외처리		: Exception </p>
     */
    public SSPASM02OutVO deleteSSPASM02(SSPASM02I01InVO inVo) throws Exception;

}