package hanalife.s.sp.as.service;

import hanalife.s.sp.as.vo.SSPASP10I01InVO;
import hanalife.s.sp.as.vo.SSPASP10InVO;
import hanalife.s.sp.as.vo.SSPASP10OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP10Service.java Class
 * 클래스설명	: 결재선지정 (SSPASP10) Service Interface
 * 작성일자	: 2023.04.26.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.26.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASP10S01	: 결재선 조회
 *          saveSSPASP10    : 결재선 저장
 *          deleteSSPASP10  : 결재선 삭제
 *
 * </pre>
 */

public interface SSPASP10Service
{
	/**
	 * <p> 메소드명		: getSSPASP10S01 - 결재선 조회 </p>
	 * <p> 작성일자		: 2023.04.26. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 결재선 내역을 조회한다. </p>
	 * <p> 메소드인수		: SSPASP10InVO </p>
	 * <p> 메소드리턴값		: SSPASP10OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASP10OutVO getSSPASP10S01(SSPASP10InVO inVo) throws Exception;

	/**
	 * <p> 메소드명		: saveSSPASP10I01 - 결재선 저장 </p>
	 * <p> 작성일자		: 2023.04.28. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 결재선 내역을 저장한다. </p>
	 * <p> 메소드인수		: SSPASP10InVO </p>
	 * <p> 메소드리턴값		: SSPASP10OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASP10OutVO saveSSPASP10(SSPASP10I01InVO inVo) throws Exception;

    /**
     * <p> 메소드명		: deleteSSPASP10 - 결재선 삭제 </p>
	 * <p> 작성일자		: 2023.04.28. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 결재선 내역을 삭제한다. </p>
	 * <p> 메소드인수		: SSPASP10I01InVO </p>
	 * <p> 메소드리턴값		: SSPASP10OutVO </p>
	 * <p> 예외처리		: Exception </p>
     */
    public SSPASP10OutVO deleteSSPASP10(SSPASP10I01InVO inVo) throws Exception;


    // 1차 심사자 등록
	/**
	 * <p> 메소드명		: getSSPASP10S02 - 결재선 등록전 등록여부 조회 </p>
	 * <p> 작성일자		: 2023.04.26. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 결재선 등록 전 등록여부  조회한다. </p>
	 * <p> 메소드인수		: SSPASP10InVO </p>
	 * <p> 메소드리턴값		: SSPASP10OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public  int getSSPASP10S02(SSPASP10I01InVO srchVO) throws Exception;

	/**
	 * <p> 메소드명		: insertSSPASP10 - 심사승인관리_신규 심사건 담당자 저장 </p>
	 * <p> 작성일자		: 2023.05.02 </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 신규 심사건 담당자 저장. </p>
	 * <p> 메소드인수		: SSPASP10InVO </p>
	 * <p> 메소드리턴값		: SSPASP10OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASP10OutVO insertSSPASP10(SSPASP10I01InVO inVo) throws Exception;
}