package hanalife.s.sp.as.service;

import hanalife.s.sp.as.vo.SSPASP12I01InVO;
import hanalife.s.sp.as.vo.SSPASP12InVO;
import hanalife.s.sp.as.vo.SSPASP12OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP10Service.java Class
 * 클래스설명	: 결재선지정 (SSPASP10) Service Interface
 * 작성일자	: 2023.04.26.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.26.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASP12S01	: 전결권자대행목록 조회
 *          getSSPASP12S02	: 전결권자대행대상 조회
 *          getSSPASP12S03	: 전결권자대행상태 등록전 중복여부 조회
 *          updSSPASP12U01	: 전결대행자 수정(해지)
 *          insertSSPASP12	: 전결대행자 신규등록
 * </pre>
 */

public interface SSPASP12Service
{
	/**
	 * <p> 메소드명		: getSSPASP12S01 / 전결권자대행목록 조회 </p>
	 * <p> 작성일자		: 2023.05.04. </p>
	 * <p> 작성자(author)	: 70305 / KBS </p>
	 * <p> 설명			: 전결권자대행목록을 조회한다. </p>
	 * <p> 메소드인수		: SSPASP12InVO </p>
	 * <p> 메소드리턴값		: SSPASP12OutVO </p>
	 * <p> 예외처리		: Exception </p>
	 */
    public SSPASP12OutVO getSSPASP12S01(SSPASP12InVO inVo) throws Exception;

    /**
     * <p> 메소드명 : getSSPASP12S02 / 전결권자대행 대상 조회 </p>
     * <p> 작성일자 : 2023.05.04. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행 대상을 조회한다. </p>
     * <p> 메소드인수 : SSPASP12InVO </p>
     * <p> 메소드리턴값 : SSPASP12OutVO </p>
     * <p> 예외처리 : Exception </p>
     */
    public SSPASP12OutVO getSSPASP12S02(SSPASP12InVO inVo) throws Exception;

    /**
     * <p>메소드명 : updSSPASP12U01 : 전결대행자 수정(해지)</p>
     * <p>작성일자 : 2023.05.04.
     * <p>작성자(author) : 70305 / KBS
     * <p>설명 : 전결대행자내역을 수정(해지)한다.</p>
     * <p>메소드인수 : SSPASP12I01InVO </p>
     * <p>메소드리턴값 : SSPASP12OutVO</p>
     * <p>예외처리 : Exception</p>
     */
    public SSPASP12OutVO updSSPASP12U01(SSPASP12I01InVO inVo) throws Exception;

    /**
     * <p> 메소드명 : getSSPASP10S03 - 전결권자대행상태 등록전 중복여부 조회 </p>
     * <p> 작성일자 : 2023.05.08. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행상태 등록전 중복여부를 조회한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    public int getSSPASP12S03(SSPASP12I01InVO srchVO) throws Exception;

    /**
     * <p>메소드명 : insertSSPASP12 : 전결대행자 신규등록</p>
     * <p>작성일자 : 2023.05.04.
     * <p>작성자(author) : 70305 / KBS
     * <p>설명 : 전결대행자내역을 신규 등록한다.</p>
     * <p>메소드인수 : SSPASP12I01InVO </p>
     * <p>메소드리턴값 : SSPASP12OutVO</p>
     * <p>예외처리 : Exception</p>
     */
    public SSPASP12OutVO insertSSPASP12(SSPASP12I01InVO inVo) throws Exception;

}