package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.StCprtComMapper;
import hanalife.s.sp.as.mapper.dto.stCprtComDSSDCDTO;
import hanalife.s.sp.as.mapper.dto.stCprtComDSSDDTO;
import hanalife.s.sp.as.mapper.dto.stCprtComDSSMDTO;
import hanalife.s.sp.as.service.SSPASM01Service;
import hanalife.s.sp.as.vo.SSPASM01DSSDVO;
import hanalife.s.sp.as.vo.SSPASM01I01InVO;
import hanalife.s.sp.as.vo.SSPASM01I01OutVO;
import hanalife.s.sp.as.vo.SSPASM01S01InVO;
import hanalife.s.sp.as.vo.SSPASM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASM01ServiceImpl.java Class
 * 클래스설명   : 제휴업체관리 (SSPASM01) Service Implements
 * 작성일자     : 2023. 4. 17.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 17.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSSPASM01S01 : 제휴업체관리목록조회
 * 				registerSSPASM01S01 : 제휴업체관리등록
 * 				modifySSPASM01S01 : 제휴업체관리수정
 * </pre>
 */
@Service("SSPASM01Service")
public class SSPASM01ServiceImpl implements SSPASM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM01ServiceImpl.class);

	private MsgEnum msgEnum;
	private Constants constants;

	@Autowired
	private StCprtComMapper stCprtComMapper;

	/**
	 * <p>메소드명      : getSSPASM01S01 : 제휴업체관리</p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 제휴업체관리 조회 한다.</p>
	 * <p>메소드인수    : SSPASM01S01InVo </p>
	 * <p>메소드리턴값  : SSPASM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASM01S01OutVO getSSPASM01S01(SSPASM01S01InVO inVo) throws Exception {

		SSPASM01S01OutVO resultVo = new SSPASM01S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		stCprtComDSSMDTO inDto = new stCprtComDSSMDTO();

		inDto.setCrptComDivCd(constants.s12049_CRPT_COM_DIV_01); 		/** 제휴사구분코드(S12049) : 모기지제휴사(00010) */
		inDto.setCprtComNo(inVo.getSSPASM01DSSMVO().getCprtComNo()); 	/** 제휴사번호 */
		inDto.setContClosFg(inVo.getSSPASM01DSSMVO().getContClosFg()); 	/** 약정해지여부 */

		List<stCprtComDSSDDTO> resultDTO = stCprtComMapper.searchStCprtComList(inDto);	/** 제휴업체관리리스트*/

		List<SSPASM01DSSDVO> resultList = new ArrayList<SSPASM01DSSDVO>();

		for (stCprtComDSSDDTO sourceIO : resultDTO) {
			SSPASM01DSSDVO targetIO = new SSPASM01DSSDVO();
			targetIO.setCrptComDivCd(sourceIO.getCrptComDivCd()); 				/** 제휴사구분코드 */
			targetIO.setCprtComNo(sourceIO.getCprtComNo()); 					/** 제휴사번호 */
			targetIO.setComNm(sourceIO.getComNm()); 							/** 회사명 */
			targetIO.setIfrmComNm(sourceIO.getIfrmComNm()); 					/** 약식회사명 */
			targetIO.setReprName(sourceIO.getReprName()); 						/** 대표자성명 */
			targetIO.setCprtComDgreCd(sourceIO.getCprtComDgreCd()); 			/** 제휴사등급코드 */
			targetIO.setSaleRegDt(sourceIO.getSaleRegDt()); 					/** 매매등록일자 */
			targetIO.setSaleRegNo(sourceIO.getSaleRegNo()); 					/** 매매등록번호 */
			targetIO.setShowRoomSize(sourceIO.getShowRoomSize()); 				/** 전시장크기 */
			targetIO.setOffcSize(sourceIO.getOffcSize()); 						/** 사무실크기 */
			targetIO.setEmpCnt(sourceIO.getEmpCnt()); 							/** 종업원수 */
			targetIO.setCprtDivCd(sourceIO.getCprtDivCd()); 					/** 제휴구분코드 */
			targetIO.setRentDivCd(sourceIO.getRentDivCd()); 					/** 임대구분코드 */
			targetIO.setCprtPlcUseFg(sourceIO.getCprtPlcUseFg()); 				/** 제휴광장사용여부 */
			targetIO.setPrfeePayDiv(sourceIO.getPrfeePayDiv()); 				/** 판촉수수료지급구분 */
			targetIO.setContClosFg(sourceIO.getContClosFg()); 					/** 약정해지여부 */
			targetIO.setContClosDt(sourceIO.getContClosDt()); 					/** 약정해지일자 */
			targetIO.setRegDt(sourceIO.getRegDt()); 							/** 등록일 */
			targetIO.setOpenDt(sourceIO.getOpenDt()); 							/** 개업일 */
			targetIO.setBsnKindDesc(sourceIO.getBsnKindDesc()); 				/** 사업의종류 */
			targetIO.setFeeSr(sourceIO.getFeeSr()); 							/** 수수료연계모집인 */
			targetIO.setFeeRigtInsu(sourceIO.getFeeRigtInsu()); 				/** 수수료연계권리보험 */
			targetIO.setFeeMciInsu(sourceIO.getFeeMciInsu()); 					/** 수수료연계MCI보험 */
			targetIO.setFeeFlmo(sourceIO.getFeeFlmo()); 						/** 수수료연계근저당 */
			targetIO.setFeeFlmoEtc(sourceIO.getFeeFlmoEtc()); 					/** 수수료연계근저당기타 */
			targetIO.setCprtFgCd(sourceIO.getCprtFgCd()); 						/** 제휴여부코드 */
			targetIO.setCapDivCd(sourceIO.getCapDivCd()); 						/** CAP구분코드 */
			targetIO.setImptcomDivCd(sourceIO.getImptcomDivCd()); 				/** 수입사구분코드 */
			targetIO.setTel0(sourceIO.getTel0()); 								/** 전화0 */
			targetIO.setTel1(sourceIO.getTel1()); 								/** 전화1 */
			targetIO.setTel2(sourceIO.getTel2()); 								/** 전화2 */
			targetIO.setTel3(sourceIO.getTel3()); 								/** 전화3 */
			targetIO.setInno(sourceIO.getInno()); 								/** 내선 */
			targetIO.setFax0(sourceIO.getFax0()); 								/** 팩스0 */
			targetIO.setFax1(sourceIO.getFax0()); 								/** 팩스1 */
			targetIO.setFax2(sourceIO.getFax0()); 								/** 팩스2 */
			targetIO.setFax3(sourceIO.getFax0()); 								/** 팩스3 */
			targetIO.setBankcd(sourceIO.getBankcd()); 							/** 은행코드 */
			targetIO.setAcntNo(sourceIO.getAcntNo()); 							/** 계좌번호 */
			targetIO.setDepoOwnno(sourceIO.getDepoOwnno()); 					/** 예금주번호 */
			targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm()); 					/** 예금주명 */
			targetIO.setZipcd(sourceIO.getZipcd()); 							/** 우편번호 */
			targetIO.setAddr(sourceIO.getAddr()); 								/** 주소 */
			targetIO.setDtlAddr(sourceIO.getDtlAddr()); 						/** 상세주소 */

			resultList.add(targetIO);
		}

		resultVo.setSSPASM01DSSDVO(resultList);		/** 제휴업체관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : registerSSPASM01S01 : 제휴업체관리등록</p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 제휴업체관리 등록 한다.</p>
	 * <p>메소드인수    : SSPASM01S01InVo </p>
	 * <p>메소드리턴값  : SSPASM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASM01I01OutVO registerSSPASM01S01(SSPASM01I01InVO inVo) throws Exception {

		SSPASM01I01OutVO resultVo = new SSPASM01I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		stCprtComDSSDCDTO inDto = new stCprtComDSSDCDTO();

		int insResult = 0;

		inDto.setCrptComDivCd(constants.s12049_CRPT_COM_DIV_01); 				/** 제휴사구분코드(S12049) : 모기지제휴사(00010) */
		inDto.setCprtComNo(inVo.getSSPASM01DSSDCVO().getCprtComNo()); 			/** 제휴사번호 */
		inDto.setComNm(inVo.getSSPASM01DSSDCVO().getComNm()); 					/** 회사명 */
		inDto.setIfrmComNm(inVo.getSSPASM01DSSDCVO().getIfrmComNm()); 			/** 약식회사명 */
		inDto.setReprName(inVo.getSSPASM01DSSDCVO().getReprName()); 			/** 대표자성명 */
		inDto.setCprtComDgreCd(inVo.getSSPASM01DSSDCVO().getCprtComDgreCd()); 	/** 제휴사등급코드 */
		inDto.setSaleRegDt(inVo.getSSPASM01DSSDCVO().getSaleRegDt()); 			/** 매매등록일자 */
		inDto.setSaleRegNo(inVo.getSSPASM01DSSDCVO().getSaleRegNo()); 			/** 매매등록번호 */
		inDto.setShowRoomSize(inVo.getSSPASM01DSSDCVO().getShowRoomSize()); 	/** 전시장크기 */
		inDto.setOffcSize(inVo.getSSPASM01DSSDCVO().getOffcSize()); 			/** 사무실크기 */
		inDto.setEmpCnt(inVo.getSSPASM01DSSDCVO().getEmpCnt()); 				/** 종업원수 */
		inDto.setCprtDivCd(inVo.getSSPASM01DSSDCVO().getCprtDivCd()); 			/** 제휴구분코드 */
		inDto.setRentDivCd(inVo.getSSPASM01DSSDCVO().getRentDivCd()); 			/** 임대구분코드 */
		inDto.setCprtPlcUseFg(inVo.getSSPASM01DSSDCVO().getCprtPlcUseFg()); 	/** 제휴광장사용여부 */
		inDto.setPrfeePayDiv(inVo.getSSPASM01DSSDCVO().getPrfeePayDiv()); 		/** 판촉수수료지급구분 */
		inDto.setContClosFg(inVo.getSSPASM01DSSDCVO().getContClosFg()); 		/** 약정해지여부 */
		inDto.setContClosDt(inVo.getSSPASM01DSSDCVO().getContClosDt()); 		/** 약정해지일자 */
		inDto.setRegDt(inVo.getSSPASM01DSSDCVO().getRegDt()); 					/** 등록일 */
		inDto.setOpenDt(inVo.getSSPASM01DSSDCVO().getOpenDt()); 				/** 개업일 */
		inDto.setBsnKindDesc(inVo.getSSPASM01DSSDCVO().getBsnKindDesc()); 		/** 사업의종류 */
		inDto.setFeeSr(inVo.getSSPASM01DSSDCVO().getFeeSr()); 					/** 수수료연계모집인 */
		inDto.setFeeRigtInsu(inVo.getSSPASM01DSSDCVO().getFeeRigtInsu()); 		/** 수수료연계권리보험 */
		inDto.setFeeMciInsu(inVo.getSSPASM01DSSDCVO().getFeeMciInsu()); 		/** 수수료연계MCI보험 */
		inDto.setFeeFlmo(inVo.getSSPASM01DSSDCVO().getFeeFlmo()); 				/** 수수료연계근저당 */
		inDto.setFeeFlmoEtc(inVo.getSSPASM01DSSDCVO().getFeeFlmoEtc()); 		/** 수수료연계근저당기타 */
		inDto.setCprtFgCd(inVo.getSSPASM01DSSDCVO().getCprtFgCd()); 			/** 제휴여부코드 */
		inDto.setCapDivCd(inVo.getSSPASM01DSSDCVO().getCapDivCd()); 			/** CAP구분코드 */
		inDto.setImptcomDivCd(inVo.getSSPASM01DSSDCVO().getImptcomDivCd()); 	/** 수입사구분코드 */
		inDto.setTel0(inVo.getSSPASM01DSSDCVO().getTel0()); 					/** 전화0 */
		inDto.setTel1(inVo.getSSPASM01DSSDCVO().getTel1()); 					/** 전화1 */
		inDto.setTel2(inVo.getSSPASM01DSSDCVO().getTel2()); 					/** 전화2 */
		inDto.setTel3(inVo.getSSPASM01DSSDCVO().getTel3()); 					/** 전화3 */
		inDto.setInno(inVo.getSSPASM01DSSDCVO().getInno()); 					/** 내선 */
		inDto.setFax0(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스0 */
		inDto.setFax1(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스1 */
		inDto.setFax2(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스2 */
		inDto.setFax3(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스3 */
		inDto.setBankcd(inVo.getSSPASM01DSSDCVO().getBankcd()); 				/** 은행코드 */
		inDto.setAcntNo(inVo.getSSPASM01DSSDCVO().getAcntNo()); 				/** 계좌번호 */
		inDto.setDepoOwnno(inVo.getSSPASM01DSSDCVO().getDepoOwnno()); 			/** 예금주번호 */
		inDto.setDepoOwnnm(inVo.getSSPASM01DSSDCVO().getDepoOwnnm()); 			/** 예금주명 */
		inDto.setZipcd(inVo.getSSPASM01DSSDCVO().getZipcd()); 					/** 우편번호 */
		inDto.setAddr(inVo.getSSPASM01DSSDCVO().getAddr()); 					/** 주소 */
		inDto.setDtlAddr(inVo.getSSPASM01DSSDCVO().getDtlAddr()); 				/** 상세주소 */
		inDto.setLogInEmpNo(inVo.getSSPASM01DSSDCVO().getLogInEmpNo());			/** 로그인사원번호 */

		insResult = stCprtComMapper.registerStCprtComList(inDto);

		if(insResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : modifySSPASM01S01 : 제휴업체관리수정</p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 제휴업체관리 수정 한다.</p>
	 * <p>메소드인수    : SSPASM01S01InVo </p>
	 * <p>메소드리턴값  : SSPASM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASM01I01OutVO modifySSPASM01S01(SSPASM01I01InVO inVo) throws Exception {

		SSPASM01I01OutVO resultVo = new SSPASM01I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		stCprtComDSSDCDTO inDto = new stCprtComDSSDCDTO();

		int updResult = 0;

		inDto.setCrptComDivCd(inVo.getSSPASM01DSSDCVO().getCrptComDivCd()); 	/** 제휴사구분코드 */
		inDto.setCprtComNo(inVo.getSSPASM01DSSDCVO().getCprtComNo()); 			/** 제휴사번호 */
		inDto.setComNm(inVo.getSSPASM01DSSDCVO().getComNm()); 					/** 회사명 */
		inDto.setIfrmComNm(inVo.getSSPASM01DSSDCVO().getIfrmComNm()); 			/** 약식회사명 */
		inDto.setReprName(inVo.getSSPASM01DSSDCVO().getReprName()); 			/** 대표자성명 */
		inDto.setCprtComDgreCd(inVo.getSSPASM01DSSDCVO().getCprtComDgreCd()); 	/** 제휴사등급코드 */
		inDto.setSaleRegDt(inVo.getSSPASM01DSSDCVO().getSaleRegDt()); 			/** 매매등록일자 */
		inDto.setSaleRegNo(inVo.getSSPASM01DSSDCVO().getSaleRegNo()); 			/** 매매등록번호 */
		inDto.setShowRoomSize(inVo.getSSPASM01DSSDCVO().getShowRoomSize()); 	/** 전시장크기 */
		inDto.setOffcSize(inVo.getSSPASM01DSSDCVO().getOffcSize()); 			/** 사무실크기 */
		inDto.setEmpCnt(inVo.getSSPASM01DSSDCVO().getEmpCnt()); 				/** 종업원수 */
		inDto.setCprtDivCd(inVo.getSSPASM01DSSDCVO().getCprtDivCd()); 			/** 제휴구분코드 */
		inDto.setRentDivCd(inVo.getSSPASM01DSSDCVO().getRentDivCd()); 			/** 임대구분코드 */
		inDto.setCprtPlcUseFg(inVo.getSSPASM01DSSDCVO().getCprtPlcUseFg()); 	/** 제휴광장사용여부 */
		inDto.setPrfeePayDiv(inVo.getSSPASM01DSSDCVO().getPrfeePayDiv()); 		/** 판촉수수료지급구분 */
		inDto.setContClosFg(inVo.getSSPASM01DSSDCVO().getContClosFg()); 		/** 약정해지여부 */
		inDto.setContClosDt(inVo.getSSPASM01DSSDCVO().getContClosDt()); 		/** 약정해지일자 */
		inDto.setRegDt(inVo.getSSPASM01DSSDCVO().getRegDt()); 					/** 등록일 */
		inDto.setOpenDt(inVo.getSSPASM01DSSDCVO().getOpenDt()); 				/** 개업일 */
		inDto.setBsnKindDesc(inVo.getSSPASM01DSSDCVO().getBsnKindDesc()); 		/** 사업의종류 */
		inDto.setFeeSr(inVo.getSSPASM01DSSDCVO().getFeeSr()); 					/** 수수료연계모집인 */
		inDto.setFeeRigtInsu(inVo.getSSPASM01DSSDCVO().getFeeRigtInsu()); 		/** 수수료연계권리보험 */
		inDto.setFeeMciInsu(inVo.getSSPASM01DSSDCVO().getFeeMciInsu()); 		/** 수수료연계MCI보험 */
		inDto.setFeeFlmo(inVo.getSSPASM01DSSDCVO().getFeeFlmo()); 				/** 수수료연계근저당 */
		inDto.setFeeFlmoEtc(inVo.getSSPASM01DSSDCVO().getFeeFlmoEtc()); 		/** 수수료연계근저당기타 */
		inDto.setCprtFgCd(inVo.getSSPASM01DSSDCVO().getCprtFgCd()); 			/** 제휴여부코드 */
		inDto.setCapDivCd(inVo.getSSPASM01DSSDCVO().getCapDivCd()); 			/** CAP구분코드 */
		inDto.setImptcomDivCd(inVo.getSSPASM01DSSDCVO().getImptcomDivCd()); 	/** 수입사구분코드 */
		inDto.setTel0(inVo.getSSPASM01DSSDCVO().getTel0()); 					/** 전화0 */
		inDto.setTel1(inVo.getSSPASM01DSSDCVO().getTel1()); 					/** 전화1 */
		inDto.setTel2(inVo.getSSPASM01DSSDCVO().getTel2()); 					/** 전화2 */
		inDto.setTel3(inVo.getSSPASM01DSSDCVO().getTel3()); 					/** 전화3 */
		inDto.setInno(inVo.getSSPASM01DSSDCVO().getInno()); 					/** 내선 */
		inDto.setFax0(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스0 */
		inDto.setFax1(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스1 */
		inDto.setFax2(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스2 */
		inDto.setFax3(inVo.getSSPASM01DSSDCVO().getFax0()); 					/** 팩스3 */
		inDto.setBankcd(inVo.getSSPASM01DSSDCVO().getBankcd()); 				/** 은행코드 */
		inDto.setAcntNo(inVo.getSSPASM01DSSDCVO().getAcntNo()); 				/** 계좌번호 */
		inDto.setDepoOwnno(inVo.getSSPASM01DSSDCVO().getDepoOwnno()); 			/** 예금주번호 */
		inDto.setDepoOwnnm(inVo.getSSPASM01DSSDCVO().getDepoOwnnm()); 			/** 예금주명 */
		inDto.setZipcd(inVo.getSSPASM01DSSDCVO().getZipcd()); 					/** 우편번호 */
		inDto.setAddr(inVo.getSSPASM01DSSDCVO().getAddr()); 					/** 주소 */
		inDto.setDtlAddr(inVo.getSSPASM01DSSDCVO().getDtlAddr()); 				/** 상세주소 */
		inDto.setLogInEmpNo(inVo.getSSPASM01DSSDCVO().getLogInEmpNo());			/** 로그인사원번호 */

		updResult = stCprtComMapper.modifyStCprtComList(inDto);

		if(updResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}
}
