package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.s.sp.as.mapper.SSPASM05Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASM05DSSDDTO;
import hanalife.s.sp.as.mapper.dto.SSPASM05DSSMDTO;
import hanalife.s.sp.as.service.SSPASM05Service;
import hanalife.s.sp.as.vo.SSPASM05DSSDVO;
import hanalife.s.sp.as.vo.SSPASM05InVO;
import hanalife.s.sp.as.vo.SSPASM05OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASM05ServiceImpl.java Class
 * 클래스설명	: KB아파트시세조회 (SSPASM05) Service Interface
 * 작성일자	: 2023.04.12.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.12.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASM05S01	: KB아파트시세조회_시도
 * 			getSSPASM05S02	: KB아파트시세조회_시군구
 *  		getSSPASM05S03	: KB아파트시세조회_읍면동
 *  		getSSPASM05S04	: KB아파트시세조회_아파트정보
 *          getSSPASM05S05	: KB아파트시세조회_조사기준일
 *          getSSPASM05S06	: KB아파트시세조회_아파트시세
 * </pre>
 */
@Service("SSPASM05Service")
public class SSPASM05ServiceImpl implements SSPASM05Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM05ServiceImpl.class);

	@Autowired
	private SSPASM05Mapper sSPASM05Mapper;

	/**
	 * <p>메소드명		: getSSPASM05S01 :KB아파트시세조회_시도내역_조회</p>
	 * 작성일자		: 2023.04.12.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_시도 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO</p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
	public SSPASM05OutVO getSSPASM05S01(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S01 Start #####");

	    // KB아파트시세조회_시도내역_ 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_시도내역_ 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();
	    /** 입력값 없음 */

        // KB아파트시세조회_시도내역_ 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchLDongCd01(i01Dto);

        // KB아파트시세조회_시도내역_ 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

       		// KB아파트시세조회_시도내역_ 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());	/** 시도명 */

            // KB아파트시세조회_시도내역_ 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S01 End #####");

        // KB아파트시세조회_시도내역_ 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명		: getSSPASM05S02 :KB아파트시세조회_시군구내역_조회</p>
	 * 작성일자		: 2023.04.12.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_시군구 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO </p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
    public SSPASM05OutVO getSSPASM05S02(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S02 Start #####");

	    // KB아파트시세조회_시군구내역 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_시군구내역 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();

        i01Dto.setProvNm(inVo.getSSPASM05DSSMVO().getProvNm());    /** 시도명 */

   		LOGGER.info("" + "i01Dto.getProvNm() : " + i01Dto.getProvNm());

        // KB아파트시세조회_시군구내역 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchLDongCd02(i01Dto);

        // KB아파트시세조회_시군구내역 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세조회_시군구내역 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());	       /* 시도명 */
       		targetIO.setCigunguNm(sourceIO.getCigunguNm());    /* 시군구명 */

            // KB아파트시세조회_시군구내역 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S02 End #####");

        // KB아파트시세조회_시군구내역 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명		: getSSPASM05S03 :KB아파트시세조회_읍면동 내역_조회</p>
	 * 작성일자		: 2023.04.12.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_읍면동 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO </p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
    public SSPASM05OutVO getSSPASM05S03(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S03 Start #####");

	    // KB아파트시세조회_아파트 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_아파트 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();

        i01Dto.setProvNm(inVo.getSSPASM05DSSMVO().getProvNm());          /** 시도명 */
        i01Dto.setCigunguNm(inVo.getSSPASM05DSSMVO().getCigunguNm());    /** 시군구명 */

   		LOGGER.info("" + "i01Dto.getProvNm()    : " + i01Dto.getProvNm());
   		LOGGER.info("" + "i01Dto.getCigunguNm() : " + i01Dto.getCigunguNm());

        // KB아파트시세조회_아파트 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchLDongCd03(i01Dto);

        // KB아파트시세조회_아파트 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세조회_아파트 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setProvNm(sourceIO.getProvNm());	               /* 시도명 */
       		targetIO.setCigunguNm(sourceIO.getCigunguNm());            /* 시군구명 */
       		targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());    /* 읍면동명 */

            // KB아파트시세조회_아파트 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S03 End #####");

        // KB아파트시세조회_아파트 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명		: getSSPASM05S04 :KB아파트시세조회_아파트 내역_조회</p>
	 * 작성일자		: 2023.04.12.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_아파트 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO </p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
    public SSPASM05OutVO getSSPASM05S04(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S04 Start #####");

	    // KB아파트시세조회_아파트 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_아파트 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();

        i01Dto.setProvNm(inVo.getSSPASM05DSSMVO().getProvNm());                  /** 시도명 */
        i01Dto.setCigunguNm(inVo.getSSPASM05DSSMVO().getCigunguNm());            /** 시군구명 */
        i01Dto.setEubmyundongNm(inVo.getSSPASM05DSSMVO().getEubmyundongNm());    /** 읍면동명 */

   		LOGGER.info("" + "i01Dto.getProvNm()        : " + i01Dto.getProvNm());
   		LOGGER.info("" + "i01Dto.getCigunguNm()     : " + i01Dto.getCigunguNm());
   		LOGGER.info("" + "i01Dto.getEubmyundongNm() : " + i01Dto.getEubmyundongNm());

        // KB아파트시세조회_아파트 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchAptNm(i01Dto);

        // KB아파트시세조회_아파트 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세조회_아파트 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setEsttGodsCd(sourceIO.getEsttGodsCd());    /* 부동산물건코드 */
       		targetIO.setLdongCd(sourceIO.getLdongCd());          /* 법정동코드 */
       		targetIO.setAptNm(sourceIO.getAptNm());              /* 아파트명 */

            // KB아파트시세조회_아파트 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S04 End #####");

        // KB아파트시세조회_아파트 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명		: getSSPASM05S05 :KB아파트시세조회_조사기준일 내역_조회</p>
	 * 작성일자		: 2023.04.12.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_조사기준일 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO </p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
    public SSPASM05OutVO getSSPASM05S05(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S05 Start #####");

	    // KB아파트시세조회_조사기준일 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_조사기준일 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();

		i01Dto.setEsttGodsCd(inVo.getSSPASM05DSSMVO().getEsttGodsCd());    /** 부동산물건코드 */
        i01Dto.setLdongCd(inVo.getSSPASM05DSSMVO().getLdongCd());          /** 법정동코드 */
        i01Dto.setAptNm(inVo.getSSPASM05DSSMVO().getAptNm());              /** 아파트명 */

   		LOGGER.info("" + "i01Dto.getEsttGodsCd() : " + i01Dto.getEsttGodsCd());
   		LOGGER.info("" + "i01Dto.getLdongCd()    : " + i01Dto.getLdongCd());
   		LOGGER.info("" + "i01Dto.getAptNm()      : " + i01Dto.getAptNm());

        // KB아파트시세조회_조사기준일 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchStndDt(i01Dto);

        // KB아파트시세조회_조사기준일 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세조회_조사기준일 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setRschStndDt(sourceIO.getRschStndDt());    /* 조사기준일 */
       		targetIO.setLdongCd(sourceIO.getLdongCd());          /* 법정동코드 */

            // KB아파트시세조회_조사기준일 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S04 End #####");

        // KB아파트시세조회_아파트 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}


	/**
	 * <p>메소드명		: getSSPASM05S06 :KB아파트시세조회_시세 내역_조회</p>
	 * 작성일자		: 2023.04.13.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_시세 내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASM05InVO </p>
	 * <p>메소드리턴값	: SSPASM05OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
    public SSPASM05OutVO getSSPASM05S06(SSPASM05InVO inVo) throws Exception {
		LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S06 Start #####");

	    // KB아파트시세조회_조사기준일 조회 서비스 결과값 객체 생성
		SSPASM05OutVO resultVo = new SSPASM05OutVO();

	    // KB아파트시세조회_조사기준일 조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM05DSSMDTO i01Dto = new SSPASM05DSSMDTO();

		i01Dto.setEsttGodsCd(inVo.getSSPASM05DSSMVO().getEsttGodsCd());    /** 부동산물건코드 */
        i01Dto.setLdongCd(inVo.getSSPASM05DSSMVO().getLdongCd());          /** 법정동코드 */
        i01Dto.setRschStndDt(inVo.getSSPASM05DSSMVO().getRschStndDt());    /** 조사기준일 */

   		LOGGER.info("" + "i01Dto.getEsttGodsCd() : " + i01Dto.getEsttGodsCd());
   		LOGGER.info("" + "i01Dto.getLdongCd()    : " + i01Dto.getLdongCd());
   		LOGGER.info("" + "i01Dto.getRschStndDt() : " + i01Dto.getRschStndDt());

        // KB아파트시세조회_조사기준일 조회 쿼리 Mapper 호출 수행
        List<SSPASM05DSSDDTO> resultDTO = sSPASM05Mapper.srchMkprInfo(i01Dto);

        // KB아파트시세조회_조사기준일 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM05DSSDVO> resultList = new ArrayList<SSPASM05DSSDVO>();
       	for (SSPASM05DSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세조회_조사기준일 조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM05DSSDVO targetIO = new SSPASM05DSSDVO();

       		targetIO.setRschStndDt   (sourceIO.getRschStndDt());       /* 조사기준일 */
       		targetIO.setEsttGodsCd   (sourceIO.getEsttGodsCd());       /* 부동산물건코드 */
       		targetIO.setPntpSeq      (sourceIO.getPntpSeq());          /* 평형순번 */
       		targetIO.setAptNm        (sourceIO.getAptNm());            /* 아파트명 */
       		targetIO.setEuseArea     (sourceIO.getEuseArea());         /* 전용면적 */
       		targetIO.setSplyArea     (sourceIO.getSplyArea());         /* 공급면적 */
       		targetIO.setSaleBtmlAmt  (sourceIO.getSaleBtmlAmt());      /* 매매하한가 */
       		targetIO.setSaleUplmitAmt(sourceIO.getSaleUplmitAmt());    /* 매매상한가 */
       		targetIO.setSaleGenTrAmt (sourceIO.getSaleGenTrAmt());     /* 매매일반가 */
       		targetIO.setDpstBtmlAmt  (sourceIO.getDpstBtmlAmt());      /* 전세하한가 */
       		targetIO.setDpstGenTrAmt (sourceIO.getDpstGenTrAmt());     /* 전세상한가 */
       		targetIO.setDpstUplmitAmt(sourceIO.getDpstUplmitAmt());    /* 전세일반가 */

            // KB아파트시세조회_조사기준일 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM05 ServiceImpl getSSPASM05S06 End #####");

        // KB아파트시세조회_아파트 조회 화면 출력 결과값 대입
        resultVo.setListSSPASM05DSSDVO(resultList);

        return resultVo;
	}

}
