package hanalife.s.sp.as.service.impl;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.CustAccInfoSrchMapper;
import hanalife.s.sp.as.mapper.dto.CustAccInfoSrchDSCUSTACCINFOSDDTO;
import hanalife.s.sp.as.mapper.dto.CustAccInfoSrchDSCUSTACCINFOSDSENDDTO;
import hanalife.s.sp.as.mapper.dto.CustAccInfoSrchDSCUSTACCINFOSMDTO;
import hanalife.s.sp.as.service.SSPASP07Service;
import hanalife.s.sp.as.vo.SSPASP07DSCUSTACCINFOSDVO;
import hanalife.s.sp.as.vo.SSPASP07I01InVO;
import hanalife.s.sp.as.vo.SSPASP07I01OutVO;
import hanalife.s.sp.as.vo.SSPASP07S01InVO;
import hanalife.s.sp.as.vo.SSPASP07S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP07ServiceImpl.java Class
 * 클래스설명   : todo1 (SSPASP07) Service Implements
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSSPASP07S01 : 대출현황계좌목록 조회
 * </pre>
 */
@Service("SSPASP07Service")
public class SSPASP07ServiceImpl implements SSPASP07Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP07ServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 **/
    private MsgEnum msgEnum;

	@Autowired
	private CustAccInfoSrchMapper custAccInfoSrchMapper;

	/**
	 * <p>메소드명      : getSSPASP07S01 : 거래처계좌관리목록 조회</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 거래처계좌관리목록을 조회한다.</p>
	 * <p>메소드인수    : SSPASP07S01InVo </p>
	 * <p>메소드리턴값  : SSPASP07S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASP07S01OutVO getSSPASP07S01(SSPASP07S01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 거래처계좌관리목록조회 서비스결과값 객체생성
		 *************************************************/
		SSPASP07S01OutVO resultVo = new SSPASP07S01OutVO();


		/*************************************************
		 * ■ 거래처계좌관리목록조회 조건입력값 객체생성 및 대입수행
		 *************************************************/
		CustAccInfoSrchDSCUSTACCINFOSMDTO dsCustAccInfoSdDto = new CustAccInfoSrchDSCUSTACCINFOSMDTO();

		dsCustAccInfoSdDto.setCustNo(inVo.getSSPASP07DSCUSTACCINFOSMVO().getCustNo());             // 고객번호
		dsCustAccInfoSdDto.setCprtComNo(inVo.getSSPASP07DSCUSTACCINFOSMVO().getCprtComNo());       // 제휴사번호
		dsCustAccInfoSdDto.setCprtBranCd(inVo.getSSPASP07DSCUSTACCINFOSMVO().getCprtBranCd());     // 제휴점코드


		/*************************************************
		 * ■ 거래처계좌관리목록조회
		 *************************************************/
        List<CustAccInfoSrchDSCUSTACCINFOSDDTO> resultDTO = custAccInfoSrchMapper.searchList(dsCustAccInfoSdDto);


        /*************************************************
		 * ■ 화면출력을 위한 결과값 ListVO 객체 생성
		 *************************************************/
        List<SSPASP07DSCUSTACCINFOSDVO> resultList = new ArrayList<SSPASP07DSCUSTACCINFOSDVO>();

        for (CustAccInfoSrchDSCUSTACCINFOSDDTO sourceIO : resultDTO) {

        	/****************************************
			 * □ VO에 조회된 MapperDTO 값을 대입
			 ****************************************/
        	SSPASP07DSCUSTACCINFOSDVO targetIO = new SSPASP07DSCUSTACCINFOSDVO();

        	targetIO.setCustNo(sourceIO.getCustNo());
        	targetIO.setBankCd(sourceIO.getBankCd());
        	targetIO.setAcntNo(sourceIO.getAcntNo());
        	targetIO.setDepoOwnNo(sourceIO.getDepoOwnNo());
        	targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm());
        	targetIO.setDepoOwnRelcd(sourceIO.getDepoOwnRelcd());
        	targetIO.setMainFg(sourceIO.getMainFg());
        	targetIO.setAcntCfmDt(sourceIO.getAcntCfmDt());
        	targetIO.setAcntCfmEmpNo(sourceIO.getAcntCfmEmpNo());
        	targetIO.setAcntUseDivCd(sourceIO.getAcntUseDivCd());
        	targetIO.setFrstRegDt(sourceIO.getFrstRegDt());
        	targetIO.setFrstRegEmpNm(sourceIO.getFrstRegEmpNm());
        	targetIO.setLastProcDt(sourceIO.getLastProcDt());
        	targetIO.setLastProcEmpNm(sourceIO.getLastProcEmpNm());
        	targetIO.setBankNm(sourceIO.getBankNm());
        	targetIO.setCprtComNo(sourceIO.getCprtComNo());
        	targetIO.setCprtBranCd(sourceIO.getCprtBranCd());
        	targetIO.setCprtBranNm(sourceIO.getCprtBranNm());

            resultList.add(targetIO);
        }


        /*************************************************
		 * ■ 거래처계좌관리목록조회 화면출력 결과값 대입
		 *************************************************/
        resultVo.setSSPASP07DSCUSTACCINFOSDVO(resultList);

		return resultVo;

	}


	/**
	 * <p>메소드명      : registerSSPASP07I01 : 거래처계좌관리 등록</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 거래처계좌관리를 등록한다.</p>
	 * <p>메소드인수    : SSPASP07I01InVo </p>
	 * <p>메소드리턴값  : SSPASP07I01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASP07I01OutVO registerSSPASP07I01(SSPASP07I01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 거래처계좌관리등록 서비스 결과값 객체생성
		 *************************************************/
		SSPASP07I01OutVO resultVo = new SSPASP07I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		/*************************************************
		 * ■ 거래처계좌관리등록 조건입력값 객체생성 및 대입수행
		 *************************************************/
		try {

			for( int i = 0; i < inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().size(); i++ ) {

				/****************************************
				 * □ 저장 및 업데이트 CHK
				 ****************************************/
				CustAccInfoSrchDSCUSTACCINFOSDSENDDTO accNumChkDto = new CustAccInfoSrchDSCUSTACCINFOSDSENDDTO();
				accNumChkDto.setCustNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCustNo());                // 고객번호
				accNumChkDto.setAcntNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntNo());                // 계좌번호

				CustAccInfoSrchDSCUSTACCINFOSDSENDDTO accNumChkYn = custAccInfoSrchMapper.accNumChkSelect(accNumChkDto);


				/****************************************
				 * □ 저장 및 업데이트 DTO_Set
				 ****************************************/
				CustAccInfoSrchDSCUSTACCINFOSDSENDDTO ListSetDto = new CustAccInfoSrchDSCUSTACCINFOSDSENDDTO();

				ListSetDto.setCustNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCustNo());                // 고객번호
				ListSetDto.setBankCd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getBankCd());                // 은행코드
				ListSetDto.setAcntNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntNo());                // 계좌번호
				ListSetDto.setDepoOwnNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getDepoOwnNo());          // 예금주번호
				ListSetDto.setDepoOwnnm(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getDepoOwnnm());          // 예금주명
				ListSetDto.setDepoOwnRelcd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getDepoOwnRelcd());    // 예금주관계코드
				ListSetDto.setMainFg(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getMainFg());                // 주거래여부
				ListSetDto.setAcntCfmDt(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntCfmDt());          // 계좌확인일자
				ListSetDto.setAcntCfmEmpNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntCfmEmpNo());    // 계좌확인사원번호
				ListSetDto.setAcntUseDivCd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntUseDivCd());    // 연체사용구분코드
				ListSetDto.setCprtComNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCprtComNo());          // 제휴사번호
				ListSetDto.setCprtBranCd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCprtBranCd());        // 제휴점코드
				ListSetDto.setFrstRegEmpNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getFrstRegEmpNo());    // 최초등록사원번호
				ListSetDto.setLastProcEmpNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getLastProcEmpNo());  // 최종처리사원번호

//				ListSetDto.setFrstRegDt(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getFrstRegDt());          // 최초등록일자
//				ListSetDto.setLastProcDt(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getLastProcDt());        // 최종수정일자
//				ListSetDto.setFrstRegEmpNm(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getFrstRegEmpNm());    // 최초등록자
//				ListSetDto.setLastProcEmpNm(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getLastProcEmpNm());  // 최종수정자
//				ListSetDto.setBankNm(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getBankNm());                // 은행명
//				ListSetDto.setCprtBranNm(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCprtBranNm());        // 제휴점


				/****************************************
				 * □ INSERT & UPDATE
				 ****************************************/
				if( accNumChkYn == null) {
					// □ INSERT
					// => 최초등록자,최종수정자 사원번호 추가
					System.out.println("Insert~~~~~");
					custAccInfoSrchMapper.insert(ListSetDto);
				}else {
					// □ UPDATE
					// => 최종수정자 사원번호 추가
					System.out.println("Update~~~~~");
					custAccInfoSrchMapper.update(ListSetDto);
				}

			}

		} catch ( SQLException e ) {
			throw new SQLException(e.getMessage());
        } catch( Exception e ) {
			throw new Exception(e.getMessage());
		}

		return resultVo;

	}


	/**
	 * <p>메소드명      : removeSSPASP07I01 : 거래처계좌관리 삭제</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 거래처계좌관리를 삭제한다.</p>
	 * <p>메소드인수    : SSPASP07I01InVo </p>
	 * <p>메소드리턴값  : SSPASP07I01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASP07I01OutVO removeSSPASP07I01(SSPASP07I01InVO inVo) throws Exception {

		/*************************************************
		 * ■ 거래처계좌관리삭제 서비스 결과값 객체생성
		 *************************************************/
		SSPASP07I01OutVO resultVo = new SSPASP07I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());


		/*************************************************
		 * ■ 거래처계좌관리삭제 조건입력값 객체생성 및 대입수행
		 *************************************************/
		try {

			for( int i = 0; i < inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().size(); i++ ) {

				/****************************************
				 * □ 삭제 DTO_Set
				 ****************************************/
				CustAccInfoSrchDSCUSTACCINFOSDSENDDTO ListSetDto = new CustAccInfoSrchDSCUSTACCINFOSDSENDDTO();

				ListSetDto.setCustNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getCustNo());                // 고객번호
				ListSetDto.setBankCd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getBankCd());                // 은행코드
				ListSetDto.setAcntNo(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getAcntNo());                // 계좌번호
				ListSetDto.setDepoOwnRelcd(inVo.getSSPASP07DSCUSTACCINFOSDSENDVO().get(i).getDepoOwnRelcd());    // 예금주관계코드


				/****************************************
				 * □ DELETE
				 ****************************************/
				System.out.println("Delete~~~~~");
				custAccInfoSrchMapper.remove(ListSetDto);

			}

		} catch ( SQLException e ) {
			throw new SQLException(e.getMessage());
        } catch( Exception e ) {
			throw new Exception(e.getMessage());
		}

		return resultVo;

	}

}
