package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.s.sp.as.mapper.LoanReptAccntReadPopMapper;
import hanalife.s.sp.as.mapper.dto.LoanReptAccntReadPopDSSDDTO;
import hanalife.s.sp.as.mapper.dto.LoanReptAccntReadPopDSSMDTO;
import hanalife.s.sp.as.service.SSPASP08Service;
import hanalife.s.sp.as.vo.SSPASP08DSSDVO;
import hanalife.s.sp.as.vo.SSPASP08S01InVO;
import hanalife.s.sp.as.vo.SSPASP08S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP08ServiceImpl.java Class
 * 클래스설명   : todo1 (SSPASP08) Service Implements
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSSPASP08S01 : 대출현황계좌목록 조회
 * </pre>
 */
@Service("SSPASP08Service")
public class SSPASP08ServiceImpl implements SSPASP08Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP08ServiceImpl.class);

	@Autowired
	private LoanReptAccntReadPopMapper loanReptAccntReadPopMapper;

	/**
	 * <p>메소드명      : getSSPASP08S01 : 대출현황계좌목록 조회</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 대출현황계좌목록을 조회한다.</p>
	 * <p>메소드인수    : SSPASP08S01InVo </p>
	 * <p>메소드리턴값  : SSPASP08S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASP08S01OutVO getSSPASP08S01(SSPASP08S01InVO inVo) throws Exception {

        /** 대출현황계좌목록조회 서비스 결과값 객체 생성 */
		SSPASP08S01OutVO resultVo = new SSPASP08S01OutVO();

        /** 대출현황계좌목록조회 조건 입력값 객체 생성 및 대입 수행 */
		LoanReptAccntReadPopDSSMDTO dsSmDto = new LoanReptAccntReadPopDSSMDTO();

		dsSmDto.setInqrKey(inVo.getSSPASP08DSSMVO().getInqrKey());       // 사업자번호
		dsSmDto.setUseGbCd(inVo.getSSPASP08DSSMVO().getUseGbCd());       // 가상계좌사용구분코드

        /** 대출현황계좌목록조회 쿼리 Mapper 호출 수행 */
        List<LoanReptAccntReadPopDSSDDTO> resultDTO = loanReptAccntReadPopMapper.searchList(dsSmDto);

        /** 대출현황계좌목록조회 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<SSPASP08DSSDVO> resultList = new ArrayList<SSPASP08DSSDVO>();

        for (LoanReptAccntReadPopDSSDDTO sourceIO : resultDTO) {
            /** 대출현황계좌목록조회 VO에 조회된 Mapper DTO 값을 대입 */
        	SSPASP08DSSDVO targetIO = new SSPASP08DSSDVO();

        	targetIO.setSeq(sourceIO.getSeq());
        	targetIO.setAccountCd(sourceIO.getAccountCd());
        	targetIO.setAccountNm(sourceIO.getAccountNm());
        	targetIO.setAccountNo(sourceIO.getAccountNo());
        	targetIO.setCustNo(sourceIO.getCustNo());
        	targetIO.setCustNm(sourceIO.getCustNm());
        	targetIO.setAccountUseYn(sourceIO.getAccountUseYn());
        	targetIO.setFirstRegDt(sourceIO.getFirstRegDt());
        	targetIO.setUserNm(sourceIO.getUserNm());
        	targetIO.setBcoNo(sourceIO.getBcoNo());
        	targetIO.setCoNo(sourceIO.getCoNo());
        	targetIO.setAccountSeq(sourceIO.getAccountSeq());
        	targetIO.setUseGdCd(sourceIO.getUseGdCd());
        	targetIO.setUseGdNm(sourceIO.getUseGdNm());
        	targetIO.setAllocCustNm(sourceIO.getAllocCustNm());
        	targetIO.setCustGdNm(sourceIO.getCustGdNm());
        	targetIO.setLoanNo(sourceIO.getLoanNo());
        	targetIO.setPolNo(sourceIO.getPolNo());
        	targetIO.setContYn(sourceIO.getContYn());
        	targetIO.setCarId(sourceIO.getCarId());
        	targetIO.setCarNum(sourceIO.getCarNum());
        	targetIO.setCarKindCd(sourceIO.getCarKindCd());
        	targetIO.setCarKindNm(sourceIO.getCarKindNm());
        	targetIO.setLoanPrcpAmt(sourceIO.getLoanPrcpAmt());
        	targetIO.setLoanRato(sourceIO.getLoanRato());
        	targetIO.setLoanDate(sourceIO.getLoanDate());
        	targetIO.setExprDate(sourceIO.getExprDate());
        	targetIO.setLoanMmth(sourceIO.getLoanMmth());
        	targetIO.setLoanBalnAmt(sourceIO.getLoanBalnAmt());
        	targetIO.setDmndAmt(sourceIO.getDmndAmt());

            /** 대출현황계좌목록조회 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 대출현황계좌목록조회 화면 출력 결과값 대입 */
        resultVo.setSSPASP08DSSDVO(resultList);

		return resultVo;

	}

}
