package hanalife.s.sp.as.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.SmsDlyrDescMapper;
import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.cm.sp.vo.sendSmsVO;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.SSPASP11Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASP11DSSDDTO;
import hanalife.s.sp.as.mapper.dto.SSPASP11DSSMDTO;
import hanalife.s.sp.as.service.SSPASP11Service;
import hanalife.s.sp.as.vo.SSPASP11DSSDVO;
import hanalife.s.sp.as.vo.SSPASP11InVO;
import hanalife.s.sp.as.vo.SSPASP11OutVO;

/**
/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP11Service.java Class
 * 클래스설명	: 서류보완요청 (SSPASP11) Service Interface
 * 작성일자	: 2023.05.09.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.05.09.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :insertSSPASP11, 서류보완요청내역 등록
 *          getSSPASP11S01, 관련인정보조회(sms발송)
 *
 * </pre>
 */
@Service("SSPASP11Service")
public class SSPASP11ServiceImpl implements SSPASP11Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP11ServiceImpl.class);

    @Autowired
    private SSPASP11Mapper sSPASP11Mapper; // 서류보완

    @Autowired
    callSpService callSpService;           // SMS 발송 SP 호출

    @Autowired
    SmsDlyrDescMapper smsDlyrDescMapper;   // sms 발송내역을 등록

    /**
     * <p>메소드명 : insertSSPASP11, 서류보완요청내역 등록</p>
     * <p>작성일자 : 2023.05.09. </p>
     * <p>작성자(author) : 70305 / KBS </p>
     * <p>설명 : 서류보완요청내역을 등록한다.</p>
     * <p>메소드인수 : SSPASP11InVO </p>
     * <p>메소드리턴값 : SSPASP11OutVO</p>
     * <p>예외처리 : Exception</p>
     */
    @Override
    public SSPASP11OutVO insertSSPASP11(SSPASP11InVO inVo) throws Exception
    {
        LOGGER.info("SSPASP11 ServiceImpl insertSSPASP11 Start");

        // 결과값 출력 객체 VO 선언 및 정상 초기값 설정
        SSPASP11OutVO resultVo = new SSPASP11OutVO();

        resultVo.setRsltCd  (MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // 입력조건 체크
        String strLoanCnslNo     = inVo.getSSPASP11DSSMVO().getLoanCnslNo().toString();    // 대출상담번호
        String strLoanDocCd      = inVo.getSSPASP11DSSMVO().getLoanDocCd().toString();     // 대출서류코드
        String strFrstRegEmpNo   = inVo.getSSPASP11DSSMVO().getFrstRegEmpNo ().toString(); // 최초등록사원번호
        String strLastProcEmpNo  = inVo.getSSPASP11DSSMVO().getLastProcEmpNo().toString(); // 최종처리사원번호

        LOGGER.info("serviceImpl" + "inVo.strLoanCnslNo    : " + strLoanCnslNo);
        LOGGER.info("serviceImpl" + "inVo.strLoanDocCd     : " + strLoanDocCd);
        LOGGER.info("serviceImpl" + "inVo.strFrstRegEmpNo  : " + strFrstRegEmpNo);
        LOGGER.info("serviceImpl" + "inVo.strLastProcEmpNo : " + strLastProcEmpNo);

        try
        {
            // 전결권자대행 등록
            SSPASP11DSSMDTO inDto = new SSPASP11DSSMDTO();

            inDto.setLoanCnslNo    (strLoanCnslNo);    // 대출상담번호
            inDto.setLoanDocCd     (strLoanDocCd);     // 대출서류코드
            inDto.setFrstRegEmpNo  (strFrstRegEmpNo);  // 최초등록사원번호
            inDto.setLastProcEmpNo (strLastProcEmpNo); // 최종처리사원번호

            // mapper 호출
            sSPASP11Mapper.insertDocSpmtRqst(inDto);

        }
        catch (Exception e)
        {
            LOGGER.error("[서류보완요청] : 서류보완요청내역 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
        LOGGER.info("SSPASP11 ServiceImpl insertSSPASP11 Normal End");
        return resultVo;
    }

    /**
     * <p> 메소드명 : getSSPASP11S01, 관련인정보조회(sms발송) </p>
     * <p> 작성일자 : 2023.05.10. </p>
     * <p> 작성자명 : 70305 / KBS </p>
     * <p> 설명 : 관련인정보를 조회한다. </p>
     * <p> 메소드인수 : SSPASP11InVO </p>
     * <p> 메소드리턴값 : SSPASP11OutVO </p>
     * <p> 예외처리 : Exception </p>
     */
    @Override
    public SSPASP11OutVO getSSPASP11S01(SSPASP11InVO inVo) throws Exception
    {
        LOGGER.info("##### SSPASP11 ServiceImpl getSSPASP11S01 Start #####");

        // 관련인정보조회 서비스 결과값 객체 생성
        SSPASP11OutVO resultVo = new SSPASP11OutVO();

        // 관련인정보조회 조건 입력값 객체 생성 및 대입 수행
        SSPASP11DSSMDTO i01Dto = new SSPASP11DSSMDTO();

        i01Dto.setLoanCnslNo(inVo.getSSPASP11DSSMVO().getLoanCnslNo());    /** 대출상담번호 */
        LOGGER.info("getSSPASP11S01 serviceImpl : i01Dto.getLoanCnslNo() : " + i01Dto.getLoanCnslNo());

        // 전결권자대행목록 조회 쿼리 Mapper 호출 수행
        List<SSPASP11DSSDDTO> resultDTO = sSPASP11Mapper.srchRelaInfo(i01Dto);

        // 전결권자대행목록 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP11DSSDVO> resultList = new ArrayList<SSPASP11DSSDVO>();

        for (SSPASP11DSSDDTO sourceIO : resultDTO)
        {
            // 전결권자대행목록 조회 VO에 조회된 Mapper DTO 값을 대입
            SSPASP11DSSDVO targetIO = new SSPASP11DSSDVO();

            targetIO.setLoanCnslNo (sourceIO.getLoanCnslNo());     /* 대출상담번호 */
            targetIO.setRelaGbCd   (sourceIO.getRelaGbCd());       /* 관련인구분코드 */
            targetIO.setRelaNm     (sourceIO.getRelaNm());         /* 관련인성명 */
            targetIO.setRelaTelNo  (sourceIO.getRelaTelNo());      /* 관련인전화번호 */
            targetIO.setLoanApplNo (sourceIO.getLoanApplNo());     /* 대출신청번호 */
            targetIO.setLoanNo     (sourceIO.getLoanNo());         /* 대출번호 */
            targetIO.setLoanSeq    (sourceIO.getLoanSeq());        /* 관련인전화번호 */

            // 전결권자대행목록 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
        }
        LOGGER.info("##### SSPASP11 ServiceImpl getSSPASP11S01 End #####");

        // 전결권자대행목록 조회 화면 출력 결과값 대입
        resultVo.setListSSPASP11DSSDVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명 : registSSPASP11, 서류보완내역 sms발송</p>
     * <p>작성일자 : 2023.05.11.
     * <p>작성자(author) : 70305 / KBS
     * <p>설명 : 서류보완내역 sms 전송한다.</p>
     * <p>예외처리 : Exception</p>
     */
    @Override
    public SSPASP11OutVO registSSPASP11(SSPASP11InVO inVo) throws Exception
    {
        LOGGER.info("##### SSPASP11 ServiceImpl registSSPASP11 Start #####");

        // KBS_결과값 출력 객체 VO 선언 및 정상 초기값 설정
        SSPASP11OutVO outVo = new SSPASP11OutVO();
//        String sendFlg    = inVo.getSSPASP11DSSMVO().getSendFlg();     /** 내메세지저장여부 */
        String rsrvSndFlg = inVo.getSSPASP11DSSMVO().getRsrvSndFlg();  /** 예약전송여부 */

        LOGGER.info("##### SSPASP11 ServiceImpl registSSPASP11 1111");
        // 내정보 저장 체크시 문자관리 INSERT TO-BE 미사용
//      if("1".equals(sendFlg)) {
//          BtSmsTxtMngDTO inDto = new BtSmsTxtMngDTO();
//          inDto.setEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//          inDto.setCntn(inVo.getBCNUIP02DSSDDO03().getCntn());
//          inDto.setProcDt(inVo.getBCNUIP02DSSDDO03().getProcDt());
//          inDto.setFrstRegEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//          inDto.setLastProcEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//          smsTxtMngMapper.insertSmsTxtMng(inDto);
//      }


        // KBS_공통 SMS 전송 서비스 호출
        sendSmsVO sendVo = new sendSmsVO();
        sendSmsVO returnVo;

        // 템플릿 미등록으로 임시
        sendVo.setVfvSmsMsgCd (inVo.getSSPASP11DSSD01VO().getSeq());                        /** EAGLE.SMS_CD_MAST@D_BEST_HE테이블의 SMS_CD */
//        sendVo.setVfvSmsMsgCd ("1");                        /** EAGLE.SMS_CD_MAST@D_BEST_HE테이블의 SMS_CD */
        sendVo.setVfvSndTelNo (inVo.getSSPASP11DSSD01VO().getRspnTelNo());                  /** 송신자전화번호*/

        // test, 실 로직에서는 대출번호 조회해서 전달가능
//        sendVo.setVfvJgno     (new BigDecimal("111111111111111"));                          /** 대출번호*/
        sendVo.setVfvJgno     (new BigDecimal(inVo.getSSPASP11DSSD01VO().getLoanNo()));  /** 대출번호*/
        sendVo.setVfvJhno     (inVo.getSSPASP11DSSD01VO().getRecvTelNo());                  /** 수신자전화번호 */
        sendVo.setVfvGgno     (inVo.getSSPASP11DSSD01VO().getCustNo());                     /** 고객번호 */
        // 확인필요 발송한사람? 로그인직원번호? 생성자?
        sendVo.setVfvZCreateBy(inVo.getSSPASP11DSSMVO().getLogInEmpNo());                   /** 생성자 */

        // 배치 & 실시간 구분(배치용 sms : Y / 실시간 sms : N)
        sendVo.setVfvBatchYn("N");  // 서류보완 sms는 "실시간"으로 발송

//        LOGGER.info("serviceImpl" + "sendFlg    : " + sendFlg); // 미사용
        LOGGER.info("serviceImpl_registSSPASP11 :" + "rsrvSndFlg       : [" + rsrvSndFlg + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvSmsMsgCd   : [" + sendVo.getVfvSmsMsgCd()  + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvSndTelNo   : [" + sendVo.getVfvSndTelNo()  + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvJgno       : [" + sendVo.getVfvJgno()      + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvJhno       : [" + sendVo.getVfvJhno()      + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvGgno       : [" + sendVo.getVfvGgno()      + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvZCreateBy  : [" + sendVo.getVfvZCreateBy() + "]");
        LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvBatchYn    : [" + sendVo.getVfvBatchYn()   + "]");


        // KBS_00410: 자유형식 양식 seq 번호
        if("00410".equals(inVo.getSSPASP11DSSD01VO().getSeq()))
        {
            LOGGER.info("serviceImpl: 자유형식양식 ");
            sendVo.setVfvSmsMsgCtt(inVo.getSSPASP11DSSD01VO().getSendTxt());     /** 전송문자_자유형식 */
        }
        else
        {
            LOGGER.info("serviceImpl: 기본형식 ");
            sendVo.setVfvParam01(inVo.getSSPASP11DSSD01VO().getVfvParam01());   /** 파라미터01_고객명 */
            sendVo.setVfvParam02(inVo.getSSPASP11DSSD01VO().getVfvParam02());   /** 파라미터02_필요서류목록 */
            sendVo.setVfvParam03(inVo.getSSPASP11DSSD01VO().getVfvParam03());   /** 파라미터03_바로가기(URL) */
            sendVo.setVfvParam04(inVo.getSSPASP11DSSD01VO().getVfvParam04());   /** 파라미터04_콜센터전화번호 */
            sendVo.setVfvParam05(inVo.getSSPASP11DSSD01VO().getVfvParam05());   /** 파라미터05 */
            sendVo.setVfvParam06(inVo.getSSPASP11DSSD01VO().getVfvParam06());   /** 파라미터06 */
            sendVo.setVfvParam07(inVo.getSSPASP11DSSD01VO().getVfvParam07());   /** 파라미터07 */
            sendVo.setVfvParam08(inVo.getSSPASP11DSSD01VO().getVfvParam08());   /** 파라미터08 */
            sendVo.setVfvParam09(inVo.getSSPASP11DSSD01VO().getVfvParam09());   /** 파라미터09 */
            sendVo.setVfvParam10(inVo.getSSPASP11DSSD01VO().getVfvParam10());   /** 파라미터10 */
            sendVo.setVfvParam11(inVo.getSSPASP11DSSD01VO().getVfvParam11());   /** 파라미터11 */
            sendVo.setVfvParam12(inVo.getSSPASP11DSSD01VO().getVfvParam12());   /** 파라미터12 */
            sendVo.setVfvParam13(inVo.getSSPASP11DSSD01VO().getVfvParam13());   /** 파라미터13 */
            sendVo.setVfvParam14(inVo.getSSPASP11DSSD01VO().getVfvParam14());   /** 파라미터14 */
            sendVo.setVfvParam15(inVo.getSSPASP11DSSD01VO().getVfvParam15());   /** 파라미터15 */

            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam01 : [" + sendVo.getVfvParam01()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam02 : [" + sendVo.getVfvParam02()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam03 : [" + sendVo.getVfvParam03()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam04 : [" + sendVo.getVfvParam04()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam05 : [" + sendVo.getVfvParam05()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam06 : [" + sendVo.getVfvParam06()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam07 : [" + sendVo.getVfvParam07()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam08 : [" + sendVo.getVfvParam08()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam09 : [" + sendVo.getVfvParam09()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam10 : [" + sendVo.getVfvParam10()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam11 : [" + sendVo.getVfvParam11()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam12 : [" + sendVo.getVfvParam12()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam13 : [" + sendVo.getVfvParam13()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam14 : [" + sendVo.getVfvParam14()+"]");
            LOGGER.info("serviceImpl_registSSPASP11 :" + "getVfvParam15 : [" + sendVo.getVfvParam15()+"]");
        }

        // SMS 모듈 호출
//        callSpService.sendSms(sendVo);

        // 서류보완sms발송 시 loan_seq가 채번되지않아, sms발송내역 테이블에(BT_SMS_DLVR_DESC) 저장불가_추후 확인예정
        // KBS_성공여부에 따라 발송내역 등록처리
//        BtSmsDlvrDescDTO inDto = new BtSmsDlvrDescDTO();
//
//        inDto.setDlvrDt    (DateUtil.getServerDate(DateUtil.YYYYMMDD));     /* 발송일자 */
//        inDto.setMngDeptCd (inVo.getSSPASP11DSSD01VO().getMngDeptCd());     /* 관리부서코드 */
//        inDto.setDlvrEmpNo (inVo.getSSPASP11DSSD01VO().getDlvrEmpNo());     /* 발송사원번호 */
//        inDto.setLoanNo    (inVo.getSSPASP11DSSD01VO().getLoanNo());        /* 대출번호 */
//        inDto.setLoanSeq   (inVo.getSSPASP11DSSD01VO().getLoanSeq());       /* 대출순번 */
//        inDto.setCustNo    (inVo.getSSPASP11DSSD01VO().getCustNo());        /* 고객번호 */
//        inDto.setSendDiv   (rsrvSndFlg);                                    /* 예약전송여부 */
//        inDto.setRecvTelNo (inVo.getSSPASP11DSSD01VO().getRecvTelNo());     /* 수신전화번호 */
//        inDto.setRspnTelNo (inVo.getSSPASP11DSSD01VO().getRspnTelNo());     /* 응답전화번호 */
//        inDto.setSendTxt   (inVo.getSSPASP11DSSD01VO().getSendTxt());       /* 전송문자 */
//        String sendRefKey = ""; // SEND_REF_KEY
//        if(Constants.SMS_RESULT_CODE.equals(sendVo.getVfvRtnCd())) {
//            String[] rtnCtt = sendVo.getVfvRtnCtt().split(":");
//            sendRefKey = rtnCtt[1];
//        }
//        inDto.setSendRefKey    (sendRefKey);                                 /* SEND_REF_KEY */
//        inDto.setSmsSendErrCd  (sendVo.getVfvRtnCd());                       /* SMS_SEND_ERR_CD */
//        inDto.setSendId        (inVo.getSSPASP11DSSMVO().getRsrvSndTime().substring(0, 6));  /* SEND_ID*/
//        inDto.setDlvrObjCd     (inVo.getSSPASP11DSSD02VO().getDlvrObjCd());  /* DLVR_OBJ_CD */
//        inDto.setDlvrDeptCd    (inVo.getSSPASP11DSSD02VO().getDlvrDeptCd()); /* DLVR_DEPT_CD */
//        inDto.setFrstRegEmpNo  (inVo.getSSPASP11DSSD02VO().getLogInEmpNo()); /* 최초등록사원번호 */
//        inDto.setLastProcEmpNo (inVo.getSSPASP11DSSD02VO().getLogInEmpNo()); /* 최종처리사원번호 */
//
//        smsDlyrDescMapper.insertSmsDlyrDesc(inDto);.
//
//        outVo.setSendSmsVO(sendVo);
        LOGGER.info("SSPASP11 ServiceImpl insertSSPASP11 End");
        return outVo;
    }

}
