package hanalife.s.sp.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.cm.sp.vo.chkAccNmVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.sp.as.service.SSPASM01Service;
import hanalife.s.sp.as.vo.SSPASM01DSSDCVO;
import hanalife.s.sp.as.vo.SSPASM01DSSMVO;
import hanalife.s.sp.as.vo.SSPASM01I01InVO;
import hanalife.s.sp.as.vo.SSPASM01I01OutVO;
import hanalife.s.sp.as.vo.SSPASM01S01InVO;
import hanalife.s.sp.as.vo.SSPASM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASM01Controller.java Class
 *
 * 클래스설명   : 제휴업체관리 (SSPASM01) Controller
 * 작성일자     : 2023. 4. 17.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 17.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASM01Controller {

	@Resource(name = "SSPASM01Service")
	private SSPASM01Service SSPASM01;

	@Resource(name = "callSpService")
	private callSpService callSp;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM01Controller.class);

	/**
	 * <p>메소드명      : 제휴업체관리 /SSPASM01S01.do </p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323
	 * <p>설명          : 제휴업체관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASM01S01.do")
	public String SSPASM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASM01Controller SSPASM01S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 제휴업체관리내역조회 업무 서비스 호출 입력값 대입 */
			SSPASM01S01InVO targetVo = new SSPASM01S01InVO();
			SSPASM01DSSMVO smVo = new SSPASM01DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setSSPASM01DSSMVO(smVo);

			/** 제휴업체관리내역조회 업무 서비스 호출 수행 */
			SSPASM01S01OutVO resultSSPASM01S01 = SSPASM01.getSSPASM01S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSSPASM01S01.getSSPASM01DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSSPASM01S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSSPASM01S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### SSPASM01Controller SSPASM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM01Controller SSPASM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 제휴업체관리등록 /SSPASM01I01.do </p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323
	 * <p>설명          : 제휴업체관리 등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASM01I01.do")
	public String SSPASM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASM01Controller SSPASM01I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** 제휴업체관리내역조회 업무 서비스 호출 입력값 대입 */
			SSPASM01I01InVO targetVo = new SSPASM01I01InVO();
			SSPASM01DSSDCVO sdcVo = new SSPASM01DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSSPASM01DSSDCVO(sdcVo);

			/** 제휴업체관리내역조회 업무 서비스 호출 수행 */
			SSPASM01I01OutVO resultSSPASM01I01 = SSPASM01.registerSSPASM01S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSSPASM01I01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSSPASM01I01.getRsltCntn());

			LOGGER.info("##### SSPASM01Controller SSPASM01I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM01Controller SSPASM01I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 제휴업체관리수정 /SSPASM01U01.do </p>
	 * <p>작성일자      : 2023. 4. 17.
	 * <p>작성자(author): 70323
	 * <p>설명          : 제휴업체관리 수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASM01U01.do")
	public String SSPASM01U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASM01Controller SSPASM01U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** 제휴업체관리내역조회 업무 서비스 호출 입력값 대입 */
			SSPASM01I01InVO targetVo = new SSPASM01I01InVO();
			SSPASM01DSSDCVO sdcVo = new SSPASM01DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSSPASM01DSSDCVO(sdcVo);

			/** 제휴업체관리내역조회 업무 서비스 호출 수행 */
			SSPASM01I01OutVO resultSSPASM01U01 = SSPASM01.modifySSPASM01S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSSPASM01U01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSSPASM01U01.getRsltCntn());

			LOGGER.info("##### SSPASM01Controller SSPASM01U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM01Controller SSPASM01U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 계좌번호확인 /SSPASM01C01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : 계좌번호 확인 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASM01C01.do")
	public String SSPASM01C01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASM01Controller SSPASM01C01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ACNT_CHK", request, response, model);

			/** SR기관관리내역조회 업무 서비스 호출 입력값 대입 */
			chkAccNmVO chkAccNmVO = new chkAccNmVO();

			chkAccNmVO.setLvvIgjbh(		(String)sourceMap.get("acntNo")		); 		/** 계좌번호 */
			chkAccNmVO.setLvvIbankcd(	(String)sourceMap.get("bankcd")		); 		/** 은행코드 */
			chkAccNmVO.setLvvIygjjmbh(	(String)sourceMap.get("cprtComNo")	); 		/** 주민번호앞자리(6자리) / 사업자번호 */

			/** SR기관관리내역조회 업무 서비스 호출 수행 */
			chkAccNmVO resultSSPASM01C01 = callSp.chkAccNm(chkAccNmVO);

			String revRecode = chkAccNmVO.getRevRecode();

			if(revRecode == null) {
				revRecode = "계좌번호 확인 오류입니다.";
			}

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, chkAccNmVO.getOutData());		/** 1:정상, 그외 에러 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, revRecode);	/** 정상인경우:실 예금주명, 에러인경우 에러내용 */

			LOGGER.info("##### SSPASM01Controller SSPASM01C01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM01Controller SSPASM01C01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}
