package hanalife.s.sp.as.web;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASM02Service;
import hanalife.s.sp.as.vo.SSPASM02DSSDVO;
import hanalife.s.sp.as.vo.SSPASM02DSSMVO;
import hanalife.s.sp.as.vo.SSPASM02I01InVO;
import hanalife.s.sp.as.vo.SSPASM02InVO;
import hanalife.s.sp.as.vo.SSPASM02OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASM02Controller.java Class
 * 클래스설명	: 특수지역관리 (SSPASM02) Controller
 * 작성일자	: 2023.04.14.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.12.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	특수지역관리_시도 조회	 		: /SSPASM02S01.do
 *          특수지역관리_시군구 조회		: /SSPASM02S02.do
 *          특수지역관리_읍면동 조회		: /SSPASM02S03.do
 *          특수지역관리_리 조회	 		: /SSPASM02S04.do
 *          특수지역관리 내역 조회	    	: /SSPASM02S05.do
 *          특수지역관리 내역 등록 & 삭제	: /SSPASM02I01.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASM02Controller {

	@Resource(name = "SSPASM02Service")
	private SSPASM02Service SSPASM02;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM02Controller.class);

	/**
	 * <p> 메소드명 		: 시도 내역조회 /SSPASM02S01.do </p>
	 * <p> 작성일자 		: 2023.04.14. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 특수지역관리_시도 내역을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASM02S01.do")
	public String SSPASM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02 Controller SSPASM02S01 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM02 Controller SSPASM02S01 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_SPCL_ZONE_SRCH", request, response, model);

			// 특수지역관리_시도명 조회 서비스 호출 입력값 대입
			SSPASM02DSSMVO dsSEARCHVO = new SSPASM02DSSMVO();

			// 특수지역관리_시도명 조회 업무 서비스 호출 입력값 대입
			/** 입력값 없음 */

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM02InVO InVO = new SSPASM02InVO();

			// 특수지역관리_시도명 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM02DSSMVO(dsSEARCHVO);

			// 특수지역관리_시도명 조회 업무 서비스 호출 수행
			SSPASM02OutVO resultListVo = SSPASM02.getSSPASM02S01(InVO);

			// 특수지역관리_시도명 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD01", resultListVo.getListSSPASM02DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02 Controller SSPASM02S01 Exception End #####");
		}
		LOGGER.info("##### SSPASM02 Controller SSPASM02S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p> 메소드명 		: 시군구 내역조회 /SSPASM02S02.do </p>
	 * <p> 작성일자 		: 2023.04.14. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 특수지역관리_시군구 내역을 조회한다. </p>
	 * 예외처리 			: Exception </p>
	 */
	@RequestMapping("/SSPASM02S02.do")
	public String SSPASM02S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02 Controller SSPASM02S02 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM02 Controller SSPASM02S02 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_SPCL_ZONE_SRCH", request,
					response, model);

			// 특수지역관리_시군구명 조회 서비스 호출 입력값 대입
			SSPASM02DSSMVO dsSEARCHVO = new SSPASM02DSSMVO();

			// 특수지역관리_시군구명 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setProvNm((String) sourceMap.get("provNm")); /** 시도명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM02InVO InVO = new SSPASM02InVO();

			// 특수지역관리_시군구명 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM02DSSMVO(dsSEARCHVO);

			// 특수지역관리_시군구명 조회 업무 서비스 호출 수행
			SSPASM02OutVO resultListVo = SSPASM02.getSSPASM02S02(InVO);

			// 특수지역관리_시군구명 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD02", resultListVo.getListSSPASM02DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02 Controller SSPASM02S02 Exception End #####");

		}
		LOGGER.info("##### SSPASM02 Controller SSPASM02S02 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p> 메소드명 		: 읍면동 내역조회 /SSPASM02S03.do </p>
	 * <p> 작성일자 		: 2023.04.14. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 특수지역관리_읍면동명 내역을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASM02S03.do")
	public String SSPASM02S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02 Controller SSPASM02S03 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM02 Controller SSPASM02S03 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_SPCL_ZONE_SRCH", request, response, model);

			// 특수지역관리_읍면동명 조회 서비스 호출 입력값 대입
			SSPASM02DSSMVO dsSEARCHVO = new SSPASM02DSSMVO();

			// 특수지역관리_읍면동명 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setProvNm((String) sourceMap.get("provNm")); /** 시도명 */
			dsSEARCHVO.setCigunguNm((String) sourceMap.get("cigunguNm")); /** 시군구명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm()     : " + dsSEARCHVO.getCigunguNm());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM02InVO InVO = new SSPASM02InVO();

			// 특수지역관리_읍면동명 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM02DSSMVO(dsSEARCHVO);

			// 특수지역관리_읍면동명 조회 업무 서비스 호출 수행
			SSPASM02OutVO resultListVo = SSPASM02.getSSPASM02S03(InVO);

			// 특수지역관리_읍면동명 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD03", resultListVo.getListSSPASM02DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02 Controller SSPASM02S02 Exception End #####");

		}
		LOGGER.info("##### SSPASM02 Controller SSPASM02S03 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p> 메소드명 		: 리 내역조회 /SSPASM02S04.do </p>
	 * <p> 작성일자 		: 2023.04.14. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 특수지역관리_리명 내역을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASM02S04.do")
	public String SSPASM02S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02 Controller SSPASM02S04 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM02 Controller SSPASM02S04 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_SPCL_ZONE_SRCH", request, response, model);

			// 특수지역관리_리명 조회 서비스 호출 입력값 대입
			SSPASM02DSSMVO dsSEARCHVO = new SSPASM02DSSMVO();

			// 특수지역관리_리명 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setProvNm((String) sourceMap.get("provNm")); /** 시도명 */
			dsSEARCHVO.setCigunguNm((String) sourceMap.get("cigunguNm")); /** 시군구명 */
			dsSEARCHVO.setEubmyundongNm((String) sourceMap.get("eubmyundongNm")); /** 읍면동명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm()     : " + dsSEARCHVO.getCigunguNm());
			LOGGER.info("" + "dsSEARCHVO.getEubmyundongNm() : " + dsSEARCHVO.getEubmyundongNm());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM02InVO InVO = new SSPASM02InVO();

			// 특수지역관리_리명 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM02DSSMVO(dsSEARCHVO);

			// 특수지역관리_리명 조회 업무 서비스 호출 수행
			SSPASM02OutVO resultListVo = SSPASM02.getSSPASM02S04(InVO);

			// 특수지역관리_리명 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD04", resultListVo.getListSSPASM02DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02 Controller SSPASM02S02 Exception End #####");

		}
		LOGGER.info("##### SSPASM02 Controller SSPASM02S03 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p> 메소드명 		: 리 내역조회 /SSPASM02S05.do </p>
	 * <p> 작성일자 		: 2023.04.17. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 특수지역관리 특수지역관리내역을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASM02S05.do")
	public String SSPASM02S05(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02 Controller SSPASM02S05 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM02 Controller SSPASM02S05 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_SPCL_ZONE_SRCH", request, response, model);

			// 특수지역관리_특수지역관리내역 조회 서비스 호출 입력값 대입
			SSPASM02DSSMVO dsSEARCHVO = new SSPASM02DSSMVO();

			// 특수지역관리_특수지역관리내역 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setLdongCd1((String) sourceMap.get("ldongCd1")); /** 법정동코드1 */
			dsSEARCHVO.setLdongCd2((String) sourceMap.get("ldongCd2")); /** 법정동코드2 */
			dsSEARCHVO.setLdongCd3((String) sourceMap.get("ldongCd3")); /** 법정동코드3 */
			dsSEARCHVO.setLdongCd4((String) sourceMap.get("ldongCd4")); /** 법정동코드4 */
			dsSEARCHVO.setSpcuZoneFg          ((String) sourceMap.get("spcuZoneFg"));          /** 투기여부 */
			dsSEARCHVO.setSpcuZoneExclFg      ((String) sourceMap.get("spcuZoneExclFg"));      /** 투기제외여부 */
			dsSEARCHVO.setSpcuOverhRegnFg     ((String) sourceMap.get("spcuOverhRegnFg"));     /** 투기과열지구여부 */
			dsSEARCHVO.setSpcuOverhRegnExclFg ((String) sourceMap.get("spcuOverhRegnExclFg")); /** 투기과열지구제외여부 */
			dsSEARCHVO.setOverpCotrZoneFg     ((String) sourceMap.get("overpCotrZoneFg"));     /** 과밀억제권역여부 */
			dsSEARCHVO.setOverpCotrZoneExclFg ((String) sourceMap.get("overpCotrZoneExclFg")); /** 과밀억제권역제외여부 */
			dsSEARCHVO.setWdarCiFg            ((String) sourceMap.get("wdarCiFg"));            /** 광역시여부 */
			dsSEARCHVO.setWdarCiExclFg        ((String) sourceMap.get("wdarCiExclFg"));        /** 광역시제외여부 */
			dsSEARCHVO.setCapiRegnFg          ((String) sourceMap.get("capiRegnFg"));          /** 수도권여부 */
			dsSEARCHVO.setCapiRegnExclFg      ((String) sourceMap.get("capiRegnExclFg"));      /** 수도권제외여부 */
			dsSEARCHVO.setAdjuRegnFg          ((String) sourceMap.get("adjuRegnFg"));          /** 조정지역여부 */
			dsSEARCHVO.setAdjuRegnExclFg      ((String) sourceMap.get("adjuRegnExclFg"));      /** 조정지역제외여부 */
			dsSEARCHVO.setSpclAdmtZoneFg      ((String) sourceMap.get("spclAdmtZoneFg"));      /** 특별인정지역여부 */
			dsSEARCHVO.setSpclAdmtZoneExclFg  ((String) sourceMap.get("spclAdmtZoneExclFg"));  /** 특별인정지역제외여부 */
			dsSEARCHVO.setEtcZoneFg           ((String) sourceMap.get("etcZoneFg"));           /** 기타지역여부 */
			dsSEARCHVO.setEtcZoneExclFg       ((String) sourceMap.get("etcZoneExclFg"));       /** 기타지역제외여부 */

			LOGGER.info("" + "dsSEARCHVO.getLdongCd1()            : " + dsSEARCHVO.getLdongCd1());
			LOGGER.info("" + "dsSEARCHVO.getLdongCd2()            : " + dsSEARCHVO.getLdongCd2());
			LOGGER.info("" + "dsSEARCHVO.getLdongCd3()            : " + dsSEARCHVO.getLdongCd3());
			LOGGER.info("" + "dsSEARCHVO.getLdongCd4()            : " + dsSEARCHVO.getLdongCd4());
			LOGGER.info("" + "dsSEARCHVO.getSpcuZoneFg()          : " + dsSEARCHVO.getSpcuZoneFg());
			LOGGER.info("" + "dsSEARCHVO.getSpcuZoneExclFg()      : " + dsSEARCHVO.getSpcuZoneExclFg());
			LOGGER.info("" + "dsSEARCHVO.getSpcuOverhRegnFg()     : " + dsSEARCHVO.getSpcuOverhRegnFg());
			LOGGER.info("" + "dsSEARCHVO.getSpcuOverhRegnExclFg() : " + dsSEARCHVO.getSpcuOverhRegnExclFg());
			LOGGER.info("" + "dsSEARCHVO.getOverpCotrZoneFg()     : " + dsSEARCHVO.getOverpCotrZoneFg());
			LOGGER.info("" + "dsSEARCHVO.getOverpCotrZoneExclFg() : " + dsSEARCHVO.getOverpCotrZoneExclFg());
			LOGGER.info("" + "dsSEARCHVO.getWdarCiFg()            : " + dsSEARCHVO.getWdarCiFg());
			LOGGER.info("" + "dsSEARCHVO.getWdarCiExclFg()        : " + dsSEARCHVO.getWdarCiExclFg());
			LOGGER.info("" + "dsSEARCHVO.getCapiRegnFg()          : " + dsSEARCHVO.getCapiRegnFg());
			LOGGER.info("" + "dsSEARCHVO.getCapiRegnExclFg()      : " + dsSEARCHVO.getCapiRegnExclFg());
			LOGGER.info("" + "dsSEARCHVO.getAdjuRegnFg()          : " + dsSEARCHVO.getAdjuRegnFg());
			LOGGER.info("" + "dsSEARCHVO.getAdjuRegnExclFg()      : " + dsSEARCHVO.getAdjuRegnExclFg());
			LOGGER.info("" + "dsSEARCHVO.getSpclAdmtZoneFg()      : " + dsSEARCHVO.getSpclAdmtZoneFg());
			LOGGER.info("" + "dsSEARCHVO.getSpclAdmtZoneExclFg()  : " + dsSEARCHVO.getSpclAdmtZoneExclFg());
			LOGGER.info("" + "dsSEARCHVO.getEtcZoneFg()           : " + dsSEARCHVO.getEtcZoneFg());
			LOGGER.info("" + "dsSEARCHVO.getEtcZoneExclFg()       : " + dsSEARCHVO.getEtcZoneExclFg());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM02InVO InVO = new SSPASM02InVO();

			// 특수지역관리_특수지역관리내역 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM02DSSMVO(dsSEARCHVO);

			// 특수지역관리_특수지역관리내역 조회 업무 서비스 호출 수행
			SSPASM02OutVO resultListVo = SSPASM02.getSSPASM02S05(InVO);

			// 특수지역관리_특수지역관리내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_SPCL_ZONE_SD", resultListVo.getListSSPASM02DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02 Controller SSPASM02S05 Exception End #####");

		}
		LOGGER.info("##### SSPASM02 Controller SSPASM02S05 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p> 메소드명 		: 특수지역관리내역 저장(등록,삭제) /SSPASM02I01.do </p>
	 * <p> 작성일자 		: 2023.04.20. <p>
	 * <p> 작성자(author) : 70305 / KBS
	 * <p> 설명 			: 특수지역관리내역 등록, 삭제)을 한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASM02I01.do")
	public String SSPASM02I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM02Controller SSPASM02I01 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			List<Map<String, Object>> sourceMapC = XFrame5DataSetUtil.getXFrameDataSetList("DS_KB_SPCL_ZONE_SD", request, response, model); // 수정 & 등록

			// ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			Map<String, Object> inMap = new HashMap<String, Object>();

			SSPASM02I01InVO InVO = null;
			SSPASM02DSSDVO inSddoVo = null;

			// ■ 등록, 삭제 처리
			SSPASM02OutVO resultI01 = new SSPASM02OutVO();
			String strOperation = "";

			if (sourceMapC.size() > 0)
			{
				for (int idx = 0; idx < sourceMapC.size(); idx++)
				{
					inMap = sourceMapC.get(idx);
					strOperation = inMap.get("XDATASET_RECORD_TYPE").toString(); // operation 종류(I : 등록, U : 수정 D:삭제)

					// □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
					inSddoVo = new SSPASM02DSSDVO();

					inSddoVo.setLdongCd            (inMap.get("ldongCd").toString());                /* 법정동코드 */
					inSddoVo.setProvNm             (inMap.get("provNm").toString());                 /* 시도명 */
					inSddoVo.setCigunguNm          (inMap.get("cigunguNm").toString());              /* 시군구명 */
					inSddoVo.setEubmyundongNm      (inMap.get("eubmyundongNm").toString());          /* 읍면동명 */
					inSddoVo.setRiNm               (inMap.get("riNm").toString());                   /* 리명 */
					inSddoVo.setSpcuZoneFg         (inMap.get("spcuZoneFg").toString());             /* 투기지역여부 */
					inSddoVo.setSpcuZoneExclFg     (inMap.get("spcuZoneExclFg").toString());         /* 투기지역제외여부 */
					inSddoVo.setSpcuOverhRegnFg    (inMap.get("spcuOverhRegnFg").toString());        /* 투기과열지구여부 */
					inSddoVo.setSpcuOverhRegnExclFg(inMap.get("spcuOverhRegnExclFg").toString());    /* 투기과열지구제외여부 */
					inSddoVo.setOverpCotrZoneFg    (inMap.get("overpCotrZoneFg").toString());        /* 과밀억제권역여부 */
					inSddoVo.setOverpCotrZoneExclFg(inMap.get("overpCotrZoneExclFg").toString());    /* 과밀억제권역제외여부 */
					inSddoVo.setWdarCiFg           (inMap.get("wdarCiFg").toString());               /* 광역시여부 */
					inSddoVo.setWdarCiExclFg       (inMap.get("wdarCiExclFg").toString());           /* 광역시제외여부 */
					inSddoVo.setCapiRegnFg         (inMap.get("capiRegnFg").toString());             /* 수도권여부 */
					inSddoVo.setCapiRegnExclFg     (inMap.get("capiRegnExclFg").toString());         /* 수도권제외여부 */
					inSddoVo.setAdjuRegnFg         (inMap.get("adjuRegnFg").toString());             /* 조정지역여부 */
					inSddoVo.setAdjuRegnExclFg     (inMap.get("adjuRegnExclFg").toString());         /* 조정지역제외여부 */
					inSddoVo.setSpclAdmtZoneFg     (inMap.get("spclAdmtZoneFg").toString());         /* 특별인정지역여부 */
					inSddoVo.setSpclAdmtZoneExclFg (inMap.get("spclAdmtZoneExclFg").toString());     /* 특별인정지역제외여부 */
					inSddoVo.setEtcZoneFg          (inMap.get("etcZoneFg").toString());              /* 기타지역여부 */
					inSddoVo.setEtcZoneExclFg      (inMap.get("etcZoneExclFg").toString());          /* 기타지역제외여부 */
					inSddoVo.setFrstRegEmpNo       (inMap.get("frstRegEmpNo").toString());           /* 최초등록사원번호 */
					inSddoVo.setLastProcEmpNo      (inMap.get("lastProcEmpNo").toString());          /* 최종등록사원번호 */

					if (!"Y".equals(inSddoVo.getSpcuZoneFg()))			inSddoVo.setSpcuZoneFg("N");
					if (!"Y".equals(inSddoVo.getSpcuZoneExclFg()))		inSddoVo.setSpcuZoneExclFg("N");
					if (!"Y".equals(inSddoVo.getSpcuOverhRegnFg()))		inSddoVo.setSpcuOverhRegnFg("N");
					if (!"Y".equals(inSddoVo.getSpcuOverhRegnExclFg()))	inSddoVo.setSpcuOverhRegnExclFg("N");
					if (!"Y".equals(inSddoVo.getOverpCotrZoneFg()))		inSddoVo.setOverpCotrZoneFg("N");
					if (!"Y".equals(inSddoVo.getOverpCotrZoneExclFg()))	inSddoVo.setOverpCotrZoneExclFg("N");
					if (!"Y".equals(inSddoVo.getWdarCiFg()))			inSddoVo.setWdarCiFg("N");
					if (!"Y".equals(inSddoVo.getWdarCiExclFg()))		inSddoVo.setWdarCiExclFg("N");
					if (!"Y".equals(inSddoVo.getCapiRegnFg()))			inSddoVo.setCapiRegnFg("N");
					if (!"Y".equals(inSddoVo.getCapiRegnExclFg()))		inSddoVo.setCapiRegnExclFg("N");
					if (!"Y".equals(inSddoVo.getAdjuRegnFg()))			inSddoVo.setAdjuRegnFg("N");
					if (!"Y".equals(inSddoVo.getAdjuRegnExclFg()))		inSddoVo.setAdjuRegnExclFg("N");
					if (!"Y".equals(inSddoVo.getSpclAdmtZoneFg()))		inSddoVo.setSpclAdmtZoneFg("N");
					if (!"Y".equals(inSddoVo.getSpclAdmtZoneExclFg()))	inSddoVo.setSpclAdmtZoneExclFg("N");
					if (!"Y".equals(inSddoVo.getEtcZoneFg()))		    inSddoVo.setEtcZoneFg("N");
					if (!"Y".equals(inSddoVo.getEtcZoneExclFg()))    	inSddoVo.setEtcZoneExclFg("N");

					LOGGER.info("inSddoVo.getLdongCd             :: " + inSddoVo.getLdongCd());
					LOGGER.info("inSddoVo.getProvNm              :: " + inSddoVo.getProvNm());
					LOGGER.info("inSddoVo.getCigunguNm           :: " + inSddoVo.getCigunguNm());
					LOGGER.info("inSddoVo.getEubmyundongNm       :: " + inSddoVo.getEubmyundongNm());
					LOGGER.info("inSddoVo.getRiNm                :: " + inSddoVo.getRiNm());
					LOGGER.info("inSddoVo.getSpcuZoneFg          :: " + inSddoVo.getSpcuZoneFg());
					LOGGER.info("inSddoVo.getSpcuZoneExclFg      :: " + inSddoVo.getSpcuZoneExclFg());
					LOGGER.info("inSddoVo.getSpcuOverhRegnFg     :: " + inSddoVo.getSpcuOverhRegnFg());
					LOGGER.info("inSddoVo.getSpcuOverhRegnExclFg :: " + inSddoVo.getSpcuOverhRegnExclFg());
					LOGGER.info("inSddoVo.getOverpCotrZoneFg     :: " + inSddoVo.getOverpCotrZoneFg());
					LOGGER.info("inSddoVo.getOverpCotrZoneExclFg :: " + inSddoVo.getOverpCotrZoneExclFg());
					LOGGER.info("inSddoVo.getWdarCiFg            :: " + inSddoVo.getWdarCiFg());
					LOGGER.info("inSddoVo.getWdarCiExclFg        :: " + inSddoVo.getWdarCiExclFg());
					LOGGER.info("inSddoVo.getCapiRegnFg          :: " + inSddoVo.getCapiRegnFg());
					LOGGER.info("inSddoVo.getCapiRegnExclFg      :: " + inSddoVo.getCapiRegnExclFg());
					LOGGER.info("inSddoVo.getAdjuRegnFg          :: " + inSddoVo.getAdjuRegnFg());
					LOGGER.info("inSddoVo.getAdjuRegnExclFg      :: " + inSddoVo.getAdjuRegnExclFg());
					LOGGER.info("inSddoVo.getSpclAdmtZoneFg      :: " + inSddoVo.getSpclAdmtZoneFg());
					LOGGER.info("inSddoVo.getSpclAdmtZoneExclFg  :: " + inSddoVo.getSpclAdmtZoneExclFg());
					LOGGER.info("inSddoVo.getEtcZoneFg           :: " + inSddoVo.getEtcZoneFg());
					LOGGER.info("inSddoVo.getEtcZoneExclFg       :: " + inSddoVo.getEtcZoneExclFg());
					LOGGER.info("inSddoVo.getFrstRegEmpNo        :: " + inSddoVo.getFrstRegEmpNo());
					LOGGER.info("inSddoVo.getLastProcEmpNo       :: " + inSddoVo.getLastProcEmpNo());

					// □ 특수지역관리내역 저장 서비스 호출 입력값 대입
					InVO = new SSPASM02I01InVO();
					InVO.setSSPASM02DSSDVO(inSddoVo);

					// 체크박스 체크여부 확인(삭제 or 수정(삭제+등록))
					if ("N".equals(inSddoVo.getSpcuZoneFg())
						&& "N".equals(inSddoVo.getSpcuZoneExclFg())
						&& "N".equals(inSddoVo.getSpcuOverhRegnFg())
						&& "N".equals(inSddoVo.getSpcuOverhRegnExclFg())
						&& "N".equals(inSddoVo.getOverpCotrZoneFg())
						&& "N".equals(inSddoVo.getOverpCotrZoneExclFg())
						&& "N".equals(inSddoVo.getWdarCiFg())
						&& "N".equals(inSddoVo.getWdarCiExclFg())
						&& "N".equals(inSddoVo.getCapiRegnFg())
						&& "N".equals(inSddoVo.getCapiRegnExclFg())
						&& "N".equals(inSddoVo.getAdjuRegnFg())
						&& "N".equals(inSddoVo.getAdjuRegnExclFg())
						&& "N".equals(inSddoVo.getSpclAdmtZoneFg())
						&& "N".equals(inSddoVo.getSpclAdmtZoneExclFg())
					    && "N".equals(inSddoVo.getEtcZoneFg())
					    && "N".equals(inSddoVo.getEtcZoneExclFg()))
					{
						// 특수지역관리 삭제 서비스 호출 수행
						resultI01 = SSPASM02.deleteSSPASM02(InVO);
					}
					else
					{
						// 특수지역관리 삭제 서비스 호출 수행
						resultI01 = SSPASM02.deleteSSPASM02(InVO);

						// 특수지역관리 등록 서비스 호출 수행
						resultI01 = SSPASM02.saveSSPASM02(InVO);
					}
				}
			}
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02Controller SSPASM02I01 Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}
}
