package hanalife.s.sp.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASM05Service;
import hanalife.s.sp.as.vo.SSPASM05DSSMVO;
import hanalife.s.sp.as.vo.SSPASM05InVO;
import hanalife.s.sp.as.vo.SSPASM05OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASM05Controller.java Class
 * 클래스설명	: KB아파트시세조회 (SSPASM05) Controller
 * 작성일자	: 2023.04.12.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.12.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	KB아파트시세조회_시도 조회		: /SSPASM05S01.do
 * 			KB아파트시세조회_시군구 조회	: /SSPASM05S02.do
 * 			KB아파트시세조회_읍면동		: /SSPASM05S03.do
 *			KB아파트시세조회_읍면동정보 	: /SSPASM05S04.do
 * 			KB아파트시세조회_조사기준일		: /SSPASM05S05.do
 *			KB아파트시세조회_아파트시세 	: /SSPASM05S06.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASM05Controller {

	@Resource(name = "SSPASM05Service")
	private SSPASM05Service SSPASM05;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM05Controller.class);

	/**
	 * <p>메소드명			: KB아파트시세조회_시도 조회 /SSPASM05S01.do </p>
	 * <p>작성일자			: 2023.04.12.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_시도내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S01.do")
	public String SSPASM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S01 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S01 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_시도 조회 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

            // KB아파트시세조회_시도 조회 업무 서비스 호출 입력값 대입
			/** 입력값 없음 */

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_시도 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_시도 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S01(InVO);

			// KB아파트시세조회_시도 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD01", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S01 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S01 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p>메소드명			: KB아파트시세조회_시군구 조회 /SSPASM05S02.do </p>
	 * <p>작성일자			: 2023.04.12.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_시군구 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S02.do")
	public String SSPASM05S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S02 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S02 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_시군구 조회 업무 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

			dsSEARCHVO.setProvNm((String)sourceMap.get("provNm"));	/** 시도_명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_시군구 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_시군구 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S02(InVO);

			// KB아파트시세조회_시군구 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD02", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S02 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S02 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p>메소드명			: KB아파트시세조회_읍면동 조회 /SSPASM05S02.do </p>
	 * <p>작성일자			: 2023.04.12.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_읍면동 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S03.do")
	public String SSPASM05S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S03 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S03 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_읍면동 조회 업무 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

			dsSEARCHVO.setProvNm((String)sourceMap.get("provNm"));	        /** 시도명 */
			dsSEARCHVO.setCigunguNm((String)sourceMap.get("cigunguNm"));    /** 시군구명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm()  : " + dsSEARCHVO.getCigunguNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_읍면동 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_읍면동 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S03(InVO);

			// KB아파트시세조회_읍면동 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD03", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S03 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S03 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p>메소드명			: KB아파트시세조회_아파트 조회 /SSPASM05S04.do </p>
	 * <p>작성일자			: 2023.04.12.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_아파트 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S04.do")
	public String SSPASM05S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S04 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S04 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

			dsSEARCHVO.setProvNm((String)sourceMap.get("provNm"));	                /** 시도명 */
			dsSEARCHVO.setCigunguNm((String)sourceMap.get("cigunguNm"));            /** 시군구명 */
			dsSEARCHVO.setEubmyundongNm((String)sourceMap.get("eubmyundongNm"));    /** 읍면동명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()         : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm()      : " + dsSEARCHVO.getCigunguNm());
			LOGGER.info("" + "dsSEARCHVO.getEubmyundongNm()  : " + dsSEARCHVO.getEubmyundongNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_아파트 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S04(InVO);

			// KB아파트시세조회_아파트 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_APT_NM_SD", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S04 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S04 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p>메소드명			: KB아파트시세조회_조사기준일 조회 /SSPASM05S05.do </p>
	 * <p>작성일자			: 2023.04.12.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_조사기준일 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S05.do")
	public String SSPASM05S05(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S05 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S05 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

			dsSEARCHVO.setEsttGodsCd((String)sourceMap.get("esttGodsCd"));    /** 부동산물건코드 */
			dsSEARCHVO.setLdongCd((String)sourceMap.get("ldongCd"));          /** 법정동코드 */
			dsSEARCHVO.setAptNm((String)sourceMap.get("aptNm"));              /** 아파트 */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd() : " + dsSEARCHVO.getEsttGodsCd());
			LOGGER.info("" + "dsSEARCHVO.getLdongCd()    : " + dsSEARCHVO.getLdongCd());
			LOGGER.info("" + "dsSEARCHVO.getAptNm()      : " + dsSEARCHVO.getAptNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_아파트 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S05(InVO);

			// KB아파트시세조회_아파트 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_STND_DT_SD", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S05 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S05 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p>메소드명			: KB아파트시세조회_시세 조회 /SSPASM05S06.do </p>
	 * <p>작성일자			: 2023.04.13.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_시세 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASM05S06.do")
	public String SSPASM05S06(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASM05 Controller SSPASM05S06 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASM05 Controller SSPASM05S06 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_SEARCH", request, response, model);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 입력값 대입
			SSPASM05DSSMVO dsSEARCHVO = new SSPASM05DSSMVO();

			dsSEARCHVO.setEsttGodsCd((String)sourceMap.get("esttGodsCd"));    /** 부동산물건코드 */
			dsSEARCHVO.setLdongCd((String)sourceMap.get("ldongCd"));          /** 법정동코드 */
			dsSEARCHVO.setRschStndDt((String)sourceMap.get("rschStndDt"));    /** 조사기준일 */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd() : " + dsSEARCHVO.getEsttGodsCd());
			LOGGER.info("" + "dsSEARCHVO.getLdongCd()    : " + dsSEARCHVO.getLdongCd());
			LOGGER.info("" + "dsSEARCHVO.getRschStndDt() : " + dsSEARCHVO.getRschStndDt());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASM05InVO InVO = new SSPASM05InVO();

			// KB아파트시세조회_아파트 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASM05DSSMVO(dsSEARCHVO);

			// KB아파트시세조회_아파트 조회 업무 서비스 호출 수행
			SSPASM05OutVO resultListVo = SSPASM05.getSSPASM05S06(InVO);

			// KB아파트시세조회_아파트 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_APT_MKPR_SD", resultListVo.getListSSPASM05DSSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM05 Controller SSPASM05S06 Exception End #####");

		}
		LOGGER.info("##### SSPASM05 Controller SSPASM05S06 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

}
