package hanalife.s.sp.as.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP07Service;
import hanalife.s.sp.as.vo.SSPASP07DSCUSTACCINFOSDSENDVO;
import hanalife.s.sp.as.vo.SSPASP07DSCUSTACCINFOSMVO;
import hanalife.s.sp.as.vo.SSPASP07I01InVO;
import hanalife.s.sp.as.vo.SSPASP07I01OutVO;
import hanalife.s.sp.as.vo.SSPASP07S01InVO;
import hanalife.s.sp.as.vo.SSPASP07S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP07Controller.java Class
 * 클래스설명   : todo1 (SSPASP07) Controller
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP07Controller {

    @Resource(name = "SSPASP07Service")
    private SSPASP07Service SSPASP07;

    private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP07Controller.class);

    /**
     * <p>메소드명      : 거래처계좌관리 조회팝업 /SSPASP07S01.do </p>
     * <p>작성일자      : 2023. 3. 21.
     * <p>작성자(author): 70324
     * <p>설명          : 거래처계좌관리 목록을 조회한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP07S01.do")
    public String SSPASP07S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP07Controller SSPASP07S01 Start #####");

        try {

            /*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CUST_ACC_INFO_SM", request, response, model);


            /*************************************************
             * ■ 거래처계좌관리 조회 DataSet 항목값 VO객체 입력값 대입
             *************************************************/
            SSPASP07DSCUSTACCINFOSMVO dsSMInVo = new SSPASP07DSCUSTACCINFOSMVO();
            dsSMInVo.setCustNo((String) sourceMap.get("custNo"));                // 고객번호
            dsSMInVo.setCprtComNo((String) sourceMap.get("cprtComNo"));          // 제휴사번호
            dsSMInVo.setCprtBranCd((String) sourceMap.get("cprtBranCd"));        // 제휴점코드

            LOGGER.info("##### sourceMap.get(\"custNo\") #####      :  " + sourceMap.get("custNo"));
            LOGGER.info("##### sourceMap.get(\"cprtComNo\") #####   :  " + sourceMap.get("cprtComNo"));
            LOGGER.info("##### sourceMap.get(\"cprtBranCd\") #####  :  " + sourceMap.get("cprtBranCd"));


            /*************************************************
             * ■ VO객체에 DataSetVO 입력값 대입
             *************************************************/
            SSPASP07S01InVO InVO = new SSPASP07S01InVO();
            InVO.setSSPASP07DSCUSTACCINFOSMVO(dsSMInVo);


            /*************************************************
             * ■ 거래처계좌관리 조회(팝업) 업무 서비스 호출
             *************************************************/
            SSPASP07S01OutVO resultListVo = SSPASP07.getSSPASP07S01(InVO);


            /*************************************************
             * ■ 거래처계좌관리 조회(팝업) DataSet 결과값 설정
             *************************************************/
            XFrame5Util.setOutputData("DS_CUST_ACC_INFO_SD", resultListVo.getSSPASP07DSCUSTACCINFOSDVO(), model);
            LOGGER.info("##### S SPASP07Controller SSPASP07S01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### SSPASP07Controller SSPASP07S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;

    }


    /**
     * <p>메소드명      : SSPASP07등록 /SSPASP07I01.do </p>
     * <p>작성일자      : 2023. 3. 21.
     * <p>작성자(author): 70324
     * <p>설명          : 거래처계좌를 등록한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP07I01.do")
    public String SSPASP07I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP07Controller SSPASP07I01 Start #####");

        try {

            /*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
            List<Map<String, Object>> sourceMap = XFrame5DataSetUtil.getXFrameDataSetList("DS_CUST_ACC_INFO_SD_SEND", request, response, model);


            /*************************************************
             * ■ 거래처계좌 등록 DataSet 항목값 ListVO객체 생성
             *************************************************/
            List<SSPASP07DSCUSTACCINFOSDSENDVO> dsCustAccInfoSdSendInVo = new ArrayList<SSPASP07DSCUSTACCINFOSDSENDVO>();

            for( int i = 0; i < sourceMap.size(); i++ ) {

                /****************************************
                 * □ ListVO에 DataSet 항목값을 대입
                 ****************************************/
                SSPASP07DSCUSTACCINFOSDSENDVO ListSetVo = new SSPASP07DSCUSTACCINFOSDSENDVO();

                ListSetVo.setCustNo((String)sourceMap.get(i).get("custNo"));               // 고객번호
                ListSetVo.setBankCd((String)sourceMap.get(i).get("bankCd"));               // 은행코드
                ListSetVo.setAcntNo((String)sourceMap.get(i).get("acntNo"));               // 계좌번호
                ListSetVo.setDepoOwnNo((String)sourceMap.get(i).get("depoOwnNo"));         // 예금주번호
                ListSetVo.setDepoOwnnm((String)sourceMap.get(i).get("depoOwnnm"));         // 예금주명
                ListSetVo.setDepoOwnRelcd((String)sourceMap.get(i).get("depoOwnRelcd"));   // 예금주관계코드
                ListSetVo.setMainFg((String)sourceMap.get(i).get("mainFg"));               // 주거래여부
                ListSetVo.setAcntCfmDt((String)sourceMap.get(i).get("acntCfmDt"));         // 계좌확인일자
                ListSetVo.setAcntCfmEmpNo((String)sourceMap.get(i).get("acntCfmEmpNo"));   // 계좌확인사원번호
                ListSetVo.setAcntUseDivCd((String)sourceMap.get(i).get("acntUseDivCd"));   // 연체사용구분코드
                ListSetVo.setCprtComNo((String)sourceMap.get(i).get("cprtComNo"));         // 제휴사번호
                ListSetVo.setCprtBranCd((String)sourceMap.get(i).get("cprtBranCd"));       // 제휴점코드
                ListSetVo.setFrstRegEmpNo((String)sourceMap.get(i).get("frstRegEmpNo"));   // 최초등록사원번호
                ListSetVo.setLastProcEmpNo((String)sourceMap.get(i).get("lastProcEmpNo")); // 최종처리사원번호

//              ListSetVo.setFrstRegDt((String)sourceMap.get(i).get("frstRegDt"));         // 최초등록일자
//              ListSetVo.setLastProcDt((String)sourceMap.get(i).get("lastProcDt"));       // 최종수정일자
//              ListSetVo.setFrstRegEmpNm((String)sourceMap.get(i).get("frstRegEmpNm"));   // 최초등록자
//              ListSetVo.setLastProcEmpNm((String)sourceMap.get(i).get("lastProcEmpNm")); // 최종수정자
//              ListSetVo.setBankNm((String)sourceMap.get(i).get("bankNm"));               // 은행명
//              ListSetVo.setCprtBranNm((String)sourceMap.get(i).get("cprtBranNm"));       // 제휴점

                dsCustAccInfoSdSendInVo.add(ListSetVo);

            }

            /*************************************************
             * ■  VO객체에 DataSetVO 입력값 대입
             *************************************************/
            SSPASP07I01InVO InVO = new SSPASP07I01InVO();
            InVO.setSSPASP07DSCUSTACCINFOSDSENDVO(dsCustAccInfoSdSendInVo);


            /*************************************************
             * ■  거래처계좌관리 등록(팝업) 업무 서비스 호출
             *************************************************/
            SSPASP07I01OutVO resultInsertVo = SSPASP07.registerSSPASP07I01(InVO);


            /*************************************************
             * ■ 거래처계좌관리 등록(팝업) DataSet 결과값 설정
             *************************************************/
//          XFrame5Util.setOutputData("DS_CUST_ACC_INFO_SD", resultInsertVo.getRsltCntn(), model);
            LOGGER.info("##### SSPASP07Controller SSPASP07I01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### SSPASP07Controller SSPASP07I01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;

    }


    /**
     * <p>메소드명      : SSPASP07삭제 /SSPASP07D01.do </p>
     * <p>작성일자      : 2023. 3. 21.
     * <p>작성자(author): 70324
     * <p>설명          : 거래처계좌를 삭제한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP07D01.do")
    public String SSPASP07D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP07Controller SSPASP07D01 Start #####");

        try {

            /*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
            List<Map<String, Object>> sourceMap = XFrame5DataSetUtil.getXFrameDataSetList("DS_CUST_ACC_INFO_SD_SEND", request, response, model);


            /*************************************************
             * ■ 거래처계좌 삭제 DataSet 항목값 ListVO객체 생성
             *************************************************/
            List<SSPASP07DSCUSTACCINFOSDSENDVO> dsCustAccInfoSdSendInVo = new ArrayList<SSPASP07DSCUSTACCINFOSDSENDVO>();

            for( int i = 0; i < sourceMap.size(); i++ ) {

                /****************************************
                 * □ ListVO에 DataSet 항목값을 대입
                 ****************************************/
                SSPASP07DSCUSTACCINFOSDSENDVO ListSetVo = new SSPASP07DSCUSTACCINFOSDSENDVO();

                ListSetVo.setCustNo((String)sourceMap.get(i).get("custNo"));               // 고객번호
                ListSetVo.setAcntNo((String)sourceMap.get(i).get("acntNo"));               // 계좌번호
                ListSetVo.setBankCd((String)sourceMap.get(i).get("bankCd"));               // 은행코드
                ListSetVo.setDepoOwnRelcd((String)sourceMap.get(i).get("depoOwnRelcd"));   // 예금주관계코드

                dsCustAccInfoSdSendInVo.add(ListSetVo);

            }

            /*************************************************
             * ■  VO객체에 DataSetVO 입력값 대입
             *************************************************/
            SSPASP07I01InVO InVO = new SSPASP07I01InVO();
            InVO.setSSPASP07DSCUSTACCINFOSDSENDVO(dsCustAccInfoSdSendInVo);


            /*************************************************
             * ■  거래처계좌관리 삭제(팝업) 업무 서비스 호출
             *************************************************/
            SSPASP07I01OutVO resultInsertVo = SSPASP07.removeSSPASP07I01(InVO);


            /*************************************************
             * ■ 거래처계좌관리 삭제(팝업) DataSet 결과값 설정
             *************************************************/
//          XFrame5Util.setOutputData("DS_CUST_ACC_INFO_SD", resultInsertVo.getRsltCntn(), model);
            LOGGER.info("##### SSPASP07Controller SSPASP07D01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### SSPASP07Controller SSPASP07S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;

    }

}

