package hanalife.s.sp.as.web;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP10Service;
import hanalife.s.sp.as.vo.SSPASP10DSSDVO;
import hanalife.s.sp.as.vo.SSPASP10DSSMVO;
import hanalife.s.sp.as.vo.SSPASP10I01InVO;
import hanalife.s.sp.as.vo.SSPASP10InVO;
import hanalife.s.sp.as.vo.SSPASP10OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP10Controller.java Class
 * 클래스설명	: 결재선지정 (SSPASP10) Controller
 * 작성일자	: 2023.04.26.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.26.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	결재선지정_결재선 조회	 		: /SSPASP10S01.do
 *          결재선지정_결재선 등록 & 삭제	: /SSPASP10I01.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP10Controller {

	@Resource(name = "SSPASP10Service")
	private SSPASP10Service SSPASP10;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP10Controller.class);

	/**
	 * <p> 메소드명 		: 결재선조회 /SSPASP10S01.do </p>
	 * <p> 작성일자 		: 2023.04.26. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 결재선 내역을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASP10S01.do")
	public String SSPASP10S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASP10 Controller SSPASP10S01 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASP10 Controller SSPASP10S01 추출 #####");

			// 화면의 입력값 Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ATRZ_MNGM_SRCH", request, response, model);

			// 결재선지정_결재선 조회 서비스 호출 입력값 대입
			SSPASP10DSSMVO dsSEARCHVO = new SSPASP10DSSMVO();

			// 결재선지정_결재선 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setUserNo       ((String) sourceMap.get("userNo"));        /** 사번 */
			dsSEARCHVO.setApplRealStsCd((String) sourceMap.get("applRealStsCd")); /** 신청현재진행상태코드 */

			LOGGER.info("kbs컨트롤러 입력-사번" + "dsSEARCHVO.getUserNo()                   : " + dsSEARCHVO.getUserNo());
			LOGGER.info("kbs컨트롤러 입력-신청현재진행상태코드" + "dsSEARCHVO.getApplRealStsCd() : " + dsSEARCHVO.getApplRealStsCd());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASP10InVO InVO = new SSPASP10InVO();

			// 결재선지정_결재선 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASP10DSSMVO(dsSEARCHVO);

			// 결재선지정_결재선 조회 업무 서비스 호출 수행
			SSPASP10OutVO resultListVo = SSPASP10.getSSPASP10S01(InVO);

			// 결재선지정_결재선 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_ATRZ_MNGM_SD", resultListVo.getListSSPASP10DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP10 Controller SSPASP10S01 Exception End #####");

		}
		LOGGER.info("##### SSPASP10 Controller SSPASP10S01 End #####");
		return XFrame5View.XFRAME5_VIEW;

	}

	/**
	 * <p> 메소드명 		: 결재선 저장(등록, 삭제) /SSPASP10I01.do </p>
	 * <p> 작성일자 		: 2023.04.28. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 결재선 등록,삭제를 한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASP10I01.do")
	public String SSPASP10I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASP10Controller SSPASP10i01 Start #####");

		int checkIndex = 0; // 2차, 3차결재자 check용

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			List<Map<String, Object>> sourceMapC = XFrame5DataSetUtil.getXFrameDataSetList("DS_ATRZ_MNGM_SD", request, response, model); // 수정 & 등록

			// ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			Map<String, Object> inMap = new HashMap<String, Object>();

			SSPASP10DSSDVO inSddoVo = null;

			// ■ 등록, 삭제 처리
			SSPASP10OutVO resultI01 = new SSPASP10OutVO();

			if (sourceMapC.size() > 0)
			{
				if ( true )
				{
					// ▣ 결재선 내역 삭제
					inMap = sourceMapC.get(0);

					// □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
					inSddoVo = new SSPASP10DSSDVO();

					inSddoVo.setLoanCnslNo	 (inMap.get("loanCnslNo").toString());       /* 대출상담번호 */
					inSddoVo.setApplRealStsCd(inMap.get("applRealStsCd").toString());    /* 신청현재진행상태코드 */
					inSddoVo.setLoanApplNo	 (inMap.get("loanApplNo").toString());       /* 대출신청번호 */
					inSddoVo.setIngUserId    (inMap.get("userNo").toString());           /* 진행담당자ID */
					inSddoVo.setIngUserNm    (inMap.get("userNm").toString());           /* 진행담당자성명 */
					inSddoVo.setRoleDivCd	 (inMap.get("roleDivCd").toString());        /* 직무구분코드 */
					inSddoVo.setFrstRegEmpNo (inMap.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
					inSddoVo.setLastProcEmpNo(inMap.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

					SSPASP10I01InVO InVO = new SSPASP10I01InVO();

					InVO = new SSPASP10I01InVO();
					InVO.setSSPASP10DSSDVO(inSddoVo);

					// 결재선 내역_삭제 서비스 호출
					resultI01 = SSPASP10.deleteSSPASP10(InVO);
					LOGGER.info("##### SSPASP10Controller >>>>> 결재선내역 삭제#####");

				}

				// ▣ 데이터 저장 - 심사자
				LOGGER.info("##### SSPASP10Controller 2차 심사자 #####");
				for (int idx = 0; idx < sourceMapC.size(); idx++)
				{
					// 결재선 내역_직무구분코드 - 심사자 등록여부 체크
					inMap = sourceMapC.get(idx);

					// ▣ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
					inSddoVo = new SSPASP10DSSDVO();

					inSddoVo.setLoanCnslNo	 (inMap.get("loanCnslNo").toString());       /* 대출상담번호 */
					inSddoVo.setApplRealStsCd(inMap.get("applRealStsCd").toString());    /* 신청현재진행상태코드 */
					inSddoVo.setLoanApplNo	 (inMap.get("loanApplNo").toString());       /* 대출신청번호 */
					inSddoVo.setIngUserId    (inMap.get("userNo").toString());           /* 진행담당자ID */
					inSddoVo.setIngUserNm    (inMap.get("userNm").toString());           /* 진행담당자성명 */
					inSddoVo.setRoleDivCd	 (inMap.get("roleDivCd").toString());        /* 직무구분코드 */
					inSddoVo.setFrstRegEmpNo (inMap.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
					inSddoVo.setLastProcEmpNo(inMap.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

//					LOGGER.info("getLoanCnslNo :'"    + inSddoVo.getLoanCnslNo() + "'"   );
//					LOGGER.info("getApplRealStsCd :'" + inSddoVo.getApplRealStsCd() + "'");
//					LOGGER.info("getLoanApplNo :'"    + inSddoVo.getLoanApplNo() + "'"   );
//					LOGGER.info("getIngUserId :'"     + inSddoVo.getIngUserId() + "'"    );
//					LOGGER.info("getIngUserNm :'"     + inSddoVo.getIngUserNm() + "'"    );
//					LOGGER.info("getRoleDivCd :'"     + inSddoVo.getRoleDivCd() + "'"    );
//					LOGGER.info("getFrstRegEmpNo :'"  + inSddoVo.getFrstRegEmpNo() + "'" );
//					LOGGER.info("getLastProcEmpNo :'" + inSddoVo.getLastProcEmpNo() + "'");

					// ▣ 결재선 내역 저장 서비스 호출 입력값 대입
					SSPASP10I01InVO InVO = new SSPASP10I01InVO();
					InVO.setSSPASP10DSSDVO(inSddoVo);

					// ▣ 직무구분코드의 데이터가 존재하는 row만 저장
					if( !"".equals(inSddoVo.getRoleDivCd()) && inSddoVo.getRoleDivCd() != null ) {

						// ▣ 직무구분의 값이 "심사자(00010)"일 경우, 신청현재진행상태코드를 2차로 세팅
						if( "00010".equals(inSddoVo.getRoleDivCd())) {
							LOGGER.info("##### SSPASP10Controller 등록 >> 심사자 존재 #####");
							checkIndex++;

							if (checkIndex == 1)
							{
								// 2차심사진행상태 저장
								inSddoVo.setApplRealStsCd("50000");
							}

							// 저장 서비스 호출
							resultI01 = SSPASP10.saveSSPASP10(InVO);

							// 심사자-2차 결재선 등록 후 break
							break;
						}
					}
				}

				// ▣ 데이터 저장 - 전결권자
				for (int idx = 0; idx < sourceMapC.size(); idx++)
				{
					// 결재선 내역_직무구분코드 - 전결권자 등록여부 체크
					inMap = sourceMapC.get(idx);

					// ▣ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
					inSddoVo = new SSPASP10DSSDVO();

					inSddoVo.setLoanCnslNo	 (inMap.get("loanCnslNo").toString());       /* 대출상담번호 */
					inSddoVo.setApplRealStsCd(inMap.get("applRealStsCd").toString());    /* 신청현재진행상태코드 */
					inSddoVo.setLoanApplNo	 (inMap.get("loanApplNo").toString());       /* 대출신청번호 */
					inSddoVo.setIngUserId    (inMap.get("userNo").toString());           /* 진행담당자ID */
					inSddoVo.setIngUserNm    (inMap.get("userNm").toString());           /* 진행담당자성명 */
					inSddoVo.setRoleDivCd	 (inMap.get("roleDivCd").toString());        /* 직무구분코드 */
					inSddoVo.setFrstRegEmpNo (inMap.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
					inSddoVo.setLastProcEmpNo(inMap.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

//					LOGGER.info("getLoanCnslNo :'"    + inSddoVo.getLoanCnslNo() + "'"   );
//					LOGGER.info("getApplRealStsCd :'" + inSddoVo.getApplRealStsCd() + "'");
//					LOGGER.info("getLoanApplNo :'"    + inSddoVo.getLoanApplNo() + "'"   );
//					LOGGER.info("getIngUserId :'"     + inSddoVo.getIngUserId() + "'"    );
//					LOGGER.info("getIngUserNm :'"     + inSddoVo.getIngUserNm() + "'"    );
//					LOGGER.info("getRoleDivCd :'"     + inSddoVo.getRoleDivCd() + "'"    );
//					LOGGER.info("getFrstRegEmpNo :'"  + inSddoVo.getFrstRegEmpNo() + "'" );
//					LOGGER.info("getLastProcEmpNo :'" + inSddoVo.getLastProcEmpNo() + "'");

					// ▣ 갤재선 내역 저장 서비스 호출 입력값 대입
					SSPASP10I01InVO InVO = new SSPASP10I01InVO();
					InVO.setSSPASP10DSSDVO(inSddoVo);

					// ▣ 직무구분코드의 데이터가 존재하는 row만 저장
					if( !"".equals(inSddoVo.getRoleDivCd()) && inSddoVo.getRoleDivCd() != null ) {
						if( "00020".equals(inSddoVo.getRoleDivCd())) {
							// 직무구분코드 = 전결권자(00020)
							checkIndex++;

							if (checkIndex == 1)
							{
								// 2차심사진행 상태 저장
								inSddoVo.setApplRealStsCd("50000");
							}
							else if (checkIndex == 2)
							{
								// 3차심사진행 상태 저장
								inSddoVo.setApplRealStsCd("60000");
							}

							// 저장 서비스 호출
							resultI01 = SSPASP10.saveSSPASP10(InVO);
						}
					}
					else {
						LOGGER.info("##### SSPASP10Controller 직무구분값 미존재");
					}
				}
			}
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02Controller SSPASM02I01 Exception End #####");
		}
		LOGGER.info("##### SSPASP10 Controller SSPASP10i01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}
}
