package hanalife.s.sp.as.web;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.cm.sp.vo.sendSmsVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP11Service;
import hanalife.s.sp.as.vo.SSPASP11DSSD01VO;
import hanalife.s.sp.as.vo.SSPASP11DSSMVO;
import hanalife.s.sp.as.vo.SSPASP11InVO;
import hanalife.s.sp.as.vo.SSPASP11OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP11Controller.java Class
 * 클래스설명	: 서류보완요청 (SSPASP11) Controller
 * 작성일자	: 2023.05.09.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.05.04.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 서류보완요청내역 등록, /SSPASP11I01.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP11Controller {

	@Resource(name = "SSPASP11Service")
	private SSPASP11Service SSPASP11;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP11Controller.class);

    /**
     * <p> 메소드명 : 서류보완요청내역 등록 /SSPASP11I01.do </p>
     * <p> 작성일자 : 2023.05.04. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 서류보완요청내역을 등록한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    @RequestMapping("/SSPASP11I01.do")
    public String SSPASP11I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SSPASP11 Controller SSPASP11I01 Start #####");

        try
        {
            List<Map<String, Object>> sourceMapC = XFrame5DataSetUtil.getXFrameDataSetList("DS_DOC_SPMT_SD_C", request, response, model);

            // ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            Map<String, Object> inMap = new HashMap<String, Object>();
            // ■ 등록 전 데이터 중복여부 조회를 위한 INVO
            SSPASP11InVO srchVO = new SSPASP11InVO();
            // ■ 등록 처리
            SSPASP11OutVO resultI01 = new SSPASP11OutVO();
            if (sourceMapC.size() > 0)
            {
                for (int idx = 0; idx < sourceMapC.size(); idx++)
                {
                    // ▣ 서류보완내역 등록
                    inMap = sourceMapC.get(idx);
                    // ▣ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
                    SSPASP11DSSMVO inSddoVo = new SSPASP11DSSMVO();

                    inSddoVo.setLoanCnslNo   (inMap.get("loanCnslNo").toString());       /* 대출상담번호 */
                    inSddoVo.setLoanDocCd    (inMap.get("loanDocCd").toString());        /* 대출서류코드 */
                    inSddoVo.setFrstRegEmpNo (inMap.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
                    inSddoVo.setLastProcEmpNo(inMap.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

                    LOGGER.info("getLoanCnslNo    :'" + inSddoVo.getLoanCnslNo()    + "'");
                    LOGGER.info("getLoanDocCd     :'" + inSddoVo.getLoanDocCd()     + "'");
                    LOGGER.info("getFrstRegEmpNo  :'" + inSddoVo.getFrstRegEmpNo()  + "'");
                    LOGGER.info("getLastProcEmpNo :'" + inSddoVo.getLastProcEmpNo() + "'");

                    // ▣ 서류보완요청내역 등록 서비스 호출 입력값 대입
                    SSPASP11InVO InVo = new SSPASP11InVO();
                    InVo.setSSPASP11DSSMVO(inSddoVo);

                    // ▣ 서류보완요청내역 등록 서비스 호출
                    resultI01 = SSPASP11.insertSSPASP11(InVo);
                }
            }
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // ■ 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP11 Controller SSPASP11I01 Exception End #####");
        }
        LOGGER.info("##### SSPASP11 Controller SSPASP11I01 End #####");

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p> 메소드명 : 관련인정보조회(sms발송) /SSPASP11S01.do </p>
     * <p> 작성일자 : 2023.05.10. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 관련인정보를 조회한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    @RequestMapping("/SSPASP11S01.do")
    public String SSPASP11S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
        LOGGER.info("##### SSPASP11 Controller SSPASP11S01 Start #####");

        try
        {
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            LOGGER.info("##### SSPASP11 Controller SSPASP11S01 추출 #####");

            // 화면의 입력값 Dataset setting
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_DOC_SPMT_SM", request, response, model);

            // 관련인정보조회 서비스 호출 입력값 대입
            SSPASP11DSSMVO dsSEARCHVO = new SSPASP11DSSMVO();

            // 관련인정보조회 업무 서비스 호출 입력값 대입
            dsSEARCHVO.setLoanCnslNo((String)sourceMap.get("loanCnslNo"));    /** 대출상담번호 */
            LOGGER.info("SSPASP11S01 Controller :: dsSEARCHVO.getLoanCnslNo() : " + dsSEARCHVO.getLoanCnslNo());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP11InVO InVO = new SSPASP11InVO();

            // 관련인정보조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSSPASP11DSSMVO(dsSEARCHVO);

            // 관련인정보조회 업무 서비스 호출 수행
            SSPASP11OutVO resultListVo = SSPASP11.getSSPASP11S01(InVO);

            // 관련인정보조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_DOC_INFO_SD", resultListVo.getListSSPASP11DSSDVO(), model);

        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP12 Controller SSPASP11S01 Exception End #####");

        }
        LOGGER.info("##### SSPASP12 Controller SSPASP11S01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }

    // 문자발송로직 서비스 제어
    /**
     * <p>메소드명 : SMS메세지 전송,등록 /SSPASP11I02.do </p>
     * <p>작성일자 : 2023.05.11.
     * <p>작성자(author) : 70305
     * <p>설명 : SMS 메세지를 전송,등록 한다.</p>
     * <p>예외처리 : Exception</p>
     */
    @RequestMapping("/SSPASP11I02.do")
    public String SSPASP11I02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP11 Controller SSPASP11I02 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMS_SEND_SM", request, response, model);

            LOGGER.info("##### SSPASP11 Controller SSPASP11I02 2222");
            SSPASP11DSSMVO smdo01 = new SSPASP11DSSMVO();
//            BeanUtil.mapToBean(sourceMap, smdo01);

            smdo01.setEmpNo       (sourceMap.get("empNo").toString());       // 로그인 사원번호
            smdo01.setSendTelNo   (sourceMap.get("sendTelNo").toString());   // 발신번호
            smdo01.setRsrvTelNo   (sourceMap.get("rsrvTelNo").toString());   // 수신번호
            smdo01.setRsrvSndFlg  (sourceMap.get("rsrvSndFlg").toString());  // 예약전송여부
            smdo01.setRsrvSndTime (sourceMap.get("rsrvSndTime").toString()); // 예약전송시간
            smdo01.setSendFlg     (sourceMap.get("sendFlg").toString());     // 내메세지저장여부

            LOGGER.info("Controller SSPASP11I02_getEmpNo       :'" + smdo01.getEmpNo      () + "'");
            LOGGER.info("Controller SSPASP11I02_getSendTelNo   :'" + smdo01.getSendTelNo  () + "'");
            LOGGER.info("Controller SSPASP11I02_getRsrvTelNo   :'" + smdo01.getRsrvTelNo  () + "'");
            LOGGER.info("Controller SSPASP11I02_getRsrvSndFlg  :'" + smdo01.getRsrvSndFlg () + "'");
            LOGGER.info("Controller SSPASP11I02_getRsrvSndTime :'" + smdo01.getRsrvSndTime() + "'");
            LOGGER.info("Controller SSPASP11I02_getSendFlg     :'" + smdo01.getSendFlg    () + "'");

            Map<String, Object> sourceMap1 = XFrame5DataSetUtil.getXFrameDataSet("DS_SMS_SEND_SD_01", request, response, model);
            SSPASP11DSSD01VO sddo01 = new SSPASP11DSSD01VO();
//            BeanUtil.mapToBean(sourceMap, sddo01);

            sddo01.setDlvrDt     (sourceMap1.get("dlvrDt").toString());      // 발송일자
            sddo01.setMngDeptCd  (sourceMap1.get("mngDeptCd").toString());   // 관리부서코드
            sddo01.setDlvrEmpNo  (sourceMap1.get("dlvrEmpNo").toString());   // 발송사원번호
            sddo01.setLoanNo     (sourceMap1.get("loanNo").toString());      // 대출번호
            sddo01.setLoanSeq    (sourceMap1.get("loanSeq").toString());     // 대출순번
            sddo01.setSeq        (sourceMap1.get("seq").toString());         // 순번
            sddo01.setCustNo     (sourceMap1.get("custNo").toString());      // 고객번호
            sddo01.setCustNm     (sourceMap1.get("custNm").toString());      // 고객명
            sddo01.setSendDiv    (sourceMap1.get("sendDiv").toString());     // 전송구분
            sddo01.setSendDttm   (sourceMap1.get("sendDttm").toString());    // 전송일시
            sddo01.setRecvTelNo  (sourceMap1.get("recvTelNo").toString());   // 수신전화번호
            sddo01.setRspnTelNo  (sourceMap1.get("rspnTelNo").toString());   // 응답전화번호
            sddo01.setSendTxt    (sourceMap1.get("sendTxt").toString());     // 전송문자
            sddo01.setVfvParam01 (sourceMap1.get("vfvParam01").toString());  // IN 파라미터01
            sddo01.setVfvParam02 (sourceMap1.get("vfvParam02").toString());  // IN 파라미터02
            sddo01.setVfvParam03 (sourceMap1.get("vfvParam03").toString());  // IN 파라미터03
            sddo01.setVfvParam04 (sourceMap1.get("vfvParam04").toString());  // IN 파라미터04
            sddo01.setVfvParam05 (sourceMap1.get("vfvParam05").toString());  // IN 파라미터05
            sddo01.setVfvParam06 (sourceMap1.get("vfvParam06").toString());  // IN 파라미터06
            sddo01.setVfvParam07 (sourceMap1.get("vfvParam07").toString());  // IN 파라미터07
            sddo01.setVfvParam08 (sourceMap1.get("vfvParam08").toString());  // IN 파라미터08
            sddo01.setVfvParam09 (sourceMap1.get("vfvParam09").toString());  // IN 파라미터09
            sddo01.setVfvParam10 (sourceMap1.get("vfvParam10").toString());  // IN 파라미터10
            sddo01.setVfvParam11 (sourceMap1.get("vfvParam11").toString());  // IN 파라미터11
            sddo01.setVfvParam12 (sourceMap1.get("vfvParam12").toString());  // IN 파라미터12
            sddo01.setVfvParam13 (sourceMap1.get("vfvParam13").toString());  // IN 파라미터13
            sddo01.setVfvParam14 (sourceMap1.get("vfvParam14").toString());  // IN 파라미터14
            sddo01.setVfvParam15 (sourceMap1.get("vfvParam15").toString());  // IN 파라미터15

            LOGGER.info("Controller SSPASP11I02_getDlvrDt     :'" + sddo01.getDlvrDt    () + "'");
            LOGGER.info("Controller SSPASP11I02_getMngDeptCd  :'" + sddo01.getMngDeptCd () + "'");
            LOGGER.info("Controller SSPASP11I02_getDlvrEmpNo  :'" + sddo01.getDlvrEmpNo () + "'");
            LOGGER.info("Controller SSPASP11I02_getLoanNo     :'" + sddo01.getLoanNo    () + "'");
            LOGGER.info("Controller SSPASP11I02_getLoanSeq    :'" + sddo01.getLoanSeq   () + "'");
            LOGGER.info("Controller SSPASP11I02_getSeq        :'" + sddo01.getSeq       () + "'");
            LOGGER.info("Controller SSPASP11I02_getCustNo     :'" + sddo01.getCustNo    () + "'");
            LOGGER.info("Controller SSPASP11I02_getCustNm     :'" + sddo01.getCustNm    () + "'");
            LOGGER.info("Controller SSPASP11I02_getSendDiv    :'" + sddo01.getSendDiv   () + "'");
            LOGGER.info("Controller SSPASP11I02_getSendDttm   :'" + sddo01.getSendDttm  () + "'");
            LOGGER.info("Controller SSPASP11I02_getRecvTelNo  :'" + sddo01.getRecvTelNo () + "'");
            LOGGER.info("Controller SSPASP11I02_getRspnTelNo  :'" + sddo01.getRspnTelNo () + "'");
            LOGGER.info("Controller SSPASP11I02_getSendTxt    :'" + sddo01.getSendTxt   () + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam01 :'" + sddo01.getVfvParam01() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam02 :'" + sddo01.getVfvParam02() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam03 :'" + sddo01.getVfvParam03() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam04 :'" + sddo01.getVfvParam04() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam05 :'" + sddo01.getVfvParam05() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam06 :'" + sddo01.getVfvParam06() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam07 :'" + sddo01.getVfvParam07() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam08 :'" + sddo01.getVfvParam08() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam09 :'" + sddo01.getVfvParam09() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam10 :'" + sddo01.getVfvParam10() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam11 :'" + sddo01.getVfvParam11() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam12 :'" + sddo01.getVfvParam12() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam13 :'" + sddo01.getVfvParam13() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam14 :'" + sddo01.getVfvParam14() + "'");
            LOGGER.info("Controller SSPASP11I02_getVfvParam15 :'" + sddo01.getVfvParam15() + "'");

//            LOGGER.info("##### SSPASP11 Controller SSPASP11I02 4444");
//            sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMS_SEND_SD_02", request, response, model);
//            LOGGER.info("##### SSPASP11 Controller SSPASP11I02 4444-1");
//            SSPASP11DSSD02VO sddo02 = new SSPASP11DSSD02VO();
//            LOGGER.info("##### SSPASP11 Controller SSPASP11I02 4444-2");
//            BeanUtil.mapToBean(sourceMap, sddo02);

            /** SMS 메세지내역조회 업무 서비스 호출 입력값 대입 */
            SSPASP11InVO inVo = new SSPASP11InVO();

            inVo.setSSPASP11DSSMVO  (smdo01);
            inVo.setSSPASP11DSSD01VO(sddo01);
//            inVo.setSSPASP11DSSD02VO(sddo02);

            /** SMS 메세지내역조회 업무 서비스 호출 수행 */
            SSPASP11OutVO resultSSPASP11I01 = SSPASP11.registSSPASP11(inVo);
            sendSmsVO sendSmsVO   = resultSSPASP11I01.getSendSmsVO();

            // 정상&오류 구분용
//            if(!"0000".equals(sendSmsVO.getVfvRtnCtt())) {
//                throw new Exception();
//            }
            LOGGER.info("##### SSPASP11 Controller SSPASP11I02 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, "SMS 전송이 실패했습니다.");

            LOGGER.info("##### ##### SSPASP11 Controller SSPASP11I02 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
