package hanalife.s.sp.gd.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.gd.service.SSPGDM03Service;
import hanalife.s.sp.gd.vo.SSPGDM03InVO;
import hanalife.s.sp.gd.vo.SSPGDM03OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPGDM03Controller.java Class
 * 클래스설명   : 금리관리 (SSPGDM03) Controller
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("s/sp/gd")
@Controller
public class SSPGDM03Controller {

    @Resource(name = "SSPGDM03Service")
    private SSPGDM03Service SSPGDM03;

    private static final Logger LOGGER = LoggerFactory.getLogger(SSPGDM03Controller.class);

    /**
     * <p>메소드명      : 상품분류관리 기본 조회 /selectMainInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류를 기본 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/selectMainInfo.do")
    public String SSPGDM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPGDM03Controller SSPGDM03S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SSPGDM03_CO", request, response, model);

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            SSPGDM03InVO InVO = new SSPGDM03InVO();
            InVO.setIntRtDivCd((String) sourceMap.get("intRtDivCd") );   /** 금리종류코드 */
            InVO.setAplyStrtMm((String) sourceMap.get("aplyStrtMm") );   /** 적용시작월 */
            InVO.setAplyEndMm((String) sourceMap.get("aplyEndMm") );   	 /** 적용종료월 */

            /** SSPGDM03S01 내역조회 업무 서비스 호출 수행 */
            SSPGDM03OutVO resultList = SSPGDM03.getSelectMainInfo(InVO);

            XFrame5Util.setOutputData("DS_SSPGDM03_SD", resultList.getSSPGDM03DSDDSSVO(), model);

            LOGGER.info("##### SSPGDM03Controller SSPGDM03S01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.toString());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.toString());

            LOGGER.info("##### SSPGDM03Controller SSPGDM03S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }



    /**
     * <p>메소드명      : 상품분류관리_저장(등록, 수정, 삭제) /registerConsProc.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리_저장(등록, 수정, 삭제) 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("unused")
    @RequestMapping("/registerMainInfo.do")
    public String SSPGDM03I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPGDM03Controller SSPGDM03I01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
        	Map<String, Object> sourceMapCO = XFrame5DataSetUtil.getXFrameDataSet("DS_SSPGDM03_CO", request, response, model);
        	Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SSPGDM03_SM", request, response, model);


            /** SSPGDM03S01 내역조회 업무 서비스 호출 입력값 대입 */

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            SSPGDM03InVO InVO = new SSPGDM03InVO();

            InVO.setIntRtDivCd((String) sourceMapCO.get("intRtDivCd"));
            InVO.setUserNo((String) sourceMapCO.get("logInEmpNo"));
            InVO.setAplyStrtDt((String) sourceMapSM.get("aplyStrtDt"));
            InVO.setAplyEndDt((String) sourceMapSM.get("aplyEndDt"));
            InVO.setBaseInt((String) sourceMapSM.get("baseInt"));
            InVO.setIntCalcFg((String) sourceMapSM.get("intCalcFg"));

            /** 등록 업무 서비스 호출 수행 */
            SSPGDM03OutVO resultI01 = SSPGDM03.insertMainInfo(InVO);
            // 등록 후 조회
            SSPGDM03OutVO resultIOut = SSPGDM03.getSelectMainInfo(InVO);

            XFrame5Util.setOutputData("DS_SSPGDM03_SD", resultIOut.getSSPGDM03DSDDSSVO(), model);

            LOGGER.info("##### SSPGDM03Controller SSPGDM03I01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### SSPGDM03Controller SSPGDM03I01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 상품분류관리_저장(등록, 수정, 삭제) /registerConsProc.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리_저장(등록, 수정, 삭제) 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("unused")
    @RequestMapping("/deleteMainInfo.do")
    public String SSPGDM03D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPGDM03Controller SSPGDM03D01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
        	Map<String, Object> sourceMapCO = XFrame5DataSetUtil.getXFrameDataSet("DS_SSPGDM03_CO", request, response, model);
            List<Map<String, Object>> sourceMapSDList = XFrame5DataSetUtil.getXFrameDataSetList("DS_SSPGDM03_SD_SEND", request, response, model);

            for(int i=0; i<sourceMapSDList.size(); i++) {
            	SSPGDM03InVO InVO = new SSPGDM03InVO();

            	Map<String, Object> sourceMapSD  = sourceMapSDList.get(i);

            	InVO.setIntRtDivCd((String) sourceMapSD.get("intRtDivCd"));
            	InVO.setAplyStrtDt((String) sourceMapSD.get("aplyStrtDt"));
            	InVO.setUserNo((String) sourceMapCO.get("logInEmpNo"));

            	/** 삭제 업무 서비스 호출 수행 */
				SSPGDM03OutVO resultI01 = SSPGDM03.deleteMainInfo(InVO);
            }

            // 재조회용 VO
            SSPGDM03InVO InVO = new SSPGDM03InVO();
            InVO.setIntRtDivCd((String) sourceMapCO.get("intRtDivCd"));
            // 등록 후 조회
            SSPGDM03OutVO resultIOut = SSPGDM03.getSelectMainInfo(InVO);
            XFrame5Util.setOutputData("DS_SSPGDM03_SD", resultIOut.getSSPGDM03DSDDSSVO(), model);


            LOGGER.info("##### SSPGDM03Controller SSPGDM03D01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPGDM03Controller SSPGDM03D01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}