package hanalife.s.xm.pv.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.xm.pv.mapper.ExamMngMapper;
import hanalife.s.xm.pv.mapper.dto.ExamMngDSSDDO01DTO;
import hanalife.s.xm.pv.mapper.dto.ExamMngDSSMDODTO;
import hanalife.s.xm.pv.service.SXMPVM01Service;
import hanalife.s.xm.pv.vo.SXMPVM01DSSDDO01VO;
import hanalife.s.xm.pv.vo.SXMPVM01I01InVO;
import hanalife.s.xm.pv.vo.SXMPVM01S01InVO;
import hanalife.s.xm.pv.vo.SXMPVM01S01OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SXMPVM01ServiceImpl.java Class
 * 클래스설명	: 심사리스트 (SXMPVM01) Service Implements
 * 작성일자	: 2023.05.03.
 * 작성자명	: 70398 / LJW / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023. 05. 03.][70398][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :getSXMPVM01S01	: 심사리스트내역 조회
 * 			getCSCPGM01S02	: 상수리스트관리내역 전 조회
 * 			saveCSCPGM05I01 : 상수리스트관리내역 등록
 * 			updCSCPGM01U01	: 상수리스트관리내역 수정
 * 			delCSCPGM01D01	: 상수리스트관리내역 삭제
 * </pre>
 */

@Service("SXMPVM01Service")
public class SXMPVM01ServiceImpl implements SXMPVM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SXMPVM01ServiceImpl.class);

	@Autowired
	private ExamMngMapper examMngMapper;

	/**
	 * <p>메소드명			: getSXMPVM01S01 : 심사리스트내역_조회</p>
	 * <p>작성일자			: 2023.05.03.</p>
	 * <p>작성자(author)	: 70398 / LJW</p>
	 * <p>설명			: 심사리스트내역을 조회한다.</p>
	 * <p>메소드인수		: SXMPVM01S01InVO</p>
	 * <p>메소드리턴값		: SXMPVM01S01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public SXMPVM01S01OutVO getSXMPVM01S01(SXMPVM01S01InVO inVo) throws Exception {

		LOGGER.debug("SXMPVM01ServiceImpl getSXMPVM01S01 Start");

	    // 심사리스트 내역 서비스 결과값 객체 생성
		SXMPVM01S01OutVO resultVo = new SXMPVM01S01OutVO();

	    // 심사리스트 내역조회 조건 입력값 객체 생성 및 대입 수행
		ExamMngDSSMDODTO i01Dto = new ExamMngDSSMDODTO();

	    i01Dto.setApplDtFr(inVo.getSXMPVM01DSSMDOVO().getApplDtFr()); 	/* 신청일자from */
	    i01Dto.setApplDtTo(inVo.getSXMPVM01DSSMDOVO().getApplDtTo()); 	/* 신청일자to */
        LOGGER.info("##### 입력값::신청일자fr = " + i01Dto.getApplDtFr() );
        LOGGER.info("##### 입력값::신청일자to = " + i01Dto.getApplDtTo() );
        i01Dto.setAprvDtFr(inVo.getSXMPVM01DSSMDOVO().getAprvDtFr()); 	/* 승인일자from */
        i01Dto.setAprvDtTo(inVo.getSXMPVM01DSSMDOVO().getAprvDtTo()); 	/* 승인일자to */
        i01Dto.setStsCd(inVo.getSXMPVM01DSSMDOVO().getStsCd()); 	/* 상태코드 */
        i01Dto.setProdCd(inVo.getSXMPVM01DSSMDOVO().getProdCd()); 	/* 상품코드 */
        i01Dto.setExamMan(inVo.getSXMPVM01DSSMDOVO().getExamMan()); 	/* 심사인 */
        i01Dto.setApplNo(inVo.getSXMPVM01DSSMDOVO().getApplNo()); 	/* 대출신청번호 */
        i01Dto.setUserNo(inVo.getSXMPVM01DSSMDOVO().getUserNo()); 	/* 사용자번호 */

        // 심사리스트 내역조회 쿼리 Mapper 호출 수행
        List<ExamMngDSSDDO01DTO> resultDTO = examMngMapper.searchExamMngList(i01Dto);

        // 심사리스트 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SXMPVM01DSSDDO01VO> resultList = new ArrayList<SXMPVM01DSSDDO01VO>();
        for (ExamMngDSSDDO01DTO sourceIO : resultDTO) {

        	// 심사리스트 내역조회 VO에 조회된 Mapper DTO 값을 대입
        	SXMPVM01DSSDDO01VO targetIO = new SXMPVM01DSSDDO01VO();

        	targetIO.setApplDt                (sourceIO.getApplDt                ()); /** 신청접수일자     */
        	targetIO.setLastJudgStepDt      (sourceIO.getLastJudgStepDt      ()); /* 최종승인일자     */
        	targetIO.setCustNo                (sourceIO.getCustNo                ()); /* 고객번호        */
        	targetIO.setCustNm                (sourceIO.getCustNm                ()); /* 고객명         */
        	targetIO.setLoanCnslNo           (sourceIO.getLoanCnslNo           ()); /* 대출_상담_번호   */
        	targetIO.setLoanApplNo                (sourceIO.getLoanApplNo                ()); /* 대출신청번호     */
        	targetIO.setProdCd                (sourceIO.getProdCd                ()); /* 상품코드        */
        	targetIO.setProdNm                (sourceIO.getProdNm                ()); /* 상품명         */
        	targetIO.setLonApplAmt                (sourceIO.getLonApplAmt                ()); /* 대출신청금액     */
        	targetIO.setRateCd                (sourceIO.getRateCd                ()); /* 금리코드        */
        	targetIO.setApplRealStsCd                (sourceIO.getApplRealStsCd                ()); /* 신청현재진행상태코드 */
        	targetIO.setLastJudgGbCd                (sourceIO.getLastJudgGbCd                ()); /* 최종판정결과구분코드 */
        	targetIO.setExamMan                (sourceIO.getExamMan                ()); /* 심사자         */
        	targetIO.setSrNm                (sourceIO.getSrNm                ()); /* SR성명        */

        	targetIO.setApplRealStsNm                (sourceIO.getApplRealStsNm                ()); /* 신청현재진행상태_명        */
        	targetIO.setHomsStepNm                (sourceIO.getHomsStepNm                ()); /* HOMS진행상태_명        */
        	targetIO.setLastJudgStepNm                (sourceIO.getLastJudgStepNm                ()); /* 최종승인단계_명        */

        	targetIO.setRoleDivCd                (sourceIO.getRoleDivCd                ()); /* 심사자역할구분코드        */

            // 심사리스트 내역조회 List 객체에 추가
            resultList.add(targetIO);
		}

        // 심사리스트내역조회 화면 출력 결과값 대입
        resultVo.setListSXMPVM01DSSDDO01VO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명			: getSXMPVM01S02 : 대리결재자_조회</p>
	 * <p>작성일자			: 2023.05.11.</p>
	 * <p>작성자(author)	: 70398 / LJW</p>
	 * <p>설명			: 대리결재자을 조회한다.</p>
	 * <p>메소드인수		: SXMPVM01S01InVO</p>
	 * <p>메소드리턴값		: SXMPVM01S01OutVO</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public SXMPVM01S01OutVO getSXMPVM01S02(SXMPVM01S01InVO inVo) throws Exception {

		LOGGER.debug("SXMPVM01ServiceImpl getSXMPVM01S02 Start");

	    // 대리결재자 내역 서비스 결과값 객체 생성
		SXMPVM01S01OutVO resultVo = new SXMPVM01S01OutVO();

	    // 대리결재자 내역조회 조건 입력값 객체 생성 및 대입 수행
		ExamMngDSSMDODTO i01Dto = new ExamMngDSSMDODTO();

        i01Dto.setApplNo(inVo.getSXMPVM01DSSMDOVO().getApplNo()); 	/* 대출신청번호 */
        i01Dto.setUserNo(inVo.getSXMPVM01DSSMDOVO().getUserNo()); 	/* 사용자번호 */

        // 대리결재자 조회 쿼리 Mapper 호출 수행
        List<ExamMngDSSDDO01DTO> resultDTO = examMngMapper.searchArvdAgncList(i01Dto);

        // 대리결재자 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SXMPVM01DSSDDO01VO> resultList = new ArrayList<SXMPVM01DSSDDO01VO>();
        for (ExamMngDSSDDO01DTO sourceIO : resultDTO) {

        	// 대리결재자 조회 VO에 조회된 Mapper DTO 값을 대입
        	SXMPVM01DSSDDO01VO targetIO = new SXMPVM01DSSDDO01VO();

        	targetIO.setLastProcEmpNo      (sourceIO.getLastProcEmpNo      ()); /* 최종_처리_사원번호      */

            // 대리결재자 조회 List 객체에 추가
            resultList.add(targetIO);
		}

        // 대리결재자 조회 화면 출력 결과값 대입
        resultVo.setListSXMPVM01DSSDDO01VO(resultList);


        return resultVo;
	}

    /**
     * <p>메소드명 : updSSPASP12U01 : 여신신청원장 진행상태 수정</p>
     * <p>작성일자 : 2023.05.10.
     * <p>작성자(author) : 70398 / LJW
     * <p>설명 : 여신신청원장 진행상태 수정한다.</p>
     * <p>메소드인수 : SXMPVM01S01InVo </p>
     * <p>메소드리턴값 : SXMPVM01OutVo</p>
     * <p>예외처리 : Exception</p>
     */
    @Override
    public SXMPVM01S01OutVO updSXMPVM01U01(SXMPVM01I01InVO inVo) throws Exception {

        LOGGER.info("##### SXMPVM01 ServiceImpl updSXMPVM01U01 Start #####");

        SXMPVM01S01OutVO resultVo = new SXMPVM01S01OutVO();

        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // 파라메터값 체크
        String strLoanApplNo = inVo.getSXMPVM01DSSDDO01VO().getLoanApplNo().toString();      // 대출신청번호
        String StrLastProcEmpNo = inVo.getSXMPVM01DSSDDO01VO().getLastProcEmpNo().toString();      // 최종_처리_사원번호
        String StrApplRealStsCd = inVo.getSXMPVM01DSSDDO01VO().getApplRealStsCd().toString();      // 진행상태

        LOGGER.info("getSXMPVM01DSSDDO01VO serviceImpl : strLoanApplNo : " + inVo.getSXMPVM01DSSDDO01VO().getLoanApplNo().toString());

        // key값 체크(대출신청번호)
        if( StringUtils.isEmpty(strLoanApplNo) ) {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

            return resultVo;
        }


        try {
            // 진행상태 수정
        	ExamMngDSSDDO01DTO inDto = new ExamMngDSSDDO01DTO();

            inDto.setLoanApplNo(strLoanApplNo);
            inDto.setLastProcEmpNo(StrLastProcEmpNo);
            inDto.setApplRealStsCd(StrApplRealStsCd);

            // 진행상태수정 서비스 호출
            examMngMapper.updatePrgsStat(inDto);

        }  catch (Exception e) {

            LOGGER.error("[여신신청원장 진행상태 수정 오류] : " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

    /**
     * <p>메소드명 : updSSPASP12U02 : 신청진행상태관리 진행상태 수정</p>
     * <p>작성일자 : 2023.05.10.
     * <p>작성자(author) : 70398 / LJW
     * <p>설명 : 신청진행상태관리 진행상태 수정한다.</p>
     * <p>메소드인수 : SXMPVM01S01InVo </p>
     * <p>메소드리턴값 : SXMPVM01OutVo</p>
     * <p>예외처리 : Exception</p>
     */
    @Override
    public SXMPVM01S01OutVO updSXMPVM01U02(SXMPVM01I01InVO inVo) throws Exception {

    	LOGGER.info("##### SXMPVM01 ServiceImpl updSXMPVM01U02 Start #####");

    	SXMPVM01S01OutVO resultVo = new SXMPVM01S01OutVO();

    	resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
    	resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

    	// 파라메터값 체크
    	String strLoanApplNo = inVo.getSXMPVM01DSSDDO01VO().getLoanApplNo().toString();      // 대출신청번호
    	String StrLastProcEmpNo = inVo.getSXMPVM01DSSDDO01VO().getLastProcEmpNo().toString();      // 최종_처리_사원번호
    	String StrApplRealStsCd = inVo.getSXMPVM01DSSDDO01VO().getApplRealStsCd().toString();      // 진행상태

    	LOGGER.info("getSXMPVM01DSSDDO01VO serviceImpl : strLoanApplNo : " + inVo.getSXMPVM01DSSDDO01VO().getLoanApplNo().toString());

    	// key값 체크(대출신청번호)
    	if( StringUtils.isEmpty(strLoanApplNo) ) {
    		resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
    		resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

    		return resultVo;
    	}


    	try {
    		// 신청진행상태관리 진행상태 수정
    		ExamMngDSSDDO01DTO inDto = new ExamMngDSSDDO01DTO();

    		inDto.setLoanApplNo(strLoanApplNo);
    		inDto.setLastProcEmpNo(StrLastProcEmpNo);
    		inDto.setApplRealStsCd(StrApplRealStsCd);

    		// 신청진행상태관리 진행상태수정 서비스 호출
    		examMngMapper.updateApplPrgsStat(inDto);

    	}  catch (Exception e) {

    		LOGGER.error("[신청진행상태관리 진행상태 수정 오류] : " + e.getMessage());
    		resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
    		resultVo.setRsltCntn( e.getMessage() );

    		return resultVo;
    	}

    	return resultVo;
    }

}