package hanalife.s.xm.pv.web;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP10Service;
import hanalife.s.sp.as.vo.SSPASP10DSSDVO;
import hanalife.s.sp.as.vo.SSPASP10I01InVO;
import hanalife.s.sp.as.vo.SSPASP10OutVO;
import hanalife.s.xm.pv.service.SXMPVM01Service;
import hanalife.s.xm.pv.vo.SXMPVM01DSSDDO01VO;
import hanalife.s.xm.pv.vo.SXMPVM01DSSMDOVO;
import hanalife.s.xm.pv.vo.SXMPVM01I01InVO;
import hanalife.s.xm.pv.vo.SXMPVM01S01InVO;
import hanalife.s.xm.pv.vo.SXMPVM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SXMPVM01Controller.java Class
 * 클래스설명	: 심사목록조회 (SXMPVM01) Controller
 * 작성일자	: 2023.05.02.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.05.02.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 1차 심사사 등록 : /SXMPVM01I01.do
 *
 * </pre>
 */

@RequestMapping("/s/xm/pv")
@Controller
public class SXMPVM01Controller {

	@Resource(name = "SSPASP10Service")
	private SSPASP10Service SSPASP10;

	@Resource(name = "SXMPVM01Service")
	private SXMPVM01Service SXMPVM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(SXMPVM01Controller.class);

	/**
	 * <p>메소드명			: 심사목록 조회 /SXMPVM01S01.do </p>
	 * <p>작성일자			: 2023. 5. 3.
	 * <p>작성자(author)	: 70398
	 * <p>설명			: 심사목록 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
	@RequestMapping("/SXMPVM01S01.do")
	public String SXMPVM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 Start #####");

		try {

			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			// 심사목록내역 조회 업무 서비스 호출 입력값 대입
			SXMPVM01DSSMDOVO dsSMDOInVo = new SXMPVM01DSSMDOVO();

			dsSMDOInVo.setApplDtFr((String) sourceMap.get("applDtFr")); 	/* 신청일자from */
			dsSMDOInVo.setApplDtTo((String) sourceMap.get("applDtTo")); 	/* 신청일자to */
			LOGGER.info("##### getApplDtFr = " + dsSMDOInVo.getApplDtFr() );
			LOGGER.info("##### getApplDtTo = " + dsSMDOInVo.getApplDtTo() );
			dsSMDOInVo.setAprvDtFr((String) sourceMap.get("aprvDtFr")); 	/* 승인일자from */
			dsSMDOInVo.setAprvDtTo((String) sourceMap.get("aprvDtTo")); 	/* 승인일자to */
			dsSMDOInVo.setStsCd((String) sourceMap.get("stsCd")); 	/* 상태코드 */
			dsSMDOInVo.setProdCd((String) sourceMap.get("prodCd")); 	/* 상품코드 */
			dsSMDOInVo.setExamMan((String) sourceMap.get("examMan")); 	/* 심사인 */
			dsSMDOInVo.setApplNo((String) sourceMap.get("applNo")); 	/* 대출신청번호 */
			dsSMDOInVo.setUserNo((String) sourceMap.get("userNo")); 	/* 사용자번호 */

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SXMPVM01S01InVO InVO = new SXMPVM01S01InVO();

			// 심사목록 내역조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSXMPVM01DSSMDOVO(dsSMDOInVo);

			// 심사목록내역 조회 업무 서비스 호출 수행
			SXMPVM01S01OutVO resultListVo = SXMPVM01.getSXMPVM01S01(InVO);

			// 심사목록내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_SDDO", resultListVo.getListSXMPVM01DSSDDO01VO(), model);

			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01  Normal End #####");

		}catch (Exception e) {

			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 Exception End #####");

		}

		LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명			: 대리결재자 조회 /SXMPVM01S02.do </p>
	 * <p>작성일자			: 2023. 5. 11.
	 * <p>작성자(author)	: 70398
	 * <p>설명			: 대리결재자을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
	@RequestMapping("/SXMPVM01S02.do")
	public String SXMPVM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SXMPVM01 Controller SXMPVM01S02 Start #####");

		try {

			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S02 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			// 심사목록내역 조회 업무 서비스 호출 입력값 대입
			SXMPVM01DSSMDOVO dsSMDOInVo = new SXMPVM01DSSMDOVO();

			dsSMDOInVo.setApplNo((String) sourceMap.get("applNo")); 	/* 대출신청번호 */
			dsSMDOInVo.setUserNo((String) sourceMap.get("userNo")); 	/* 사용자번호 */

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SXMPVM01S01InVO InVO = new SXMPVM01S01InVO();

			// 심사목록 내역조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSXMPVM01DSSMDOVO(dsSMDOInVo);

			// 심사목록내역 조회 업무 서비스 호출 수행
			SXMPVM01S01OutVO resultListVo = SXMPVM01.getSXMPVM01S02(InVO);

			// 심사목록내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_SDDO", resultListVo.getListSXMPVM01DSSDDO01VO(), model);

			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S02  Normal End #####");

		}catch (Exception e) {

			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 Exception End #####");

		}

		LOGGER.info("##### SXMPVM01 Controller SXMPVM01S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p> 메소드명 		: 결재선 저장(등록, 삭제) /SSPASP10I01.do </p>
	 * <p> 작성일자 		: 2023.05.10. </p>
	 * <p> 작성자(author) : 70398 / KBS </p>
	 * <p> 설명 			: 1차심사-진행 결재선 등록,삭제를 한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SXMPVM01I01.do")
	public String SXMPVM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SXMPVM01Controller SXMPVM01I01 Start #####");

		int checkIndex = 0; // 2차, 3차결재자 check용

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			Map<String, Object> sourceMapC = XFrame5DataSetUtil.getXFrameDataSet("DS_EXAM_MAN_SD", request, response, model);

	        // 심사목록 대상 조회 서비스 호출 입력값 대입
	        SXMPVM01DSSDDO01VO sXMPVM01DSSDDO01VO = new SXMPVM01DSSDDO01VO();

			LOGGER.info("##### 1111111111 #####");
			// ▣ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASP10DSSDVO inSddoVo = new SSPASP10DSSDVO();

			// ■ 등록, 삭제 처리
			SSPASP10OutVO resultI01 = new SSPASP10OutVO();

			if (sourceMapC.size() > 0)
			{

				LOGGER.info("##### 2222222222222 #####");

				inSddoVo.setLoanCnslNo	 (sourceMapC.get("loanCnslNo").toString());      /* 대출상담번호 */
				inSddoVo.setApplRealStsCd(sourceMapC.get("applRealStsCd").toString());    /* 신청현재진행상태코드 */
				inSddoVo.setLoanApplNo	 (sourceMapC.get("loanApplNo").toString());       /* 대출신청번호 */
				inSddoVo.setIngUserId    (sourceMapC.get("userNo").toString());           /* 진행담당자ID */
				inSddoVo.setIngUserNm    (sourceMapC.get("userNm").toString());           /* 진행담당자성명 */
				inSddoVo.setRoleDivCd	 (sourceMapC.get("roleDivCd").toString());        /* 직무구분코드 */
				inSddoVo.setFrstRegEmpNo (sourceMapC.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
				inSddoVo.setLastProcEmpNo(sourceMapC.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

		        // 심사목록 대상 조회 업무 서비스 호출 입력값 대입
		        sXMPVM01DSSDDO01VO.setLoanApplNo((String) sourceMapC.get("loanApplNo")); 	/* 대출신청번호 */
		        sXMPVM01DSSDDO01VO.setLastProcEmpNo((String) sourceMapC.get("lastProcEmpNo")); 	/* 최종_처리_사원번호 */
		        sXMPVM01DSSDDO01VO.setApplRealStsCd("40000");// 1차심사진행상태

		        // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
		        SXMPVM01I01InVO stsInVO = new SXMPVM01I01InVO();

		        // 심사목록 대상 조회 DS_SMDO 입력값 VO 객체 대입
		        stsInVO.setSXMPVM01DSSDDO01VO(sXMPVM01DSSDDO01VO);

				if ( true )
				{

					// ▣ 직무구분코드의 데이터가 존재하는 row만 저장
					if( !"".equals(inSddoVo.getRoleDivCd()) && inSddoVo.getRoleDivCd() != null ) {
						// ▣ 직무구분의 값이 "심사자(00010)"일 경우, 신청현재진행상태코드를 1차로 세팅
						if( "00010".equals(inSddoVo.getRoleDivCd())) {
							LOGGER.info("##### SSPASP10Controller >>>>> 1차 심사자 존재#####");

							// 신청진행상태관리 신청현재진행상태코드를 1차로 세팅
							SXMPVM01.updSXMPVM01U02(stsInVO);

							//여신신청원장 진행상태 업데이트
							SXMPVM01.updSXMPVM01U01(stsInVO);
						}

					}

					return XFrame5View.XFRAME5_VIEW;

				}

				// ▣ 결재선 내역 저장 서비스 호출 입력값 대입
				SSPASP10I01InVO InVO = new SSPASP10I01InVO();
				InVO.setSSPASP10DSSDVO(inSddoVo);

				// ▣ 직무구분코드의 데이터가 존재하는 row만 저장
				if( !"".equals(inSddoVo.getRoleDivCd()) && inSddoVo.getRoleDivCd() != null ) {

					// ▣ 직무구분의 값이 "심사자(00010)"일 경우, 신청현재진행상태코드를 1차로 세팅
					if( "00010".equals(inSddoVo.getRoleDivCd())) {
						LOGGER.info("##### SSPASP10Controller 등록 >> 심사자 존재 #####");
						checkIndex++;

						if (checkIndex == 1)
						{
							// 1차심사진행상태 저장
							inSddoVo.setApplRealStsCd("40000");
						}

						LOGGER.info("##### 333333333 #####");

						// 저장 서비스 호출
						resultI01 = SSPASP10.saveSSPASP10(InVO);

						// 여신신청원장 진행상태 업데이트
				        SXMPVM01.updSXMPVM01U01(stsInVO);

					}
				}

			}

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASM02Controller SSPASM02I01 Exception End #####");
		}
		LOGGER.info("##### SSPASP10 Controller SSPASP10i01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

}
