package hanalife.t.ch.on.web;

import java.math.BigDecimal;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.service.TCHON001Service;
import hanalife.t.ch.on.vo.HeaderVO;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.t.ch.on.vo.TCHONInVO;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON001Controller.java Class
 * 클래스설명    : 한도조회 (TCHON001) Controller
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/ch/on")
@Controller
public class TCHON001Controller {

    @Resource(name = "TCHON001Service")
    private TCHON001Service TCHON001;

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON001Controller.class);

    /**
     *<pre>
     * 메소드명      : 한도조회 /TCHON001S01.do
     * 작성일자      : 2023. 2. 27.
     * 작성자(author): 70278
     * 설명          : 대출한도를 조회한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TCHON001.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TCHON001(@RequestBody TCHONInVO reqInVO) throws Exception {

        LOGGER.info("##### TCHON001Controller TCHON001 Start #####");

        HeaderVO returnHeader = new HeaderVO();
        ResBodyVO outResultVo = new ResBodyVO();

        try {

            // 리퀘스트 Body
            ReqBodyVO inVO = reqInVO.getBody();

            // 파라미터 확인
            LOGGER.info("##### TCHON001Controller TCHON001 Start #####");
            LOGGER.info(">>>>>> Hedaer Time " + reqInVO.getHeader().getSendDttm());
            LOGGER.info(">>>>>> 대출상담번호 " + inVO.getLoanCnslNo());

            // 서비스에서 수행해야 할 처리
            // 1. 신정원 조회 (연체조회/대출조회)
            // 2. MCI 적격조회
            // 3. 한도조회(CSS)

            // 응답 : 한도금리/대출가능금액, 신정원의 대출조회한 신정원의 전문송수신번호
            // Vo를 Json Object로 전달

            // 결과값 system error 없을 경우 설정 안하게 기본설정
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setScrnId(reqInVO.getHeader().getScrnId());
            returnHeader.setSendDttm(DateUtil.getCurrentBaseDateString());
            returnHeader.setTrId(reqInVO.getHeader().getTrId());


            outResultVo.setRspnCd("000");
            outResultVo.setRspnMsg("대출한도조회 처리성공");



            // 채널 테스트 데이터 반환
            outResultVo.setRspnCd           ("000");                        // 응답코드 : 000: 정상, 999 오류
            outResultVo.setLoanPossAmt1     (new BigDecimal(100000000));    // 대출가능금액1
            outResultVo.setLoanMnrt         (2.5);                          // 대출금리
            outResultVo.setJudgGbCd         ("00010");                      // 판정결과 [S11093](승인:00010, 거절00020, 취소:00030)
            outResultVo.setRejtTinkGbCd     ("");                           // 판정사유 [거절사유구분코드:S00248]()
            outResultVo.setLoanPossAmt2     (new BigDecimal(120000000));    // 대출가능금액2
            outResultVo.setMciEntrQlfcFg    ("00001");                      // MCI가입적격여부 (S12030, 00001 : 적격, 00002 : 부적격)
            outResultVo.setCrdtInfoReadKey  ("1234567890");                 // 신용정보조회키



            LOGGER.info("##### TCHON001Controller TCHON001S01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            returnHeader.setRstrCd("999");
            returnHeader.setRstrMsg("ERROR : "+ e.getMessage());

            LOGGER.info("##### TCHON001Controller TCHON001 Exception End #####");

        }

        // 결과값 설정
//        TCHONOutVO outVo = new TCHONOutVO();
//        outVo.setHeader(returnHeader);
//        outVo.setBody(outResultVo);

        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject("header"  , returnHeader    );
        mav.addObject("body"    , reqInVO     );


        return mav;
    }

}
