package hanalife.t.ch.on.web;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.service.TCHON002Service;
import hanalife.t.ch.on.vo.HeaderVO;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.t.ch.on.vo.TCHONInVO;



/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON002Controller.java Class
 * 클래스설명   : 대출신청 (TCHON002) Controller
 * 작성일자     : 2023. 3. 28.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 28.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/ch/on")
@Controller
public class TCHON002Controller {

    @Resource(name = "TCHON002Service")
    private TCHON002Service TCHON002;

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON002Controller.class);

    /**
     *<pre>
     * 메소드명      : 대출신청처리 /TCHON002.do
     * 작성일자      : 2023. 2. 27.
     * 작성자(author): 70278
     * 설명          : 대출신청정보를 저장한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TCHON002.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TCHON002(@RequestBody TCHONInVO reqInVO) throws Exception {

        LOGGER.info("##### TCHON002Controller TCHON002 Start #####");
        HeaderVO returnHeader = new HeaderVO();
        ResBodyVO outResultVo = new ResBodyVO();

        try {

            // 리퀘스트 Body
            ReqBodyVO inVO = reqInVO.getBody();

            LOGGER.info(">>>>>>>>>>>>>> Hedaer Screenid " + reqInVO.getHeader().getScrnId());
            LOGGER.info(">>>>>>>>>>>>>> 대출상담번호 " + inVO.getLoanCnslNo());


            // 필수값 체크
            if(inVO.getLoanCnslNo().isEmpty() || inVO.getLoanCnslNo() == null) {
                // 결과값 system error 없을 경우 설정 안하게 기본설정
                returnHeader.setRstrCd("000");
                returnHeader.setRstrMsg("성공");

                outResultVo.setRspnCd("999");
                outResultVo.setRspnMsg("대출상담번호가 존재하지 않습니다.");
            }
            /*
            if(RUtil.isNull(inVO.getLoanCnslNo())) {

            }
            */

            // TODO : 대출신청정보 저장 필요
            // 대출상담번호, 주민등록번호
//            ResResultVO serviceResultVo = TCHON002.saveLoanApplInfo(inVO);
            outResultVo = TCHON002.saveLoanApplInfoTest(inVO);  // 채번 테스트용 메서드

            // 결과값 system error 없을 경우 설정 안하게 기본설정
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setScrnId(reqInVO.getHeader().getScrnId());
            returnHeader.setSendDttm(DateUtil.getCurrentBaseDateString());
            returnHeader.setTrId(reqInVO.getHeader().getTrId());

            LOGGER.info("##### TCHON002Controller TCHON002 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            returnHeader.setRstrCd("999");
            returnHeader.setRstrMsg("ERROR : "+ e.getMessage());

            outResultVo.setRspnCd("000");
            outResultVo.setRspnCd("대출신청 처리 실패");

            LOGGER.info("##### TCHON002Controller TCHON002 Exception End #####");
        }

        // 결과값 설정
        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject("header"  , returnHeader    );
        mav.addObject("body"    , outResultVo     );

        return mav;

    }


}

