package hanalife.t.ch.on.web;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.service.TCHON003Service;
import hanalife.t.ch.on.vo.HeaderVO;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.t.ch.on.vo.TCHONInVO;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON003Controller.java Class
 * 클래스설명    : 서류제출 (TCHON003) Controller
 * 작성일자     : 2023.04.04
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.04][70278][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/ch/on")
@Controller
public class TCHON003Controller {

    @Resource(name = "TCHON003Service")
    private TCHON003Service TCHON003;

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON003Controller.class);

    /**
     *<pre>
     * 메소드명       : 서류제출 /TCHON003.do
     * 작성일자       : 2023.04. 04
     * 작성자(author): 70278
     * 설명          : 제출서류정보를 저장한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TCHON003.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TCHON003(@RequestBody TCHONInVO reqInVO) throws Exception {

        LOGGER.info("##### TCHON003Controller TCHON003 Start #####");

        HeaderVO returnHeader = new HeaderVO();
        ResBodyVO outResultVo = new ResBodyVO();

        try {

            // 리퀘스트 Body
            ReqBodyVO inVO = reqInVO.getBody();

            // 파라미터 확인
            LOGGER.info(">>>>>>>>>>>>>> Hedaer Screenid " + reqInVO.getHeader().getScrnId());
            LOGGER.info(">>>>>>>>>>>>>> 대출상담번호 " + inVO.getLoanCnslNo());

            // 서비스에서 수행해야 할 처리
            // 1. 서류제출 데이터를 저장

            // 결과값
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setScrnId(reqInVO.getHeader().getScrnId());
            returnHeader.setSendDttm(DateUtil.getCurrentBaseDateString());
            returnHeader.setTrId(reqInVO.getHeader().getTrId());

            outResultVo.setRspnCd("000");
            outResultVo.setRspnMsg("서류제출 처리성공");

            LOGGER.info("##### TCHON003Controller TCHON003S01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            returnHeader.setRstrCd("999");
            returnHeader.setRstrMsg("ERROR : "+ e.getMessage());

            LOGGER.info("##### TCHON003Controller TCHON003 Exception End #####");

        }

        // 결과값 설정
        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject("header"  , returnHeader    );
        mav.addObject("body"    , outResultVo     );

        return mav;
    }

}
