package hanalife.t.ch.on.web;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.service.TCHON004Service;
import hanalife.t.ch.on.vo.HeaderVO;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.t.ch.on.vo.TCHONInVO;
import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON004Controller.java Class
 * 클래스설명    : 약정입력 (TCHON004) Controller
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/ch/on")
@Controller
public class TCHON004Controller {

    @Resource(name = "TCHON004Service")
    private TCHON004Service TCHON004;

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON004Controller.class);

    /**
     *<pre>
     * 메소드명      :  /TCHON004.do
     * 작성일자      : 2023. 2. 27.
     * 작성자(author): 70278
     * 설명          : 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TCHON004.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TCHON004(@RequestBody TCHONInVO reqInVO) throws Exception {

        LOGGER.info("##### TCHON004Controller TCHON004 Start #####");

        HeaderVO returnHeader = new HeaderVO();
        ResBodyVO outResultVo = new ResBodyVO();


        try {

            // 리퀘스트 Body
            ReqBodyVO inVO = reqInVO.getBody(); // TODO 위치조정?

            // 파라미터 확인
            LOGGER.info(">>>>>>>>>>>>>> Hedaer Screenid " + reqInVO.getHeader().getScrnId());

            LOGGER.info(">>>>>>>>>>>>>> 대출상담번호 " + inVO.getLoanCnslNo());
            LOGGER.info(">>>>>>>>>>>>>> 주민등록번호 " + inVO.getResiNo());

            // 서비스에서 수행해야 할 처리
            // 1. 약정입력 데이터 저장

            // 응답 : 한도금리/대출가능금액, 신정원의 대출조회한 신정원의 전문송수신번호
            // Vo를 Json Object로 전달

            // 결과값
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setScrnId(reqInVO.getHeader().getScrnId());
            returnHeader.setSendDttm(DateUtil.getCurrentBaseDateString());
            returnHeader.setTrId(reqInVO.getHeader().getTrId());


            outResultVo.setRspnCd("000");
            outResultVo.setRspnMsg("약정입력 처리성공");
            outResultVo.setLoanCnslNo(inVO.getLoanCnslNo());    // 대출상담번호

            // 대출신청번호 : S + yyyymmdd + 9999(시퀀스)
            int tempSeq         = (int)(Math.random() * 10000);
            String loanApplNo   = "S" + DateUtil.getCurrentDateString()
                                      + GramUtil.fixEndZero(Integer.toString(tempSeq), 4);

            outResultVo.setLoanApplNo(loanApplNo);              // 대출신청번호 TODO : 어디서 처리되어 리턴되는지 확인 필요


            LOGGER.info("##### TCHON004Controller TCHON004S01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            returnHeader.setRstrCd("999");
            returnHeader.setRstrMsg("ERROR : "+ e.getMessage());

            LOGGER.info("##### TCHON004Controller TCHON004 Exception End #####");

        }

        // 결과값 설정
        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject("header"  , returnHeader    );
        mav.addObject("body"    , outResultVo     );

        return mav;
    }

}
