package hanalife.t.ch.on.web;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.service.TCHON009Service;
import hanalife.t.ch.on.vo.HeaderVO;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.t.ch.on.vo.TCHONInVO;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON009Controller.java Class
 * 클래스설명    : 대출계약철회신청 (TCHON009) Controller
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/ch/on")
@Controller
public class TCHON009Controller {

    @Resource(name = "TCHON009Service")
    private TCHON009Service TCHON009;

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON009Controller.class);

    /**
     *<pre>
     * 메소드명      : 적합성적정성입력조회 /TCHON009S01.do
     * 작성일자      : 2023. 2. 27.
     * 작성자(author): 70278
     * 설명          : 적합성적정성입력조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TCHON009.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TCHON009(@RequestBody TCHONInVO reqInVO) throws Exception {

        LOGGER.info("##### TCHON009Controller TCHON009 Start #####");

        HeaderVO returnHeader = new HeaderVO();
        ResBodyVO outResultVo = new ResBodyVO();

        try {

            // 리퀘스트 Body
            ReqBodyVO inVO = reqInVO.getBody();

            // 파라미터 확인
            LOGGER.info("##### TCHON009Controller TCHON009 Start #####");

            LOGGER.info(">>>>>>>>>>>>>> Hedaer Screenid " + reqInVO.getHeader().getScrnId());
            LOGGER.info(">>>>>> Hedaer Time " + reqInVO.getHeader().getSendDttm());

            LOGGER.info(">>>>>>>>>>>>>> 대출상담번호 " + inVO.getLoanCnslNo());
            LOGGER.info(">>>>>>>>>>>>>> 주민등록번호 " + inVO.getResiNo());


            // 서비스에서 수행해야 할 처리
            // 1.

            // 결과값
            returnHeader.setRstrCd("000");
            returnHeader.setRstrMsg("성공");
            returnHeader.setScrnId(reqInVO.getHeader().getScrnId());
            returnHeader.setSendDttm(DateUtil.getCurrentBaseDateString());
            returnHeader.setTrId(reqInVO.getHeader().getTrId());

            outResultVo.setRspnCd("000");
            outResultVo.setRspnMsg("대출계약철회신청 처리성공");

            LOGGER.info("##### TCHON009Controller TCHON009 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            returnHeader.setRstrCd("999");
            returnHeader.setRstrMsg("ERROR : "+ e.getMessage());

            LOGGER.info("##### TCHON009Controller TCHON009 Exception End #####");
        }

        // 결과값 설정
        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject("header"  , returnHeader    );
        mav.addObject("body"    , outResultVo     );

        return mav;
    }

}
