package hanalife.t.kc.on.vo;

import org.apache.log4j.Logger;

import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : Kcb400RqstInfoEntity
 * 클래스설명    : KCB 요청 정보부 Entity (VO)
 * 작성일자     : 2023. 4. 20.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 20.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class KCB400RqstInfoEntity {
    private Logger log = Logger.getLogger(this.getClass().getName());

    private String confNo;              //인증번호
    private String reRqstCnt;           //재요청횟수
    private String custTpCd;            //개인/법인구분코드
    private String resiNo;              //주민등록번호 (custNo => resiNo)
    private String readObjCd;           //조회목적코드
    private String custNm;              //성명
    private String readDeptNm;          //조회지점명
    private String empNo;               //담당자ID

    private String cbTotCnt;            //CB Score 총수신건수 (SEG 100)
    private String cbReqCnt;            //CB Score 요청건수 (SEG 100)

    private String cbCpsTotCnt;         //CPS 총수신건수 (SEG 103)
    private String cbCpsReqCnt;         //CPS 요청건수 (SEG 103)

    /** 2. 송신 요청 정보 선언 */
    public KCB400RqstInfoEntity(){
        // 요청정보부 ( 150 byte )
        setConfNo               (GramUtil.fillSpace("000000000000",12));  // 01. 인증번호
        setReRqstCnt            (GramUtil.fixEndZero("0",2));              // 02. 재요청횟수
        setCustTpCd             (GramUtil.fillSpace("1",1));              // 03. 개인/법인구분코드 (1:개인, 2:법인)
        setResiNo               (GramUtil.fillSpace("",13));              // 04. 주민등록번호
        setReadObjCd            ("01");                                         // 05. 조회목적코드 (01:단순상담)
        setCustNm               (GramUtil.fillPkStringB("",50));             // 06. 성명
        setReadDeptNm           (GramUtil.fillPkStringB("",20));             // 07. 조회지점명
        setEmpNo                (GramUtil.fillSpace("",15));              // 08. 담당자 ID

        //Segment 100 (고객평점조회)
        setCbTotCnt             (GramUtil.fixEndZero("0",3));              // 09. CB Score 총수신건수
        setCbReqCnt             (GramUtil.fixEndZero("99",2));             // 10. CB Score 요청건수

        // Segment 103 (CPS(고정))
        setCbCpsTotCnt          (GramUtil.fixEndZero("0",3));              // 11. CPS 총수신건수
        setCbCpsReqCnt          (GramUtil.fixEndZero("99",2));             // 12. CPS 요청건수
    }

    public String getConfNo() {
        return confNo;
    }
    public void setConfNo(String confNo) {
        this.confNo = confNo;
    }
    public String getReRqstCnt() {
        return reRqstCnt;
    }
    public void setReRqstCnt(String reRqstCnt) {
        this.reRqstCnt = reRqstCnt;
    }
    public String getCustTpCd() {
        return custTpCd;
    }
    public void setCustTpCd(String custTpCd) {
        this.custTpCd = custTpCd;
    }
    public String getResiNo() {
        return resiNo;
    }
    public void setResiNo(String resiNo) {
        this.resiNo = resiNo;
    }
    public String getReadObjCd() {
        return readObjCd;
    }
    public void setReadObjCd(String readObjCd) {
        this.readObjCd = readObjCd;
    }
    public String getCustNm() {
        return custNm;
    }
    public void setCustNm(String custNm) {
        this.custNm = custNm;
    }
    public String getReadDeptNm() {
        return readDeptNm;
    }
    public void setReadDeptNm(String readDeptNm) {
        this.readDeptNm = readDeptNm;
    }
    public String getEmpNo() {
        return empNo;
    }
    public void setEmpNo(String empNo) {
        this.empNo = empNo;
    }
    public String getCbTotCnt() {
        return cbTotCnt;
    }
    public void setCbTotCnt(String cbTotCnt) {
        this.cbTotCnt = cbTotCnt;
    }
    public String getCbReqCnt() {
        return cbReqCnt;
    }
    public void setCbReqCnt(String cbReqCnt) {
        this.cbReqCnt = cbReqCnt;
    }
    public String getCbCpsTotCnt() {
        return cbCpsTotCnt;
    }
    public void setCbCpsTotCnt(String cbCpsTotCnt) {
        this.cbCpsTotCnt = cbCpsTotCnt;
    }
    public String getCbCpsReqCnt() {
        return cbCpsReqCnt;
    }
    public void setCbCpsReqCnt(String cbCpsReqCnt) {
        this.cbCpsReqCnt = cbCpsReqCnt;
    }

    public String getSendStr() {
        // 요청정보부(150 byte)
        StringBuffer sendBuff = new StringBuffer();

        sendBuff.append(getConfNo());               //1.인증번호
        sendBuff.append(getReRqstCnt());            //2.재요청횟수
        sendBuff.append(getCustTpCd());             //3.개인/법인구분코드
        sendBuff.append(getResiNo());               //4.주민등록번호
        sendBuff.append(getReadObjCd());            //5.조회목적코드
        sendBuff.append(getCustNm());               //6.성명
        sendBuff.append(getReadDeptNm());           //7.조회지점명
        sendBuff.append(getEmpNo());                //8.담당자ID
        sendBuff.append(getCbTotCnt());             //100 신상정보 총요청 건수
        sendBuff.append(getCbReqCnt());             //100 신상정보 요청건수
        sendBuff.append(getCbCpsTotCnt());          //103 대출이력정보(개인별) 총수신건수
        sendBuff.append(getCbCpsReqCnt());          //103 대출이력정보 (개인별) 요청건수

        log.debug(getConfNo());                 //1.인증번호
        log.debug(getReRqstCnt());              //2.재요청횟수
        log.debug(getCustTpCd());               //3.개인/법인구분코드
        log.debug(getResiNo());                 //4.주민등록번호
        log.debug(getReadObjCd());              //5.조회목적코드
        log.debug(getCustNm()+" "+getCustNm().length());            //6.성명
        log.debug(getReadDeptNm()+" "+getReadDeptNm().length());    //7.조회지점명
        log.debug(getEmpNo()+" "+getEmpNo().length());              //8.담당자ID
        log.debug(getCbTotCnt());               //029 신상정보 총요청 건수
        log.debug(getCbReqCnt());               //029 신상정보 요청건수
        log.debug(getCbCpsTotCnt());            //034 대출이력정보(개인별) 총수신건수
        log.debug(getCbCpsReqCnt());            //034 대출이력정보 (개인별) 요청건수

        log.debug("400 전문 요청부 사이즈:"+sendBuff.toString().getBytes().length);
        return sendBuff.toString();
    }
}
