package hanalife.t.kc.on.vo;

import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : KcbCommonEntity
 * 클래스설명    : KCB 공통 정보 Entity (VO)
 * 작성일자     : 2023. 4. 20.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 19.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class KCBCommonEntity {
//  private Logger log = Logger.getLogger(this.getClass().getName());

    private String tranCd;                            //트랜젝션 코드 (Transaction Code)
    private String userNo;                            //이용자번호
    private String gramKindCd;                        //전문종별코드 (layTpCd =>gramKindCd)
    private String bsnDivCd;                          //업무구분코드 (jobDivCd=>bsnDivCd)
    private String sendRecvFg;                        //송수신 Flag
    private String rspnCd;                            //응답코드
    private String kcbLayMngNo;                       //KCB전문관리번호
    private String kcbLaySendTm;                      //KCB전문전송시간
    private String wricLayMngNo;                      //회원사전문관리번호
    private String wricLaySendTm;                     //회원사전문전송시간
    private String kcbSystInfo;                       //KCB시스템정보
    private String viewAgreeFg;                       //조회동의코드
    private String filler;                            //FILLER

    public KCBCommonEntity(){
        /*
        setTranCd       (StringUtils.fillPkString("SEV",9));
        setUserNo       ("C0050301");
        setLayTpCd      ("0100");
        setJobDivCd     ("100");
        setSendRecvFg   ("B");
        setRspnCd       (StringUtils.fillPkString("",4));
        setKcbLayMngNo  (StringUtils.fillPkString("",7));
        setKcbLaySendTm (StringUtils.fillPkString("",14));
        setWricLayMngNo (StringUtils.fillPkString("",7));
        setWricLaySendTm(StringUtils.fillPkString("",14));
        setKcbSystInfo  (StringUtils.fillPkString("",16));
        setViewAgreeFg  (StringUtils.fillPkString("",1)); // 2018-08-01 (두비스) : 조회동의 여부 추가
        setFiller       (StringUtils.fillPkString("",42)); // 2018-08-01 (두비스) : 조회동의 여부 추가
        // setFiller       (StringUtils.fillPkString("",43));
         */
    }

    /**
     * KCB 송신 공통전문 정의
     * @param gramKindCd   : 요청전문코드 ( 최초요청시 : 0400, 재요청시 : 0500 으로 셋팅 )
     * @param bsnDivCd  : 업무구분코드 ( 기본신용보고서 : 437 , 신용요약정보_온라인(고정) : 141 )
     */
    public KCBCommonEntity(String gramKindCd, String bsnDivCd){

        if("001".equals(bsnDivCd)) {
            setTranCd       (GramUtil.fillSpace("SOHO",9));  //트랜젝션 코드
        } else if("231".equals(bsnDivCd)){
            setTranCd       (GramUtil.fillSpace("GRAS",9));  //트랜젝션 코드
        } else {
            setTranCd       (GramUtil.fillSpace("SEV",9));  //트랜젝션 코드 : 개인
        }

        setUserNo       ("C0050301");                         //이용자번호   TODO : 이용자번호 설정 필요
        setGramKindCd   (gramKindCd);                         //전문종별코드
        setBsnDivCd     (bsnDivCd);                           //업무구분코드
        setSendRecvFg   ("B");                                //송수신구분
        setRspnCd       (GramUtil.fillSpace("",4));     //응답코드
        setKcbLayMngNo  (GramUtil.fixEndZero("",7));     //KCB전문관리번호
        setKcbLaySendTm (GramUtil.fixEndZero("",14));    //KCB전문전송시간
        setWricLayMngNo (GramUtil.fixEndZero("",7));     //회원사전문관리번호
        setWricLaySendTm(GramUtil.fixEndZero("",14));    //회원사전문전송시간
        setKcbSystInfo  (GramUtil.fillSpace("",16));    //KCB시스템정보

        if("611".equals(bsnDivCd)) {
            setFiller       (GramUtil.fillSpace("",43));    //FILLER
        } else {
            setViewAgreeFg  (GramUtil.fillSpace("",1));     //조회동의코드
            setFiller       (GramUtil.fillSpace("",42));    //FILLER
        }
    }

    public void setTranCd(String tranCd){
        this.tranCd = tranCd;
    }
    public void setUserNo(String userNo){
        this.userNo = userNo;
    }
    public void setGramKindCd(String gramKindCd) {
        this.gramKindCd = gramKindCd;
    }
    public void setBsnDivCd(String bsnDivCd) {
        this.bsnDivCd = bsnDivCd;
    }
    public void setSendRecvFg(String sendRecvFg){
        this.sendRecvFg = sendRecvFg;
    }
    public void setRspnCd(String rspnCd){
        this.rspnCd = rspnCd;
    }
    public void setKcbLayMngNo(String kcbLayMngNo){
        this.kcbLayMngNo = kcbLayMngNo;
    }
    public void setKcbLaySendTm(String kcbLaySendTm){
        this.kcbLaySendTm = kcbLaySendTm;
    }
    public void setWricLayMngNo(String wricLayMngNo){
        this.wricLayMngNo = wricLayMngNo;
    }
    public void setWricLaySendTm(String wricLaySendTm){
        this.wricLaySendTm = wricLaySendTm;
    }
    public void setKcbSystInfo(String kcbSystInfo){
        this.kcbSystInfo = kcbSystInfo;
    }

    public void setViewAgreeFg(String viewAgreeFg){
        this.viewAgreeFg = viewAgreeFg;
    }

    public void setFiller(String filler){
        this.filler = filler;
    }

    public String getTranCd(){
        return tranCd;
    }
    public String getUserNo(){
        return userNo;
    }
    public String getGramKindCd() {
        return gramKindCd;
    }
    public String getBsnDivCd() {
        return bsnDivCd;
    }
    public String getSendRecvFg(){
        return sendRecvFg;
    }
    public String getRspnCd(){
        return rspnCd;
    }
    public String getKcbLayMngNo(){
        return kcbLayMngNo;
    }
    public String getKcbLaySendTm(){
        return kcbLaySendTm;
    }
    public String getWricLayMngNo(){
        return wricLayMngNo;
    }
    public String getWricLaySendTm(){
        return wricLaySendTm;
    }
    public String getKcbSystInfo(){
        return kcbSystInfo;
    }

    public String getViewAgreeFg(){
        return viewAgreeFg;
    }

    public String getFiller(){
        return filler;
    }

    public String getSendStr() {
        // 공통부(130 byte)
        StringBuffer sendBuff = new StringBuffer();

        sendBuff.append(getTranCd());
        sendBuff.append(getUserNo());
        sendBuff.append(getGramKindCd());       // 전문종별코드
        sendBuff.append(getBsnDivCd());         // 업무구분코드
        sendBuff.append(getSendRecvFg());
        sendBuff.append(getRspnCd());
        sendBuff.append(getKcbLayMngNo());
        sendBuff.append(getKcbLaySendTm());
        sendBuff.append(getWricLayMngNo());
        sendBuff.append(getWricLaySendTm());
        sendBuff.append(getKcbSystInfo());

        if("611".equals(getBsnDivCd())) {
            sendBuff.append(getFiller());
        } else {
            sendBuff.append(getViewAgreeFg());
            sendBuff.append(getFiller());
        }

//        log.debug("공통부 사이즈::"+sendBuff.toString().getBytes().length);
        return sendBuff.toString();
    }

    public void setRecvObj(String recvData) {
        int totlByte = 0;
        byte[] convData = recvData.getBytes();
        setTranCd       (new String(convData,totlByte+=0,9));
        setUserNo       (new String(convData,totlByte+=9,8));
        setGramKindCd   (new String(convData,totlByte+=8,4));
        setBsnDivCd     (new String(convData,totlByte+=4,3));
        setSendRecvFg   (new String(convData,totlByte+=3,1));
        setRspnCd       (new String(convData,totlByte+=1,4));
        setKcbLayMngNo  (new String(convData,totlByte+=4,7));
        setKcbLaySendTm (new String(convData,totlByte+=7,14));
        setWricLayMngNo (new String(convData,totlByte+=14,7));
        setWricLaySendTm(new String(convData,totlByte+=7,14));
        setKcbSystInfo  (new String(convData,totlByte+=14,16));

        if("611".equals(getBsnDivCd())) {
            setFiller       (new String(convData,totlByte+=16,43));
        } else {
            setViewAgreeFg  (new String(convData,totlByte+=16,1));
            setFiller       (new String(convData,totlByte+=1,42));
        }

//        log.debug("___getTranCd       ():[" + getTranCd       () + "]");
//        log.debug("___getUserNo       ():[" + getUserNo       () + "]");
//        log.debug("___getLayTpCd      ():[" + getLayTpCd      () + "]");
//        log.debug("___getJobDivCd     ():[" + getJobDivCd     () + "]");
//        log.debug("___getSendRecvFg   ():[" + getSendRecvFg   () + "]");
//        log.debug("___getRspnCd       ():[" + getRspnCd       () + "]");
//        log.debug("___getKcbLayMngNo  ():[" + getKcbLayMngNo  () + "]");
//        log.debug("___getKcbLaySendTm ():[" + getKcbLaySendTm () + "]");
//        log.debug("___getWricLayMngNo ():[" + getWricLayMngNo () + "]");
//        log.debug("___getWricLaySendTm():[" + getWricLaySendTm() + "]");
//        log.debug("___getKcbSystInfo  ():[" + getKcbSystInfo  () + "]");
//        log.debug("___getViewAgreeFg  ():[" + getViewAgreeFg  () + "]");
    }
}
