package hanalife.t.kf.on.vo;

import java.util.ArrayList;
import java.util.List;

import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : KFB0200239Entity
 * 클래스설명    : 주택관련대출 추가약정정보 조회(0200/239) 용 Entity (VO)
 * 작성일자     : 2023. 5. 05.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 05.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@SuppressWarnings("rawtypes")
public class KFB0200239Entity {

    private String regNo;                   // 주민(사업자)등록번호
    private String unUse1;                  // (미사용)
    private String reason;                  // 자료이용목적
    private String viewAgreeFg;             // 조회 동의 여부
    private String unUse2;                  // (미사용)
    private String name;                    // 성명
    private String unUse3;                  // (미사용)
    private String lastUpdateDt;            // 대출정보 Update 최근 일자
    private String addContInfoMore;         // 추가약정 정보 More
    private String addContInfoTotCnt;       // 추가약정 정보 총 건수
    private String addContInfoReptCnt;      // 추가약정 정보 회보 건수
    private List   addContInfoArry;         // 추가약정 정보 회보 사항 (1 to 20 Times) → (140 × 20 = 2,800)

    // 생성자
    public KFB0200239Entity() {
        setRegNo                (GramUtil.fixEndZero("",13 ));     // 주민(사업자)등록번호 (13)
        setUnUse1               (GramUtil.fixEndZero("", 1 ));     // (미사용) (1)
        setReason               (GramUtil.fixEndZero("", 2 ));     // 자료이용목적 (2)
        setViewAgreeFg          (GramUtil.fixEndZero("", 1 ));     // 조회 동의 여부 (1)
        setUnUse2               (GramUtil.fixEndZero("",40 ));     // (미사용) (40)
        setName                 (GramUtil.fixEndZero("",20 ));     // 성명 (20)
        setUnUse3               (GramUtil.fixEndZero("",17 ));     // (미사용) (17)
        setLastUpdateDt         (GramUtil.fixEndZero("", 8 ));     // 대출정보 Update 최근 일자 (8)
        setAddContInfoMore      (GramUtil.fixEndZero("", 1 ));     // 추가약정 정보 More (1)
        setAddContInfoTotCnt    (GramUtil.fixEndZero("", 4 ));     // 추가약정 정보 총 건수 (4)
        setAddContInfoReptCnt   (GramUtil.fixEndZero("", 2 ));     // 추가약정 정보 회보 건수 (2)
        setAddContInfoArry      (""                              );     // 대출･단기카드대출 정보 회보 사항 (1 to 20 Times) → (120 × 20 = 2,400)
    }

    public String getRegNo                        () { return this.regNo                  ; }
    public String getUnUse1                       () { return this.unUse1                 ; }
    public String getReason                       () { return this.reason                 ; }
    public String getViewAgreeFg                  () { return this.viewAgreeFg            ; }
    public String getUnUse2                       () { return this.unUse2                 ; }
    public String getName                         () { return this.name                   ; }
    public String getUnUse3                       () { return this.unUse3                 ; }
    public String getLastUpdateDt                 () { return this.lastUpdateDt           ; }
    public String getAddContInfoMore              () { return this.addContInfoMore        ; }
    public String getAddContInfoTotCnt            () { return this.addContInfoTotCnt      ; }
    public String getAddContInfoReptCnt           () { return this.addContInfoReptCnt     ; }
    public List   getAaddContInfoArry             () { return this.addContInfoArry        ; }

    public void setRegNo                ( String regNo                ){ this.regNo                  = regNo                ; }
    public void setUnUse1               ( String unUse1               ){ this.unUse1                 = unUse1               ; }
    public void setReason               ( String reason               ){ this.reason                 = reason               ; }
    public void setViewAgreeFg          ( String viewAgreeFg          ){ this.viewAgreeFg            = viewAgreeFg          ; }
    public void setUnUse2               ( String unUse2               ){ this.unUse2                 = unUse2               ; }
    public void setName                 ( String name                 ){ this.name                   = name                 ; }
    public void setUnUse3               ( String unUse3               ){ this.unUse3                 = unUse3               ; }
    public void setLastUpdateDt         ( String lastUpdateDt         ){ this.lastUpdateDt           = lastUpdateDt         ; }
    public void setAddContInfoMore      ( String addContInfoMore      ){ this.addContInfoMore        = addContInfoMore      ; }
    public void setAddContInfoTotCnt    ( String addContInfoTotCnt    ){ this.addContInfoTotCnt      = addContInfoTotCnt    ; }
    public void setAddContInfoReptCnt   ( String addContInfoReptCnt   ){ this.addContInfoReptCnt     = addContInfoReptCnt   ; }
    // 추가약정 정보 회보 사항 (1 to 20 Times) → (140 × 20 = 2,800)
    public void setAddContInfoArry(String data){

        addContInfoArry = new ArrayList();

        byte[] convData = data.getBytes();
        int addContInfoReptCnt = Integer.parseInt(getAddContInfoReptCnt());
        int totlByte = -1;

        for (int i=0; i < addContInfoReptCnt; i++){
            String[] rsltData = new String[16];
            rsltData[0]  = new String(convData,totlByte+= 1 , 4 );       // 등록 코드 (4))
            rsltData[1]  = new String(convData,totlByte+= 4 , 7 );       // 점포 코드 (7)
            rsltData[2]  = new String(convData,totlByte+= 7 , 20);       // 계좌(관리)번호 (20)
            rsltData[3]  = new String(convData,totlByte+= 20, 2 );       // 추가약정 코드 (2)
            rsltData[4]  = new String(convData,totlByte+= 2 , 8 );       // 정보 변경일자 (8)
            rsltData[5]  = new String(convData,totlByte+= 8 , 8 );       // 대출 실행일자 (8)
            rsltData[6]  = new String(convData,totlByte+= 8 , 10);       // 최초 대출금액(단위:천원) (10)
            rsltData[7]  = new String(convData,totlByte+= 10,  3);       // 대출(담보)종류 구분 (3)
            rsltData[8]  = new String(convData,totlByte+= 3 ,  1);       // 집단대출 구분 (1)
            rsltData[9]  = new String(convData,totlByte+= 1 ,  2);       // 담보종류 구분 (2)
            rsltData[10] = new String(convData,totlByte+= 2 ,  4);       // 주택 수 (4)
            rsltData[11] = new String(convData,totlByte+= 4 ,  2);       // 이행 확인상태 (2)
            rsltData[12] = new String(convData,totlByte+= 2 ,  8);       // 이행 확인일자 (8)
            rsltData[13] = new String(convData,totlByte+= 8 ,  2);       // 약정 위반여부 (2)
            rsltData[14] = new String(convData,totlByte+= 2 ,  8);       // 약정 위반일자 (8)
            rsltData[15] = new String(convData,totlByte+= 8 , 51);       // SPACE  (51)

            addContInfoArry.add(rsltData);
        }
    }


    /**
     * Send 보낼 문자열을 생성한다.
     */
    public String getSendStr() {
        StringBuffer sendBuff = new StringBuffer();

        sendBuff.append(getRegNo                        ());
        sendBuff.append(getUnUse1                       ());
        sendBuff.append(getReason                       ());
        sendBuff.append(getViewAgreeFg                  ());
        sendBuff.append(getUnUse2                       ());
        sendBuff.append(getName                         ());
        sendBuff.append(getUnUse3                       ());
        sendBuff.append(getLastUpdateDt                 ());
        sendBuff.append(getAddContInfoMore              ());
        sendBuff.append(getAddContInfoTotCnt            ());
        sendBuff.append(getAddContInfoReptCnt           ());
        sendBuff.append(getAaddContInfoArry             ());

        //sendBuff.append(getDsrInfoArry                  ());

        return (sendBuff.toString());
    }

    public void setRecvObj(String recvData) {
        int totlByte = 0;
        byte[] convData = recvData.getBytes();

        setRegNo                (new String(convData,totlByte+=0 ,  13  ).trim());      // 주민(사업자)등록번호 (13)
        setUnUse1               (new String(convData,totlByte+=13,  1   ).trim());      // (미사용) (1)
        setReason               (new String(convData,totlByte+=1 ,  2   ).trim());      // 자료이용목적 (2)
        setViewAgreeFg          (new String(convData,totlByte+=2 ,  1   ).trim());      // 조회 동의 여부 (1)
        setUnUse2               (new String(convData,totlByte+=1 ,  40  ).trim());      // (미사용) (40)
        setName                 (new String(convData,totlByte+=40,  20  ).trim());      // 성명 (20)
        setUnUse3               (new String(convData,totlByte+=20,  17  ).trim());      // (미사용) (17)
        setLastUpdateDt         (new String(convData,totlByte+=17,  8   ).trim());      // 대출정보 Update 최근 일자 (8)
        setAddContInfoMore      (new String(convData,totlByte+=8 ,  1   ).trim());      // 추가약정 정보 More (1)
        setAddContInfoTotCnt    (new String(convData,totlByte+=4 ,  4   ).trim());      // 추가약정 정보 총 건수 (4)
        setAddContInfoReptCnt   (new String(convData,totlByte+=2 ,  2   ).trim());      // 추가약정 정보 회보 건수 (2)

        setAddContInfoArry      (new String(convData,totlByte+=2 ,  convData.length-totlByte).trim());  // 추가약정 정보 회보 사항 (1 to 20 Times) → (140 × 20 = 2,800)
    }
}
