package hanalife.t.kf.on.vo;


import hanalife.c.co.util.DateUtil;
import hanalife.t.comm.constants.IF_COMMON_DEFINE;
import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 클래스명    : KFBCommonEntity
 * 클래스설명 : 신정원(신용정보원 /은행연합회)에 보내줄 데이터 처리 Entity
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class KFBCommonEntity {
    /**  요청/응답 - 공통 Block(90) */
    private String txCode;          // Transaction-ID AN(9) - Input KFBCIF
    private String sysID;           // System-ID N(2) - Input   90
    private String orgCode;         // 대표기관코드 N(3) - Input
    private String gramKindCd;      // 전문종별코드 N(4) - Input
    private String bsnDivCd;        // 전문구분코드 N(3) - Input
    private String snrFg;           // 송수신플래그 A(1) - Input
    private String rspnCd;          // 응답코드 N(3) - Input
    private String brnchCd;         // 점포코드 N(7) - Input
    private String orgMngNo;        // 금융기관 전문관리번호 N(7) - Input
    private String orgSndTm;        // 금융익관 전문전송시간 N(14) - Input
    private String unionMngNo;      // 연합회 전문관리번호 N(7) - Input
    private String unionSndTm;      // 연합회 전문전송시간 N(14) - Input
    private String reserved;        // 예비정보 Field N(16) - Input

    /**
     * 생성자
     * @param String to Set : 주민번호
     */
    public KFBCommonEntity() {
        try{
        /**  요청/응답 - 공통 Block(90) */
        setTxCode       (GramUtil.fillSpace(IF_COMMON_DEFINE.KFB_TRANSACTION_CODE ,9  ));    // Transaction-ID AN(9) - Input    CISIFPSOT or KFBCIF
        setSysID        (GramUtil.fillSpace(IF_COMMON_DEFINE.KFB_SYSTEM_ID        ,2  ));    // System-ID N(2) - Input
        setOrgCode      (GramUtil.fillSpace(IF_COMMON_DEFINE.KFB_ORG_CODE         ,3  ));    // 대표기관코드 N(3) - Input
        setGramKindCd   (GramUtil.fillSpace("0000"                                ,4  ));    // 전문종별코드 N(4) - Input
        setBsnDivCd     (GramUtil.fillSpace("000"                                 ,3  ));    // 전문구분코드 N(3) - Input
        setSnrFg        (GramUtil.fillSpace(IF_COMMON_DEFINE.KFB_SNDRCV_FLAG      ,1  ));    // 송수신플래그 A(1) - Input
        setRspnCd       (GramUtil.fillSpace(""                                    ,3  ));    // 응답코드 N(3) - Input
        setBrnchCd      (GramUtil.fillSpace(IF_COMMON_DEFINE.KFB_REQ_ORG_CD       ,7  ));    // 점포코드 N(7) - Input
        setOrgMngNo     (GramUtil.fixEndZero(""+IF_COMMON_DEFINE.getKfbMngNo()    ,7  ));    // 금융기관 전문관리번호 N(7) - Input
        setOrgSndTm     (DateUtil.getCurrentBaseDateString()                           );     // 금융기관 전문전송시간 N(14) - Input
        setUnionMngNo   (GramUtil.fillSpace(""                                    ,7  ));    // 연합회 전문관리번호 N(7) - Input
        setUnionSndTm   (GramUtil.fillSpace(""                                    ,14 ));    // 연합회 전문전송시간 N(14) - Input
        setReserved     (GramUtil.fillSpace(""                                    ,16 ));    // 예비정보 Field N(16) - Input

        }catch(Exception e){
            e.printStackTrace();
        }
    }

    /**  요청/응답 - 공통 Block(90) */
    public void setTxCode(String txCode){ this.txCode = txCode;}        // Transaction-ID AN(9) - Input
    public void setSysID(String sysID){this.sysID=sysID;}       // System-ID N(2) - Input   90
    public void setOrgCode(String orgCode){this.orgCode = orgCode;}         // 대표기관코드 N(3) - Input
    public void setGramKindCd(String gramKindCd){this.gramKindCd = gramKindCd;} // 전문종별코드 N(4) - Input
    public void setBsnDivCd(String bsnDivCd){this.bsnDivCd = bsnDivCd;}     // 전문구분코드 N(3) - Input
    public void setSnrFg(String snrFg){this.snrFg = snrFg;}     // 송수신플래그 A(1) - Input
    public void setRspnCd(String rspnCd){this.rspnCd = rspnCd;}     // 응답코드 N(3) - Input
    public void setBrnchCd(String brnchCd){this.brnchCd = brnchCd;}     // 점포코드 N(7) - Input
    public void setOrgMngNo(String orgMngNo){this.orgMngNo = orgMngNo;}     // 금융기관 전문관리번호 N(7) - Input
    public void setOrgSndTm(String orgSndTm){this.orgSndTm = orgSndTm;}     // 금융익관 전문전송시간 N(14) - Input
    public void setUnionMngNo(String unionMngNo){this.unionMngNo = unionMngNo;} // 연합회 전문관리번호 N(7) - Input
    public void setUnionSndTm(String unionSndTm){this.unionSndTm = unionSndTm;} // 연합회 전문전송시간 N(14) - Input
    public void setReserved(String reserved){this.reserved = reserved;}     // 예비정보 Field N(16) - Input

    /**  요청/응답 - 공통 Block(90) */
    public String getTxCode(){ return txCode;}          // Transaction-ID AN(9) - Input KFBCIF
    public String getSysID(){return sysID;}             // System-ID N(2) - Input   90
    public String getOrgCode(){return orgCode;}         // 대표기관코드 N(3) - Input
    public String getGramKindCd(){return gramKindCd;}   // 전문종별코드 N(4) - Input
    public String getBsnDivCd(){return bsnDivCd;}       // 전문구분코드 N(3) - Input
    public String getSnrFg(){return snrFg;}             // 송수신플래그 A(1) - Input
    public String getRspnCd(){return rspnCd;}           // 응답코드 N(3) - Input
    public String getBrnchCd(){return brnchCd;}         // 점포코드 N(7) - Input
    public String getOrgMngNo(){return orgMngNo;}       // 금융기관 전문관리번호 N(7) - Input
    public String getOrgSndTm(){return orgSndTm;}       // 금융익관 전문전송시간 N(14) - Input
    public String getUnionMngNo(){return unionMngNo;}   // 연합회 전문관리번호 N(7) - Input
    public String getUnionSndTm(){return unionSndTm;}   // 연합회 전문전송시간 N(14) - Input
    public String getReserved(){return reserved;}       // 예비정보 Field N(16) - Input

    /**
     * Send 보낼 문자열을 생성한다.
     */
    public String getSendStr() {
        StringBuffer sendBuff = new StringBuffer();

        /**  요청/응답 - 공통 Block(90) */
        sendBuff.append(getTxCode());       // Transaction-ID AN(9) - Input KFBCIF
        sendBuff.append(getSysID());        // System-ID N(2) - Input   90
        sendBuff.append(getOrgCode());      // 대표기관코드 N(3) - Input
        sendBuff.append(getGramKindCd());   // 전문종별코드 N(4) - Input
        sendBuff.append(getBsnDivCd());     // 전문구분코드 N(3) - Input
        sendBuff.append(getSnrFg());            // 송수신플래그 A(1) - Input
        sendBuff.append(getRspnCd());       // 응답코드 N(3) - Input
        sendBuff.append(getBrnchCd());      // 점포코드 N(7) - Input
        sendBuff.append(getOrgMngNo());     // 금융기관 전문관리번호 N(7) - Input
        sendBuff.append(getOrgSndTm());     // 금융익관 전문전송시간 N(14) - Input
        sendBuff.append(getUnionMngNo());   // 연합회 전문관리번호 N(7) - Input
        sendBuff.append(getUnionSndTm());   // 연합회 전문전송시간 N(14) - Input
        sendBuff.append(getReserved());     // 예비정보 Field N(16) - Input

        return (sendBuff.toString());
    }

    public void setRecvObj(String recvData) {
        int totlByte = 0;
        String revGramLen = "" ;

        byte[] convData = recvData.getBytes();
        setTxCode            (new String(convData,totlByte+=0,9));
        revGramLen = (new String(convData,totlByte+=9,4));      // 전문길이(4) : 2018-08-01 (두비스)
        setSysID             (new String(convData,totlByte+=4,2));
        setOrgCode           (new String(convData,totlByte+=2,3));
        setGramKindCd        (new String(convData,totlByte+=3,4));
        setBsnDivCd          (new String(convData,totlByte+=4,3));
        setSnrFg             (new String(convData,totlByte+=3,1));
        setRspnCd            (new String(convData,totlByte+=1,3));
        setBrnchCd           (new String(convData,totlByte+=3,7));
        setOrgMngNo          (new String(convData,totlByte+=7,7));
        setOrgSndTm          (new String(convData,totlByte+=7,14));
        setUnionMngNo        (new String(convData,totlByte+=14,7));
        setUnionSndTm        (new String(convData,totlByte+=7,14));
        setReserved          (new String(convData,totlByte+=14,16));
    }

}
