package hanalife.t.kf.on.web;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;

import hanalife.t.kf.on.service.TKFON003Service;
import hanalife.t.kf.on.vo.KFBOnlnVo;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TKFON002Controller
 * 클래스설명   : [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236) Controller
 * 작성일자     : 2023.05.05
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 3.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/t/kf/on")
@Controller
public class TKFON003Controller {

    @Resource(name = "TKFON003Service")
    private TKFON003Service tKFON003Service;

    private static final Logger LOGGER = LoggerFactory.getLogger(TKFON003Controller.class);

    /**
     *<pre>
     * 메소드명      : [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236) TKFON003.do
     * 작성일자      : 2023. 5. 5.
     * 작성자(author): 70317
     * 설명          : 개인회생 신청 등 정보 온라인 조회 전문을 호출 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping(value = "/TKFON003.do", method = RequestMethod.POST, produces="application/json")
    public ModelAndView TKFON003(@RequestBody KFBOnlnVo reqInVO) throws Exception {

        LOGGER.info("##### TKFON003Controller TKFON003 Start #####");

        try {

            // VO 설정
            KFBOnlnVo inVo = reqInVO;

            // 체크 필요하면 넣을 것
            LOGGER.info("주민번호 : " + reqInVO.getResiNo());

            // [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236) 호출
            tKFON003Service.KFB_0200236_Call(reqInVO);

            LOGGER.info("##### TKFON003Controller TKFON003 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정

            LOGGER.info("##### TKFON003Controller TKFON003 Exception End #####");
        }

        // 결과값 설정
        ModelAndView mav = new ModelAndView("jsonView");
        mav.addObject(reqInVO);

        return mav;
    }
}
