package hanalife.util.format;

import java.util.Calendar;

import org.apache.log4j.Logger;

import hanalife.util.log.CallerInfo;


/**
* <pre>
* 클래스명    : ServerSysDate
* 클래스설명 : 서버의 시스템 일자를 가져오기 PROCEDURE Call
*  (시스템 => 1:년, 2:년월, 3:월일, 4:년월일 5:년월일시분초 6:연(2자리) 7:연(2자리)월 8:연(2자리)월일, 9:시분초 얻어오기)
* 프로젝트명 : DOBSCAP
* 작성일자    : 2018-08-01
* 변경이력
* -----------------------------------------------------------------------------
* [변경일자 ][변경자][변경사유-수정내용]
* -----------------------------------------------------------------------------
* [20180801][두비스][캐피탈패키지-최초작성]
* -----------------------------------------------------------------------------
* </pre>
*/
public class ServerSysDate {
    private static Logger logger = Logger.getLogger(ServerSysDate.class.getName());

    /* ServerSysDate에서 사용할 Parameter 상수값 */
    public static final int YYYY = 1; // 연
    public static final int YYYYMM = 2; // 연월
    public static final int MMDD = 3; // 월일
    public static final int YYYYMMDD = 4; // 연월일
    public static final int YYYYMMDDHHMMSS = 5; // 연월일시분초
    public static final int YY = 6; // 연(2자리)
    public static final int YYMM = 7; // 연월
    public static final int YYMMDD = 8; // 연월일
    public static final int HHMMSS = 9; // 시분초
    public static final int YYYYMMDD_WITH_DELIMETER = 10; // 시분초
    public static final int HHMMSS_DELIMETER = 11; // 시분초

    /**
     * <p>메소드명      : processErrorJob </p>
     * <p>설명         : error 발생시 log 남기고 Exception 생성하여 throw 시키는. </p>
     * <p>              메소드  </p>
     * <p>메소드인수1   : String message - 에러 메세지  </p>
     *
     */
    private static void processErrorJob(String message) // throws DAOException
     {
        logger.warn("ESC9999" + CallerInfo.getPath(new Throwable()) + "^" +
            message);
    }

    /**
     * <p>메소드명      : chNul </p>
     * <p>설명         : null또는 ""로 넘어오는 값을 String "0"으로 바꾼다. </p>
     * <p>              사용예) chNul(tdo1.getDelvQty()) </p>
     * <p>메소드인수1   : String value = do값 </p>
     * <p>메소드리턴값  : String </p>
     */
    private static String chNul(String value) {
        String chaNul = ((value == null) || value.equals("")) ? "0" : value;

        return chaNul;
    }

    /**
     * <p>메소드명      : getServerDate </p>
     * <p>설명         : 구분자에 따라 서버의 날짜를 가져온다 </p>
     * <p>메소드인수1   : int gubun </p>
     * <p>메소드리턴값  : String </p>
     * <p>특이사항 : jsp에서 서버 날짜를 얻어올 때 사용한다 </p>
     */
    public static String getServerDate(int gubun) {
        Calendar calendar = Calendar.getInstance();
        StringBuffer time = new StringBuffer();

        switch (gubun) {
        case 1:
            time.append(getYear(calendar));

            break;

        case 2:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));

            break;

        case 3:
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 4:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 5:
            time.append(getYear(calendar));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));
            time.append(getHour(calendar));
            time.append(getMinute(calendar));
            time.append(getSecond(calendar));

            break;

        case 6:
            time.append(getYear(calendar).substring(2, 4));

            break;

        case 7:
            time.append(getYear(calendar).substring(2, 4));
            time.append(getMonth(calendar));

            break;

        case 8:
            time.append(getYear(calendar).substring(2, 4));
            time.append(getMonth(calendar));
            time.append(getDate(calendar));

            break;

        case 9:
            time.append(getHour(calendar));
            time.append(getMinute(calendar));
            time.append(getSecond(calendar));

            break;

        case 10: //"-" 날짜포맷 중간에 추가 2005.10.10
            time.append(getYear(calendar));
            time.append("-");
            time.append(getMonth(calendar));
            time.append("-");
            time.append(getDate(calendar));

            break;

        case 11: //":" 시간포맷 중간에 추가 2005.10.10
            time.append(getHour(calendar));
            time.append(":");
            time.append(getMinute(calendar));
            time.append(":");
            time.append(getSecond(calendar));

            break;

        default:
            break;
        }

        return time.toString();
    }

    private static String getYear(Calendar calendar) {
        int year = calendar.get(Calendar.YEAR);

        return year + "";
    }

    private static String getMonth(Calendar calendar) {
        int month = calendar.get(Calendar.MONTH) + 1;

        // 월을 두 자리로 표현하기 위해 (01, 02, ...)
        if (month < 10) {
            return "0" + month;
        } else {
            return month + "";
        }
    }

    private static String getDate(Calendar calendar) {
        int date = calendar.get(Calendar.DATE);

        // 일을 두 자리로 표현하기 위해 (01, 02, ...)
        if (date < 10) {
            return "0" + date;
        } else {
            return date + "";
        }
    }

    private static String getHour(Calendar calendar) {
        int hour = calendar.get(Calendar.HOUR_OF_DAY);

        // 시를 두 자리로 표현하기 위해 (01, 02, ...)
        if (hour < 10) {
            return "0" + hour;
        } else {
            return hour + "";
        }
    }

    private static String getMinute(Calendar calendar) {
        int minute = calendar.get(Calendar.MINUTE);

        // 분을 두 자리로 표현하기 위해 (01, 02, ...)
        if (minute < 10) {
            return "0" + minute;
        } else {
            return minute + "";
        }
    }

    private static String getSecond(Calendar calendar) {
        int second = calendar.get(Calendar.SECOND);

        // 초을 두 자리로 표현하기 위해 (01, 02, ...)
        if (second < 10) {
            return "0" + second;
        } else {
            return second + "";
        }
    }
}
