package hanalife.util.gram;

import java.io.UnsupportedEncodingException;
import java.math.BigInteger;
import java.sql.Timestamp;
import java.util.StringTokenizer;

import org.apache.log4j.Logger;

/**
 * <pre>
 * 클래스명    : GramUtil
 * 클래스설명 : String 데이터 처리를 위한 클래스 Util
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class GramUtil{

	private static Logger log = Logger.getLogger(GramUtil.class.getName());


	//왼쪽정렬, 모자라는 길이만큼 스페이스를 채워넣는다.
    public static String fillSpace(String s, int leng)
    {
    	if(s==null || s.equals("")){
    		s = " ";
    	}
    	return fill(s, leng, " ");
    }


    //왼쪽정렬, 모자라는 길이만큼 fillStr을 채워넣는다.
    public static String fill(String inStr, int size, String fillStr)
    {
//        StringBuffer st = new StringBuffer();
//        st.append(s);
//
//        byte[] b = s.getBytes();   //한글 2byte로 인식해서 계산
//        for (int i=b.length ; i<leng ; i++ ){
//            st.append(c) ;
//        }
//
//        return st.toString();
    	String tmp = (inStr == null) ? "" : inStr.trim();
        //byte[] inByte = tmp.getBytes();
        //int inStrLen = inByte.length;
        int inStrLen = tmp.getBytes().length;

        if (inStrLen > size) {
        	/*skw 2018.04.13
        	return subString(inByte, 0, size );
        	*/
        	tmp = cutstringForHangul(tmp, size);
        	if (tmp.getBytes().length == size) {
        		return tmp;
        	} else {
        		inStrLen = tmp.getBytes().length;
        	}
        }
        StringBuffer buff = new StringBuffer(size);
        buff.append(tmp);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        return buff.toString();
    }

    public static String fillPkStringB(String str, int pkLen) {
        byte [] conv = str.getBytes();
        int nCnt = conv.length;

        if (conv == null) {
            return "";
        }

        if (nCnt >= pkLen) {
            return str;
        }

        String temp = "";

        for (int i = 0; i < (pkLen - nCnt); i++) {
            temp += " ";
        }

        return str + temp;
    }

    public static String cutstringForHangul(String str, int size) {
    	byte[] strBytes = str.getBytes();
    	int count = 0;
    	if (strBytes.length > size) {
	    	for (int i = 0; i < size; i++) {
	    		if (strBytes[i] < 0) count++;
	    	}
    	} else {
    		size = strBytes.length;
    	}
    	return new String(strBytes, 0, size - (count%2));
    }

    //오른쪽 정렬, 모자라는 길이만큼 "0"을 채워넣는다.
    public static String fixEndZero(String s, int leng)
    {
        return fillEnd(s, leng, "0");
    }

    public static String fixDouble(String input, int length, int precision) {
    	int number = 0;
    	if (input != null) {
    		input = input.trim();
    		if (input.length() > 0) {
		    	number = (int)(Double.parseDouble(input) * Math.pow(10, precision));
    		}
    	}
    	return fixEndZero(String.valueOf(number), length);
    }

    //오른쪽 정렬, 모자라는 길이만큼  fillStr을 채워넣는다.
    //이때, 소수점두비스리 절삭.
    public static String fillEnd(String inStr, int size, String fillStr)
    {
    	String tmp = (inStr == null) ? "" : inStr.trim();
        byte[] inByte = tmp.getBytes();
        int inStrLen = inByte.length;

        if (inStrLen > size) {
        	return subString(inByte, 0, size );
        }
        StringBuffer buff = new StringBuffer(size);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        buff.append(tmp);
        return buff.toString();
    }

    public static String cnvNum(String s)
    {
        BigInteger bi = new BigInteger("0");
        try{
            if(s==null || "".equals(s.trim())){
               s = "0";
            }
            bi = new BigInteger(s);
        }catch(Exception e){
            e.printStackTrace();
            return s;
        }

    	return bi.toString();
    }

    public static String subString(byte[] cToBytes,
    		                        int start, int end) {
        String strRtn = "";
        byte[]   bOut = new byte[end - start];

        try {
            for (int i = start; i < end; i++) {
                bOut[i - start] = cToBytes[i];
            }

            strRtn = new String(bOut);

            return strRtn;
        } catch (NullPointerException ne) {
            ne.printStackTrace();
            return null;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

	public static String[] parseString(byte[] byteArr, int[] len) {

		//int itmp = 0;
		int[] lenStart = new int[len.length];
		int[] lenEnd   = new int[len.length];
		for(int i=0;i<len.length;i++){
			if(i==0){
				lenStart[i] = 0;
			}else{
				lenStart[i] = lenStart[i-1] + len[i-1];
			}
			lenEnd[i] = lenStart[i] + len[i];
		}

		String[] strArr = new String[len.length];
		for(int i=0;i<len.length;i++){
                    strArr[i] = GramUtil.subString(byteArr, lenStart[i], lenEnd[i]);
		}

		return strArr;
	}

	/**
	 * 문자열 바이트로 계산 - Exception 에러 발생
	 * @return a String - 요청한 바이트 사이의 문자열
	 * @param int to Set - 시작 바이트
	 * @param int to Set - 마지막 바이트
	*/
	public static String subString(int start, int end, byte[] sToBytes) {
		String strRtn = "";
		byte[]   bOut = new byte[end - start];

		try {
			for (int i = start; i < end; i++) {
				bOut[i - start] = sToBytes[i];
			}

			strRtn = new String(bOut);

			return strRtn;
		} catch (NullPointerException ne) {
			ne.printStackTrace();
			return null;
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

    //charSet없는 substr
    public static String substr(byte[] bytes, int spos, int epos)  {
        int length = epos - spos;
        byte[] outbytes = new byte[length];
        System.arraycopy(bytes, spos, outbytes, 0, length);
        return new String(outbytes);
    }

    public static String substr(byte[] bytes, int spos, int epos, String charSet) throws UnsupportedEncodingException  {
        int length = epos - spos;
        byte[] outbytes = new byte[length];
        System.arraycopy(bytes, spos, outbytes, 0, length);
        return new String(outbytes, charSet);
    }

    public static byte[] subbyte(byte[] bytes, int spos, int epos)  {
        int length = epos - spos;
        byte[] outbytes = new byte[length];
        System.arraycopy(bytes, spos, outbytes, 0, length);
        return outbytes;
    }

	public static String getDay()
    {
        Timestamp timestamp = new Timestamp( System.currentTimeMillis() );

        String retVal = "";

        String temp = timestamp.toString().substring( 0, 10 );
        StringTokenizer st = new StringTokenizer( temp, "- :" );
        while ( st.hasMoreElements() )
        {
            retVal += st.nextElement();
        }

        return retVal;
    }

	public static String getTime()
    {
        Timestamp timestamp = new Timestamp( System.currentTimeMillis() );

        String retVal = "";

        String temp = timestamp.toString().substring( 11, 19 );
        StringTokenizer st = new StringTokenizer( temp, "- :" );
        while ( st.hasMoreElements() )
        {
            retVal += st.nextElement();
        }

        return retVal;
    }

	public static String getSendNum()
	{
		Timestamp timestamp = new Timestamp( System.currentTimeMillis() );

        String retVal = "";

        String timestring = timestamp.toString();
        String temp;
        if (timestring.length() > 21) {
        	temp = timestring.substring(11, 22);
        } else {
        	temp = timestring.substring(11, 21) + "0";
        }
        StringTokenizer st = new StringTokenizer( temp, "- : ." );
        while ( st.hasMoreElements() )
        {
            retVal += st.nextElement();
        }

        return getDay() + retVal;
	}

	/**
	 * 공통 헤더 전문 파싱
	 *
	 * @param rcvGram 수신전문
	 * @return 파싱된 전문
	 */
	public static String[] parseCommHeader(String rcvGram) throws Exception {
		byte[] byteArray = rcvGram.getBytes();
		String[] attr = new String[39];

		try{
			attr[0]  = subString(0, 8, byteArray);		    // 총전문길이(8)
			attr[1]  = subString(8, 18, byteArray);		    // 업무전문길이(10)
			attr[2]  = subString(18, 46, byteArray);		// 송신서버일련번호(28)
			attr[3]  = subString(46, 52, byteArray);		// 전문구분(6)
			attr[4]  = subString(52, 75, byteArray);		// 매체IP(23)
			attr[5]  = subString(75, 78, byteArray);		// 저축은행코드(3)
			attr[6]  = subString(78, 80, byteArray);		// 지점코드(2)
			attr[7]  = subString(80, 83, byteArray);		// 단말번호(3)
			attr[8]  = subString(83, 89, byteArray);		// 조작자번호(6)
			attr[9]  = subString(89, 90, byteArray);		// 다음출력대상구분(1)
			attr[10]  = subString(90, 91, byteArray);		// 지점회계마감여부(1)
			attr[11]  = subString(91, 92, byteArray);		// CD기 마감여부(1)
			attr[12]  = subString(92, 108, byteArray);		// 책임자승인번호(16)
			attr[13]  = subString(108, 109, byteArray);		// 책임자승인상황(1)
			attr[14]  = subString(109, 115, byteArray);		// 책임자직원번호(6)
			attr[15]  = subString(115, 123, byteArray);		// 책임자비밀번호(8)
			attr[16]  = subString(123, 124, byteArray);		// 복수책임자승인상황(1)
			attr[17]  = subString(124, 130, byteArray);		// 복수책임자직원번호(6)
			attr[18]  = subString(130, 138, byteArray);		// 복수책임자비밀번호(8)
			attr[19]  = subString(138, 139, byteArray);		// 승인요청건수(1)
			attr[20]  = subString(139, 143, byteArray);		// 승인요청사유코드1(4)
			attr[21]  = subString(143, 144, byteArray);		// 복수승인여부1(1)
			attr[22]  = subString(144, 148, byteArray);		// 승인요청사유코드2(4)
			attr[23]  = subString(148, 149, byteArray);		// 복수승인여부2(1)
			attr[24]  = subString(149, 153, byteArray);		// 승인요청사유코드3(4)
			attr[25]  = subString(153, 154, byteArray);		// 복수승인여부3(1)
			attr[26]  = subString(154, 158, byteArray);		// 승인요청사유코드4(4)
			attr[27]  = subString(158, 159, byteArray);		// 복수승인여부4(1)
			attr[28]  = subString(159, 163, byteArray);		// 승인요청사유코드5(4)
			attr[29]  = subString(163, 164, byteArray);		// 복수승인여부(1)
			attr[30]  = subString(164, 169, byteArray);		// 거래코드(화면코드)(5)
			attr[31]  = subString(169, 170, byteArray);		// 기능구분(1)
			attr[32]  = subString(170, 171, byteArray);		// 정상거래구분(1)
			attr[33]  = subString(171, 172, byteArray);		// 마감후구분(1)
			attr[34]  = subString(172, 173, byteArray);		// 거래형태(1)
			attr[35]  = subString(173, 174, byteArray);		// 처리결과(1)
			attr[36]  = subString(174, 180, byteArray);		// 오류코드(6)
			attr[37]  = subString(180, 190, byteArray);		// 오류프로그램명(10)
			attr[38]  = subString(190, 240, byteArray);		// 여유(50)

			log.info("저축은행 중앙회 응답전문(공통부)==============================");
			log.info("attr[0]   총전문길이(8)         : " + attr[0] );
			log.info("attr[1]   업무전문길이(10)      : " + attr[1] );
			log.info("attr[2]   송신서버일련번호(28)   : " + attr[2] );
			log.info("attr[3]   전문구분(6)          : " + attr[3] );
			log.info("attr[4]   매체IP(23)          : " + attr[4] );
			log.info("attr[5]   저축은행코드(3)       : " + attr[5] );
			log.info("attr[6]   지점코드(2)          : " + attr[6] );
			log.info("attr[7]   단말번호(3)          : " + attr[7] );
			log.info("attr[8]   조작자번호(6)        : " + attr[8] );
			log.info("attr[9]   다음출력대상구분(1)   : " + attr[9] );
			log.info("attr[10]  지점회계마감여부(1)   : " + attr[10]);
			log.info("attr[11]  CD기 마감여부(1)     : " + attr[11]);
			log.info("attr[12]  책임자승인번호(16)    : " + attr[12]);
			log.info("attr[13]  책임자승인상황(1)     : " + attr[13]);
			log.info("attr[14]  책임자직원번호(6)     : " + attr[14]);
			log.info("attr[15]  책임자비밀번호(8)     : " + attr[15]);
			log.info("attr[16]  복수책임자승인상황(1)  : " + attr[16]);
			log.info("attr[17]  복수책임자직원번호(6)  : " + attr[17]);
			log.info("attr[18]  복수책임자비밀번호(8)  : " + attr[18]);
			log.info("attr[19]  승인요청건수(1)       : " + attr[19]);
			log.info("attr[20]  승인요청사유코드1(4)   : " + attr[20]);
			log.info("attr[21]  복수승인여부1(1)      : " + attr[21]);
			log.info("attr[22]  승인요청사유코드2(4)   : " + attr[22]);
			log.info("attr[23]  복수승인여부2(1)      : " + attr[23]);
			log.info("attr[24]  승인요청사유코드3(4)   : " + attr[24]);
			log.info("attr[25]  복수승인여부3(1)      : " + attr[25]);
			log.info("attr[26]  승인요청사유코드4(4)   : " + attr[26]);
			log.info("attr[27]  복수승인여부4(1)      : " + attr[27]);
			log.info("attr[28]  승인요청사유코드5(4)   : " + attr[28]);
			log.info("attr[29]  복수승인여부(1)       : " + attr[29]);
			log.info("attr[30]  거래코드(화면코드)(5)  : " + attr[30]);
			log.info("attr[31]  기능구분(1)          : " + attr[31]);
			log.info("attr[32]  정상거래구분(1)       : " + attr[32]);
			log.info("attr[33]  마감후구분(1)        : " + attr[33]);
			log.info("attr[34]  거래형태(1)          : " + attr[34]);
			log.info("attr[35]  처리결과(1)          : " + attr[35]);
			log.info("attr[36]  오류코드(6)          : " + attr[36]);
			log.info("attr[37]  오류프로그램명(10)    : " + attr[37]);
			log.info("attr[38]  여유(50)            : " + attr[38]);
			log.info("저축은행 중앙회 응답전문(공통부)==============================");
		}catch(Exception e){
			e.printStackTrace();
			throw e;
		}

		return attr;
	}

	/**
	 * 오류발생시 응답 업무전문 파싱
	 * <pre>
	 * 1. 오류코드(6)
	 * 2. 프로그램명(10)
	 * 3. 함수명(30)
	 * 4. 줄번호(5)
	 * 5. 메시지내용(100)
	 * 6. 조치사항(200)
	 * </pre>
	 * @param rcvGram 응답전문 문자열
	 * @return 파싱된 전문 배열
	 * @throws Exception
	 */
	public static String[] parseError(String rcvGram) throws Exception {
		if (rcvGram == null || rcvGram.getBytes().length < 591) {
			throw new IllegalArgumentException("'RcvGram'이 널 또는 문자열의 길이가 591보다 작을 수 없습니다");
		}
		byte[] byteArray = rcvGram.getBytes();
		String[] attrs = new String[6];
		try{
			attrs[0]  = GramUtil.subString(240, 246, byteArray);	// 오류코드(6)
			attrs[1]  = GramUtil.subString(246, 256, byteArray);	// 프로그램명(10)
			attrs[2]  = GramUtil.subString(256, 286, byteArray);	// 함수명(30)
			attrs[3]  = GramUtil.subString(286, 291, byteArray);	// 줄번호(5)
			attrs[4]  = GramUtil.subString(291, 391, byteArray);	// 메시지내용(100)
			attrs[5]  = GramUtil.subString(391, 591, byteArray);	// 조치사항(200)

			log.info("저축은행 중앙회 오류발생시 응답전문=============================");
			log.info("attr[0]  오류코드(6)				: " + attrs[0]);
			log.info("attr[1]  프로그램명(10)				: " + attrs[1]);
			log.info("attr[2]  함수명(30)					: " + attrs[2]);
			log.info("attr[3]  줄번호(5)					: " + attrs[3]);
			log.info("attr[4]  메시지내용(100)			: " + attrs[4]);
			log.info("attr[5]  조치사항(200)				: " + attrs[5]);
			log.info("저축은행 중앙회 오류발생시 응답전문=============================");
		}catch(Exception e){
			e.printStackTrace();
			throw e;
		}
		return attrs;
	}
}
