﻿/**
 * 헤더행 사용자 정의 표현 함수
 * @param nRow 헤더행 인덱스 (Zero-Based)
 * @param nColumn 헤더열 인덱스 (Zero-Based)
 * @param strItemText 아이템 텍스트
 */
function ExprFuncHeader(nRow, nColumn, strItemText, objGrid)
{
	var retInfo = {
		css : "",			  // css 문자열
		itemtext: undefined,  // 아이템 텍스트(setvalue 미지정시 값이 그리드에 저장되지 않음)
		setvalue: undefined,  // true인 경우, itemtext 값에 지정된 값으로 저장, 
							  // 문자열/숫자인 경우, setvalue에 지정된 값으로 값 저장		
		formatted: false      // 패턴 처리 여부 (true로 설정된 경우, 칼럼 패턴이 적용되지 않음)
	};

    if (objGrid === undefined) { 
		// objGrid 파라미터가 undefined인 경우에는 솔루션 패치 이전 상태이며,
		// expr_func, midstat_expr_func, statrow_expr_func 속성에 
		// 글로벌 모듈 함수로 지정할 수 없다.
		factory.consoleprint("objGrid is undefined");
    }

	retInfo.formatted = true;
	retInfo.itemtext = "Header(" + nRow + ":" + nColumn + ") " + strItemText;
	
	return retInfo;
}

/**
 * 데이터행 사용자 정의 표현 함수
 * @param nRow 행 인덱스 (Zero-Based)
 * @param nColumn 열 인덱스 (Zero-Based)
 * @param strItemText 아이템 텍스트
 */
function ExprFuncData(nRow, nColumn, strItemText, objGrid)
{
	var retInfo = {
		css : "",             // css 문자열
		itemtext: undefined,  // 아이템 텍스트(setvalue 미지정시 값이 그리드에 저장되지 않음)
		setvalue: undefined,  // true인 경우, itemtext 값에 지정된 값으로 저장, 
							  // 문자열/숫자인 경우, setvalue에 지정된 값으로 값 저장
		formatted: false,     // 패턴 처리 여부 (true로 설정된 경우, 칼럼 패턴이 적용되지 않음)
		hidden: false,        // 숨김 처리 여부 (true로 설정된 경우, 값이 표현되지 않음)
		pattern_front_symbol: undefined, // 패턴 front symbol
		pattern_rear_symbol: undefined   // 패턴 rear symbol
	};

    if (objGrid === undefined) { 
        // objGrid 파라미터가 undefined인 경우에는 솔루션 패치 이전 상태이며,
        // expr_func, midstat_expr_func, statrow_expr_func 속성에 
        // 글로벌 모듈 함수로 지정할 수 없다.
		factory.consoleprint("objGrid is undefined");
		
		// objGrid 변수를 아래 라인처럼, 화면내 그리드 이름이 "grdList"인 경우에
		// 화면내 실제 그리드 이름으로 지정하여 사용한다.
		// objGiid = this.grdList;
    }

	// 패턴 심볼 설정
	if (nRow == 0 && nColumn == 2) {
		// retInfo 값 지정 방식
		// retInfo.pattern_front_symbol = "$";
		// retInfo.pattern_rear_symbol = "%";
		
		// API 호출 방식 (bRefresh 파라미터를 false로 지정)
		if (objGrid) {
			objGrid.setitempatternfrontsymbol(nRow, nColumn, "$", false);
			objGrid.setitempatternrearsymbol(nRow, nColumn, "%", false);
		}
	}	
	
	// 전경색 및 배경색 변경
	if (nRow == 1 && nColumn == 2) {
		// retInfo 값 지정 방식
		// retInfo.css = "color: rgb(255,255,255); background-color: rgb(0,0,255);";
		
		// API 호출 방식 (bRefresh 파라미터를 false로 지정)
		if (objGrid) {
			objGrid.setitemforecolor(nRow, nColumn, factory.rgb(255,255,255), false);
			objGrid.setitembackcolor(nRow, nColumn, factory.rgb(0,0,255), false);
		}
	}
	
	// 데이터 변경 및 포맷팅 처리 값 지정
	if (nRow == 2 && nColumn == 2) {
		retInfo.itemtext = "DataRow(" + nRow + ":" + nColumn + ") " + strItemText;
		retInfo.formatted = true;
	}		
	
	// 숨김 지정
	if (nRow == 3 && nColumn == 2) {
		retInfo.hidden = true;
	}		
	
	return retInfo;
}

/**
 * 소계행 사용자 정의 표현 함수
 * @param nRow 헤더 행 인덱스 (Zero-Based)
 * @param nColumn 헤더 열 인덱스 (Zero-Based)
 * @param strItemText 아이템 텍스트
 */
function ExprFuncMidStat(nRow, nColumn, strItemText, objGrid)
{
	var retInfo = {
		css : "",             // css 문자열
		itemtext: undefined,  // 아이템 텍스트(setvalue 미지정시 값이 그리드에 저장되지 않음)
		setvalue: undefined,  // true인 경우, itemtext 값에 지정된 값으로 저장, 
							  // 문자열/숫자인 경우, setvalue에 지정된 값으로 값 저장
		formatted: false,     // 패턴 처리 여부 (true로 설정된 경우, 칼럼 패턴이 적용되지 않음)
		hidden: false,        // 숨김 처리 여부
		pattern_front_symbol: undefined, // 패턴 front symbol
		pattern_rear_symbol: undefined   // 패턴 rear symbol
	};

    if (objGrid === undefined) { 
        // objGrid 파라미터가 undefined인 경우에는 솔루션 패치 이전 상태이며,
        // 글로벌 모듈 함수로 지정할 수 없다.
		factory.consoleprint("objGrid is undefined");
    }

	// retInfo.formatted = true;
	// retInfo.itemtext = "MidStat(" + nRow + ":" + nColumn + ") " + strItemText;
	
	retInfo.pattern_front_symbol = "MidStat(" + nRow + ":" + nColumn + ") ";
	
	return retInfo;	
}

/**
 * 통계행 사용자 정의 표현 함수
 * @param nRow 통계행 인덱스 (Zero-Based)
 * @param nColumn 통계열 인덱스 (Zero-Based)
 * @param strItemText 아이템 텍스트
 */
function ExprFuncStatRow(nRow, nColumn, strItemText)
{
	var retInfo = {
		css : "",             // css 문자열
		itemtext: undefined,  // 아이템 텍스트(setvalue 미지정시 값이 그리드에 저장되지 않음)
		setvalue: undefined,  // true인 경우, itemtext 값에 지정된 값으로 저장, 
							  // 문자열/숫자인 경우, setvalue에 지정된 값으로 값 저장		
		formatted: false,     // 패턴 처리 여부 (true로 설정된 경우, 칼럼 패턴이 적용되지 않음)
		hidden: false,        // 숨김 처리 여부
		pattern_front_symbol: undefined, // 패턴 front symbol
		pattern_rear_symbol: undefined   // 패턴 rear symbol
	};
		
	// retInfo.formatted = true;
	// retInfo.itemtext = "StatRow(" + nRow + ":" + nColumn + ") " + strItemText;
	
	retInfo.pattern_front_symbol = "StatRow(" + nRow + ":" + nColumn + ") ";
	
	return retInfo;
}