﻿/**
 * screen.browserhistorypushstate : 브라우저 히스토리에 state 및 Url을 추가 등록처리한다.
 * screen.browserhistoryreplacestate : 브라우저에 현재 히스트리에 대한 state 값을 재정의 및 URL 조작한다.
 * screen_on_browserpopstate : 브라우저에서 Back이나 Forward 처리할때 호출되는 이벤트
 */

/**
 * 뒤로가기 가능여부 전역 변수
 */
var bUseBackButton = true;

/**
 * 로그인페이지로 이동처리
 */
function gotoLoginFirst()
{
	// HTML 문서 타이틀 변경
	document.title = "1차 인증 페이지";
	
	// 탭아이템을 이동하여 1차 인증 페이지용 UI 표시
	tab1.settabitemfocus(0);
}

/**
 * 2차 인증페이지로 이동처리
 */
function gotoLoginSecond()
{
	// 브라우저 히스토리에 정보 추가
	this.PushOrReplaceBrowserHistory(true, "login_second", "gotoLoginSecond", "2차 인증 페이지");

	// 탭아이템을 이동하여 2차 인증 페이지용 UI 표시
	tab1.settabitemfocus(1);
}

/**
 * 메인페이지로 이동처리
 */
function gotoMainPage()
{
	// 더이상 "Back" 버튼으로 이동하지 못하게 뒤로가기 가능 여부 변수 설정
	bUseBackButton = false;

	// 현재 히스토리 정보인 "2차 인증 페이지"를 "메인 페이지"로 변경한다.
	this.PushOrReplaceBrowserHistory(false, "main", "gotoMainPage", "메인 페이지");

	// 탭아이템을 이동하여 메인 페이지용 UI 표시
	tab1.settabitemfocus(2);
}

function PushOrReplaceBrowserHistory(is_push, page, desc, doc_title) {
	var row_index, objStateData;
	
	objStateData = {
		"page" : page, 
		"desc" : desc
	};
	
	// 브라우저 히스토리에 정보 추가
	if (is_push == true) {
		screen.browserhistorypushstate(objStateData);
		row_index = this.grd.addrow();
	}	
	else {
		// 현재 브라우저 히스토리에 정보 변경
		screen.browserhistoryreplacestate(objStateData);
		row_index = this.grd.getrowcount() - 1;		
	}

	// History 정보 처리 이후에, HTML 문서 타이틀 변경해야 
	// 브라우저 히스토리에 목록이 정상적으로 표시됨
	document.title = doc_title;
	
	this.grd.setitemtext(row_index, 0, objStateData.page);
	this.grd.setitemtext(row_index, 1, objStateData.desc);
}
				
// 화면 로드 이벤트
function screen_on_load()
{
	var objStateData;
	
	// 현재 페이제이 대한 브라우저 히스로리 정보를 변경 등록한다.
	this.PushOrReplaceBrowserHistory(true, "login_first", "screen_on_load", "1차 인증 페이지");
}

/**
 * 브라우저 뒤로가기 및 앞으로가기 이벤트
 * @param {object} objStateData 지정된 상태값
 * @returns 
 */
function screen_on_browserpopstate(objStateData)
{
	if (objStateData == null) { return; }
	if (objStateData.page == null) { return; }

	this.grd.deleterow(this.grd.getrowcount() - 1);
	
	switch (objStateData.page) {
		case "login_first":
			if (bUseBackButton === false) {
				screen.alert("뒤로 가기 불가능합니다.\n로그아웃완료 버튼을 클릭하면 로그인 페이지로 이동합니다.");
				
				// [중요] 뒤로 가기를 막기 위해서 다시 브라우저 히스토리에 main 페이지 정보 추가
				// ReplaceBrowserHistory("main", "screen_on_browserpopstate");
				this.PushOrReplaceBrowserHistory(true, "main", "screen_on_browserpopstate", "메인 페이지");
			} 
			else {
				this.gotoLoginFirst();
			}
			break;
	}
}

// "1차 인증 완료" 버튼 이벤트
function btnLoginFirstComplete_on_mouseup(objInst)
{
	this.gotoLoginSecond();
}

// "2차 인증 완료" 버튼 이벤트
function btnLoginSecondComplete_on_mouseup(objInst)
{
	this.gotoMainPage();
}

// "1차 인증 페이지로 이동" 버튼 이벤트
function btnGotoLoginFirstPage_on_mouseup(objInst)
{
    var history_length;

	// 브라우저 히스토리 정보 갯수를 구함
    history_length = screen.browserhistorylength();
    factory.consoleprint("history_length = " + history_length);
    
    if (history_length > 1) {
        screen.browserhistorygo(-1);  // 한번 뒤로 이동
    }
}

// "로그 아웃 완료"
function btnLogoutComplete_on_mouseup(objInst)
{
	// 더이상 "Back" 버튼으로 이동하지 못하게 뒤로가기 가능 여부 변수 설정
	bUseBackButton = true;
		
	this.gotoLoginFirst();
}